(macro_expansion) @injection.content (#set! injection.language epics_msi_template)
(ccode) @injection.content (#set! injection.language c)
(json_value) @injection.content (#set! injection.language json)
