#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 13
#define STATE_COUNT 921
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 106
#define ALIAS_COUNT 0
#define TOKEN_COUNT 63
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 2
#define MAX_ALIAS_SEQUENCE_LENGTH 13
#define PRODUCTION_ID_COUNT 14

enum {
  anon_sym_SEMI = 1,
  anon_sym_POUND = 2,
  aux_sym_comment_token1 = 3,
  anon_sym_EQ = 4,
  anon_sym_DOLLAR = 5,
  aux_sym_variable_token1 = 6,
  anon_sym_Error = 7,
  anon_sym_Ignore = 8,
  anon_sym_LBRACE = 9,
  anon_sym_RBRACE = 10,
  anon_sym_LPAREN = 11,
  anon_sym_RPAREN = 12,
  anon_sym_AT = 13,
  anon_sym_COMMA = 14,
  anon_sym_DQUOTE = 15,
  anon_sym_SQUOTE = 16,
  sym__quoted_string_text_fragment = 17,
  sym__quoted_string_text_fragment2 = 18,
  anon_sym_BSLASH_DOLLAR = 19,
  aux_sym_variable_expansion_token1 = 20,
  aux_sym_escape_sequence_token1 = 21,
  aux_sym_escape_sequence_token2 = 22,
  aux_sym_escape_sequence_token3 = 23,
  aux_sym_escape_sequence_token4 = 24,
  anon_sym_PERCENT_PERCENT = 25,
  anon_sym_PERCENT = 26,
  anon_sym_LPAREN2 = 27,
  anon_sym_RPAREN2 = 28,
  aux_sym_format_converter_token1 = 29,
  anon_sym_DOT = 30,
  aux_sym_format_converter_token2 = 31,
  anon_sym_LBRACK = 32,
  anon_sym_RBRACK = 33,
  anon_sym_LBRACE2 = 34,
  anon_sym_RBRACE2 = 35,
  anon_sym_B = 36,
  anon_sym_LT = 37,
  anon_sym_GT = 38,
  anon_sym_SLASH = 39,
  anon_sym_POUND_SLASH = 40,
  anon_sym_T = 41,
  anon_sym_DOT2 = 42,
  anon_sym_POUND2 = 43,
  aux_sym_format_flag_token1 = 44,
  anon_sym_CARET = 45,
  aux_sym_charset_token1 = 46,
  anon_sym_BSLASH_RBRACK = 47,
  anon_sym_PIPE = 48,
  anon_sym_QMARK = 49,
  sym_enum_constant = 50,
  aux_sym__char_token1 = 51,
  sym_checksum_flag = 52,
  sym_regex_pattern = 53,
  aux_sym_timeformat_token1 = 54,
  sym_time_conversion_spec = 55,
  aux_sym_record_name_token1 = 56,
  anon_sym_DASH = 57,
  aux_sym_number_literal_token1 = 58,
  aux_sym_number_literal_token2 = 59,
  aux_sym_number_literal_token3 = 60,
  sym_ascii_name = 61,
  sym__identifier = 62,
  sym_source_file = 63,
  sym_comment = 64,
  sym_assignment = 65,
  sym_variable_name = 66,
  sym_variable = 67,
  sym__value = 68,
  sym_keyword = 69,
  sym_function = 70,
  sym_function_name = 71,
  sym_command = 72,
  sym_command_name = 73,
  sym_handler = 74,
  sym_handler_name = 75,
  sym_string = 76,
  sym_quoted_literal = 77,
  sym__double_quoted_string = 78,
  sym__single_quoted_string = 79,
  sym_variable_expansion = 80,
  sym_escape_sequence = 81,
  sym_format_converter = 82,
  sym_format_inout = 83,
  sym_format_flag = 84,
  sym_charset = 85,
  sym_format_enum = 86,
  sym_enum_specifier = 87,
  sym__char = 88,
  sym_checksum = 89,
  sym_timeformat = 90,
  sym_record_name = 91,
  sym_field_name = 92,
  sym_number = 93,
  sym_number_literal = 94,
  aux_sym_source_file_repeat1 = 95,
  aux_sym_function_repeat1 = 96,
  aux_sym_handler_repeat1 = 97,
  aux_sym_string_repeat1 = 98,
  aux_sym__double_quoted_string_repeat1 = 99,
  aux_sym__single_quoted_string_repeat1 = 100,
  aux_sym_charset_repeat1 = 101,
  aux_sym_format_enum_repeat1 = 102,
  aux_sym_timeformat_repeat1 = 103,
  aux_sym_record_name_repeat1 = 104,
  aux_sym_field_name_repeat1 = 105,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_SEMI] = ";",
  [anon_sym_POUND] = "#",
  [aux_sym_comment_token1] = "comment_token1",
  [anon_sym_EQ] = "=",
  [anon_sym_DOLLAR] = "$",
  [aux_sym_variable_token1] = "variable_token1",
  [anon_sym_Error] = "Error",
  [anon_sym_Ignore] = "Ignore",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_AT] = "@",
  [anon_sym_COMMA] = ",",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_SQUOTE] = "'",
  [sym__quoted_string_text_fragment] = "_quoted_string_text_fragment",
  [sym__quoted_string_text_fragment2] = "_quoted_string_text_fragment2",
  [anon_sym_BSLASH_DOLLAR] = "\\$",
  [aux_sym_variable_expansion_token1] = "variable_name",
  [aux_sym_escape_sequence_token1] = "escape_sequence_token1",
  [aux_sym_escape_sequence_token2] = "escape_sequence_token2",
  [aux_sym_escape_sequence_token3] = "escape_sequence_token3",
  [aux_sym_escape_sequence_token4] = "escape_sequence_token4",
  [anon_sym_PERCENT_PERCENT] = "%%",
  [anon_sym_PERCENT] = "%",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_RPAREN2] = ")",
  [aux_sym_format_converter_token1] = "number_literal",
  [anon_sym_DOT] = ".",
  [aux_sym_format_converter_token2] = "format_converter_token2",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE2] = "{",
  [anon_sym_RBRACE2] = "}",
  [anon_sym_B] = "B",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_SLASH] = "/",
  [anon_sym_POUND_SLASH] = "#/",
  [anon_sym_T] = "T",
  [anon_sym_DOT2] = ".",
  [anon_sym_POUND2] = "#",
  [aux_sym_format_flag_token1] = "format_flag_token1",
  [anon_sym_CARET] = "^",
  [aux_sym_charset_token1] = "charset_token1",
  [anon_sym_BSLASH_RBRACK] = "\\]",
  [anon_sym_PIPE] = "|",
  [anon_sym_QMARK] = "\?",
  [sym_enum_constant] = "enum_constant",
  [aux_sym__char_token1] = "_char_token1",
  [sym_checksum_flag] = "checksum_flag",
  [sym_regex_pattern] = "regex_pattern",
  [aux_sym_timeformat_token1] = "thing",
  [sym_time_conversion_spec] = "time_conversion_spec",
  [aux_sym_record_name_token1] = "record_name_token1",
  [anon_sym_DASH] = "-",
  [aux_sym_number_literal_token1] = "number_literal_token1",
  [aux_sym_number_literal_token2] = "number_literal_token2",
  [aux_sym_number_literal_token3] = "number_literal_token3",
  [sym_ascii_name] = "ascii_name",
  [sym__identifier] = "_identifier",
  [sym_source_file] = "source_file",
  [sym_comment] = "comment",
  [sym_assignment] = "assignment",
  [sym_variable_name] = "variable_name",
  [sym_variable] = "variable",
  [sym__value] = "_value",
  [sym_keyword] = "keyword",
  [sym_function] = "function",
  [sym_function_name] = "function_name",
  [sym_command] = "command",
  [sym_command_name] = "command_name",
  [sym_handler] = "handler",
  [sym_handler_name] = "handler_name",
  [sym_string] = "string",
  [sym_quoted_literal] = "quoted_literal",
  [sym__double_quoted_string] = "_double_quoted_string",
  [sym__single_quoted_string] = "_single_quoted_string",
  [sym_variable_expansion] = "variable_expansion",
  [sym_escape_sequence] = "escape_sequence",
  [sym_format_converter] = "format_converter",
  [sym_format_inout] = "format_inout",
  [sym_format_flag] = "format_flag",
  [sym_charset] = "charset",
  [sym_format_enum] = "format_enum",
  [sym_enum_specifier] = "enum_specifier",
  [sym__char] = "_char",
  [sym_checksum] = "checksum",
  [sym_timeformat] = "timeformat",
  [sym_record_name] = "record_name",
  [sym_field_name] = "field_name",
  [sym_number] = "number",
  [sym_number_literal] = "number_literal",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_function_repeat1] = "function_repeat1",
  [aux_sym_handler_repeat1] = "handler_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym__double_quoted_string_repeat1] = "_double_quoted_string_repeat1",
  [aux_sym__single_quoted_string_repeat1] = "_single_quoted_string_repeat1",
  [aux_sym_charset_repeat1] = "charset_repeat1",
  [aux_sym_format_enum_repeat1] = "format_enum_repeat1",
  [aux_sym_timeformat_repeat1] = "timeformat_repeat1",
  [aux_sym_record_name_repeat1] = "record_name_repeat1",
  [aux_sym_field_name_repeat1] = "field_name_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_POUND] = anon_sym_POUND,
  [aux_sym_comment_token1] = aux_sym_comment_token1,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [aux_sym_variable_token1] = aux_sym_variable_token1,
  [anon_sym_Error] = anon_sym_Error,
  [anon_sym_Ignore] = anon_sym_Ignore,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym__quoted_string_text_fragment] = sym__quoted_string_text_fragment,
  [sym__quoted_string_text_fragment2] = sym__quoted_string_text_fragment2,
  [anon_sym_BSLASH_DOLLAR] = anon_sym_BSLASH_DOLLAR,
  [aux_sym_variable_expansion_token1] = sym_variable_name,
  [aux_sym_escape_sequence_token1] = aux_sym_escape_sequence_token1,
  [aux_sym_escape_sequence_token2] = aux_sym_escape_sequence_token2,
  [aux_sym_escape_sequence_token3] = aux_sym_escape_sequence_token3,
  [aux_sym_escape_sequence_token4] = aux_sym_escape_sequence_token4,
  [anon_sym_PERCENT_PERCENT] = anon_sym_PERCENT_PERCENT,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_RPAREN2] = anon_sym_RPAREN,
  [aux_sym_format_converter_token1] = sym_number_literal,
  [anon_sym_DOT] = anon_sym_DOT,
  [aux_sym_format_converter_token2] = aux_sym_format_converter_token2,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE2] = anon_sym_LBRACE,
  [anon_sym_RBRACE2] = anon_sym_RBRACE,
  [anon_sym_B] = anon_sym_B,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_POUND_SLASH] = anon_sym_POUND_SLASH,
  [anon_sym_T] = anon_sym_T,
  [anon_sym_DOT2] = anon_sym_DOT,
  [anon_sym_POUND2] = anon_sym_POUND,
  [aux_sym_format_flag_token1] = aux_sym_format_flag_token1,
  [anon_sym_CARET] = anon_sym_CARET,
  [aux_sym_charset_token1] = aux_sym_charset_token1,
  [anon_sym_BSLASH_RBRACK] = anon_sym_BSLASH_RBRACK,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [sym_enum_constant] = sym_enum_constant,
  [aux_sym__char_token1] = aux_sym__char_token1,
  [sym_checksum_flag] = sym_checksum_flag,
  [sym_regex_pattern] = sym_regex_pattern,
  [aux_sym_timeformat_token1] = aux_sym_timeformat_token1,
  [sym_time_conversion_spec] = sym_time_conversion_spec,
  [aux_sym_record_name_token1] = aux_sym_record_name_token1,
  [anon_sym_DASH] = anon_sym_DASH,
  [aux_sym_number_literal_token1] = aux_sym_number_literal_token1,
  [aux_sym_number_literal_token2] = aux_sym_number_literal_token2,
  [aux_sym_number_literal_token3] = aux_sym_number_literal_token3,
  [sym_ascii_name] = sym_ascii_name,
  [sym__identifier] = sym__identifier,
  [sym_source_file] = sym_source_file,
  [sym_comment] = sym_comment,
  [sym_assignment] = sym_assignment,
  [sym_variable_name] = sym_variable_name,
  [sym_variable] = sym_variable,
  [sym__value] = sym__value,
  [sym_keyword] = sym_keyword,
  [sym_function] = sym_function,
  [sym_function_name] = sym_function_name,
  [sym_command] = sym_command,
  [sym_command_name] = sym_command_name,
  [sym_handler] = sym_handler,
  [sym_handler_name] = sym_handler_name,
  [sym_string] = sym_string,
  [sym_quoted_literal] = sym_quoted_literal,
  [sym__double_quoted_string] = sym__double_quoted_string,
  [sym__single_quoted_string] = sym__single_quoted_string,
  [sym_variable_expansion] = sym_variable_expansion,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_format_converter] = sym_format_converter,
  [sym_format_inout] = sym_format_inout,
  [sym_format_flag] = sym_format_flag,
  [sym_charset] = sym_charset,
  [sym_format_enum] = sym_format_enum,
  [sym_enum_specifier] = sym_enum_specifier,
  [sym__char] = sym__char,
  [sym_checksum] = sym_checksum,
  [sym_timeformat] = sym_timeformat,
  [sym_record_name] = sym_record_name,
  [sym_field_name] = sym_field_name,
  [sym_number] = sym_number,
  [sym_number_literal] = sym_number_literal,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_function_repeat1] = aux_sym_function_repeat1,
  [aux_sym_handler_repeat1] = aux_sym_handler_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym__double_quoted_string_repeat1] = aux_sym__double_quoted_string_repeat1,
  [aux_sym__single_quoted_string_repeat1] = aux_sym__single_quoted_string_repeat1,
  [aux_sym_charset_repeat1] = aux_sym_charset_repeat1,
  [aux_sym_format_enum_repeat1] = aux_sym_format_enum_repeat1,
  [aux_sym_timeformat_repeat1] = aux_sym_timeformat_repeat1,
  [aux_sym_record_name_repeat1] = aux_sym_record_name_repeat1,
  [aux_sym_field_name_repeat1] = aux_sym_field_name_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_variable_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_Error] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Ignore] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__quoted_string_text_fragment] = {
    .visible = false,
    .named = true,
  },
  [sym__quoted_string_text_fragment2] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BSLASH_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_variable_expansion_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_format_converter_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_format_converter_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_B] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_T] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_format_flag_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_charset_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_enum_constant] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__char_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_checksum_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_regex_pattern] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_timeformat_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_time_conversion_spec] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_record_name_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_number_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_literal_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_number_literal_token3] = {
    .visible = false,
    .named = false,
  },
  [sym_ascii_name] = {
    .visible = true,
    .named = true,
  },
  [sym__identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_variable] = {
    .visible = true,
    .named = true,
  },
  [sym__value] = {
    .visible = false,
    .named = true,
  },
  [sym_keyword] = {
    .visible = true,
    .named = true,
  },
  [sym_function] = {
    .visible = true,
    .named = true,
  },
  [sym_function_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_handler] = {
    .visible = true,
    .named = true,
  },
  [sym_handler_name] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_quoted_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__double_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym__single_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_format_converter] = {
    .visible = true,
    .named = true,
  },
  [sym_format_inout] = {
    .visible = true,
    .named = true,
  },
  [sym_format_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_charset] = {
    .visible = true,
    .named = true,
  },
  [sym_format_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym__char] = {
    .visible = false,
    .named = true,
  },
  [sym_checksum] = {
    .visible = true,
    .named = true,
  },
  [sym_timeformat] = {
    .visible = true,
    .named = true,
  },
  [sym_record_name] = {
    .visible = true,
    .named = true,
  },
  [sym_field_name] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_handler_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__double_quoted_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__single_quoted_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_charset_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_format_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_timeformat_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_name_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_name_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum {
  field_precision = 1,
  field_width = 2,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_precision] = "precision",
  [field_width] = "width",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 1},
  [5] = {.index = 3, .length = 2},
  [6] = {.index = 5, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 2},
  [9] = {.index = 9, .length = 1},
  [10] = {.index = 10, .length = 1},
  [11] = {.index = 11, .length = 2},
  [12] = {.index = 13, .length = 1},
  [13] = {.index = 14, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_width, 1},
  [1] =
    {field_precision, 2},
  [2] =
    {field_width, 2},
  [3] =
    {field_precision, 3},
    {field_width, 1},
  [5] =
    {field_precision, 3},
  [6] =
    {field_width, 4},
  [7] =
    {field_precision, 4},
    {field_width, 2},
  [9] =
    {field_precision, 5},
  [10] =
    {field_width, 5},
  [11] =
    {field_precision, 6},
    {field_width, 4},
  [13] =
    {field_precision, 6},
  [14] =
    {field_precision, 7},
    {field_width, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [1] = sym_variable_name,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static inline bool aux_sym_escape_sequence_token1_character_set_1(int32_t c) {
  return (c < '_'
    ? (c < '\''
      ? (c < '%'
        ? c == '"'
        : c <= '%')
      : (c <= '\'' || (c < '\\'
        ? c == '?'
        : c <= '\\')))
    : (c <= '_' || (c < 'n'
      ? (c < 'e'
        ? (c >= 'a' && c <= 'b')
        : c <= 'e')
      : (c <= 'n' || (c < 't'
        ? c == 'r'
        : c <= 't')))));
}

static inline bool aux_sym_format_converter_token2_character_set_1(int32_t c) {
  return (c < 'i'
    ? (c < 'R'
      ? (c < 'G'
        ? c == 'E'
        : c <= 'G')
      : (c <= 'R' || (c < 'b'
        ? c == 'X'
        : c <= 'g')))
    : (c <= 'i' || (c < 'r'
      ? (c < 'o'
        ? c == 'm'
        : c <= 'o')
      : (c <= 's' || (c < 'x'
        ? c == 'u'
        : c <= 'x')))));
}

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(44);
      if (lookahead == '"') ADVANCE(66);
      if (lookahead == '#') ADVANCE(102);
      if (lookahead == '$') ADVANCE(56);
      if (lookahead == '%') ADVANCE(84);
      if (lookahead == '\'') ADVANCE(67);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '+') ADVANCE(116);
      if (lookahead == ',') ADVANCE(65);
      if (lookahead == '-') ADVANCE(126);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == '/') ADVANCE(98);
      if (lookahead == '0') ADVANCE(87);
      if (lookahead == ';') ADVANCE(45);
      if (lookahead == '<') ADVANCE(96);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '>') ADVANCE(97);
      if (lookahead == '?') ADVANCE(111);
      if (lookahead == '@') ADVANCE(64);
      if (lookahead == 'B') ADVANCE(95);
      if (lookahead == 'I') ADVANCE(28);
      if (lookahead == 'T') ADVANCE(100);
      if (lookahead == '[') ADVANCE(91);
      if (lookahead == '\\') ADVANCE(20);
      if (lookahead == ']') ADVANCE(92);
      if (lookahead == '^') ADVANCE(104);
      if (lookahead == '{') ADVANCE(93);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(94);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(41)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(88);
      if (aux_sym_format_converter_token2_character_set_1(lookahead)) ADVANCE(90);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(12)
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '%') ADVANCE(114);
      if (lookahead == '\\') ADVANCE(115);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(113);
      if (lookahead != 0) ADVANCE(113);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(12)
      if (lookahead == '#') ADVANCE(48);
      if (lookahead == '[') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(40);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(118);
      if (lookahead != 0 &&
          lookahead != '/') ADVANCE(119);
      END_STATE();
    case 3:
      if (lookahead == ' ') ADVANCE(103);
      if (lookahead == '#') ADVANCE(102);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == '/') ADVANCE(98);
      if (lookahead == '0') ADVANCE(88);
      if (lookahead == '<') ADVANCE(96);
      if (lookahead == 'B') ADVANCE(95);
      if (lookahead == 'T') ADVANCE(100);
      if (lookahead == '[') ADVANCE(91);
      if (lookahead == '{') ADVANCE(93);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r') SKIP(11)
      if (lookahead == '!' ||
          lookahead == '*' ||
          lookahead == '+' ||
          lookahead == '-' ||
          lookahead == '=' ||
          lookahead == '?') ADVANCE(103);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(88);
      if (aux_sym_format_converter_token2_character_set_1(lookahead)) ADVANCE(90);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(66);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '$') ADVANCE(56);
      if (lookahead == '\'') ADVANCE(67);
      if (lookahead == '(') ADVANCE(62);
      if (lookahead == ')') ADVANCE(63);
      if (lookahead == ',') ADVANCE(65);
      if (lookahead == '-') ADVANCE(126);
      if (lookahead == '0') ADVANCE(130);
      if (lookahead == ';') ADVANCE(45);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '?') ADVANCE(111);
      if (lookahead == 'E') ADVANCE(133);
      if (lookahead == 'I') ADVANCE(132);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(61);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(4)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(131);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(134);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(66);
      if (lookahead == '#') ADVANCE(49);
      if (lookahead == '%') ADVANCE(84);
      if (lookahead == '\\') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(68);
      if (lookahead != 0) ADVANCE(69);
      END_STATE();
    case 6:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '%') ADVANCE(22);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '.') ADVANCE(101);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '\\') ADVANCE(23);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(94);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(7)
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(125);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(124);
      END_STATE();
    case 7:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '.') ADVANCE(101);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(7)
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(125);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(124);
      END_STATE();
    case 8:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\\') ADVANCE(108);
      if (lookahead == ']') ADVANCE(92);
      if (lookahead == '^') ADVANCE(104);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(106);
      if (lookahead != 0) ADVANCE(105);
      END_STATE();
    case 9:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\\') ADVANCE(108);
      if (lookahead == ']') ADVANCE(92);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(107);
      if (lookahead != 0) ADVANCE(105);
      END_STATE();
    case 10:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '+' ||
          lookahead == '-' ||
          lookahead == '0') ADVANCE(116);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(10)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 11:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(11)
      if (aux_sym_format_converter_token2_character_set_1(lookahead)) ADVANCE(90);
      END_STATE();
    case 12:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(12)
      END_STATE();
    case 13:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(12)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 14:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(14)
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(112);
      END_STATE();
    case 15:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(15)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      END_STATE();
    case 16:
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(15)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 17:
      if (lookahead == '#') ADVANCE(50);
      if (lookahead == '%') ADVANCE(84);
      if (lookahead == '\'') ADVANCE(67);
      if (lookahead == '\\') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(70);
      if (lookahead != 0) ADVANCE(71);
      END_STATE();
    case 18:
      if (lookahead == '#') ADVANCE(47);
      if (lookahead == '.') ADVANCE(89);
      if (lookahead == '/') ADVANCE(98);
      if (lookahead == '<') ADVANCE(96);
      if (lookahead == 'B') ADVANCE(95);
      if (lookahead == 'T') ADVANCE(100);
      if (lookahead == '[') ADVANCE(91);
      if (lookahead == '{') ADVANCE(93);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(11)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      if (aux_sym_format_converter_token2_character_set_1(lookahead)) ADVANCE(90);
      END_STATE();
    case 19:
      if (lookahead == '#') ADVANCE(51);
      if (lookahead == '%') ADVANCE(24);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(120);
      if (lookahead != 0) ADVANCE(121);
      END_STATE();
    case 20:
      if (lookahead == '$') ADVANCE(72);
      if (lookahead == '0') ADVANCE(35);
      if (lookahead == ']') ADVANCE(109);
      if (lookahead == 'x') ADVANCE(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(82);
      if (aux_sym_escape_sequence_token1_character_set_1(lookahead)) ADVANCE(74);
      END_STATE();
    case 21:
      if (lookahead == '$') ADVANCE(72);
      if (lookahead == '0') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(82);
      if (aux_sym_escape_sequence_token1_character_set_1(lookahead)) ADVANCE(74);
      END_STATE();
    case 22:
      if (lookahead == '%') ADVANCE(83);
      END_STATE();
    case 23:
      if (lookahead == '0') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(82);
      if (aux_sym_escape_sequence_token1_character_set_1(lookahead)) ADVANCE(74);
      END_STATE();
    case 24:
      if (lookahead == '0') ADVANCE(36);
      if (lookahead == 'E' ||
          lookahead == 'O') ADVANCE(122);
      if (lookahead == '#' ||
          lookahead == '-' ||
          lookahead == '.' ||
          lookahead == '^' ||
          lookahead == '_') ADVANCE(36);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead == '%' ||
          lookahead == '+' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(123);
      END_STATE();
    case 25:
      if (lookahead == '\\') ADVANCE(39);
      if (lookahead == ']') ADVANCE(119);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(25);
      END_STATE();
    case 26:
      if (lookahead == ']') ADVANCE(109);
      END_STATE();
    case 27:
      if (lookahead == 'e') ADVANCE(59);
      END_STATE();
    case 28:
      if (lookahead == 'g') ADVANCE(29);
      END_STATE();
    case 29:
      if (lookahead == 'n') ADVANCE(30);
      END_STATE();
    case 30:
      if (lookahead == 'o') ADVANCE(32);
      END_STATE();
    case 31:
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 32:
      if (lookahead == 'r') ADVANCE(27);
      END_STATE();
    case 33:
      if (lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 34:
      if (lookahead == 'r') ADVANCE(31);
      END_STATE();
    case 35:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(79);
      END_STATE();
    case 36:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead == '%' ||
          lookahead == '+' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(123);
      END_STATE();
    case 37:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(76);
      END_STATE();
    case 38:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(127);
      END_STATE();
    case 39:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(25);
      END_STATE();
    case 40:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(119);
      END_STATE();
    case 41:
      if (eof) ADVANCE(44);
      if (lookahead == '"') ADVANCE(66);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '$') ADVANCE(56);
      if (lookahead == '\'') ADVANCE(67);
      if (lookahead == '(') ADVANCE(62);
      if (lookahead == ')') ADVANCE(63);
      if (lookahead == '+') ADVANCE(116);
      if (lookahead == ',') ADVANCE(65);
      if (lookahead == '-') ADVANCE(126);
      if (lookahead == '.') ADVANCE(101);
      if (lookahead == '0') ADVANCE(117);
      if (lookahead == ';') ADVANCE(45);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '?') ADVANCE(111);
      if (lookahead == '@') ADVANCE(64);
      if (lookahead == 'I') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(26);
      if (lookahead == '^') ADVANCE(104);
      if (lookahead == '{') ADVANCE(60);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(61);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(41)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(73);
      if (aux_sym_format_converter_token2_character_set_1(lookahead)) ADVANCE(90);
      END_STATE();
    case 42:
      if (eof) ADVANCE(44);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '%') ADVANCE(22);
      if (lookahead == '(') ADVANCE(85);
      if (lookahead == ')') ADVANCE(86);
      if (lookahead == '.') ADVANCE(101);
      if (lookahead == '/') ADVANCE(98);
      if (lookahead == '0') ADVANCE(130);
      if (lookahead == ';') ADVANCE(45);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '>') ADVANCE(97);
      if (lookahead == '@') ADVANCE(64);
      if (lookahead == '\\') ADVANCE(23);
      if (lookahead == ']') ADVANCE(92);
      if (lookahead == '{') ADVANCE(60);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(61);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(43)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(131);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 43:
      if (eof) ADVANCE(44);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '.') ADVANCE(101);
      if (lookahead == '0') ADVANCE(130);
      if (lookahead == ';') ADVANCE(45);
      if (lookahead == '=') ADVANCE(55);
      if (lookahead == '@') ADVANCE(64);
      if (lookahead == '{') ADVANCE(60);
      if (lookahead == '|') ADVANCE(110);
      if (lookahead == '}') ADVANCE(61);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(43)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(131);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '/') ADVANCE(99);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == '[') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(40);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '/') ADVANCE(119);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(69);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(71);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != ')') ADVANCE(121);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(54);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '#') ADVANCE(52);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(53);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(54);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(54);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(aux_sym_variable_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_Error);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_Ignore);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym__quoted_string_text_fragment);
      if (lookahead == '#') ADVANCE(49);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(68);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(69);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym__quoted_string_text_fragment);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '%' &&
          lookahead != '\\') ADVANCE(69);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym__quoted_string_text_fragment2);
      if (lookahead == '#') ADVANCE(50);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(70);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(71);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym__quoted_string_text_fragment2);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(71);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_BSLASH_DOLLAR);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(aux_sym_variable_expansion_token1);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token1);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(75);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(77);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(78);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(80);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(81);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '%') ADVANCE(83);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_RPAREN2);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(aux_sym_format_converter_token1);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(87);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(aux_sym_format_converter_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(88);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(aux_sym_format_converter_token2);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_LBRACE2);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_RBRACE2);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_B);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_POUND_SLASH);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_T);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_DOT2);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_POUND2);
      if (lookahead == '/') ADVANCE(99);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(aux_sym_format_flag_token1);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(aux_sym_charset_token1);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(aux_sym_charset_token1);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\\') ADVANCE(108);
      if (lookahead == '^') ADVANCE(104);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(106);
      if (lookahead != 0 &&
          lookahead != ']') ADVANCE(105);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(aux_sym_charset_token1);
      if (lookahead == '#') ADVANCE(46);
      if (lookahead == '\\') ADVANCE(108);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(107);
      if (lookahead != 0 &&
          lookahead != ']') ADVANCE(105);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(aux_sym_charset_token1);
      if (lookahead == ']') ADVANCE(109);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_BSLASH_RBRACK);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(sym_enum_constant);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(112);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym__char_token1);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(aux_sym__char_token1);
      if (lookahead == '%') ADVANCE(83);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(aux_sym__char_token1);
      if (lookahead == '0') ADVANCE(35);
      if (lookahead == 'x') ADVANCE(37);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(82);
      if (aux_sym_escape_sequence_token1_character_set_1(lookahead)) ADVANCE(74);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym_checksum_flag);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(sym_checksum_flag);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(129);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '#') ADVANCE(48);
      if (lookahead == '[') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(40);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(118);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '/') ADVANCE(119);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(sym_regex_pattern);
      if (lookahead == '[') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(40);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '/') ADVANCE(119);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym_timeformat_token1);
      if (lookahead == '#') ADVANCE(51);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(120);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != ')') ADVANCE(121);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym_timeformat_token1);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != ')') ADVANCE(121);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_time_conversion_spec);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(36);
      if (lookahead == '%' ||
          lookahead == '+' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(123);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_time_conversion_spec);
      if (lookahead == '%' ||
          lookahead == '+' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(123);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(aux_sym_record_name_token1);
      if (lookahead == ':') ADVANCE(125);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(124);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(aux_sym_record_name_token1);
      if (('0' <= lookahead && lookahead <= ':') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(125);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(aux_sym_number_literal_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(127);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(aux_sym_number_literal_token2);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(131);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(128);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(aux_sym_number_literal_token2);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(129);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(aux_sym_number_literal_token3);
      if (lookahead == 'x') ADVANCE(38);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(131);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(128);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(aux_sym_number_literal_token3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(131);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_ascii_name);
      if (lookahead == 'g') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z')) ADVANCE(134);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_ascii_name);
      if (lookahead == 'r') ADVANCE(34);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z')) ADVANCE(134);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_ascii_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z')) ADVANCE(134);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym__identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(135);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 42},
  [2] = {.lex_state = 4},
  [3] = {.lex_state = 4},
  [4] = {.lex_state = 4},
  [5] = {.lex_state = 4},
  [6] = {.lex_state = 4},
  [7] = {.lex_state = 4},
  [8] = {.lex_state = 3},
  [9] = {.lex_state = 3},
  [10] = {.lex_state = 4},
  [11] = {.lex_state = 3},
  [12] = {.lex_state = 5},
  [13] = {.lex_state = 4},
  [14] = {.lex_state = 6},
  [15] = {.lex_state = 17},
  [16] = {.lex_state = 17},
  [17] = {.lex_state = 4},
  [18] = {.lex_state = 5},
  [19] = {.lex_state = 3},
  [20] = {.lex_state = 5},
  [21] = {.lex_state = 17},
  [22] = {.lex_state = 6},
  [23] = {.lex_state = 4},
  [24] = {.lex_state = 4},
  [25] = {.lex_state = 4},
  [26] = {.lex_state = 4},
  [27] = {.lex_state = 4},
  [28] = {.lex_state = 4},
  [29] = {.lex_state = 4},
  [30] = {.lex_state = 4},
  [31] = {.lex_state = 4},
  [32] = {.lex_state = 4},
  [33] = {.lex_state = 18},
  [34] = {.lex_state = 18},
  [35] = {.lex_state = 42},
  [36] = {.lex_state = 6},
  [37] = {.lex_state = 18},
  [38] = {.lex_state = 18},
  [39] = {.lex_state = 42},
  [40] = {.lex_state = 6},
  [41] = {.lex_state = 18},
  [42] = {.lex_state = 5},
  [43] = {.lex_state = 5},
  [44] = {.lex_state = 5},
  [45] = {.lex_state = 5},
  [46] = {.lex_state = 5},
  [47] = {.lex_state = 5},
  [48] = {.lex_state = 42},
  [49] = {.lex_state = 5},
  [50] = {.lex_state = 5},
  [51] = {.lex_state = 5},
  [52] = {.lex_state = 5},
  [53] = {.lex_state = 5},
  [54] = {.lex_state = 5},
  [55] = {.lex_state = 5},
  [56] = {.lex_state = 5},
  [57] = {.lex_state = 42},
  [58] = {.lex_state = 18},
  [59] = {.lex_state = 5},
  [60] = {.lex_state = 5},
  [61] = {.lex_state = 5},
  [62] = {.lex_state = 5},
  [63] = {.lex_state = 5},
  [64] = {.lex_state = 17},
  [65] = {.lex_state = 5},
  [66] = {.lex_state = 5},
  [67] = {.lex_state = 5},
  [68] = {.lex_state = 5},
  [69] = {.lex_state = 5},
  [70] = {.lex_state = 42},
  [71] = {.lex_state = 5},
  [72] = {.lex_state = 5},
  [73] = {.lex_state = 5},
  [74] = {.lex_state = 5},
  [75] = {.lex_state = 18},
  [76] = {.lex_state = 5},
  [77] = {.lex_state = 5},
  [78] = {.lex_state = 5},
  [79] = {.lex_state = 5},
  [80] = {.lex_state = 5},
  [81] = {.lex_state = 18},
  [82] = {.lex_state = 5},
  [83] = {.lex_state = 5},
  [84] = {.lex_state = 5},
  [85] = {.lex_state = 4},
  [86] = {.lex_state = 5},
  [87] = {.lex_state = 5},
  [88] = {.lex_state = 5},
  [89] = {.lex_state = 5},
  [90] = {.lex_state = 5},
  [91] = {.lex_state = 5},
  [92] = {.lex_state = 6},
  [93] = {.lex_state = 5},
  [94] = {.lex_state = 18},
  [95] = {.lex_state = 5},
  [96] = {.lex_state = 42},
  [97] = {.lex_state = 5},
  [98] = {.lex_state = 5},
  [99] = {.lex_state = 5},
  [100] = {.lex_state = 5},
  [101] = {.lex_state = 5},
  [102] = {.lex_state = 5},
  [103] = {.lex_state = 18},
  [104] = {.lex_state = 18},
  [105] = {.lex_state = 5},
  [106] = {.lex_state = 5},
  [107] = {.lex_state = 5},
  [108] = {.lex_state = 5},
  [109] = {.lex_state = 5},
  [110] = {.lex_state = 5},
  [111] = {.lex_state = 17},
  [112] = {.lex_state = 6},
  [113] = {.lex_state = 17},
  [114] = {.lex_state = 5},
  [115] = {.lex_state = 5},
  [116] = {.lex_state = 17},
  [117] = {.lex_state = 17},
  [118] = {.lex_state = 17},
  [119] = {.lex_state = 17},
  [120] = {.lex_state = 17},
  [121] = {.lex_state = 17},
  [122] = {.lex_state = 18},
  [123] = {.lex_state = 17},
  [124] = {.lex_state = 5},
  [125] = {.lex_state = 17},
  [126] = {.lex_state = 5},
  [127] = {.lex_state = 17},
  [128] = {.lex_state = 17},
  [129] = {.lex_state = 17},
  [130] = {.lex_state = 17},
  [131] = {.lex_state = 5},
  [132] = {.lex_state = 17},
  [133] = {.lex_state = 42},
  [134] = {.lex_state = 5},
  [135] = {.lex_state = 42},
  [136] = {.lex_state = 17},
  [137] = {.lex_state = 5},
  [138] = {.lex_state = 17},
  [139] = {.lex_state = 17},
  [140] = {.lex_state = 17},
  [141] = {.lex_state = 17},
  [142] = {.lex_state = 17},
  [143] = {.lex_state = 17},
  [144] = {.lex_state = 17},
  [145] = {.lex_state = 17},
  [146] = {.lex_state = 5},
  [147] = {.lex_state = 17},
  [148] = {.lex_state = 17},
  [149] = {.lex_state = 5},
  [150] = {.lex_state = 17},
  [151] = {.lex_state = 17},
  [152] = {.lex_state = 17},
  [153] = {.lex_state = 17},
  [154] = {.lex_state = 17},
  [155] = {.lex_state = 5},
  [156] = {.lex_state = 17},
  [157] = {.lex_state = 5},
  [158] = {.lex_state = 17},
  [159] = {.lex_state = 17},
  [160] = {.lex_state = 17},
  [161] = {.lex_state = 17},
  [162] = {.lex_state = 17},
  [163] = {.lex_state = 17},
  [164] = {.lex_state = 17},
  [165] = {.lex_state = 17},
  [166] = {.lex_state = 17},
  [167] = {.lex_state = 5},
  [168] = {.lex_state = 17},
  [169] = {.lex_state = 17},
  [170] = {.lex_state = 17},
  [171] = {.lex_state = 17},
  [172] = {.lex_state = 17},
  [173] = {.lex_state = 5},
  [174] = {.lex_state = 17},
  [175] = {.lex_state = 17},
  [176] = {.lex_state = 17},
  [177] = {.lex_state = 17},
  [178] = {.lex_state = 17},
  [179] = {.lex_state = 17},
  [180] = {.lex_state = 17},
  [181] = {.lex_state = 17},
  [182] = {.lex_state = 17},
  [183] = {.lex_state = 17},
  [184] = {.lex_state = 18},
  [185] = {.lex_state = 17},
  [186] = {.lex_state = 5},
  [187] = {.lex_state = 17},
  [188] = {.lex_state = 17},
  [189] = {.lex_state = 17},
  [190] = {.lex_state = 17},
  [191] = {.lex_state = 17},
  [192] = {.lex_state = 17},
  [193] = {.lex_state = 17},
  [194] = {.lex_state = 17},
  [195] = {.lex_state = 17},
  [196] = {.lex_state = 5},
  [197] = {.lex_state = 5},
  [198] = {.lex_state = 17},
  [199] = {.lex_state = 17},
  [200] = {.lex_state = 17},
  [201] = {.lex_state = 17},
  [202] = {.lex_state = 17},
  [203] = {.lex_state = 17},
  [204] = {.lex_state = 5},
  [205] = {.lex_state = 1},
  [206] = {.lex_state = 1},
  [207] = {.lex_state = 1},
  [208] = {.lex_state = 18},
  [209] = {.lex_state = 1},
  [210] = {.lex_state = 1},
  [211] = {.lex_state = 1},
  [212] = {.lex_state = 1},
  [213] = {.lex_state = 1},
  [214] = {.lex_state = 1},
  [215] = {.lex_state = 1},
  [216] = {.lex_state = 1},
  [217] = {.lex_state = 1},
  [218] = {.lex_state = 1},
  [219] = {.lex_state = 1},
  [220] = {.lex_state = 18},
  [221] = {.lex_state = 18},
  [222] = {.lex_state = 1},
  [223] = {.lex_state = 1},
  [224] = {.lex_state = 1},
  [225] = {.lex_state = 1},
  [226] = {.lex_state = 1},
  [227] = {.lex_state = 4},
  [228] = {.lex_state = 18},
  [229] = {.lex_state = 1},
  [230] = {.lex_state = 1},
  [231] = {.lex_state = 4},
  [232] = {.lex_state = 1},
  [233] = {.lex_state = 1},
  [234] = {.lex_state = 1},
  [235] = {.lex_state = 1},
  [236] = {.lex_state = 1},
  [237] = {.lex_state = 1},
  [238] = {.lex_state = 1},
  [239] = {.lex_state = 1},
  [240] = {.lex_state = 1},
  [241] = {.lex_state = 18},
  [242] = {.lex_state = 1},
  [243] = {.lex_state = 18},
  [244] = {.lex_state = 18},
  [245] = {.lex_state = 1},
  [246] = {.lex_state = 1},
  [247] = {.lex_state = 1},
  [248] = {.lex_state = 1},
  [249] = {.lex_state = 1},
  [250] = {.lex_state = 18},
  [251] = {.lex_state = 1},
  [252] = {.lex_state = 1},
  [253] = {.lex_state = 1},
  [254] = {.lex_state = 1},
  [255] = {.lex_state = 1},
  [256] = {.lex_state = 18},
  [257] = {.lex_state = 1},
  [258] = {.lex_state = 18},
  [259] = {.lex_state = 18},
  [260] = {.lex_state = 18},
  [261] = {.lex_state = 1},
  [262] = {.lex_state = 1},
  [263] = {.lex_state = 1},
  [264] = {.lex_state = 1},
  [265] = {.lex_state = 1},
  [266] = {.lex_state = 1},
  [267] = {.lex_state = 18},
  [268] = {.lex_state = 4},
  [269] = {.lex_state = 1},
  [270] = {.lex_state = 1},
  [271] = {.lex_state = 1},
  [272] = {.lex_state = 1},
  [273] = {.lex_state = 6},
  [274] = {.lex_state = 1},
  [275] = {.lex_state = 1},
  [276] = {.lex_state = 18},
  [277] = {.lex_state = 1},
  [278] = {.lex_state = 1},
  [279] = {.lex_state = 1},
  [280] = {.lex_state = 1},
  [281] = {.lex_state = 18},
  [282] = {.lex_state = 1},
  [283] = {.lex_state = 18},
  [284] = {.lex_state = 1},
  [285] = {.lex_state = 1},
  [286] = {.lex_state = 1},
  [287] = {.lex_state = 1},
  [288] = {.lex_state = 1},
  [289] = {.lex_state = 42},
  [290] = {.lex_state = 42},
  [291] = {.lex_state = 8},
  [292] = {.lex_state = 8},
  [293] = {.lex_state = 8},
  [294] = {.lex_state = 8},
  [295] = {.lex_state = 8},
  [296] = {.lex_state = 42},
  [297] = {.lex_state = 8},
  [298] = {.lex_state = 8},
  [299] = {.lex_state = 8},
  [300] = {.lex_state = 8},
  [301] = {.lex_state = 8},
  [302] = {.lex_state = 8},
  [303] = {.lex_state = 8},
  [304] = {.lex_state = 8},
  [305] = {.lex_state = 8},
  [306] = {.lex_state = 42},
  [307] = {.lex_state = 42},
  [308] = {.lex_state = 8},
  [309] = {.lex_state = 8},
  [310] = {.lex_state = 42},
  [311] = {.lex_state = 8},
  [312] = {.lex_state = 1},
  [313] = {.lex_state = 8},
  [314] = {.lex_state = 8},
  [315] = {.lex_state = 8},
  [316] = {.lex_state = 8},
  [317] = {.lex_state = 8},
  [318] = {.lex_state = 8},
  [319] = {.lex_state = 8},
  [320] = {.lex_state = 8},
  [321] = {.lex_state = 1},
  [322] = {.lex_state = 8},
  [323] = {.lex_state = 42},
  [324] = {.lex_state = 8},
  [325] = {.lex_state = 8},
  [326] = {.lex_state = 8},
  [327] = {.lex_state = 8},
  [328] = {.lex_state = 8},
  [329] = {.lex_state = 8},
  [330] = {.lex_state = 19},
  [331] = {.lex_state = 14},
  [332] = {.lex_state = 14},
  [333] = {.lex_state = 19},
  [334] = {.lex_state = 19},
  [335] = {.lex_state = 19},
  [336] = {.lex_state = 19},
  [337] = {.lex_state = 14},
  [338] = {.lex_state = 14},
  [339] = {.lex_state = 14},
  [340] = {.lex_state = 14},
  [341] = {.lex_state = 19},
  [342] = {.lex_state = 42},
  [343] = {.lex_state = 19},
  [344] = {.lex_state = 14},
  [345] = {.lex_state = 19},
  [346] = {.lex_state = 19},
  [347] = {.lex_state = 14},
  [348] = {.lex_state = 19},
  [349] = {.lex_state = 19},
  [350] = {.lex_state = 19},
  [351] = {.lex_state = 14},
  [352] = {.lex_state = 14},
  [353] = {.lex_state = 19},
  [354] = {.lex_state = 19},
  [355] = {.lex_state = 19},
  [356] = {.lex_state = 9},
  [357] = {.lex_state = 9},
  [358] = {.lex_state = 14},
  [359] = {.lex_state = 14},
  [360] = {.lex_state = 19},
  [361] = {.lex_state = 19},
  [362] = {.lex_state = 14},
  [363] = {.lex_state = 19},
  [364] = {.lex_state = 14},
  [365] = {.lex_state = 19},
  [366] = {.lex_state = 14},
  [367] = {.lex_state = 19},
  [368] = {.lex_state = 14},
  [369] = {.lex_state = 19},
  [370] = {.lex_state = 9},
  [371] = {.lex_state = 19},
  [372] = {.lex_state = 14},
  [373] = {.lex_state = 19},
  [374] = {.lex_state = 14},
  [375] = {.lex_state = 19},
  [376] = {.lex_state = 14},
  [377] = {.lex_state = 19},
  [378] = {.lex_state = 42},
  [379] = {.lex_state = 42},
  [380] = {.lex_state = 14},
  [381] = {.lex_state = 14},
  [382] = {.lex_state = 14},
  [383] = {.lex_state = 42},
  [384] = {.lex_state = 14},
  [385] = {.lex_state = 19},
  [386] = {.lex_state = 19},
  [387] = {.lex_state = 14},
  [388] = {.lex_state = 19},
  [389] = {.lex_state = 42},
  [390] = {.lex_state = 19},
  [391] = {.lex_state = 19},
  [392] = {.lex_state = 14},
  [393] = {.lex_state = 42},
  [394] = {.lex_state = 42},
  [395] = {.lex_state = 14},
  [396] = {.lex_state = 19},
  [397] = {.lex_state = 14},
  [398] = {.lex_state = 19},
  [399] = {.lex_state = 14},
  [400] = {.lex_state = 14},
  [401] = {.lex_state = 14},
  [402] = {.lex_state = 14},
  [403] = {.lex_state = 19},
  [404] = {.lex_state = 42},
  [405] = {.lex_state = 14},
  [406] = {.lex_state = 19},
  [407] = {.lex_state = 42},
  [408] = {.lex_state = 10},
  [409] = {.lex_state = 10},
  [410] = {.lex_state = 10},
  [411] = {.lex_state = 10},
  [412] = {.lex_state = 10},
  [413] = {.lex_state = 10},
  [414] = {.lex_state = 10},
  [415] = {.lex_state = 10},
  [416] = {.lex_state = 10},
  [417] = {.lex_state = 10},
  [418] = {.lex_state = 4},
  [419] = {.lex_state = 10},
  [420] = {.lex_state = 10},
  [421] = {.lex_state = 4},
  [422] = {.lex_state = 10},
  [423] = {.lex_state = 10},
  [424] = {.lex_state = 10},
  [425] = {.lex_state = 19},
  [426] = {.lex_state = 10},
  [427] = {.lex_state = 14},
  [428] = {.lex_state = 10},
  [429] = {.lex_state = 42},
  [430] = {.lex_state = 10},
  [431] = {.lex_state = 10},
  [432] = {.lex_state = 10},
  [433] = {.lex_state = 10},
  [434] = {.lex_state = 10},
  [435] = {.lex_state = 10},
  [436] = {.lex_state = 10},
  [437] = {.lex_state = 10},
  [438] = {.lex_state = 10},
  [439] = {.lex_state = 14},
  [440] = {.lex_state = 10},
  [441] = {.lex_state = 10},
  [442] = {.lex_state = 6},
  [443] = {.lex_state = 10},
  [444] = {.lex_state = 10},
  [445] = {.lex_state = 10},
  [446] = {.lex_state = 42},
  [447] = {.lex_state = 9},
  [448] = {.lex_state = 9},
  [449] = {.lex_state = 10},
  [450] = {.lex_state = 42},
  [451] = {.lex_state = 42},
  [452] = {.lex_state = 42},
  [453] = {.lex_state = 42},
  [454] = {.lex_state = 42},
  [455] = {.lex_state = 16},
  [456] = {.lex_state = 42},
  [457] = {.lex_state = 42},
  [458] = {.lex_state = 42},
  [459] = {.lex_state = 16},
  [460] = {.lex_state = 42},
  [461] = {.lex_state = 42},
  [462] = {.lex_state = 6},
  [463] = {.lex_state = 42},
  [464] = {.lex_state = 42},
  [465] = {.lex_state = 42},
  [466] = {.lex_state = 42},
  [467] = {.lex_state = 42},
  [468] = {.lex_state = 42},
  [469] = {.lex_state = 42},
  [470] = {.lex_state = 42},
  [471] = {.lex_state = 42},
  [472] = {.lex_state = 42},
  [473] = {.lex_state = 42},
  [474] = {.lex_state = 42},
  [475] = {.lex_state = 6},
  [476] = {.lex_state = 42},
  [477] = {.lex_state = 42},
  [478] = {.lex_state = 16},
  [479] = {.lex_state = 42},
  [480] = {.lex_state = 42},
  [481] = {.lex_state = 42},
  [482] = {.lex_state = 42},
  [483] = {.lex_state = 42},
  [484] = {.lex_state = 42},
  [485] = {.lex_state = 42},
  [486] = {.lex_state = 42},
  [487] = {.lex_state = 42},
  [488] = {.lex_state = 42},
  [489] = {.lex_state = 42},
  [490] = {.lex_state = 6},
  [491] = {.lex_state = 6},
  [492] = {.lex_state = 42},
  [493] = {.lex_state = 42},
  [494] = {.lex_state = 6},
  [495] = {.lex_state = 42},
  [496] = {.lex_state = 42},
  [497] = {.lex_state = 42},
  [498] = {.lex_state = 42},
  [499] = {.lex_state = 16},
  [500] = {.lex_state = 42},
  [501] = {.lex_state = 42},
  [502] = {.lex_state = 6},
  [503] = {.lex_state = 42},
  [504] = {.lex_state = 42},
  [505] = {.lex_state = 42},
  [506] = {.lex_state = 42},
  [507] = {.lex_state = 42},
  [508] = {.lex_state = 42},
  [509] = {.lex_state = 42},
  [510] = {.lex_state = 42},
  [511] = {.lex_state = 42},
  [512] = {.lex_state = 42},
  [513] = {.lex_state = 42},
  [514] = {.lex_state = 2},
  [515] = {.lex_state = 2},
  [516] = {.lex_state = 42},
  [517] = {.lex_state = 2},
  [518] = {.lex_state = 42},
  [519] = {.lex_state = 42},
  [520] = {.lex_state = 42},
  [521] = {.lex_state = 2},
  [522] = {.lex_state = 6},
  [523] = {.lex_state = 42},
  [524] = {.lex_state = 42},
  [525] = {.lex_state = 42},
  [526] = {.lex_state = 42},
  [527] = {.lex_state = 42},
  [528] = {.lex_state = 2},
  [529] = {.lex_state = 42},
  [530] = {.lex_state = 42},
  [531] = {.lex_state = 42},
  [532] = {.lex_state = 42},
  [533] = {.lex_state = 6},
  [534] = {.lex_state = 42},
  [535] = {.lex_state = 42},
  [536] = {.lex_state = 2},
  [537] = {.lex_state = 42},
  [538] = {.lex_state = 42},
  [539] = {.lex_state = 2},
  [540] = {.lex_state = 2},
  [541] = {.lex_state = 42},
  [542] = {.lex_state = 6},
  [543] = {.lex_state = 42},
  [544] = {.lex_state = 42},
  [545] = {.lex_state = 2},
  [546] = {.lex_state = 2},
  [547] = {.lex_state = 42},
  [548] = {.lex_state = 42},
  [549] = {.lex_state = 13},
  [550] = {.lex_state = 42},
  [551] = {.lex_state = 42},
  [552] = {.lex_state = 42},
  [553] = {.lex_state = 42},
  [554] = {.lex_state = 42},
  [555] = {.lex_state = 6},
  [556] = {.lex_state = 42},
  [557] = {.lex_state = 42},
  [558] = {.lex_state = 2},
  [559] = {.lex_state = 2},
  [560] = {.lex_state = 13},
  [561] = {.lex_state = 42},
  [562] = {.lex_state = 13},
  [563] = {.lex_state = 2},
  [564] = {.lex_state = 42},
  [565] = {.lex_state = 42},
  [566] = {.lex_state = 2},
  [567] = {.lex_state = 42},
  [568] = {.lex_state = 42},
  [569] = {.lex_state = 42},
  [570] = {.lex_state = 14},
  [571] = {.lex_state = 42},
  [572] = {.lex_state = 42},
  [573] = {.lex_state = 42},
  [574] = {.lex_state = 2},
  [575] = {.lex_state = 2},
  [576] = {.lex_state = 2},
  [577] = {.lex_state = 6},
  [578] = {.lex_state = 42},
  [579] = {.lex_state = 42},
  [580] = {.lex_state = 42},
  [581] = {.lex_state = 42},
  [582] = {.lex_state = 2},
  [583] = {.lex_state = 6},
  [584] = {.lex_state = 42},
  [585] = {.lex_state = 42},
  [586] = {.lex_state = 2},
  [587] = {.lex_state = 2},
  [588] = {.lex_state = 42},
  [589] = {.lex_state = 42},
  [590] = {.lex_state = 13},
  [591] = {.lex_state = 42},
  [592] = {.lex_state = 42},
  [593] = {.lex_state = 42},
  [594] = {.lex_state = 42},
  [595] = {.lex_state = 42},
  [596] = {.lex_state = 42},
  [597] = {.lex_state = 2},
  [598] = {.lex_state = 42},
  [599] = {.lex_state = 6},
  [600] = {.lex_state = 6},
  [601] = {.lex_state = 53},
  [602] = {.lex_state = 42},
  [603] = {.lex_state = 42},
  [604] = {.lex_state = 42},
  [605] = {.lex_state = 42},
  [606] = {.lex_state = 42},
  [607] = {.lex_state = 42},
  [608] = {.lex_state = 42},
  [609] = {.lex_state = 42},
  [610] = {.lex_state = 42},
  [611] = {.lex_state = 2},
  [612] = {.lex_state = 2},
  [613] = {.lex_state = 42},
  [614] = {.lex_state = 6},
  [615] = {.lex_state = 13},
  [616] = {.lex_state = 42},
  [617] = {.lex_state = 42},
  [618] = {.lex_state = 6},
  [619] = {.lex_state = 42},
  [620] = {.lex_state = 42},
  [621] = {.lex_state = 42},
  [622] = {.lex_state = 2},
  [623] = {.lex_state = 42},
  [624] = {.lex_state = 42},
  [625] = {.lex_state = 42},
  [626] = {.lex_state = 42},
  [627] = {.lex_state = 6},
  [628] = {.lex_state = 42},
  [629] = {.lex_state = 42},
  [630] = {.lex_state = 42},
  [631] = {.lex_state = 42},
  [632] = {.lex_state = 42},
  [633] = {.lex_state = 42},
  [634] = {.lex_state = 4},
  [635] = {.lex_state = 42},
  [636] = {.lex_state = 2},
  [637] = {.lex_state = 42},
  [638] = {.lex_state = 6},
  [639] = {.lex_state = 42},
  [640] = {.lex_state = 2},
  [641] = {.lex_state = 2},
  [642] = {.lex_state = 2},
  [643] = {.lex_state = 13},
  [644] = {.lex_state = 42},
  [645] = {.lex_state = 2},
  [646] = {.lex_state = 42},
  [647] = {.lex_state = 42},
  [648] = {.lex_state = 42},
  [649] = {.lex_state = 6},
  [650] = {.lex_state = 42},
  [651] = {.lex_state = 42},
  [652] = {.lex_state = 42},
  [653] = {.lex_state = 42},
  [654] = {.lex_state = 42},
  [655] = {.lex_state = 6},
  [656] = {.lex_state = 42},
  [657] = {.lex_state = 42},
  [658] = {.lex_state = 42},
  [659] = {.lex_state = 2},
  [660] = {.lex_state = 42},
  [661] = {.lex_state = 42},
  [662] = {.lex_state = 42},
  [663] = {.lex_state = 42},
  [664] = {.lex_state = 2},
  [665] = {.lex_state = 42},
  [666] = {.lex_state = 6},
  [667] = {.lex_state = 42},
  [668] = {.lex_state = 42},
  [669] = {.lex_state = 42},
  [670] = {.lex_state = 42},
  [671] = {.lex_state = 42},
  [672] = {.lex_state = 42},
  [673] = {.lex_state = 6},
  [674] = {.lex_state = 42},
  [675] = {.lex_state = 42},
  [676] = {.lex_state = 42},
  [677] = {.lex_state = 42},
  [678] = {.lex_state = 42},
  [679] = {.lex_state = 2},
  [680] = {.lex_state = 6},
  [681] = {.lex_state = 42},
  [682] = {.lex_state = 42},
  [683] = {.lex_state = 42},
  [684] = {.lex_state = 6},
  [685] = {.lex_state = 42},
  [686] = {.lex_state = 42},
  [687] = {.lex_state = 42},
  [688] = {.lex_state = 42},
  [689] = {.lex_state = 6},
  [690] = {.lex_state = 42},
  [691] = {.lex_state = 42},
  [692] = {.lex_state = 42},
  [693] = {.lex_state = 42},
  [694] = {.lex_state = 42},
  [695] = {.lex_state = 42},
  [696] = {.lex_state = 16},
  [697] = {.lex_state = 42},
  [698] = {.lex_state = 42},
  [699] = {.lex_state = 42},
  [700] = {.lex_state = 6},
  [701] = {.lex_state = 42},
  [702] = {.lex_state = 42},
  [703] = {.lex_state = 42},
  [704] = {.lex_state = 42},
  [705] = {.lex_state = 42},
  [706] = {.lex_state = 6},
  [707] = {.lex_state = 42},
  [708] = {.lex_state = 42},
  [709] = {.lex_state = 42},
  [710] = {.lex_state = 42},
  [711] = {.lex_state = 42},
  [712] = {.lex_state = 42},
  [713] = {.lex_state = 2},
  [714] = {.lex_state = 42},
  [715] = {.lex_state = 13},
  [716] = {.lex_state = 42},
  [717] = {.lex_state = 6},
  [718] = {.lex_state = 42},
  [719] = {.lex_state = 42},
  [720] = {.lex_state = 42},
  [721] = {.lex_state = 42},
  [722] = {.lex_state = 42},
  [723] = {.lex_state = 6},
  [724] = {.lex_state = 42},
  [725] = {.lex_state = 42},
  [726] = {.lex_state = 42},
  [727] = {.lex_state = 42},
  [728] = {.lex_state = 42},
  [729] = {.lex_state = 42},
  [730] = {.lex_state = 42},
  [731] = {.lex_state = 42},
  [732] = {.lex_state = 42},
  [733] = {.lex_state = 42},
  [734] = {.lex_state = 42},
  [735] = {.lex_state = 6},
  [736] = {.lex_state = 42},
  [737] = {.lex_state = 42},
  [738] = {.lex_state = 42},
  [739] = {.lex_state = 42},
  [740] = {.lex_state = 42},
  [741] = {.lex_state = 42},
  [742] = {.lex_state = 2},
  [743] = {.lex_state = 42},
  [744] = {.lex_state = 42},
  [745] = {.lex_state = 42},
  [746] = {.lex_state = 6},
  [747] = {.lex_state = 42},
  [748] = {.lex_state = 42},
  [749] = {.lex_state = 42},
  [750] = {.lex_state = 42},
  [751] = {.lex_state = 42},
  [752] = {.lex_state = 42},
  [753] = {.lex_state = 42},
  [754] = {.lex_state = 42},
  [755] = {.lex_state = 6},
  [756] = {.lex_state = 42},
  [757] = {.lex_state = 42},
  [758] = {.lex_state = 42},
  [759] = {.lex_state = 42},
  [760] = {.lex_state = 42},
  [761] = {.lex_state = 42},
  [762] = {.lex_state = 42},
  [763] = {.lex_state = 42},
  [764] = {.lex_state = 42},
  [765] = {.lex_state = 42},
  [766] = {.lex_state = 42},
  [767] = {.lex_state = 13},
  [768] = {.lex_state = 2},
  [769] = {.lex_state = 2},
  [770] = {.lex_state = 2},
  [771] = {.lex_state = 42},
  [772] = {.lex_state = 13},
  [773] = {.lex_state = 42},
  [774] = {.lex_state = 42},
  [775] = {.lex_state = 2},
  [776] = {.lex_state = 42},
  [777] = {.lex_state = 42},
  [778] = {.lex_state = 13},
  [779] = {.lex_state = 6},
  [780] = {.lex_state = 42},
  [781] = {.lex_state = 2},
  [782] = {.lex_state = 2},
  [783] = {.lex_state = 42},
  [784] = {.lex_state = 42},
  [785] = {.lex_state = 2},
  [786] = {.lex_state = 2},
  [787] = {.lex_state = 2},
  [788] = {.lex_state = 13},
  [789] = {.lex_state = 2},
  [790] = {.lex_state = 42},
  [791] = {.lex_state = 2},
  [792] = {.lex_state = 42},
  [793] = {.lex_state = 42},
  [794] = {.lex_state = 13},
  [795] = {.lex_state = 42},
  [796] = {.lex_state = 42},
  [797] = {.lex_state = 2},
  [798] = {.lex_state = 42},
  [799] = {.lex_state = 6},
  [800] = {.lex_state = 2},
  [801] = {.lex_state = 2},
  [802] = {.lex_state = 42},
  [803] = {.lex_state = 42},
  [804] = {.lex_state = 42},
  [805] = {.lex_state = 6},
  [806] = {.lex_state = 42},
  [807] = {.lex_state = 42},
  [808] = {.lex_state = 2},
  [809] = {.lex_state = 13},
  [810] = {.lex_state = 42},
  [811] = {.lex_state = 6},
  [812] = {.lex_state = 2},
  [813] = {.lex_state = 42},
  [814] = {.lex_state = 42},
  [815] = {.lex_state = 13},
  [816] = {.lex_state = 42},
  [817] = {.lex_state = 2},
  [818] = {.lex_state = 2},
  [819] = {.lex_state = 42},
  [820] = {.lex_state = 42},
  [821] = {.lex_state = 2},
  [822] = {.lex_state = 42},
  [823] = {.lex_state = 2},
  [824] = {.lex_state = 2},
  [825] = {.lex_state = 2},
  [826] = {.lex_state = 2},
  [827] = {.lex_state = 42},
  [828] = {.lex_state = 42},
  [829] = {.lex_state = 2},
  [830] = {.lex_state = 42},
  [831] = {.lex_state = 42},
  [832] = {.lex_state = 2},
  [833] = {.lex_state = 2},
  [834] = {.lex_state = 13},
  [835] = {.lex_state = 42},
  [836] = {.lex_state = 42},
  [837] = {.lex_state = 2},
  [838] = {.lex_state = 42},
  [839] = {.lex_state = 42},
  [840] = {.lex_state = 2},
  [841] = {.lex_state = 6},
  [842] = {.lex_state = 42},
  [843] = {.lex_state = 2},
  [844] = {.lex_state = 42},
  [845] = {.lex_state = 42},
  [846] = {.lex_state = 2},
  [847] = {.lex_state = 2},
  [848] = {.lex_state = 2},
  [849] = {.lex_state = 42},
  [850] = {.lex_state = 42},
  [851] = {.lex_state = 42},
  [852] = {.lex_state = 6},
  [853] = {.lex_state = 42},
  [854] = {.lex_state = 2},
  [855] = {.lex_state = 2},
  [856] = {.lex_state = 2},
  [857] = {.lex_state = 42},
  [858] = {.lex_state = 2},
  [859] = {.lex_state = 2},
  [860] = {.lex_state = 2},
  [861] = {.lex_state = 13},
  [862] = {.lex_state = 2},
  [863] = {.lex_state = 2},
  [864] = {.lex_state = 42},
  [865] = {.lex_state = 2},
  [866] = {.lex_state = 2},
  [867] = {.lex_state = 42},
  [868] = {.lex_state = 42},
  [869] = {.lex_state = 2},
  [870] = {.lex_state = 2},
  [871] = {.lex_state = 2},
  [872] = {.lex_state = 53},
  [873] = {.lex_state = 42},
  [874] = {.lex_state = 42},
  [875] = {.lex_state = 42},
  [876] = {.lex_state = 42},
  [877] = {.lex_state = 42},
  [878] = {.lex_state = 42},
  [879] = {.lex_state = 42},
  [880] = {.lex_state = 42},
  [881] = {.lex_state = 42},
  [882] = {.lex_state = 42},
  [883] = {.lex_state = 42},
  [884] = {.lex_state = 42},
  [885] = {.lex_state = 42},
  [886] = {.lex_state = 42},
  [887] = {.lex_state = 42},
  [888] = {.lex_state = 42},
  [889] = {.lex_state = 42},
  [890] = {.lex_state = 42},
  [891] = {.lex_state = 42},
  [892] = {.lex_state = 42},
  [893] = {.lex_state = 42},
  [894] = {.lex_state = 42},
  [895] = {.lex_state = 42},
  [896] = {.lex_state = 42},
  [897] = {.lex_state = 42},
  [898] = {.lex_state = 42},
  [899] = {.lex_state = 42},
  [900] = {.lex_state = 42},
  [901] = {.lex_state = 42},
  [902] = {.lex_state = 42},
  [903] = {.lex_state = 42},
  [904] = {.lex_state = 42},
  [905] = {.lex_state = 2},
  [906] = {.lex_state = 2},
  [907] = {.lex_state = 2},
  [908] = {.lex_state = 2},
  [909] = {.lex_state = 2},
  [910] = {.lex_state = 2},
  [911] = {.lex_state = 2},
  [912] = {.lex_state = 2},
  [913] = {.lex_state = 2},
  [914] = {.lex_state = 2},
  [915] = {.lex_state = 2},
  [916] = {.lex_state = 2},
  [917] = {.lex_state = 2},
  [918] = {.lex_state = 2},
  [919] = {.lex_state = 2},
  [920] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(3),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_Ignore] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_BSLASH_DOLLAR] = ACTIONS(1),
    [aux_sym_variable_expansion_token1] = ACTIONS(1),
    [aux_sym_escape_sequence_token1] = ACTIONS(1),
    [aux_sym_escape_sequence_token2] = ACTIONS(1),
    [aux_sym_escape_sequence_token3] = ACTIONS(1),
    [aux_sym_escape_sequence_token4] = ACTIONS(1),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_RPAREN2] = ACTIONS(1),
    [aux_sym_format_converter_token1] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [aux_sym_format_converter_token2] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE2] = ACTIONS(1),
    [anon_sym_RBRACE2] = ACTIONS(1),
    [anon_sym_B] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_POUND_SLASH] = ACTIONS(1),
    [anon_sym_T] = ACTIONS(1),
    [anon_sym_DOT2] = ACTIONS(1),
    [anon_sym_POUND2] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_BSLASH_RBRACK] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [sym_checksum_flag] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [aux_sym_number_literal_token2] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(741),
    [sym_comment] = STATE(1),
    [sym_assignment] = STATE(727),
    [sym_variable_name] = STATE(726),
    [sym_function] = STATE(35),
    [sym_function_name] = STATE(721),
    [sym_handler] = STATE(35),
    [aux_sym_source_file_repeat1] = STATE(35),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_SEMI] = ACTIONS(7),
    [anon_sym_POUND] = ACTIONS(9),
    [anon_sym_AT] = ACTIONS(11),
    [sym__identifier] = ACTIONS(13),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 17,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(17), 1,
      anon_sym_DOLLAR,
    ACTIONS(21), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_DQUOTE,
    ACTIONS(25), 1,
      anon_sym_SQUOTE,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(33), 1,
      sym_ascii_name,
    STATE(2), 1,
      sym_comment,
    STATE(6), 1,
      aux_sym_string_repeat1,
    STATE(10), 1,
      sym_number_literal,
    STATE(476), 1,
      sym__value,
    ACTIONS(19), 2,
      anon_sym_Error,
      anon_sym_Ignore,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(421), 2,
      sym_keyword,
      sym_string,
    STATE(24), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [58] = 16,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(17), 1,
      anon_sym_DOLLAR,
    ACTIONS(23), 1,
      anon_sym_DQUOTE,
    ACTIONS(25), 1,
      anon_sym_SQUOTE,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(33), 1,
      sym_ascii_name,
    STATE(3), 1,
      sym_comment,
    STATE(6), 1,
      aux_sym_string_repeat1,
    STATE(10), 1,
      sym_number_literal,
    STATE(498), 1,
      sym__value,
    ACTIONS(19), 2,
      anon_sym_Error,
      anon_sym_Ignore,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(421), 2,
      sym_keyword,
      sym_string,
    STATE(24), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [113] = 16,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(17), 1,
      anon_sym_DOLLAR,
    ACTIONS(23), 1,
      anon_sym_DQUOTE,
    ACTIONS(25), 1,
      anon_sym_SQUOTE,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(33), 1,
      sym_ascii_name,
    STATE(4), 1,
      sym_comment,
    STATE(6), 1,
      aux_sym_string_repeat1,
    STATE(10), 1,
      sym_number_literal,
    STATE(634), 1,
      sym__value,
    ACTIONS(19), 2,
      anon_sym_Error,
      anon_sym_Ignore,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(421), 2,
      sym_keyword,
      sym_string,
    STATE(24), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [168] = 16,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(17), 1,
      anon_sym_DOLLAR,
    ACTIONS(23), 1,
      anon_sym_DQUOTE,
    ACTIONS(25), 1,
      anon_sym_SQUOTE,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(33), 1,
      sym_ascii_name,
    STATE(5), 1,
      sym_comment,
    STATE(6), 1,
      aux_sym_string_repeat1,
    STATE(10), 1,
      sym_number_literal,
    STATE(487), 1,
      sym__value,
    ACTIONS(19), 2,
      anon_sym_Error,
      anon_sym_Ignore,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(421), 2,
      sym_keyword,
      sym_string,
    STATE(24), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [223] = 13,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(17), 1,
      anon_sym_DOLLAR,
    ACTIONS(23), 1,
      anon_sym_DQUOTE,
    ACTIONS(25), 1,
      anon_sym_SQUOTE,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(35), 1,
      sym_ascii_name,
    STATE(6), 1,
      sym_comment,
    STATE(7), 1,
      aux_sym_string_repeat1,
    STATE(10), 1,
      sym_number_literal,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(28), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [267] = 12,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(37), 1,
      anon_sym_DOLLAR,
    ACTIONS(40), 1,
      anon_sym_DQUOTE,
    ACTIONS(43), 1,
      anon_sym_SQUOTE,
    ACTIONS(46), 1,
      anon_sym_DASH,
    ACTIONS(49), 1,
      aux_sym_number_literal_token1,
    ACTIONS(55), 1,
      sym_ascii_name,
    STATE(10), 1,
      sym_number_literal,
    ACTIONS(52), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    STATE(7), 2,
      sym_comment,
      aux_sym_string_repeat1,
    STATE(26), 2,
      sym__double_quoted_string,
      sym__single_quoted_string,
    STATE(85), 3,
      sym_variable,
      sym_quoted_literal,
      sym_number,
  [309] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(58), 1,
      anon_sym_LPAREN2,
    ACTIONS(60), 1,
      aux_sym_format_converter_token1,
    ACTIONS(62), 1,
      anon_sym_DOT,
    ACTIONS(64), 1,
      aux_sym_format_converter_token2,
    ACTIONS(66), 1,
      anon_sym_LBRACK,
    ACTIONS(68), 1,
      anon_sym_LBRACE2,
    ACTIONS(70), 1,
      anon_sym_B,
    ACTIONS(72), 1,
      anon_sym_LT,
    ACTIONS(74), 1,
      anon_sym_SLASH,
    ACTIONS(76), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(78), 1,
      anon_sym_T,
    STATE(8), 1,
      sym_comment,
    STATE(34), 1,
      sym_format_flag,
    ACTIONS(80), 2,
      anon_sym_POUND2,
      aux_sym_format_flag_token1,
  [356] = 15,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(82), 1,
      anon_sym_LPAREN2,
    ACTIONS(84), 1,
      aux_sym_format_converter_token1,
    ACTIONS(86), 1,
      anon_sym_DOT,
    ACTIONS(88), 1,
      aux_sym_format_converter_token2,
    ACTIONS(90), 1,
      anon_sym_LBRACK,
    ACTIONS(92), 1,
      anon_sym_LBRACE2,
    ACTIONS(94), 1,
      anon_sym_B,
    ACTIONS(96), 1,
      anon_sym_LT,
    ACTIONS(98), 1,
      anon_sym_SLASH,
    ACTIONS(100), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(102), 1,
      anon_sym_T,
    STATE(9), 1,
      sym_comment,
    STATE(33), 1,
      sym_format_flag,
    ACTIONS(80), 2,
      anon_sym_POUND2,
      aux_sym_format_flag_token1,
  [403] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(10), 1,
      sym_comment,
    ACTIONS(106), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(104), 11,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [427] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(108), 1,
      aux_sym_format_converter_token1,
    ACTIONS(110), 1,
      anon_sym_DOT,
    ACTIONS(112), 1,
      aux_sym_format_converter_token2,
    ACTIONS(114), 1,
      anon_sym_LBRACK,
    ACTIONS(116), 1,
      anon_sym_LBRACE2,
    ACTIONS(118), 1,
      anon_sym_B,
    ACTIONS(120), 1,
      anon_sym_LT,
    ACTIONS(122), 1,
      anon_sym_SLASH,
    ACTIONS(124), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(126), 1,
      anon_sym_T,
    STATE(11), 1,
      sym_comment,
    STATE(41), 1,
      sym_format_flag,
    ACTIONS(80), 2,
      anon_sym_POUND2,
      aux_sym_format_flag_token1,
  [471] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(128), 1,
      anon_sym_DQUOTE,
    ACTIONS(130), 1,
      sym__quoted_string_text_fragment,
    ACTIONS(132), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(136), 1,
      anon_sym_PERCENT,
    STATE(12), 1,
      sym_comment,
    STATE(18), 1,
      aux_sym__double_quoted_string_repeat1,
    STATE(61), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [505] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(13), 1,
      sym_comment,
    ACTIONS(138), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(142), 3,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
      sym_ascii_name,
    ACTIONS(140), 8,
      anon_sym_DOLLAR,
      anon_sym_Error,
      anon_sym_Ignore,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
  [531] = 11,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(146), 1,
      aux_sym_record_name_token1,
    ACTIONS(148), 1,
      sym__identifier,
    STATE(14), 1,
      sym_comment,
    STATE(40), 1,
      aux_sym_record_name_repeat1,
    STATE(92), 1,
      sym_escape_sequence,
    STATE(96), 1,
      aux_sym_field_name_repeat1,
    STATE(460), 1,
      sym_record_name,
    STATE(585), 1,
      sym_field_name,
    STATE(623), 1,
      sym_format_inout,
    ACTIONS(144), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [569] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(150), 1,
      anon_sym_SQUOTE,
    ACTIONS(152), 1,
      sym__quoted_string_text_fragment2,
    ACTIONS(154), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(158), 1,
      anon_sym_PERCENT,
    STATE(15), 1,
      sym_comment,
    STATE(16), 1,
      aux_sym__single_quoted_string_repeat1,
    STATE(64), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [603] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(160), 1,
      anon_sym_SQUOTE,
    ACTIONS(162), 1,
      sym__quoted_string_text_fragment2,
    ACTIONS(165), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(171), 1,
      anon_sym_PERCENT,
    STATE(16), 2,
      sym_comment,
      aux_sym__single_quoted_string_repeat1,
    STATE(64), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(168), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [635] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(17), 1,
      sym_comment,
    ACTIONS(176), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(174), 11,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [659] = 8,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(178), 1,
      anon_sym_DQUOTE,
    ACTIONS(180), 1,
      sym__quoted_string_text_fragment,
    ACTIONS(183), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(189), 1,
      anon_sym_PERCENT,
    STATE(18), 2,
      sym_comment,
      aux_sym__double_quoted_string_repeat1,
    STATE(61), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(186), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [691] = 14,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(192), 1,
      aux_sym_format_converter_token1,
    ACTIONS(194), 1,
      anon_sym_DOT,
    ACTIONS(196), 1,
      aux_sym_format_converter_token2,
    ACTIONS(198), 1,
      anon_sym_LBRACK,
    ACTIONS(200), 1,
      anon_sym_LBRACE2,
    ACTIONS(202), 1,
      anon_sym_B,
    ACTIONS(204), 1,
      anon_sym_LT,
    ACTIONS(206), 1,
      anon_sym_SLASH,
    ACTIONS(208), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(210), 1,
      anon_sym_T,
    STATE(19), 1,
      sym_comment,
    STATE(37), 1,
      sym_format_flag,
    ACTIONS(80), 2,
      anon_sym_POUND2,
      aux_sym_format_flag_token1,
  [735] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(130), 1,
      sym__quoted_string_text_fragment,
    ACTIONS(132), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(136), 1,
      anon_sym_PERCENT,
    ACTIONS(212), 1,
      anon_sym_DQUOTE,
    STATE(12), 1,
      aux_sym__double_quoted_string_repeat1,
    STATE(20), 1,
      sym_comment,
    STATE(61), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [769] = 9,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(152), 1,
      sym__quoted_string_text_fragment2,
    ACTIONS(154), 1,
      anon_sym_BSLASH_DOLLAR,
    ACTIONS(158), 1,
      anon_sym_PERCENT,
    ACTIONS(214), 1,
      anon_sym_SQUOTE,
    STATE(15), 1,
      aux_sym__single_quoted_string_repeat1,
    STATE(21), 1,
      sym_comment,
    STATE(64), 3,
      sym_variable_expansion,
      sym_escape_sequence,
      sym_format_converter,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [803] = 11,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(146), 1,
      aux_sym_record_name_token1,
    ACTIONS(148), 1,
      sym__identifier,
    STATE(22), 1,
      sym_comment,
    STATE(40), 1,
      aux_sym_record_name_repeat1,
    STATE(92), 1,
      sym_escape_sequence,
    STATE(96), 1,
      aux_sym_field_name_repeat1,
    STATE(460), 1,
      sym_record_name,
    STATE(585), 1,
      sym_field_name,
    STATE(771), 1,
      sym_format_inout,
    ACTIONS(144), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [841] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(23), 1,
      sym_comment,
    ACTIONS(218), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(216), 11,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_PIPE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [865] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(224), 1,
      anon_sym_COMMA,
    STATE(24), 1,
      sym_comment,
    ACTIONS(226), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(220), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(222), 6,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [892] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(25), 1,
      sym_comment,
    ACTIONS(230), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(228), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [915] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(26), 1,
      sym_comment,
    ACTIONS(234), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(232), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [938] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(236), 1,
      anon_sym_EQ,
    STATE(27), 1,
      sym_comment,
    ACTIONS(142), 3,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
      sym_ascii_name,
    ACTIONS(140), 8,
      anon_sym_DOLLAR,
      anon_sym_Error,
      anon_sym_Ignore,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
  [963] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(224), 1,
      anon_sym_COMMA,
    STATE(28), 1,
      sym_comment,
    ACTIONS(226), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(238), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(222), 6,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [990] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(29), 1,
      sym_comment,
    ACTIONS(242), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(240), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [1013] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(30), 1,
      sym_comment,
    ACTIONS(246), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(244), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [1036] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(31), 1,
      sym_comment,
    ACTIONS(250), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(248), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [1059] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(32), 1,
      sym_comment,
    ACTIONS(254), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(252), 10,
      anon_sym_SEMI,
      anon_sym_DOLLAR,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [1082] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(256), 1,
      aux_sym_format_converter_token1,
    ACTIONS(258), 1,
      anon_sym_DOT,
    ACTIONS(260), 1,
      aux_sym_format_converter_token2,
    ACTIONS(262), 1,
      anon_sym_LBRACK,
    ACTIONS(264), 1,
      anon_sym_LBRACE2,
    ACTIONS(266), 1,
      anon_sym_B,
    ACTIONS(268), 1,
      anon_sym_LT,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(274), 1,
      anon_sym_T,
    STATE(33), 1,
      sym_comment,
  [1119] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(276), 1,
      aux_sym_format_converter_token1,
    ACTIONS(278), 1,
      anon_sym_DOT,
    ACTIONS(280), 1,
      aux_sym_format_converter_token2,
    ACTIONS(282), 1,
      anon_sym_LBRACK,
    ACTIONS(284), 1,
      anon_sym_LBRACE2,
    ACTIONS(286), 1,
      anon_sym_B,
    ACTIONS(288), 1,
      anon_sym_LT,
    ACTIONS(290), 1,
      anon_sym_SLASH,
    ACTIONS(292), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(294), 1,
      anon_sym_T,
    STATE(34), 1,
      sym_comment,
  [1156] = 10,
    ACTIONS(9), 1,
      anon_sym_POUND,
    ACTIONS(11), 1,
      anon_sym_AT,
    ACTIONS(13), 1,
      sym__identifier,
    ACTIONS(296), 1,
      ts_builtin_sym_end,
    ACTIONS(298), 1,
      anon_sym_SEMI,
    STATE(35), 1,
      sym_comment,
    STATE(721), 1,
      sym_function_name,
    STATE(726), 1,
      sym_variable_name,
    STATE(727), 1,
      sym_assignment,
    STATE(39), 3,
      sym_function,
      sym_handler,
      aux_sym_source_file_repeat1,
  [1189] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(305), 1,
      aux_sym_record_name_token1,
    STATE(273), 1,
      sym_escape_sequence,
    ACTIONS(303), 2,
      anon_sym_RPAREN2,
      anon_sym_DOT2,
    STATE(36), 2,
      sym_comment,
      aux_sym_record_name_repeat1,
    ACTIONS(300), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1214] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(308), 1,
      aux_sym_format_converter_token1,
    ACTIONS(310), 1,
      anon_sym_DOT,
    ACTIONS(312), 1,
      aux_sym_format_converter_token2,
    ACTIONS(314), 1,
      anon_sym_LBRACK,
    ACTIONS(316), 1,
      anon_sym_LBRACE2,
    ACTIONS(318), 1,
      anon_sym_B,
    ACTIONS(320), 1,
      anon_sym_LT,
    ACTIONS(322), 1,
      anon_sym_SLASH,
    ACTIONS(324), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(326), 1,
      anon_sym_T,
    STATE(37), 1,
      sym_comment,
  [1251] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(38), 1,
      sym_comment,
    ACTIONS(328), 10,
      aux_sym_format_converter_token1,
      anon_sym_DOT,
      aux_sym_format_converter_token2,
      anon_sym_LBRACK,
      anon_sym_LBRACE2,
      anon_sym_B,
      anon_sym_LT,
      anon_sym_SLASH,
      anon_sym_POUND_SLASH,
      anon_sym_T,
  [1270] = 9,
    ACTIONS(330), 1,
      ts_builtin_sym_end,
    ACTIONS(332), 1,
      anon_sym_SEMI,
    ACTIONS(335), 1,
      anon_sym_POUND,
    ACTIONS(338), 1,
      anon_sym_AT,
    ACTIONS(341), 1,
      sym__identifier,
    STATE(721), 1,
      sym_function_name,
    STATE(726), 1,
      sym_variable_name,
    STATE(727), 1,
      sym_assignment,
    STATE(39), 4,
      sym_comment,
      sym_function,
      sym_handler,
      aux_sym_source_file_repeat1,
  [1301] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(146), 1,
      aux_sym_record_name_token1,
    STATE(36), 1,
      aux_sym_record_name_repeat1,
    STATE(40), 1,
      sym_comment,
    STATE(273), 1,
      sym_escape_sequence,
    ACTIONS(344), 2,
      anon_sym_RPAREN2,
      anon_sym_DOT2,
    ACTIONS(144), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1328] = 12,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(346), 1,
      aux_sym_format_converter_token1,
    ACTIONS(348), 1,
      anon_sym_DOT,
    ACTIONS(350), 1,
      aux_sym_format_converter_token2,
    ACTIONS(352), 1,
      anon_sym_LBRACK,
    ACTIONS(354), 1,
      anon_sym_LBRACE2,
    ACTIONS(356), 1,
      anon_sym_B,
    ACTIONS(358), 1,
      anon_sym_LT,
    ACTIONS(360), 1,
      anon_sym_SLASH,
    ACTIONS(362), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(364), 1,
      anon_sym_T,
    STATE(41), 1,
      sym_comment,
  [1365] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(42), 1,
      sym_comment,
    ACTIONS(366), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(368), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1385] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(43), 1,
      sym_comment,
    ACTIONS(370), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(372), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1405] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(44), 1,
      sym_comment,
    ACTIONS(374), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(376), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1425] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(45), 1,
      sym_comment,
    ACTIONS(378), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(380), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1445] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(46), 1,
      sym_comment,
    ACTIONS(382), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(384), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1465] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(47), 1,
      sym_comment,
    ACTIONS(386), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(388), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1485] = 9,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(390), 1,
      anon_sym_RBRACE,
    ACTIONS(392), 1,
      anon_sym_AT,
    ACTIONS(394), 1,
      sym__identifier,
    STATE(2), 1,
      sym_command_name,
    STATE(48), 1,
      sym_comment,
    STATE(57), 1,
      aux_sym_function_repeat1,
    STATE(726), 1,
      sym_variable_name,
    STATE(489), 3,
      sym_assignment,
      sym_command,
      sym_handler,
  [1515] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(49), 1,
      sym_comment,
    ACTIONS(396), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(398), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1535] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(50), 1,
      sym_comment,
    ACTIONS(400), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(402), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1555] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(51), 1,
      sym_comment,
    ACTIONS(404), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(406), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1575] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(52), 1,
      sym_comment,
    ACTIONS(408), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(410), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1595] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(53), 1,
      sym_comment,
    ACTIONS(412), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(414), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1615] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(54), 1,
      sym_comment,
    ACTIONS(416), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(418), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1635] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(55), 1,
      sym_comment,
    ACTIONS(420), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(422), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1655] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(56), 1,
      sym_comment,
    ACTIONS(424), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(426), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1675] = 9,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(392), 1,
      anon_sym_AT,
    ACTIONS(394), 1,
      sym__identifier,
    ACTIONS(428), 1,
      anon_sym_RBRACE,
    STATE(2), 1,
      sym_command_name,
    STATE(57), 1,
      sym_comment,
    STATE(70), 1,
      aux_sym_function_repeat1,
    STATE(726), 1,
      sym_variable_name,
    STATE(450), 3,
      sym_assignment,
      sym_command,
      sym_handler,
  [1705] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(430), 1,
      anon_sym_DOT,
    ACTIONS(432), 1,
      aux_sym_format_converter_token2,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(436), 1,
      anon_sym_LBRACE2,
    ACTIONS(438), 1,
      anon_sym_B,
    ACTIONS(440), 1,
      anon_sym_LT,
    ACTIONS(442), 1,
      anon_sym_SLASH,
    ACTIONS(444), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(446), 1,
      anon_sym_T,
    STATE(58), 1,
      sym_comment,
  [1739] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(59), 1,
      sym_comment,
    ACTIONS(448), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(450), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1759] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(60), 1,
      sym_comment,
    ACTIONS(452), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(454), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1779] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(61), 1,
      sym_comment,
    ACTIONS(456), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(458), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1799] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(62), 1,
      sym_comment,
    ACTIONS(460), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(462), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1819] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(63), 1,
      sym_comment,
    ACTIONS(464), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(466), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1839] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(64), 1,
      sym_comment,
    ACTIONS(468), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(470), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1859] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(65), 1,
      sym_comment,
    ACTIONS(472), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(474), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1879] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(66), 1,
      sym_comment,
    ACTIONS(476), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(478), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1899] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(67), 1,
      sym_comment,
    ACTIONS(480), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(482), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1919] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(68), 1,
      sym_comment,
    ACTIONS(484), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(486), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1939] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(69), 1,
      sym_comment,
    ACTIONS(488), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(490), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [1959] = 8,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(492), 1,
      anon_sym_RBRACE,
    ACTIONS(494), 1,
      anon_sym_AT,
    ACTIONS(497), 1,
      sym__identifier,
    STATE(2), 1,
      sym_command_name,
    STATE(726), 1,
      sym_variable_name,
    STATE(70), 2,
      sym_comment,
      aux_sym_function_repeat1,
    STATE(630), 3,
      sym_assignment,
      sym_command,
      sym_handler,
  [1987] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(71), 1,
      sym_comment,
    ACTIONS(500), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(502), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2007] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(72), 1,
      sym_comment,
    ACTIONS(504), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(506), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2027] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(73), 1,
      sym_comment,
    ACTIONS(508), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(510), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2047] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(74), 1,
      sym_comment,
    ACTIONS(512), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(514), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2067] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(516), 1,
      anon_sym_DOT,
    ACTIONS(518), 1,
      aux_sym_format_converter_token2,
    ACTIONS(520), 1,
      anon_sym_LBRACK,
    ACTIONS(522), 1,
      anon_sym_LBRACE2,
    ACTIONS(524), 1,
      anon_sym_B,
    ACTIONS(526), 1,
      anon_sym_LT,
    ACTIONS(528), 1,
      anon_sym_SLASH,
    ACTIONS(530), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(532), 1,
      anon_sym_T,
    STATE(75), 1,
      sym_comment,
  [2101] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(76), 1,
      sym_comment,
    ACTIONS(534), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(536), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2121] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(77), 1,
      sym_comment,
    ACTIONS(538), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(540), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2141] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(78), 1,
      sym_comment,
    ACTIONS(542), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(544), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2161] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(79), 1,
      sym_comment,
    ACTIONS(546), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(548), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2181] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(80), 1,
      sym_comment,
    ACTIONS(550), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(552), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2201] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(554), 1,
      anon_sym_DOT,
    ACTIONS(556), 1,
      aux_sym_format_converter_token2,
    ACTIONS(558), 1,
      anon_sym_LBRACK,
    ACTIONS(560), 1,
      anon_sym_LBRACE2,
    ACTIONS(562), 1,
      anon_sym_B,
    ACTIONS(564), 1,
      anon_sym_LT,
    ACTIONS(566), 1,
      anon_sym_SLASH,
    ACTIONS(568), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(570), 1,
      anon_sym_T,
    STATE(81), 1,
      sym_comment,
  [2235] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(82), 1,
      sym_comment,
    ACTIONS(572), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(574), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2255] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(83), 1,
      sym_comment,
    ACTIONS(576), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(578), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2275] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(84), 1,
      sym_comment,
    ACTIONS(580), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(582), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2295] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(224), 1,
      anon_sym_COMMA,
    STATE(85), 1,
      sym_comment,
    ACTIONS(226), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(222), 6,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [2317] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(86), 1,
      sym_comment,
    ACTIONS(584), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(586), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2337] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(87), 1,
      sym_comment,
    ACTIONS(588), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(590), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2357] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(88), 1,
      sym_comment,
    ACTIONS(592), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(594), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2377] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(89), 1,
      sym_comment,
    ACTIONS(596), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(598), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2397] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(90), 1,
      sym_comment,
    ACTIONS(600), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(602), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2417] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(91), 1,
      sym_comment,
    ACTIONS(604), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(606), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2437] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(610), 1,
      sym__identifier,
    STATE(92), 1,
      sym_comment,
    ACTIONS(608), 8,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RPAREN2,
      anon_sym_DOT2,
      aux_sym_record_name_token1,
  [2457] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(93), 1,
      sym_comment,
    ACTIONS(612), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(614), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2477] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(616), 1,
      anon_sym_DOT,
    ACTIONS(618), 1,
      aux_sym_format_converter_token2,
    ACTIONS(620), 1,
      anon_sym_LBRACK,
    ACTIONS(622), 1,
      anon_sym_LBRACE2,
    ACTIONS(624), 1,
      anon_sym_B,
    ACTIONS(626), 1,
      anon_sym_LT,
    ACTIONS(628), 1,
      anon_sym_SLASH,
    ACTIONS(630), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(632), 1,
      anon_sym_T,
    STATE(94), 1,
      sym_comment,
  [2511] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(95), 1,
      sym_comment,
    ACTIONS(634), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(636), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2531] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(640), 1,
      anon_sym_RPAREN2,
    ACTIONS(642), 1,
      sym__identifier,
    STATE(96), 1,
      sym_comment,
    STATE(135), 1,
      aux_sym_field_name_repeat1,
    STATE(290), 1,
      sym_escape_sequence,
    ACTIONS(638), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2557] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(97), 1,
      sym_comment,
    ACTIONS(644), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(646), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2577] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(98), 1,
      sym_comment,
    ACTIONS(648), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(650), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2597] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(99), 1,
      sym_comment,
    ACTIONS(652), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(654), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2617] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(100), 1,
      sym_comment,
    ACTIONS(656), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(658), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2637] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(101), 1,
      sym_comment,
    ACTIONS(660), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(662), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2657] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(102), 1,
      sym_comment,
    ACTIONS(664), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(666), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2677] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(668), 1,
      anon_sym_DOT,
    ACTIONS(670), 1,
      aux_sym_format_converter_token2,
    ACTIONS(672), 1,
      anon_sym_LBRACK,
    ACTIONS(674), 1,
      anon_sym_LBRACE2,
    ACTIONS(676), 1,
      anon_sym_B,
    ACTIONS(678), 1,
      anon_sym_LT,
    ACTIONS(680), 1,
      anon_sym_SLASH,
    ACTIONS(682), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(684), 1,
      anon_sym_T,
    STATE(103), 1,
      sym_comment,
  [2711] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(686), 1,
      anon_sym_DOT,
    ACTIONS(688), 1,
      aux_sym_format_converter_token2,
    ACTIONS(690), 1,
      anon_sym_LBRACK,
    ACTIONS(692), 1,
      anon_sym_LBRACE2,
    ACTIONS(694), 1,
      anon_sym_B,
    ACTIONS(696), 1,
      anon_sym_LT,
    ACTIONS(698), 1,
      anon_sym_SLASH,
    ACTIONS(700), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(702), 1,
      anon_sym_T,
    STATE(104), 1,
      sym_comment,
  [2745] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(105), 1,
      sym_comment,
    ACTIONS(704), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(706), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2765] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(106), 1,
      sym_comment,
    ACTIONS(708), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(710), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2785] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(107), 1,
      sym_comment,
    ACTIONS(712), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(714), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2805] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(108), 1,
      sym_comment,
    ACTIONS(716), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(718), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2825] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(109), 1,
      sym_comment,
    ACTIONS(720), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(722), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2845] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(110), 1,
      sym_comment,
    ACTIONS(724), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(726), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2865] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(111), 1,
      sym_comment,
    ACTIONS(728), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(730), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2885] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(464), 1,
      sym__identifier,
    STATE(112), 1,
      sym_comment,
    ACTIONS(466), 8,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RPAREN2,
      anon_sym_DOT2,
      aux_sym_record_name_token1,
  [2905] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(113), 1,
      sym_comment,
    ACTIONS(732), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(734), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2925] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(114), 1,
      sym_comment,
    ACTIONS(736), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(738), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2945] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(115), 1,
      sym_comment,
    ACTIONS(740), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(742), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2965] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(116), 1,
      sym_comment,
    ACTIONS(366), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(368), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [2985] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(117), 1,
      sym_comment,
    ACTIONS(744), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(746), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3005] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(118), 1,
      sym_comment,
    ACTIONS(748), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(750), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3025] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(119), 1,
      sym_comment,
    ACTIONS(736), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(738), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3045] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(120), 1,
      sym_comment,
    ACTIONS(724), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(726), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3065] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(121), 1,
      sym_comment,
    ACTIONS(720), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(722), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3085] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(752), 1,
      anon_sym_DOT,
    ACTIONS(754), 1,
      aux_sym_format_converter_token2,
    ACTIONS(756), 1,
      anon_sym_LBRACK,
    ACTIONS(758), 1,
      anon_sym_LBRACE2,
    ACTIONS(760), 1,
      anon_sym_B,
    ACTIONS(762), 1,
      anon_sym_LT,
    ACTIONS(764), 1,
      anon_sym_SLASH,
    ACTIONS(766), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(768), 1,
      anon_sym_T,
    STATE(122), 1,
      sym_comment,
  [3119] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(123), 1,
      sym_comment,
    ACTIONS(370), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(372), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3139] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(124), 1,
      sym_comment,
    ACTIONS(748), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(750), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3159] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(125), 1,
      sym_comment,
    ACTIONS(716), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(718), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3179] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(126), 1,
      sym_comment,
    ACTIONS(744), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(746), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3199] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(127), 1,
      sym_comment,
    ACTIONS(712), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(714), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3219] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(128), 1,
      sym_comment,
    ACTIONS(704), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(706), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3239] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(129), 1,
      sym_comment,
    ACTIONS(664), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(666), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3259] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(130), 1,
      sym_comment,
    ACTIONS(660), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(662), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3279] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(131), 1,
      sym_comment,
    ACTIONS(732), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(734), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3299] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(132), 1,
      sym_comment,
    ACTIONS(464), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(466), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3319] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(642), 1,
      sym__identifier,
    STATE(96), 1,
      aux_sym_field_name_repeat1,
    STATE(133), 1,
      sym_comment,
    STATE(290), 1,
      sym_escape_sequence,
    STATE(543), 1,
      sym_field_name,
    ACTIONS(638), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3345] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(134), 1,
      sym_comment,
    ACTIONS(770), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(772), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3365] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(777), 1,
      anon_sym_RPAREN2,
    ACTIONS(779), 1,
      sym__identifier,
    STATE(290), 1,
      sym_escape_sequence,
    STATE(135), 2,
      sym_comment,
      aux_sym_field_name_repeat1,
    ACTIONS(774), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3389] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(136), 1,
      sym_comment,
    ACTIONS(512), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(514), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3409] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(137), 1,
      sym_comment,
    ACTIONS(782), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(784), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3429] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(138), 1,
      sym_comment,
    ACTIONS(538), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(540), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3449] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(139), 1,
      sym_comment,
    ACTIONS(656), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(658), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3469] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(140), 1,
      sym_comment,
    ACTIONS(648), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(650), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3489] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(141), 1,
      sym_comment,
    ACTIONS(652), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(654), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3509] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(142), 1,
      sym_comment,
    ACTIONS(644), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(646), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3529] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(143), 1,
      sym_comment,
    ACTIONS(612), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(614), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3549] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(144), 1,
      sym_comment,
    ACTIONS(604), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(606), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3569] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(145), 1,
      sym_comment,
    ACTIONS(600), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(602), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3589] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(146), 1,
      sym_comment,
    ACTIONS(786), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(788), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3609] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(147), 1,
      sym_comment,
    ACTIONS(708), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(710), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3629] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(148), 1,
      sym_comment,
    ACTIONS(596), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(598), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3649] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(149), 1,
      sym_comment,
    ACTIONS(728), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(730), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3669] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(150), 1,
      sym_comment,
    ACTIONS(782), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(784), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3689] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(151), 1,
      sym_comment,
    ACTIONS(592), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(594), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3709] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(152), 1,
      sym_comment,
    ACTIONS(588), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(590), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3729] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(153), 1,
      sym_comment,
    ACTIONS(576), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(578), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3749] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(154), 1,
      sym_comment,
    ACTIONS(572), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(574), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3769] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(155), 1,
      sym_comment,
    ACTIONS(790), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(792), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3789] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(156), 1,
      sym_comment,
    ACTIONS(546), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(548), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3809] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(157), 1,
      sym_comment,
    ACTIONS(794), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(796), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3829] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(158), 1,
      sym_comment,
    ACTIONS(542), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(544), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3849] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(159), 1,
      sym_comment,
    ACTIONS(786), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(788), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3869] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(160), 1,
      sym_comment,
    ACTIONS(534), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(536), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3889] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(161), 1,
      sym_comment,
    ACTIONS(508), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(510), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3909] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(162), 1,
      sym_comment,
    ACTIONS(500), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(502), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3929] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(163), 1,
      sym_comment,
    ACTIONS(488), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(490), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3949] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(164), 1,
      sym_comment,
    ACTIONS(484), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(486), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3969] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(165), 1,
      sym_comment,
    ACTIONS(476), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(478), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [3989] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(166), 1,
      sym_comment,
    ACTIONS(472), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(474), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4009] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(167), 1,
      sym_comment,
    ACTIONS(798), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(800), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4029] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(168), 1,
      sym_comment,
    ACTIONS(790), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(792), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4049] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(169), 1,
      sym_comment,
    ACTIONS(798), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(800), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4069] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(170), 1,
      sym_comment,
    ACTIONS(802), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(804), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4089] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(171), 1,
      sym_comment,
    ACTIONS(460), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(462), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4109] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(172), 1,
      sym_comment,
    ACTIONS(448), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(450), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4129] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(173), 1,
      sym_comment,
    ACTIONS(806), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(808), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4149] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(174), 1,
      sym_comment,
    ACTIONS(424), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(426), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4169] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(175), 1,
      sym_comment,
    ACTIONS(810), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(812), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4189] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(176), 1,
      sym_comment,
    ACTIONS(420), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(422), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4209] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(177), 1,
      sym_comment,
    ACTIONS(416), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(418), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4229] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(178), 1,
      sym_comment,
    ACTIONS(814), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(816), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4249] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(179), 1,
      sym_comment,
    ACTIONS(408), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(410), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4269] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(180), 1,
      sym_comment,
    ACTIONS(378), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(380), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4289] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(181), 1,
      sym_comment,
    ACTIONS(818), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4309] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(182), 1,
      sym_comment,
    ACTIONS(404), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(406), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4329] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(183), 1,
      sym_comment,
    ACTIONS(386), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(388), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4349] = 11,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(822), 1,
      anon_sym_DOT,
    ACTIONS(824), 1,
      aux_sym_format_converter_token2,
    ACTIONS(826), 1,
      anon_sym_LBRACK,
    ACTIONS(828), 1,
      anon_sym_LBRACE2,
    ACTIONS(830), 1,
      anon_sym_B,
    ACTIONS(832), 1,
      anon_sym_LT,
    ACTIONS(834), 1,
      anon_sym_SLASH,
    ACTIONS(836), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(838), 1,
      anon_sym_T,
    STATE(184), 1,
      sym_comment,
  [4383] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(185), 1,
      sym_comment,
    ACTIONS(400), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(402), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4403] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(186), 1,
      sym_comment,
    ACTIONS(802), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(804), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4423] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(187), 1,
      sym_comment,
    ACTIONS(806), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(808), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4443] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(188), 1,
      sym_comment,
    ACTIONS(382), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(384), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4463] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(189), 1,
      sym_comment,
    ACTIONS(794), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(796), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4483] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(190), 1,
      sym_comment,
    ACTIONS(770), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(772), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4503] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(191), 1,
      sym_comment,
    ACTIONS(374), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(376), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4523] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(192), 1,
      sym_comment,
    ACTIONS(396), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(398), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4543] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(193), 1,
      sym_comment,
    ACTIONS(412), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(414), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4563] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(194), 1,
      sym_comment,
    ACTIONS(740), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(742), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4583] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(195), 1,
      sym_comment,
    ACTIONS(634), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(636), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4603] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(196), 1,
      sym_comment,
    ACTIONS(810), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(812), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4623] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(197), 1,
      sym_comment,
    ACTIONS(818), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(820), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4643] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(198), 1,
      sym_comment,
    ACTIONS(452), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(454), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4663] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(199), 1,
      sym_comment,
    ACTIONS(584), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(586), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4683] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(200), 1,
      sym_comment,
    ACTIONS(580), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(582), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4703] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(201), 1,
      sym_comment,
    ACTIONS(480), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(482), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4723] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(202), 1,
      sym_comment,
    ACTIONS(504), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(506), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4743] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(203), 1,
      sym_comment,
    ACTIONS(550), 3,
      anon_sym_SQUOTE,
      sym__quoted_string_text_fragment2,
      anon_sym_PERCENT,
    ACTIONS(552), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4763] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(204), 1,
      sym_comment,
    ACTIONS(814), 3,
      anon_sym_DQUOTE,
      sym__quoted_string_text_fragment,
      anon_sym_PERCENT,
    ACTIONS(816), 6,
      anon_sym_BSLASH_DOLLAR,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4783] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(52), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(205), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4806] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(206), 1,
      sym_comment,
    STATE(229), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4829] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(188), 1,
      sym__char,
    STATE(207), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4852] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(848), 1,
      aux_sym_format_converter_token2,
    ACTIONS(850), 1,
      anon_sym_LBRACK,
    ACTIONS(852), 1,
      anon_sym_LBRACE2,
    ACTIONS(854), 1,
      anon_sym_B,
    ACTIONS(856), 1,
      anon_sym_LT,
    ACTIONS(858), 1,
      anon_sym_SLASH,
    ACTIONS(860), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(862), 1,
      anon_sym_T,
    STATE(208), 1,
      sym_comment,
  [4883] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(176), 1,
      sym__char,
    STATE(209), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4906] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(192), 1,
      sym__char,
    STATE(210), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4929] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(84), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(211), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4952] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(212), 1,
      sym_comment,
    STATE(235), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4975] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(172), 1,
      sym__char,
    STATE(213), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [4998] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(214), 1,
      sym_comment,
    STATE(254), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5021] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(202), 1,
      sym__char,
    STATE(215), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5044] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(216), 1,
      sym_comment,
    STATE(226), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5067] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(200), 1,
      sym__char,
    STATE(217), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5090] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(163), 1,
      sym__char,
    STATE(218), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5113] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(186), 1,
      sym__char,
    STATE(219), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5136] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(864), 1,
      aux_sym_format_converter_token2,
    ACTIONS(866), 1,
      anon_sym_LBRACK,
    ACTIONS(868), 1,
      anon_sym_LBRACE2,
    ACTIONS(870), 1,
      anon_sym_B,
    ACTIONS(872), 1,
      anon_sym_LT,
    ACTIONS(874), 1,
      anon_sym_SLASH,
    ACTIONS(876), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(878), 1,
      anon_sym_T,
    STATE(220), 1,
      sym_comment,
  [5167] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(880), 1,
      aux_sym_format_converter_token2,
    ACTIONS(882), 1,
      anon_sym_LBRACK,
    ACTIONS(884), 1,
      anon_sym_LBRACE2,
    ACTIONS(886), 1,
      anon_sym_B,
    ACTIONS(888), 1,
      anon_sym_LT,
    ACTIONS(890), 1,
      anon_sym_SLASH,
    ACTIONS(892), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(894), 1,
      anon_sym_T,
    STATE(221), 1,
      sym_comment,
  [5198] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(156), 1,
      sym__char,
    STATE(222), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5221] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(223), 1,
      sym_comment,
    STATE(225), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5244] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(170), 1,
      sym__char,
    STATE(224), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5267] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(72), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(225), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5290] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(152), 1,
      sym__char,
    STATE(226), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5313] = 9,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(27), 1,
      anon_sym_DASH,
    ACTIONS(29), 1,
      aux_sym_number_literal_token1,
    ACTIONS(35), 1,
      sym_ascii_name,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    STATE(10), 1,
      sym_number_literal,
    STATE(227), 1,
      sym_comment,
    STATE(502), 1,
      sym_number,
    ACTIONS(31), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
  [5342] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(898), 1,
      aux_sym_format_converter_token2,
    ACTIONS(900), 1,
      anon_sym_LBRACK,
    ACTIONS(902), 1,
      anon_sym_LBRACE2,
    ACTIONS(904), 1,
      anon_sym_B,
    ACTIONS(906), 1,
      anon_sym_LT,
    ACTIONS(908), 1,
      anon_sym_SLASH,
    ACTIONS(910), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(912), 1,
      anon_sym_T,
    STATE(228), 1,
      sym_comment,
  [5373] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(143), 1,
      sym__char,
    STATE(229), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5396] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(222), 1,
      sym__char,
    STATE(230), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5419] = 9,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(896), 1,
      anon_sym_QMARK,
    ACTIONS(914), 1,
      anon_sym_DASH,
    ACTIONS(916), 1,
      aux_sym_number_literal_token1,
    ACTIONS(920), 1,
      sym_ascii_name,
    STATE(231), 1,
      sym_comment,
    STATE(491), 1,
      sym_number_literal,
    STATE(502), 1,
      sym_number,
    ACTIONS(918), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
  [5448] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(69), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(232), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5471] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(178), 1,
      sym__char,
    STATE(233), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5494] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(205), 1,
      sym__char,
    STATE(234), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5517] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(129), 1,
      sym__char,
    STATE(235), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5540] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(168), 1,
      sym__char,
    STATE(236), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5563] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(211), 1,
      sym__char,
    STATE(237), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5586] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(238), 1,
      sym_comment,
    STATE(266), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5609] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(204), 1,
      sym__char,
    STATE(239), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5632] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(121), 1,
      sym__char,
    STATE(240), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5655] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(922), 1,
      aux_sym_format_converter_token2,
    ACTIONS(924), 1,
      anon_sym_LBRACK,
    ACTIONS(926), 1,
      anon_sym_LBRACE2,
    ACTIONS(928), 1,
      anon_sym_B,
    ACTIONS(930), 1,
      anon_sym_LT,
    ACTIONS(932), 1,
      anon_sym_SLASH,
    ACTIONS(934), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(936), 1,
      anon_sym_T,
    STATE(241), 1,
      sym_comment,
  [5686] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(242), 1,
      sym_comment,
    STATE(257), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5709] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(938), 1,
      aux_sym_format_converter_token2,
    ACTIONS(940), 1,
      anon_sym_LBRACK,
    ACTIONS(942), 1,
      anon_sym_LBRACE2,
    ACTIONS(944), 1,
      anon_sym_B,
    ACTIONS(946), 1,
      anon_sym_LT,
    ACTIONS(948), 1,
      anon_sym_SLASH,
    ACTIONS(950), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(952), 1,
      anon_sym_T,
    STATE(243), 1,
      sym_comment,
  [5740] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(954), 1,
      aux_sym_format_converter_token2,
    ACTIONS(956), 1,
      anon_sym_LBRACK,
    ACTIONS(958), 1,
      anon_sym_LBRACE2,
    ACTIONS(960), 1,
      anon_sym_B,
    ACTIONS(962), 1,
      anon_sym_LT,
    ACTIONS(964), 1,
      anon_sym_SLASH,
    ACTIONS(966), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(968), 1,
      anon_sym_T,
    STATE(244), 1,
      sym_comment,
  [5771] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(245), 1,
      sym_comment,
    STATE(255), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5794] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(240), 1,
      sym__char,
    STATE(246), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5817] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(59), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(247), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5840] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(219), 1,
      sym__char,
    STATE(248), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5863] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(218), 1,
      sym__char,
    STATE(249), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5886] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(970), 1,
      aux_sym_format_converter_token2,
    ACTIONS(972), 1,
      anon_sym_LBRACK,
    ACTIONS(974), 1,
      anon_sym_LBRACE2,
    ACTIONS(976), 1,
      anon_sym_B,
    ACTIONS(978), 1,
      anon_sym_LT,
    ACTIONS(980), 1,
      anon_sym_SLASH,
    ACTIONS(982), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(984), 1,
      anon_sym_T,
    STATE(250), 1,
      sym_comment,
  [5917] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(155), 1,
      sym__char,
    STATE(251), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5940] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(252), 1,
      sym_comment,
    STATE(288), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5963] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(213), 1,
      sym__char,
    STATE(253), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [5986] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(49), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(254), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6009] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(55), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(255), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6032] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(986), 1,
      aux_sym_format_converter_token2,
    ACTIONS(988), 1,
      anon_sym_LBRACK,
    ACTIONS(990), 1,
      anon_sym_LBRACE2,
    ACTIONS(992), 1,
      anon_sym_B,
    ACTIONS(994), 1,
      anon_sym_LT,
    ACTIONS(996), 1,
      anon_sym_SLASH,
    ACTIONS(998), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1000), 1,
      anon_sym_T,
    STATE(256), 1,
      sym_comment,
  [6063] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(79), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(257), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6086] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1002), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1004), 1,
      anon_sym_LBRACK,
    ACTIONS(1006), 1,
      anon_sym_LBRACE2,
    ACTIONS(1008), 1,
      anon_sym_B,
    ACTIONS(1010), 1,
      anon_sym_LT,
    ACTIONS(1012), 1,
      anon_sym_SLASH,
    ACTIONS(1014), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1016), 1,
      anon_sym_T,
    STATE(258), 1,
      sym_comment,
  [6117] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1018), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1022), 1,
      anon_sym_LBRACE2,
    ACTIONS(1024), 1,
      anon_sym_B,
    ACTIONS(1026), 1,
      anon_sym_LT,
    ACTIONS(1028), 1,
      anon_sym_SLASH,
    ACTIONS(1030), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1032), 1,
      anon_sym_T,
    STATE(259), 1,
      sym_comment,
  [6148] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1034), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1036), 1,
      anon_sym_LBRACK,
    ACTIONS(1038), 1,
      anon_sym_LBRACE2,
    ACTIONS(1040), 1,
      anon_sym_B,
    ACTIONS(1042), 1,
      anon_sym_LT,
    ACTIONS(1044), 1,
      anon_sym_SLASH,
    ACTIONS(1046), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1048), 1,
      anon_sym_T,
    STATE(260), 1,
      sym_comment,
  [6179] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(236), 1,
      sym__char,
    STATE(261), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6202] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(209), 1,
      sym__char,
    STATE(262), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6225] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(239), 1,
      sym__char,
    STATE(263), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6248] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(247), 1,
      sym__char,
    STATE(264), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6271] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(109), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(265), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6294] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(87), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(266), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6317] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1050), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1052), 1,
      anon_sym_LBRACK,
    ACTIONS(1054), 1,
      anon_sym_LBRACE2,
    ACTIONS(1056), 1,
      anon_sym_B,
    ACTIONS(1058), 1,
      anon_sym_LT,
    ACTIONS(1060), 1,
      anon_sym_SLASH,
    ACTIONS(1062), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1064), 1,
      anon_sym_T,
    STATE(267), 1,
      sym_comment,
  [6348] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(268), 1,
      sym_comment,
    ACTIONS(1068), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
    ACTIONS(1066), 6,
      anon_sym_DOLLAR,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      anon_sym_DASH,
      aux_sym_number_literal_token1,
      sym_ascii_name,
  [6367] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(269), 1,
      sym_comment,
    STATE(272), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6390] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(846), 1,
      aux_sym__char_token1,
    STATE(111), 1,
      sym_escape_sequence,
    STATE(179), 1,
      sym__char,
    STATE(270), 1,
      sym_comment,
    ACTIONS(156), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6413] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(271), 1,
      sym_comment,
    STATE(275), 1,
      sym__char,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6436] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(46), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(272), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6459] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(273), 1,
      sym_comment,
    ACTIONS(608), 8,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RPAREN2,
      anon_sym_DOT2,
      aux_sym_record_name_token1,
  [6476] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(224), 1,
      sym__char,
    STATE(274), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6499] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(102), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(275), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6522] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1070), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1072), 1,
      anon_sym_LBRACK,
    ACTIONS(1074), 1,
      anon_sym_LBRACE2,
    ACTIONS(1076), 1,
      anon_sym_B,
    ACTIONS(1078), 1,
      anon_sym_LT,
    ACTIONS(1080), 1,
      anon_sym_SLASH,
    ACTIONS(1082), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1084), 1,
      anon_sym_T,
    STATE(276), 1,
      sym_comment,
  [6553] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(270), 1,
      sym__char,
    STATE(277), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6576] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(217), 1,
      sym__char,
    STATE(278), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6599] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(265), 1,
      sym__char,
    STATE(279), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6622] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(233), 1,
      sym__char,
    STATE(280), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6645] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1086), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1088), 1,
      anon_sym_LBRACK,
    ACTIONS(1090), 1,
      anon_sym_LBRACE2,
    ACTIONS(1092), 1,
      anon_sym_B,
    ACTIONS(1094), 1,
      anon_sym_LT,
    ACTIONS(1096), 1,
      anon_sym_SLASH,
    ACTIONS(1098), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1100), 1,
      anon_sym_T,
    STATE(281), 1,
      sym_comment,
  [6676] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(215), 1,
      sym__char,
    STATE(282), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6699] = 10,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1102), 1,
      aux_sym_format_converter_token2,
    ACTIONS(1104), 1,
      anon_sym_LBRACK,
    ACTIONS(1106), 1,
      anon_sym_LBRACE2,
    ACTIONS(1108), 1,
      anon_sym_B,
    ACTIONS(1110), 1,
      anon_sym_LT,
    ACTIONS(1112), 1,
      anon_sym_SLASH,
    ACTIONS(1114), 1,
      anon_sym_POUND_SLASH,
    ACTIONS(1116), 1,
      anon_sym_T,
    STATE(283), 1,
      sym_comment,
  [6730] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(251), 1,
      sym__char,
    STATE(284), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6753] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(207), 1,
      sym__char,
    STATE(285), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6776] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(210), 1,
      sym__char,
    STATE(286), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6799] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(844), 1,
      aux_sym__char_token1,
    STATE(232), 1,
      sym__char,
    STATE(287), 1,
      sym_comment,
    STATE(312), 1,
      sym_escape_sequence,
    ACTIONS(842), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6822] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(840), 1,
      aux_sym__char_token1,
    STATE(93), 1,
      sym__char,
    STATE(149), 1,
      sym_escape_sequence,
    STATE(288), 1,
      sym_comment,
    ACTIONS(134), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [6845] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(289), 1,
      sym_comment,
    ACTIONS(466), 7,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RPAREN2,
      sym__identifier,
  [6861] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(290), 1,
      sym_comment,
    ACTIONS(1118), 7,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
      anon_sym_RPAREN2,
      sym__identifier,
  [6877] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_RBRACK,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    STATE(291), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(637), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [6900] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1126), 1,
      anon_sym_RBRACK,
    STATE(292), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(654), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [6923] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1128), 1,
      anon_sym_RBRACK,
    STATE(293), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(672), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [6946] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1130), 1,
      anon_sym_RBRACK,
    STATE(294), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(842), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [6969] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1132), 1,
      anon_sym_RBRACK,
    STATE(295), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(699), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [6992] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1134), 1,
      anon_sym_RBRACE,
    ACTIONS(1136), 1,
      sym__identifier,
    STATE(2), 1,
      sym_command_name,
    STATE(296), 1,
      sym_comment,
    STATE(307), 1,
      aux_sym_handler_repeat1,
    STATE(457), 2,
      sym_function_name,
      sym_command,
  [7015] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1138), 1,
      anon_sym_RBRACK,
    STATE(297), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(648), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7038] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1140), 1,
      anon_sym_RBRACK,
    STATE(298), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(688), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7061] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(280), 1,
      anon_sym_RBRACK,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    STATE(299), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(605), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7084] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1142), 1,
      anon_sym_RBRACK,
    STATE(300), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(602), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7107] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1144), 1,
      anon_sym_RBRACK,
    STATE(301), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(683), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7130] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1146), 1,
      anon_sym_RBRACK,
    STATE(302), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(626), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7153] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1148), 1,
      anon_sym_RBRACK,
    STATE(303), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(853), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7176] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(260), 1,
      anon_sym_RBRACK,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    STATE(304), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(616), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7199] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1150), 1,
      anon_sym_RBRACK,
    STATE(305), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(584), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7222] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1136), 1,
      sym__identifier,
    ACTIONS(1152), 1,
      anon_sym_RBRACE,
    STATE(2), 1,
      sym_command_name,
    STATE(306), 1,
      sym_comment,
    STATE(310), 1,
      aux_sym_handler_repeat1,
    STATE(467), 2,
      sym_function_name,
      sym_command,
  [7245] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1136), 1,
      sym__identifier,
    ACTIONS(1154), 1,
      anon_sym_RBRACE,
    STATE(2), 1,
      sym_command_name,
    STATE(307), 1,
      sym_comment,
    STATE(310), 1,
      aux_sym_handler_repeat1,
    STATE(454), 2,
      sym_function_name,
      sym_command,
  [7268] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1156), 1,
      anon_sym_RBRACK,
    STATE(308), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(578), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7291] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1158), 1,
      anon_sym_RBRACK,
    STATE(309), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(722), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7314] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1160), 1,
      anon_sym_RBRACE,
    ACTIONS(1162), 1,
      sym__identifier,
    STATE(2), 1,
      sym_command_name,
    STATE(310), 2,
      sym_comment,
      aux_sym_handler_repeat1,
    STATE(508), 2,
      sym_function_name,
      sym_command,
  [7335] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1165), 1,
      anon_sym_RBRACK,
    STATE(311), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(776), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7358] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(728), 1,
      aux_sym__char_token1,
    STATE(312), 1,
      sym_comment,
    ACTIONS(730), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [7375] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1167), 1,
      anon_sym_RBRACK,
    STATE(313), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(687), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7398] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1169), 1,
      anon_sym_RBRACK,
    STATE(314), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(705), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7421] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1171), 1,
      anon_sym_RBRACK,
    STATE(315), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(556), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7444] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1173), 1,
      anon_sym_RBRACK,
    STATE(316), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(813), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7467] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1175), 1,
      anon_sym_RBRACK,
    STATE(317), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(803), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7490] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1177), 1,
      anon_sym_RBRACK,
    STATE(318), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(745), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7513] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1179), 1,
      anon_sym_RBRACK,
    STATE(319), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(534), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7536] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1181), 1,
      anon_sym_RBRACK,
    STATE(320), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(716), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7559] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(464), 1,
      aux_sym__char_token1,
    STATE(321), 1,
      sym_comment,
    ACTIONS(466), 5,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
      anon_sym_PERCENT_PERCENT,
  [7576] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1183), 1,
      anon_sym_RBRACK,
    STATE(322), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(754), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7599] = 7,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1136), 1,
      sym__identifier,
    ACTIONS(1185), 1,
      anon_sym_RBRACE,
    STATE(2), 1,
      sym_command_name,
    STATE(306), 1,
      aux_sym_handler_repeat1,
    STATE(323), 1,
      sym_comment,
    STATE(451), 2,
      sym_function_name,
      sym_command,
  [7622] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(350), 1,
      anon_sym_RBRACK,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    STATE(324), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(665), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7645] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1187), 1,
      anon_sym_RBRACK,
    STATE(325), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(523), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7668] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(312), 1,
      anon_sym_RBRACK,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    STATE(326), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(548), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7691] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1189), 1,
      anon_sym_RBRACK,
    STATE(327), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(591), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7714] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1191), 1,
      anon_sym_RBRACK,
    STATE(328), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(734), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7737] = 7,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1122), 1,
      anon_sym_CARET,
    ACTIONS(1193), 1,
      anon_sym_RBRACK,
    STATE(329), 1,
      sym_comment,
    STATE(370), 1,
      aux_sym_charset_repeat1,
    STATE(802), 1,
      sym_charset,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [7760] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(330), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(774), 1,
      sym_timeformat,
  [7779] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(331), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(618), 1,
      sym_format_enum,
  [7798] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(332), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(600), 1,
      sym_format_enum,
  [7817] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(333), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(763), 1,
      sym_timeformat,
  [7836] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(334), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(653), 1,
      sym_timeformat,
  [7855] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(335), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(760), 1,
      sym_timeformat,
  [7874] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1201), 1,
      anon_sym_RPAREN2,
    ACTIONS(1203), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1206), 1,
      sym_time_conversion_spec,
    STATE(336), 2,
      sym_comment,
      aux_sym_timeformat_repeat1,
  [7891] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(337), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(779), 1,
      sym_format_enum,
  [7910] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(338), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(755), 1,
      sym_format_enum,
  [7929] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(339), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(799), 1,
      sym_format_enum,
  [7948] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(340), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(805), 1,
      sym_format_enum,
  [7967] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(341), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(752), 1,
      sym_timeformat,
  [7986] = 2,
    STATE(342), 1,
      sym_comment,
    ACTIONS(1209), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [7997] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(343), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(511), 1,
      sym_timeformat,
  [8016] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(344), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(746), 1,
      sym_format_enum,
  [8035] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(345), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(744), 1,
      sym_timeformat,
  [8054] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(346), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(864), 1,
      sym_timeformat,
  [8073] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(347), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(522), 1,
      sym_format_enum,
  [8092] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(348), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(740), 1,
      sym_timeformat,
  [8111] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(349), 1,
      sym_comment,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(780), 1,
      sym_timeformat,
  [8130] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    ACTIONS(1211), 1,
      anon_sym_RPAREN2,
    STATE(336), 1,
      aux_sym_timeformat_repeat1,
    STATE(350), 1,
      sym_comment,
  [8149] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(351), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(852), 1,
      sym_format_enum,
  [8168] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(352), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(735), 1,
      sym_format_enum,
  [8187] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(353), 1,
      sym_comment,
    STATE(732), 1,
      sym_timeformat,
  [8206] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(354), 1,
      sym_comment,
    STATE(532), 1,
      sym_timeformat,
  [8225] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(355), 1,
      sym_comment,
    STATE(729), 1,
      sym_timeformat,
  [8244] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1213), 1,
      anon_sym_RBRACK,
    ACTIONS(1215), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
    STATE(356), 2,
      sym_comment,
      aux_sym_charset_repeat1,
  [8259] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1218), 1,
      anon_sym_RBRACK,
    STATE(356), 1,
      aux_sym_charset_repeat1,
    STATE(357), 1,
      sym_comment,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [8276] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(358), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(533), 1,
      sym_format_enum,
  [8295] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(359), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(723), 1,
      sym_format_enum,
  [8314] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(360), 1,
      sym_comment,
    STATE(617), 1,
      sym_timeformat,
  [8333] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(361), 1,
      sym_comment,
    STATE(535), 1,
      sym_timeformat,
  [8352] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(362), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(717), 1,
      sym_format_enum,
  [8371] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(363), 1,
      sym_comment,
    STATE(509), 1,
      sym_timeformat,
  [8390] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(364), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(555), 1,
      sym_format_enum,
  [8409] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(365), 1,
      sym_comment,
    STATE(711), 1,
      sym_timeformat,
  [8428] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(366), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(811), 1,
      sym_format_enum,
  [8447] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(367), 1,
      sym_comment,
    STATE(816), 1,
      sym_timeformat,
  [8466] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(368), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(680), 1,
      sym_format_enum,
  [8485] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(369), 1,
      sym_comment,
    STATE(564), 1,
      sym_timeformat,
  [8504] = 5,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1220), 1,
      anon_sym_RBRACK,
    STATE(356), 1,
      aux_sym_charset_repeat1,
    STATE(370), 1,
      sym_comment,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [8521] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(371), 1,
      sym_comment,
    STATE(561), 1,
      sym_timeformat,
  [8540] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(372), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(706), 1,
      sym_format_enum,
  [8559] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(373), 1,
      sym_comment,
    STATE(703), 1,
      sym_timeformat,
  [8578] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(374), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(583), 1,
      sym_format_enum,
  [8597] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(375), 1,
      sym_comment,
    STATE(845), 1,
      sym_timeformat,
  [8616] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(376), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(700), 1,
      sym_format_enum,
  [8635] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(377), 1,
      sym_comment,
    STATE(695), 1,
      sym_timeformat,
  [8654] = 2,
    STATE(378), 1,
      sym_comment,
    ACTIONS(1222), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8665] = 2,
    STATE(379), 1,
      sym_comment,
    ACTIONS(1224), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8676] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(380), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(689), 1,
      sym_format_enum,
  [8695] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(381), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(599), 1,
      sym_format_enum,
  [8714] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(382), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(577), 1,
      sym_format_enum,
  [8733] = 2,
    STATE(383), 1,
      sym_comment,
    ACTIONS(1226), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8744] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(384), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(684), 1,
      sym_format_enum,
  [8763] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(385), 1,
      sym_comment,
    STATE(682), 1,
      sym_timeformat,
  [8782] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(386), 1,
      sym_comment,
    STATE(658), 1,
      sym_timeformat,
  [8801] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(387), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(841), 1,
      sym_format_enum,
  [8820] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(388), 1,
      sym_comment,
    STATE(678), 1,
      sym_timeformat,
  [8839] = 2,
    STATE(389), 1,
      sym_comment,
    ACTIONS(1228), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8850] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(390), 1,
      sym_comment,
    STATE(828), 1,
      sym_timeformat,
  [8869] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(391), 1,
      sym_comment,
    STATE(596), 1,
      sym_timeformat,
  [8888] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(392), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(673), 1,
      sym_format_enum,
  [8907] = 2,
    STATE(393), 1,
      sym_comment,
    ACTIONS(1230), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8918] = 2,
    STATE(394), 1,
      sym_comment,
    ACTIONS(1232), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [8929] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(395), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(666), 1,
      sym_format_enum,
  [8948] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(396), 1,
      sym_comment,
    STATE(661), 1,
      sym_timeformat,
  [8967] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(397), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(542), 1,
      sym_format_enum,
  [8986] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(398), 1,
      sym_comment,
    STATE(621), 1,
      sym_timeformat,
  [9005] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(399), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(627), 1,
      sym_format_enum,
  [9024] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(400), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(655), 1,
      sym_format_enum,
  [9043] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(401), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(614), 1,
      sym_format_enum,
  [9062] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(402), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(638), 1,
      sym_format_enum,
  [9081] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(403), 1,
      sym_comment,
    STATE(633), 1,
      sym_timeformat,
  [9100] = 2,
    STATE(404), 1,
      sym_comment,
    ACTIONS(330), 5,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_AT,
      sym__identifier,
  [9111] = 6,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(405), 1,
      sym_comment,
    STATE(439), 1,
      aux_sym_format_enum_repeat1,
    STATE(462), 1,
      sym_enum_specifier,
    STATE(649), 1,
      sym_format_enum,
  [9130] = 6,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1195), 1,
      aux_sym_timeformat_token1,
    ACTIONS(1197), 1,
      sym_time_conversion_spec,
    STATE(350), 1,
      aux_sym_timeformat_repeat1,
    STATE(406), 1,
      sym_comment,
    STATE(647), 1,
      sym_timeformat,
  [9149] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1234), 1,
      aux_sym_number_literal_token1,
    STATE(407), 1,
      sym_comment,
    ACTIONS(1236), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
  [9163] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1238), 1,
      sym_checksum_flag,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(408), 1,
      sym_comment,
    STATE(581), 1,
      sym_checksum,
  [9179] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1242), 1,
      sym_checksum_flag,
    STATE(409), 1,
      sym_comment,
    STATE(554), 1,
      sym_checksum,
  [9195] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1244), 1,
      sym_checksum_flag,
    STATE(410), 1,
      sym_comment,
    STATE(609), 1,
      sym_checksum,
  [9211] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1246), 1,
      sym_checksum_flag,
    STATE(411), 1,
      sym_comment,
    STATE(650), 1,
      sym_checksum,
  [9227] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1248), 1,
      sym_checksum_flag,
    STATE(412), 1,
      sym_comment,
    STATE(603), 1,
      sym_checksum,
  [9243] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1250), 1,
      sym_checksum_flag,
    STATE(413), 1,
      sym_comment,
    STATE(632), 1,
      sym_checksum,
  [9259] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1252), 1,
      sym_checksum_flag,
    STATE(414), 1,
      sym_comment,
    STATE(756), 1,
      sym_checksum,
  [9275] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1254), 1,
      sym_checksum_flag,
    STATE(415), 1,
      sym_comment,
    STATE(628), 1,
      sym_checksum,
  [9291] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1256), 1,
      sym_checksum_flag,
    STATE(416), 1,
      sym_comment,
    STATE(619), 1,
      sym_checksum,
  [9307] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1258), 1,
      sym_checksum_flag,
    STATE(417), 1,
      sym_comment,
    STATE(796), 1,
      sym_checksum,
  [9323] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(418), 1,
      sym_comment,
    ACTIONS(1260), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
  [9335] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1262), 1,
      sym_checksum_flag,
    STATE(419), 1,
      sym_comment,
    STATE(790), 1,
      sym_checksum,
  [9351] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1264), 1,
      sym_checksum_flag,
    STATE(420), 1,
      sym_comment,
    STATE(814), 1,
      sym_checksum,
  [9367] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(421), 1,
      sym_comment,
    ACTIONS(1266), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
  [9379] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1268), 1,
      sym_checksum_flag,
    STATE(422), 1,
      sym_comment,
    STATE(747), 1,
      sym_checksum,
  [9395] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1270), 1,
      sym_checksum_flag,
    STATE(423), 1,
      sym_comment,
    STATE(520), 1,
      sym_checksum,
  [9411] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1272), 1,
      sym_checksum_flag,
    STATE(424), 1,
      sym_comment,
    STATE(736), 1,
      sym_checksum,
  [9427] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1276), 1,
      aux_sym_timeformat_token1,
    STATE(425), 1,
      sym_comment,
    ACTIONS(1274), 2,
      anon_sym_RPAREN2,
      sym_time_conversion_spec,
  [9441] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1278), 1,
      sym_checksum_flag,
    STATE(426), 1,
      sym_comment,
    STATE(867), 1,
      sym_checksum,
  [9457] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1280), 1,
      sym_enum_constant,
    STATE(526), 1,
      sym_enum_specifier,
    STATE(427), 2,
      sym_comment,
      aux_sym_format_enum_repeat1,
  [9471] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1283), 1,
      sym_checksum_flag,
    STATE(428), 1,
      sym_comment,
    STATE(667), 1,
      sym_checksum,
  [9487] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(429), 1,
      sym_comment,
    ACTIONS(492), 3,
      anon_sym_RBRACE,
      anon_sym_AT,
      sym__identifier,
  [9499] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1285), 1,
      sym_checksum_flag,
    STATE(430), 1,
      sym_comment,
    STATE(674), 1,
      sym_checksum,
  [9515] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1287), 1,
      sym_checksum_flag,
    STATE(431), 1,
      sym_comment,
    STATE(839), 1,
      sym_checksum,
  [9531] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1289), 1,
      sym_checksum_flag,
    STATE(432), 1,
      sym_comment,
    STATE(724), 1,
      sym_checksum,
  [9547] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1291), 1,
      sym_checksum_flag,
    STATE(433), 1,
      sym_comment,
    STATE(656), 1,
      sym_checksum,
  [9563] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1293), 1,
      sym_checksum_flag,
    STATE(434), 1,
      sym_comment,
    STATE(531), 1,
      sym_checksum,
  [9579] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1295), 1,
      sym_checksum_flag,
    STATE(435), 1,
      sym_comment,
    STATE(718), 1,
      sym_checksum,
  [9595] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1297), 1,
      sym_checksum_flag,
    STATE(436), 1,
      sym_comment,
    STATE(567), 1,
      sym_checksum,
  [9611] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1299), 1,
      sym_checksum_flag,
    STATE(437), 1,
      sym_comment,
    STATE(671), 1,
      sym_checksum,
  [9627] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1301), 1,
      sym_checksum_flag,
    STATE(438), 1,
      sym_comment,
    STATE(685), 1,
      sym_checksum,
  [9643] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1199), 1,
      sym_enum_constant,
    STATE(427), 1,
      aux_sym_format_enum_repeat1,
    STATE(439), 1,
      sym_comment,
    STATE(475), 1,
      sym_enum_specifier,
  [9659] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1303), 1,
      sym_checksum_flag,
    STATE(440), 1,
      sym_comment,
    STATE(572), 1,
      sym_checksum,
  [9675] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1305), 1,
      sym_checksum_flag,
    STATE(441), 1,
      sym_comment,
    STATE(594), 1,
      sym_checksum,
  [9691] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1307), 1,
      anon_sym_EQ,
    STATE(442), 1,
      sym_comment,
    ACTIONS(1309), 2,
      anon_sym_RBRACE2,
      anon_sym_PIPE,
  [9705] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1311), 1,
      sym_checksum_flag,
    STATE(443), 1,
      sym_comment,
    STATE(690), 1,
      sym_checksum,
  [9721] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1313), 1,
      sym_checksum_flag,
    STATE(444), 1,
      sym_comment,
    STATE(810), 1,
      sym_checksum,
  [9737] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1315), 1,
      sym_checksum_flag,
    STATE(445), 1,
      sym_comment,
    STATE(707), 1,
      sym_checksum,
  [9753] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1317), 1,
      aux_sym_number_literal_token1,
    STATE(446), 1,
      sym_comment,
    ACTIONS(1319), 2,
      aux_sym_number_literal_token2,
      aux_sym_number_literal_token3,
  [9767] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    STATE(357), 1,
      aux_sym_charset_repeat1,
    STATE(447), 1,
      sym_comment,
    ACTIONS(1124), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [9781] = 4,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1321), 1,
      anon_sym_RBRACK,
    STATE(448), 1,
      sym_comment,
    ACTIONS(1323), 2,
      aux_sym_charset_token1,
      anon_sym_BSLASH_RBRACK,
  [9795] = 5,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    ACTIONS(1325), 1,
      sym_checksum_flag,
    STATE(449), 1,
      sym_comment,
    STATE(694), 1,
      sym_checksum,
  [9811] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1327), 1,
      anon_sym_SEMI,
    ACTIONS(1329), 1,
      anon_sym_RBRACE,
    STATE(450), 1,
      sym_comment,
  [9824] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1152), 1,
      anon_sym_RBRACE,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    STATE(451), 1,
      sym_comment,
  [9837] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(452), 1,
      sym_comment,
    STATE(694), 1,
      sym_checksum,
  [9850] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(453), 1,
      sym_comment,
    STATE(565), 1,
      sym_checksum,
  [9863] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    ACTIONS(1333), 1,
      anon_sym_RBRACE,
    STATE(454), 1,
      sym_comment,
  [9876] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(455), 1,
      sym_comment,
    ACTIONS(1335), 2,
      aux_sym_variable_token1,
      aux_sym_variable_expansion_token1,
  [9887] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(456), 1,
      sym_comment,
    STATE(702), 1,
      sym_checksum,
  [9900] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_RBRACE,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    STATE(457), 1,
      sym_comment,
  [9913] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(458), 1,
      sym_comment,
    STATE(830), 1,
      sym_checksum,
  [9926] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1337), 1,
      aux_sym_variable_token1,
    STATE(459), 1,
      sym_comment,
    STATE(698), 1,
      sym_handler_name,
  [9939] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1339), 1,
      anon_sym_RPAREN2,
    ACTIONS(1341), 1,
      anon_sym_DOT2,
    STATE(460), 1,
      sym_comment,
  [9952] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(461), 1,
      sym_comment,
    STATE(849), 1,
      sym_checksum,
  [9965] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1343), 1,
      anon_sym_RBRACE2,
    ACTIONS(1345), 1,
      anon_sym_PIPE,
    STATE(462), 1,
      sym_comment,
  [9978] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(463), 1,
      sym_comment,
    STATE(819), 1,
      sym_checksum,
  [9991] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(464), 1,
      sym_comment,
    STATE(567), 1,
      sym_checksum,
  [10004] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(465), 1,
      sym_comment,
    STATE(662), 1,
      sym_checksum,
  [10017] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(466), 1,
      sym_comment,
    STATE(710), 1,
      sym_checksum,
  [10030] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    ACTIONS(1347), 1,
      anon_sym_RBRACE,
    STATE(467), 1,
      sym_comment,
  [10043] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(468), 1,
      sym_comment,
    STATE(537), 1,
      sym_checksum,
  [10056] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(469), 1,
      sym_comment,
    STATE(714), 1,
      sym_checksum,
  [10069] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(470), 1,
      sym_comment,
    STATE(681), 1,
      sym_checksum,
  [10082] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(471), 1,
      sym_comment,
    STATE(677), 1,
      sym_checksum,
  [10095] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(472), 1,
      sym_comment,
    ACTIONS(1160), 2,
      anon_sym_RBRACE,
      sym__identifier,
  [10106] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(473), 1,
      sym_comment,
    STATE(527), 1,
      sym_checksum,
  [10119] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(474), 1,
      sym_comment,
    STATE(728), 1,
      sym_checksum,
  [10132] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1345), 1,
      anon_sym_PIPE,
    ACTIONS(1349), 1,
      anon_sym_RBRACE2,
    STATE(475), 1,
      sym_comment,
  [10145] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(476), 1,
      sym_comment,
    ACTIONS(1351), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10156] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(477), 1,
      sym_comment,
    STATE(773), 1,
      sym_checksum,
  [10169] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(478), 1,
      sym_comment,
    ACTIONS(1353), 2,
      aux_sym_variable_token1,
      aux_sym_variable_expansion_token1,
  [10180] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1309), 1,
      anon_sym_PIPE,
    ACTIONS(1355), 1,
      anon_sym_EQ,
    STATE(479), 1,
      sym_comment,
  [10193] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(480), 1,
      sym_comment,
    STATE(731), 1,
      sym_checksum,
  [10206] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(481), 1,
      sym_comment,
    STATE(624), 1,
      sym_checksum,
  [10219] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(482), 1,
      sym_comment,
    STATE(739), 1,
      sym_checksum,
  [10232] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(483), 1,
      sym_comment,
    STATE(598), 1,
      sym_checksum,
  [10245] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(484), 1,
      sym_comment,
    STATE(512), 1,
      sym_checksum,
  [10258] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(485), 1,
      sym_comment,
    STATE(743), 1,
      sym_checksum,
  [10271] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(486), 1,
      sym_comment,
    STATE(783), 1,
      sym_checksum,
  [10284] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(487), 1,
      sym_comment,
    ACTIONS(1357), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10295] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(488), 1,
      sym_comment,
    STATE(867), 1,
      sym_checksum,
  [10308] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(428), 1,
      anon_sym_RBRACE,
    ACTIONS(1327), 1,
      anon_sym_SEMI,
    STATE(489), 1,
      sym_comment,
  [10321] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(490), 1,
      sym_comment,
    ACTIONS(216), 2,
      anon_sym_RBRACE2,
      anon_sym_PIPE,
  [10332] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(491), 1,
      sym_comment,
    ACTIONS(104), 2,
      anon_sym_RBRACE2,
      anon_sym_PIPE,
  [10343] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(492), 1,
      sym_comment,
    ACTIONS(1230), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10354] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(493), 1,
      sym_comment,
    STATE(660), 1,
      sym_checksum,
  [10367] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(494), 1,
      sym_comment,
    ACTIONS(174), 2,
      anon_sym_RBRACE2,
      anon_sym_PIPE,
  [10378] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(495), 1,
      sym_comment,
    ACTIONS(1226), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10389] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(496), 1,
      sym_comment,
    STATE(751), 1,
      sym_checksum,
  [10402] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(497), 1,
      sym_comment,
    ACTIONS(1222), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10413] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(498), 1,
      sym_comment,
    ACTIONS(1359), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [10424] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1337), 1,
      aux_sym_variable_token1,
    STATE(499), 1,
      sym_comment,
    STATE(766), 1,
      sym_handler_name,
  [10437] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(500), 1,
      sym_comment,
    STATE(697), 1,
      sym_checksum,
  [10450] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(138), 1,
      anon_sym_LBRACE,
    ACTIONS(236), 1,
      anon_sym_EQ,
    STATE(501), 1,
      sym_comment,
  [10463] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    STATE(502), 1,
      sym_comment,
    ACTIONS(1361), 2,
      anon_sym_RBRACE2,
      anon_sym_PIPE,
  [10474] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(503), 1,
      sym_comment,
    STATE(759), 1,
      sym_checksum,
  [10487] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(504), 1,
      sym_comment,
    STATE(644), 1,
      sym_checksum,
  [10500] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(505), 1,
      sym_comment,
    STATE(632), 1,
      sym_checksum,
  [10513] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(506), 1,
      sym_comment,
    STATE(762), 1,
      sym_checksum,
  [10526] = 4,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1240), 1,
      sym__identifier,
    STATE(507), 1,
      sym_comment,
    STATE(646), 1,
      sym_checksum,
  [10539] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    STATE(508), 1,
      sym_comment,
  [10549] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1363), 1,
      anon_sym_RPAREN2,
    STATE(509), 1,
      sym_comment,
  [10559] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1365), 1,
      anon_sym_LPAREN2,
    STATE(510), 1,
      sym_comment,
  [10569] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(312), 1,
      anon_sym_RPAREN2,
    STATE(511), 1,
      sym_comment,
  [10579] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(312), 1,
      anon_sym_GT,
    STATE(512), 1,
      sym_comment,
  [10589] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1367), 1,
      anon_sym_LPAREN2,
    STATE(513), 1,
      sym_comment,
  [10599] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1369), 1,
      sym_regex_pattern,
    STATE(514), 1,
      sym_comment,
  [10609] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1371), 1,
      sym_regex_pattern,
    STATE(515), 1,
      sym_comment,
  [10619] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1373), 1,
      anon_sym_SLASH,
    STATE(516), 1,
      sym_comment,
  [10629] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1375), 1,
      sym_regex_pattern,
    STATE(517), 1,
      sym_comment,
  [10639] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1377), 1,
      anon_sym_SLASH,
    STATE(518), 1,
      sym_comment,
  [10649] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1379), 1,
      anon_sym_SLASH,
    STATE(519), 1,
      sym_comment,
  [10659] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1379), 1,
      anon_sym_GT,
    STATE(520), 1,
      sym_comment,
  [10669] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1381), 1,
      sym_regex_pattern,
    STATE(521), 1,
      sym_comment,
  [10679] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1379), 1,
      anon_sym_RBRACE2,
    STATE(522), 1,
      sym_comment,
  [10689] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1379), 1,
      anon_sym_RBRACK,
    STATE(523), 1,
      sym_comment,
  [10699] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1383), 1,
      anon_sym_LPAREN2,
    STATE(524), 1,
      sym_comment,
  [10709] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(312), 1,
      anon_sym_SLASH,
    STATE(525), 1,
      sym_comment,
  [10719] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1345), 1,
      anon_sym_PIPE,
    STATE(526), 1,
      sym_comment,
  [10729] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1385), 1,
      anon_sym_GT,
    STATE(527), 1,
      sym_comment,
  [10739] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1387), 1,
      sym_regex_pattern,
    STATE(528), 1,
      sym_comment,
  [10749] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1389), 1,
      anon_sym_SLASH,
    STATE(529), 1,
      sym_comment,
  [10759] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1391), 1,
      anon_sym_SLASH,
    STATE(530), 1,
      sym_comment,
  [10769] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1391), 1,
      anon_sym_GT,
    STATE(531), 1,
      sym_comment,
  [10779] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1385), 1,
      anon_sym_RPAREN2,
    STATE(532), 1,
      sym_comment,
  [10789] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1391), 1,
      anon_sym_RBRACE2,
    STATE(533), 1,
      sym_comment,
  [10799] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1391), 1,
      anon_sym_RBRACK,
    STATE(534), 1,
      sym_comment,
  [10809] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1393), 1,
      anon_sym_RPAREN2,
    STATE(535), 1,
      sym_comment,
  [10819] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1395), 1,
      sym_regex_pattern,
    STATE(536), 1,
      sym_comment,
  [10829] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1393), 1,
      anon_sym_GT,
    STATE(537), 1,
      sym_comment,
  [10839] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1397), 1,
      anon_sym_LPAREN2,
    STATE(538), 1,
      sym_comment,
  [10849] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1399), 1,
      sym_regex_pattern,
    STATE(539), 1,
      sym_comment,
  [10859] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1401), 1,
      sym_regex_pattern,
    STATE(540), 1,
      sym_comment,
  [10869] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1148), 1,
      anon_sym_SLASH,
    STATE(541), 1,
      sym_comment,
  [10879] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1148), 1,
      anon_sym_RBRACE2,
    STATE(542), 1,
      sym_comment,
  [10889] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1403), 1,
      anon_sym_RPAREN2,
    STATE(543), 1,
      sym_comment,
  [10899] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1405), 1,
      anon_sym_LPAREN2,
    STATE(544), 1,
      sym_comment,
  [10909] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1407), 1,
      sym_regex_pattern,
    STATE(545), 1,
      sym_comment,
  [10919] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1409), 1,
      sym_regex_pattern,
    STATE(546), 1,
      sym_comment,
  [10929] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1411), 1,
      anon_sym_SLASH,
    STATE(547), 1,
      sym_comment,
  [10939] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1148), 1,
      anon_sym_RBRACK,
    STATE(548), 1,
      sym_comment,
  [10949] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1413), 1,
      aux_sym_format_converter_token1,
    STATE(549), 1,
      sym_comment,
  [10959] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1415), 1,
      anon_sym_SLASH,
    STATE(550), 1,
      sym_comment,
  [10969] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1417), 1,
      anon_sym_SLASH,
    STATE(551), 1,
      sym_comment,
  [10979] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(206), 1,
      anon_sym_SLASH,
    STATE(552), 1,
      sym_comment,
  [10989] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1419), 1,
      anon_sym_SLASH,
    STATE(553), 1,
      sym_comment,
  [10999] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1148), 1,
      anon_sym_GT,
    STATE(554), 1,
      sym_comment,
  [11009] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1419), 1,
      anon_sym_RBRACE2,
    STATE(555), 1,
      sym_comment,
  [11019] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1419), 1,
      anon_sym_RBRACK,
    STATE(556), 1,
      sym_comment,
  [11029] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1421), 1,
      anon_sym_LPAREN2,
    STATE(557), 1,
      sym_comment,
  [11039] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1423), 1,
      sym_regex_pattern,
    STATE(558), 1,
      sym_comment,
  [11049] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1425), 1,
      sym_regex_pattern,
    STATE(559), 1,
      sym_comment,
  [11059] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1427), 1,
      aux_sym_format_converter_token1,
    STATE(560), 1,
      sym_comment,
  [11069] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1429), 1,
      anon_sym_RPAREN2,
    STATE(561), 1,
      sym_comment,
  [11079] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1431), 1,
      aux_sym_format_converter_token1,
    STATE(562), 1,
      sym_comment,
  [11089] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1433), 1,
      sym_regex_pattern,
    STATE(563), 1,
      sym_comment,
  [11099] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1419), 1,
      anon_sym_RPAREN2,
    STATE(564), 1,
      sym_comment,
  [11109] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1429), 1,
      anon_sym_GT,
    STATE(565), 1,
      sym_comment,
  [11119] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1435), 1,
      sym_regex_pattern,
    STATE(566), 1,
      sym_comment,
  [11129] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1419), 1,
      anon_sym_GT,
    STATE(567), 1,
      sym_comment,
  [11139] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1437), 1,
      anon_sym_SLASH,
    STATE(568), 1,
      sym_comment,
  [11149] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1439), 1,
      anon_sym_SLASH,
    STATE(569), 1,
      sym_comment,
  [11159] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1441), 1,
      sym_enum_constant,
    STATE(570), 1,
      sym_comment,
  [11169] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1443), 1,
      anon_sym_SLASH,
    STATE(571), 1,
      sym_comment,
  [11179] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1443), 1,
      anon_sym_GT,
    STATE(572), 1,
      sym_comment,
  [11189] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1445), 1,
      anon_sym_LPAREN2,
    STATE(573), 1,
      sym_comment,
  [11199] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1447), 1,
      sym_regex_pattern,
    STATE(574), 1,
      sym_comment,
  [11209] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1449), 1,
      sym_regex_pattern,
    STATE(575), 1,
      sym_comment,
  [11219] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1451), 1,
      sym_regex_pattern,
    STATE(576), 1,
      sym_comment,
  [11229] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1443), 1,
      anon_sym_RBRACE2,
    STATE(577), 1,
      sym_comment,
  [11239] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1443), 1,
      anon_sym_RBRACK,
    STATE(578), 1,
      sym_comment,
  [11249] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1453), 1,
      anon_sym_SLASH,
    STATE(579), 1,
      sym_comment,
  [11259] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1455), 1,
      anon_sym_SLASH,
    STATE(580), 1,
      sym_comment,
  [11269] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1455), 1,
      anon_sym_GT,
    STATE(581), 1,
      sym_comment,
  [11279] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1457), 1,
      sym_regex_pattern,
    STATE(582), 1,
      sym_comment,
  [11289] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1455), 1,
      anon_sym_RBRACE2,
    STATE(583), 1,
      sym_comment,
  [11299] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1455), 1,
      anon_sym_RBRACK,
    STATE(584), 1,
      sym_comment,
  [11309] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1339), 1,
      anon_sym_RPAREN2,
    STATE(585), 1,
      sym_comment,
  [11319] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1459), 1,
      sym_regex_pattern,
    STATE(586), 1,
      sym_comment,
  [11329] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1461), 1,
      sym_regex_pattern,
    STATE(587), 1,
      sym_comment,
  [11339] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1463), 1,
      anon_sym_SLASH,
    STATE(588), 1,
      sym_comment,
  [11349] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1465), 1,
      anon_sym_LPAREN2,
    STATE(589), 1,
      sym_comment,
  [11359] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1467), 1,
      aux_sym_format_converter_token1,
    STATE(590), 1,
      sym_comment,
  [11369] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1469), 1,
      anon_sym_RBRACK,
    STATE(591), 1,
      sym_comment,
  [11379] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1471), 1,
      anon_sym_SLASH,
    STATE(592), 1,
      sym_comment,
  [11389] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1171), 1,
      anon_sym_SLASH,
    STATE(593), 1,
      sym_comment,
  [11399] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1171), 1,
      anon_sym_GT,
    STATE(594), 1,
      sym_comment,
  [11409] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1473), 1,
      anon_sym_GT,
    STATE(595), 1,
      sym_comment,
  [11419] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1475), 1,
      anon_sym_RPAREN2,
    STATE(596), 1,
      sym_comment,
  [11429] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1477), 1,
      sym_regex_pattern,
    STATE(597), 1,
      sym_comment,
  [11439] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1475), 1,
      anon_sym_GT,
    STATE(598), 1,
      sym_comment,
  [11449] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1171), 1,
      anon_sym_RBRACE2,
    STATE(599), 1,
      sym_comment,
  [11459] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1469), 1,
      anon_sym_RBRACE2,
    STATE(600), 1,
      sym_comment,
  [11469] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1479), 1,
      aux_sym_comment_token1,
    STATE(601), 1,
      sym_comment,
  [11479] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1481), 1,
      anon_sym_RBRACK,
    STATE(602), 1,
      sym_comment,
  [11489] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1469), 1,
      anon_sym_GT,
    STATE(603), 1,
      sym_comment,
  [11499] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1469), 1,
      anon_sym_SLASH,
    STATE(604), 1,
      sym_comment,
  [11509] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1171), 1,
      anon_sym_RBRACK,
    STATE(605), 1,
      sym_comment,
  [11519] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1483), 1,
      anon_sym_SLASH,
    STATE(606), 1,
      sym_comment,
  [11529] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1485), 1,
      anon_sym_SLASH,
    STATE(607), 1,
      sym_comment,
  [11539] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1481), 1,
      anon_sym_SLASH,
    STATE(608), 1,
      sym_comment,
  [11549] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1481), 1,
      anon_sym_GT,
    STATE(609), 1,
      sym_comment,
  [11559] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1487), 1,
      anon_sym_LPAREN2,
    STATE(610), 1,
      sym_comment,
  [11569] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1489), 1,
      sym_regex_pattern,
    STATE(611), 1,
      sym_comment,
  [11579] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1491), 1,
      sym_regex_pattern,
    STATE(612), 1,
      sym_comment,
  [11589] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1493), 1,
      anon_sym_SLASH,
    STATE(613), 1,
      sym_comment,
  [11599] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1481), 1,
      anon_sym_RBRACE2,
    STATE(614), 1,
      sym_comment,
  [11609] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1495), 1,
      aux_sym_format_converter_token1,
    STATE(615), 1,
      sym_comment,
  [11619] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_RBRACK,
    STATE(616), 1,
      sym_comment,
  [11629] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1497), 1,
      anon_sym_RPAREN2,
    STATE(617), 1,
      sym_comment,
  [11639] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_RBRACE2,
    STATE(618), 1,
      sym_comment,
  [11649] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_GT,
    STATE(619), 1,
      sym_comment,
  [11659] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1120), 1,
      anon_sym_SLASH,
    STATE(620), 1,
      sym_comment,
  [11669] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1499), 1,
      anon_sym_RPAREN2,
    STATE(621), 1,
      sym_comment,
  [11679] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1501), 1,
      sym_regex_pattern,
    STATE(622), 1,
      sym_comment,
  [11689] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1503), 1,
      anon_sym_RPAREN2,
    STATE(623), 1,
      sym_comment,
  [11699] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1499), 1,
      anon_sym_GT,
    STATE(624), 1,
      sym_comment,
  [11709] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1505), 1,
      anon_sym_SLASH,
    STATE(625), 1,
      sym_comment,
  [11719] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1507), 1,
      anon_sym_RBRACK,
    STATE(626), 1,
      sym_comment,
  [11729] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1507), 1,
      anon_sym_RBRACE2,
    STATE(627), 1,
      sym_comment,
  [11739] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1507), 1,
      anon_sym_GT,
    STATE(628), 1,
      sym_comment,
  [11749] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1507), 1,
      anon_sym_SLASH,
    STATE(629), 1,
      sym_comment,
  [11759] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1327), 1,
      anon_sym_SEMI,
    STATE(630), 1,
      sym_comment,
  [11769] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1509), 1,
      anon_sym_LPAREN2,
    STATE(631), 1,
      sym_comment,
  [11779] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_GT,
    STATE(632), 1,
      sym_comment,
  [11789] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_RPAREN2,
    STATE(633), 1,
      sym_comment,
  [11799] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1513), 1,
      anon_sym_RPAREN,
    STATE(634), 1,
      sym_comment,
  [11809] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1515), 1,
      anon_sym_LPAREN2,
    STATE(635), 1,
      sym_comment,
  [11819] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1517), 1,
      sym_regex_pattern,
    STATE(636), 1,
      sym_comment,
  [11829] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_RBRACK,
    STATE(637), 1,
      sym_comment,
  [11839] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_RBRACE2,
    STATE(638), 1,
      sym_comment,
  [11849] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1511), 1,
      anon_sym_SLASH,
    STATE(639), 1,
      sym_comment,
  [11859] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1519), 1,
      sym_regex_pattern,
    STATE(640), 1,
      sym_comment,
  [11869] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1521), 1,
      sym_regex_pattern,
    STATE(641), 1,
      sym_comment,
  [11879] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1523), 1,
      sym_regex_pattern,
    STATE(642), 1,
      sym_comment,
  [11889] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1525), 1,
      aux_sym_format_converter_token1,
    STATE(643), 1,
      sym_comment,
  [11899] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1527), 1,
      anon_sym_GT,
    STATE(644), 1,
      sym_comment,
  [11909] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1529), 1,
      sym_regex_pattern,
    STATE(645), 1,
      sym_comment,
  [11919] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1531), 1,
      anon_sym_GT,
    STATE(646), 1,
      sym_comment,
  [11929] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1531), 1,
      anon_sym_RPAREN2,
    STATE(647), 1,
      sym_comment,
  [11939] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1533), 1,
      anon_sym_RBRACK,
    STATE(648), 1,
      sym_comment,
  [11949] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1533), 1,
      anon_sym_RBRACE2,
    STATE(649), 1,
      sym_comment,
  [11959] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1533), 1,
      anon_sym_GT,
    STATE(650), 1,
      sym_comment,
  [11969] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1533), 1,
      anon_sym_SLASH,
    STATE(651), 1,
      sym_comment,
  [11979] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(350), 1,
      anon_sym_SLASH,
    STATE(652), 1,
      sym_comment,
  [11989] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1527), 1,
      anon_sym_RPAREN2,
    STATE(653), 1,
      sym_comment,
  [11999] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1535), 1,
      anon_sym_RBRACK,
    STATE(654), 1,
      sym_comment,
  [12009] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1535), 1,
      anon_sym_RBRACE2,
    STATE(655), 1,
      sym_comment,
  [12019] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1535), 1,
      anon_sym_GT,
    STATE(656), 1,
      sym_comment,
  [12029] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1535), 1,
      anon_sym_SLASH,
    STATE(657), 1,
      sym_comment,
  [12039] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1537), 1,
      anon_sym_RPAREN2,
    STATE(658), 1,
      sym_comment,
  [12049] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1539), 1,
      sym_regex_pattern,
    STATE(659), 1,
      sym_comment,
  [12059] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(350), 1,
      anon_sym_GT,
    STATE(660), 1,
      sym_comment,
  [12069] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(350), 1,
      anon_sym_RPAREN2,
    STATE(661), 1,
      sym_comment,
  [12079] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1537), 1,
      anon_sym_GT,
    STATE(662), 1,
      sym_comment,
  [12089] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1541), 1,
      anon_sym_SLASH,
    STATE(663), 1,
      sym_comment,
  [12099] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1543), 1,
      sym_regex_pattern,
    STATE(664), 1,
      sym_comment,
  [12109] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_RBRACK,
    STATE(665), 1,
      sym_comment,
  [12119] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_RBRACE2,
    STATE(666), 1,
      sym_comment,
  [12129] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_GT,
    STATE(667), 1,
      sym_comment,
  [12139] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1132), 1,
      anon_sym_SLASH,
    STATE(668), 1,
      sym_comment,
  [12149] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1545), 1,
      anon_sym_SLASH,
    STATE(669), 1,
      sym_comment,
  [12159] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1547), 1,
      anon_sym_SLASH,
    STATE(670), 1,
      sym_comment,
  [12169] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1547), 1,
      anon_sym_GT,
    STATE(671), 1,
      sym_comment,
  [12179] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1549), 1,
      anon_sym_RBRACK,
    STATE(672), 1,
      sym_comment,
  [12189] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1549), 1,
      anon_sym_RBRACE2,
    STATE(673), 1,
      sym_comment,
  [12199] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1549), 1,
      anon_sym_GT,
    STATE(674), 1,
      sym_comment,
  [12209] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1549), 1,
      anon_sym_SLASH,
    STATE(675), 1,
      sym_comment,
  [12219] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1551), 1,
      anon_sym_SLASH,
    STATE(676), 1,
      sym_comment,
  [12229] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1553), 1,
      anon_sym_GT,
    STATE(677), 1,
      sym_comment,
  [12239] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1553), 1,
      anon_sym_RPAREN2,
    STATE(678), 1,
      sym_comment,
  [12249] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1555), 1,
      sym_regex_pattern,
    STATE(679), 1,
      sym_comment,
  [12259] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1547), 1,
      anon_sym_RBRACE2,
    STATE(680), 1,
      sym_comment,
  [12269] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1557), 1,
      anon_sym_GT,
    STATE(681), 1,
      sym_comment,
  [12279] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1557), 1,
      anon_sym_RPAREN2,
    STATE(682), 1,
      sym_comment,
  [12289] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1559), 1,
      anon_sym_RBRACK,
    STATE(683), 1,
      sym_comment,
  [12299] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1559), 1,
      anon_sym_RBRACE2,
    STATE(684), 1,
      sym_comment,
  [12309] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1559), 1,
      anon_sym_GT,
    STATE(685), 1,
      sym_comment,
  [12319] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1559), 1,
      anon_sym_SLASH,
    STATE(686), 1,
      sym_comment,
  [12329] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1547), 1,
      anon_sym_RBRACK,
    STATE(687), 1,
      sym_comment,
  [12339] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1561), 1,
      anon_sym_RBRACK,
    STATE(688), 1,
      sym_comment,
  [12349] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1561), 1,
      anon_sym_RBRACE2,
    STATE(689), 1,
      sym_comment,
  [12359] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1561), 1,
      anon_sym_GT,
    STATE(690), 1,
      sym_comment,
  [12369] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1561), 1,
      anon_sym_SLASH,
    STATE(691), 1,
      sym_comment,
  [12379] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1563), 1,
      anon_sym_LPAREN2,
    STATE(692), 1,
      sym_comment,
  [12389] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1565), 1,
      anon_sym_SLASH,
    STATE(693), 1,
      sym_comment,
  [12399] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1567), 1,
      anon_sym_GT,
    STATE(694), 1,
      sym_comment,
  [12409] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1567), 1,
      anon_sym_RPAREN2,
    STATE(695), 1,
      sym_comment,
  [12419] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1569), 1,
      aux_sym_variable_token1,
    STATE(696), 1,
      sym_comment,
  [12429] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1571), 1,
      anon_sym_GT,
    STATE(697), 1,
      sym_comment,
  [12439] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1573), 1,
      anon_sym_LBRACE,
    STATE(698), 1,
      sym_comment,
  [12449] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1567), 1,
      anon_sym_RBRACK,
    STATE(699), 1,
      sym_comment,
  [12459] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1567), 1,
      anon_sym_RBRACE2,
    STATE(700), 1,
      sym_comment,
  [12469] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1567), 1,
      anon_sym_SLASH,
    STATE(701), 1,
      sym_comment,
  [12479] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1575), 1,
      anon_sym_GT,
    STATE(702), 1,
      sym_comment,
  [12489] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1575), 1,
      anon_sym_RPAREN2,
    STATE(703), 1,
      sym_comment,
  [12499] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1577), 1,
      anon_sym_SLASH,
    STATE(704), 1,
      sym_comment,
  [12509] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1579), 1,
      anon_sym_RBRACK,
    STATE(705), 1,
      sym_comment,
  [12519] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1579), 1,
      anon_sym_RBRACE2,
    STATE(706), 1,
      sym_comment,
  [12529] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1579), 1,
      anon_sym_GT,
    STATE(707), 1,
      sym_comment,
  [12539] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1579), 1,
      anon_sym_SLASH,
    STATE(708), 1,
      sym_comment,
  [12549] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1581), 1,
      anon_sym_SLASH,
    STATE(709), 1,
      sym_comment,
  [12559] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1583), 1,
      anon_sym_GT,
    STATE(710), 1,
      sym_comment,
  [12569] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1583), 1,
      anon_sym_RPAREN2,
    STATE(711), 1,
      sym_comment,
  [12579] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1585), 1,
      anon_sym_LBRACE,
    STATE(712), 1,
      sym_comment,
  [12589] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1587), 1,
      sym_regex_pattern,
    STATE(713), 1,
      sym_comment,
  [12599] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1363), 1,
      anon_sym_GT,
    STATE(714), 1,
      sym_comment,
  [12609] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1589), 1,
      aux_sym_format_converter_token1,
    STATE(715), 1,
      sym_comment,
  [12619] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1591), 1,
      anon_sym_RBRACK,
    STATE(716), 1,
      sym_comment,
  [12629] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1591), 1,
      anon_sym_RBRACE2,
    STATE(717), 1,
      sym_comment,
  [12639] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1591), 1,
      anon_sym_GT,
    STATE(718), 1,
      sym_comment,
  [12649] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1591), 1,
      anon_sym_SLASH,
    STATE(719), 1,
      sym_comment,
  [12659] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1593), 1,
      anon_sym_SLASH,
    STATE(720), 1,
      sym_comment,
  [12669] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1595), 1,
      anon_sym_LBRACE,
    STATE(721), 1,
      sym_comment,
  [12679] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1597), 1,
      anon_sym_RBRACK,
    STATE(722), 1,
      sym_comment,
  [12689] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1597), 1,
      anon_sym_RBRACE2,
    STATE(723), 1,
      sym_comment,
  [12699] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1597), 1,
      anon_sym_GT,
    STATE(724), 1,
      sym_comment,
  [12709] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1597), 1,
      anon_sym_SLASH,
    STATE(725), 1,
      sym_comment,
  [12719] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1599), 1,
      anon_sym_EQ,
    STATE(726), 1,
      sym_comment,
  [12729] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1601), 1,
      anon_sym_SEMI,
    STATE(727), 1,
      sym_comment,
  [12739] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1593), 1,
      anon_sym_GT,
    STATE(728), 1,
      sym_comment,
  [12749] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1593), 1,
      anon_sym_RPAREN2,
    STATE(729), 1,
      sym_comment,
  [12759] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1603), 1,
      anon_sym_SLASH,
    STATE(730), 1,
      sym_comment,
  [12769] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1605), 1,
      anon_sym_GT,
    STATE(731), 1,
      sym_comment,
  [12779] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1605), 1,
      anon_sym_RPAREN2,
    STATE(732), 1,
      sym_comment,
  [12789] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1607), 1,
      anon_sym_SLASH,
    STATE(733), 1,
      sym_comment,
  [12799] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1609), 1,
      anon_sym_RBRACK,
    STATE(734), 1,
      sym_comment,
  [12809] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1609), 1,
      anon_sym_RBRACE2,
    STATE(735), 1,
      sym_comment,
  [12819] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1609), 1,
      anon_sym_GT,
    STATE(736), 1,
      sym_comment,
  [12829] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1609), 1,
      anon_sym_SLASH,
    STATE(737), 1,
      sym_comment,
  [12839] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1611), 1,
      anon_sym_SLASH,
    STATE(738), 1,
      sym_comment,
  [12849] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1613), 1,
      anon_sym_GT,
    STATE(739), 1,
      sym_comment,
  [12859] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1613), 1,
      anon_sym_RPAREN2,
    STATE(740), 1,
      sym_comment,
  [12869] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1615), 1,
      ts_builtin_sym_end,
    STATE(741), 1,
      sym_comment,
  [12879] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1617), 1,
      sym_regex_pattern,
    STATE(742), 1,
      sym_comment,
  [12889] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1619), 1,
      anon_sym_GT,
    STATE(743), 1,
      sym_comment,
  [12899] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1619), 1,
      anon_sym_RPAREN2,
    STATE(744), 1,
      sym_comment,
  [12909] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1621), 1,
      anon_sym_RBRACK,
    STATE(745), 1,
      sym_comment,
  [12919] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1621), 1,
      anon_sym_RBRACE2,
    STATE(746), 1,
      sym_comment,
  [12929] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1621), 1,
      anon_sym_GT,
    STATE(747), 1,
      sym_comment,
  [12939] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1621), 1,
      anon_sym_SLASH,
    STATE(748), 1,
      sym_comment,
  [12949] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1623), 1,
      anon_sym_SLASH,
    STATE(749), 1,
      sym_comment,
  [12959] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1625), 1,
      anon_sym_SLASH,
    STATE(750), 1,
      sym_comment,
  [12969] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1627), 1,
      anon_sym_GT,
    STATE(751), 1,
      sym_comment,
  [12979] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1627), 1,
      anon_sym_RPAREN2,
    STATE(752), 1,
      sym_comment,
  [12989] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1629), 1,
      anon_sym_SLASH,
    STATE(753), 1,
      sym_comment,
  [12999] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1631), 1,
      anon_sym_RBRACK,
    STATE(754), 1,
      sym_comment,
  [13009] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1631), 1,
      anon_sym_RBRACE2,
    STATE(755), 1,
      sym_comment,
  [13019] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1631), 1,
      anon_sym_GT,
    STATE(756), 1,
      sym_comment,
  [13029] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1631), 1,
      anon_sym_SLASH,
    STATE(757), 1,
      sym_comment,
  [13039] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1633), 1,
      anon_sym_SLASH,
    STATE(758), 1,
      sym_comment,
  [13049] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1635), 1,
      anon_sym_GT,
    STATE(759), 1,
      sym_comment,
  [13059] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1635), 1,
      anon_sym_RPAREN2,
    STATE(760), 1,
      sym_comment,
  [13069] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1637), 1,
      anon_sym_SLASH,
    STATE(761), 1,
      sym_comment,
  [13079] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1639), 1,
      anon_sym_GT,
    STATE(762), 1,
      sym_comment,
  [13089] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1639), 1,
      anon_sym_RPAREN2,
    STATE(763), 1,
      sym_comment,
  [13099] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1641), 1,
      anon_sym_SLASH,
    STATE(764), 1,
      sym_comment,
  [13109] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1643), 1,
      anon_sym_SLASH,
    STATE(765), 1,
      sym_comment,
  [13119] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1645), 1,
      anon_sym_LBRACE,
    STATE(766), 1,
      sym_comment,
  [13129] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1647), 1,
      aux_sym_format_converter_token1,
    STATE(767), 1,
      sym_comment,
  [13139] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1649), 1,
      sym_regex_pattern,
    STATE(768), 1,
      sym_comment,
  [13149] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1651), 1,
      sym_regex_pattern,
    STATE(769), 1,
      sym_comment,
  [13159] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1653), 1,
      sym_regex_pattern,
    STATE(770), 1,
      sym_comment,
  [13169] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1655), 1,
      anon_sym_RPAREN2,
    STATE(771), 1,
      sym_comment,
  [13179] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1657), 1,
      aux_sym_format_converter_token1,
    STATE(772), 1,
      sym_comment,
  [13189] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1497), 1,
      anon_sym_GT,
    STATE(773), 1,
      sym_comment,
  [13199] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1571), 1,
      anon_sym_RPAREN2,
    STATE(774), 1,
      sym_comment,
  [13209] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1659), 1,
      sym_regex_pattern,
    STATE(775), 1,
      sym_comment,
  [13219] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1661), 1,
      anon_sym_RBRACK,
    STATE(776), 1,
      sym_comment,
  [13229] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1663), 1,
      anon_sym_SLASH,
    STATE(777), 1,
      sym_comment,
  [13239] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1665), 1,
      aux_sym_format_converter_token1,
    STATE(778), 1,
      sym_comment,
  [13249] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1661), 1,
      anon_sym_RBRACE2,
    STATE(779), 1,
      sym_comment,
  [13259] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1667), 1,
      anon_sym_RPAREN2,
    STATE(780), 1,
      sym_comment,
  [13269] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1669), 1,
      sym_regex_pattern,
    STATE(781), 1,
      sym_comment,
  [13279] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1671), 1,
      sym_regex_pattern,
    STATE(782), 1,
      sym_comment,
  [13289] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1667), 1,
      anon_sym_GT,
    STATE(783), 1,
      sym_comment,
  [13299] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1673), 1,
      anon_sym_LPAREN2,
    STATE(784), 1,
      sym_comment,
  [13309] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1675), 1,
      sym_regex_pattern,
    STATE(785), 1,
      sym_comment,
  [13319] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1677), 1,
      sym_regex_pattern,
    STATE(786), 1,
      sym_comment,
  [13329] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1679), 1,
      sym_regex_pattern,
    STATE(787), 1,
      sym_comment,
  [13339] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1681), 1,
      aux_sym_format_converter_token1,
    STATE(788), 1,
      sym_comment,
  [13349] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1683), 1,
      sym_regex_pattern,
    STATE(789), 1,
      sym_comment,
  [13359] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1661), 1,
      anon_sym_GT,
    STATE(790), 1,
      sym_comment,
  [13369] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1685), 1,
      sym_regex_pattern,
    STATE(791), 1,
      sym_comment,
  [13379] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1661), 1,
      anon_sym_SLASH,
    STATE(792), 1,
      sym_comment,
  [13389] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1687), 1,
      anon_sym_SLASH,
    STATE(793), 1,
      sym_comment,
  [13399] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1689), 1,
      aux_sym_format_converter_token1,
    STATE(794), 1,
      sym_comment,
  [13409] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1691), 1,
      anon_sym_SLASH,
    STATE(795), 1,
      sym_comment,
  [13419] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1691), 1,
      anon_sym_GT,
    STATE(796), 1,
      sym_comment,
  [13429] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1693), 1,
      sym_regex_pattern,
    STATE(797), 1,
      sym_comment,
  [13439] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1695), 1,
      anon_sym_SLASH,
    STATE(798), 1,
      sym_comment,
  [13449] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1691), 1,
      anon_sym_RBRACE2,
    STATE(799), 1,
      sym_comment,
  [13459] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1697), 1,
      sym_regex_pattern,
    STATE(800), 1,
      sym_comment,
  [13469] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1699), 1,
      sym_regex_pattern,
    STATE(801), 1,
      sym_comment,
  [13479] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1691), 1,
      anon_sym_RBRACK,
    STATE(802), 1,
      sym_comment,
  [13489] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1701), 1,
      anon_sym_RBRACK,
    STATE(803), 1,
      sym_comment,
  [13499] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1667), 1,
      anon_sym_SLASH,
    STATE(804), 1,
      sym_comment,
  [13509] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1701), 1,
      anon_sym_RBRACE2,
    STATE(805), 1,
      sym_comment,
  [13519] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1703), 1,
      anon_sym_SLASH,
    STATE(806), 1,
      sym_comment,
  [13529] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      anon_sym_SLASH,
    STATE(807), 1,
      sym_comment,
  [13539] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1707), 1,
      sym_regex_pattern,
    STATE(808), 1,
      sym_comment,
  [13549] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1709), 1,
      aux_sym_format_converter_token1,
    STATE(809), 1,
      sym_comment,
  [13559] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      anon_sym_GT,
    STATE(810), 1,
      sym_comment,
  [13569] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      anon_sym_RBRACE2,
    STATE(811), 1,
      sym_comment,
  [13579] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1711), 1,
      sym_regex_pattern,
    STATE(812), 1,
      sym_comment,
  [13589] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1705), 1,
      anon_sym_RBRACK,
    STATE(813), 1,
      sym_comment,
  [13599] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1701), 1,
      anon_sym_GT,
    STATE(814), 1,
      sym_comment,
  [13609] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1713), 1,
      aux_sym_format_converter_token1,
    STATE(815), 1,
      sym_comment,
  [13619] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1715), 1,
      anon_sym_RPAREN2,
    STATE(816), 1,
      sym_comment,
  [13629] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1717), 1,
      sym_regex_pattern,
    STATE(817), 1,
      sym_comment,
  [13639] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1719), 1,
      sym_regex_pattern,
    STATE(818), 1,
      sym_comment,
  [13649] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1715), 1,
      anon_sym_GT,
    STATE(819), 1,
      sym_comment,
  [13659] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1701), 1,
      anon_sym_SLASH,
    STATE(820), 1,
      sym_comment,
  [13669] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1721), 1,
      sym_regex_pattern,
    STATE(821), 1,
      sym_comment,
  [13679] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1723), 1,
      anon_sym_LPAREN2,
    STATE(822), 1,
      sym_comment,
  [13689] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1725), 1,
      sym_regex_pattern,
    STATE(823), 1,
      sym_comment,
  [13699] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1727), 1,
      sym_regex_pattern,
    STATE(824), 1,
      sym_comment,
  [13709] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1729), 1,
      sym_regex_pattern,
    STATE(825), 1,
      sym_comment,
  [13719] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1731), 1,
      sym_regex_pattern,
    STATE(826), 1,
      sym_comment,
  [13729] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1733), 1,
      anon_sym_SLASH,
    STATE(827), 1,
      sym_comment,
  [13739] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1735), 1,
      anon_sym_RPAREN2,
    STATE(828), 1,
      sym_comment,
  [13749] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1737), 1,
      sym_regex_pattern,
    STATE(829), 1,
      sym_comment,
  [13759] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1735), 1,
      anon_sym_GT,
    STATE(830), 1,
      sym_comment,
  [13769] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1739), 1,
      anon_sym_SLASH,
    STATE(831), 1,
      sym_comment,
  [13779] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1741), 1,
      sym_regex_pattern,
    STATE(832), 1,
      sym_comment,
  [13789] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1743), 1,
      sym_regex_pattern,
    STATE(833), 1,
      sym_comment,
  [13799] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1745), 1,
      aux_sym_format_converter_token1,
    STATE(834), 1,
      sym_comment,
  [13809] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1747), 1,
      anon_sym_SLASH,
    STATE(835), 1,
      sym_comment,
  [13819] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1749), 1,
      anon_sym_SLASH,
    STATE(836), 1,
      sym_comment,
  [13829] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1751), 1,
      sym_regex_pattern,
    STATE(837), 1,
      sym_comment,
  [13839] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1753), 1,
      anon_sym_SLASH,
    STATE(838), 1,
      sym_comment,
  [13849] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1753), 1,
      anon_sym_GT,
    STATE(839), 1,
      sym_comment,
  [13859] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1755), 1,
      sym_regex_pattern,
    STATE(840), 1,
      sym_comment,
  [13869] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1753), 1,
      anon_sym_RBRACE2,
    STATE(841), 1,
      sym_comment,
  [13879] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1753), 1,
      anon_sym_RBRACK,
    STATE(842), 1,
      sym_comment,
  [13889] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1757), 1,
      sym_regex_pattern,
    STATE(843), 1,
      sym_comment,
  [13899] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1759), 1,
      anon_sym_SLASH,
    STATE(844), 1,
      sym_comment,
  [13909] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1761), 1,
      anon_sym_RPAREN2,
    STATE(845), 1,
      sym_comment,
  [13919] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1763), 1,
      sym_regex_pattern,
    STATE(846), 1,
      sym_comment,
  [13929] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1765), 1,
      sym_regex_pattern,
    STATE(847), 1,
      sym_comment,
  [13939] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1767), 1,
      sym_regex_pattern,
    STATE(848), 1,
      sym_comment,
  [13949] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1761), 1,
      anon_sym_GT,
    STATE(849), 1,
      sym_comment,
  [13959] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1769), 1,
      anon_sym_SLASH,
    STATE(850), 1,
      sym_comment,
  [13969] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1771), 1,
      anon_sym_SLASH,
    STATE(851), 1,
      sym_comment,
  [13979] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1771), 1,
      anon_sym_RBRACE2,
    STATE(852), 1,
      sym_comment,
  [13989] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1771), 1,
      anon_sym_RBRACK,
    STATE(853), 1,
      sym_comment,
  [13999] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1773), 1,
      sym_regex_pattern,
    STATE(854), 1,
      sym_comment,
  [14009] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1775), 1,
      sym_regex_pattern,
    STATE(855), 1,
      sym_comment,
  [14019] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1777), 1,
      sym_regex_pattern,
    STATE(856), 1,
      sym_comment,
  [14029] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1779), 1,
      anon_sym_LPAREN2,
    STATE(857), 1,
      sym_comment,
  [14039] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1781), 1,
      sym_regex_pattern,
    STATE(858), 1,
      sym_comment,
  [14049] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1783), 1,
      sym_regex_pattern,
    STATE(859), 1,
      sym_comment,
  [14059] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1785), 1,
      sym_regex_pattern,
    STATE(860), 1,
      sym_comment,
  [14069] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1787), 1,
      aux_sym_format_converter_token1,
    STATE(861), 1,
      sym_comment,
  [14079] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1789), 1,
      sym_regex_pattern,
    STATE(862), 1,
      sym_comment,
  [14089] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1791), 1,
      sym_regex_pattern,
    STATE(863), 1,
      sym_comment,
  [14099] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1771), 1,
      anon_sym_RPAREN2,
    STATE(864), 1,
      sym_comment,
  [14109] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1793), 1,
      sym_regex_pattern,
    STATE(865), 1,
      sym_comment,
  [14119] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1795), 1,
      sym_regex_pattern,
    STATE(866), 1,
      sym_comment,
  [14129] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1771), 1,
      anon_sym_GT,
    STATE(867), 1,
      sym_comment,
  [14139] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1797), 1,
      anon_sym_LPAREN2,
    STATE(868), 1,
      sym_comment,
  [14149] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1799), 1,
      sym_regex_pattern,
    STATE(869), 1,
      sym_comment,
  [14159] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1801), 1,
      sym_regex_pattern,
    STATE(870), 1,
      sym_comment,
  [14169] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1803), 1,
      sym_regex_pattern,
    STATE(871), 1,
      sym_comment,
  [14179] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1805), 1,
      aux_sym_comment_token1,
    STATE(872), 1,
      sym_comment,
  [14189] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1807), 1,
      anon_sym_LPAREN2,
    STATE(873), 1,
      sym_comment,
  [14199] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1809), 1,
      anon_sym_LPAREN2,
    STATE(874), 1,
      sym_comment,
  [14209] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1811), 1,
      anon_sym_SLASH,
    STATE(875), 1,
      sym_comment,
  [14219] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1813), 1,
      anon_sym_LPAREN2,
    STATE(876), 1,
      sym_comment,
  [14229] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1815), 1,
      anon_sym_SLASH,
    STATE(877), 1,
      sym_comment,
  [14239] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1817), 1,
      anon_sym_LPAREN2,
    STATE(878), 1,
      sym_comment,
  [14249] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1819), 1,
      anon_sym_LPAREN2,
    STATE(879), 1,
      sym_comment,
  [14259] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(122), 1,
      anon_sym_SLASH,
    STATE(880), 1,
      sym_comment,
  [14269] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1821), 1,
      anon_sym_LPAREN2,
    STATE(881), 1,
      sym_comment,
  [14279] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1823), 1,
      anon_sym_LPAREN2,
    STATE(882), 1,
      sym_comment,
  [14289] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1825), 1,
      anon_sym_SLASH,
    STATE(883), 1,
      sym_comment,
  [14299] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1827), 1,
      anon_sym_SLASH,
    STATE(884), 1,
      sym_comment,
  [14309] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1829), 1,
      anon_sym_LPAREN2,
    STATE(885), 1,
      sym_comment,
  [14319] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1831), 1,
      anon_sym_LPAREN2,
    STATE(886), 1,
      sym_comment,
  [14329] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1833), 1,
      anon_sym_SLASH,
    STATE(887), 1,
      sym_comment,
  [14339] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1835), 1,
      anon_sym_LPAREN2,
    STATE(888), 1,
      sym_comment,
  [14349] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1837), 1,
      anon_sym_SLASH,
    STATE(889), 1,
      sym_comment,
  [14359] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1839), 1,
      anon_sym_LPAREN2,
    STATE(890), 1,
      sym_comment,
  [14369] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1841), 1,
      anon_sym_SLASH,
    STATE(891), 1,
      sym_comment,
  [14379] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1843), 1,
      anon_sym_SLASH,
    STATE(892), 1,
      sym_comment,
  [14389] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1845), 1,
      anon_sym_LPAREN2,
    STATE(893), 1,
      sym_comment,
  [14399] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1847), 1,
      anon_sym_LPAREN2,
    STATE(894), 1,
      sym_comment,
  [14409] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1849), 1,
      anon_sym_SLASH,
    STATE(895), 1,
      sym_comment,
  [14419] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1851), 1,
      anon_sym_SLASH,
    STATE(896), 1,
      sym_comment,
  [14429] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1853), 1,
      anon_sym_LPAREN2,
    STATE(897), 1,
      sym_comment,
  [14439] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1855), 1,
      anon_sym_SLASH,
    STATE(898), 1,
      sym_comment,
  [14449] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1857), 1,
      anon_sym_SLASH,
    STATE(899), 1,
      sym_comment,
  [14459] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1859), 1,
      anon_sym_LPAREN2,
    STATE(900), 1,
      sym_comment,
  [14469] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1861), 1,
      anon_sym_SLASH,
    STATE(901), 1,
      sym_comment,
  [14479] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1863), 1,
      anon_sym_LPAREN2,
    STATE(902), 1,
      sym_comment,
  [14489] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1865), 1,
      anon_sym_SLASH,
    STATE(903), 1,
      sym_comment,
  [14499] = 3,
    ACTIONS(15), 1,
      anon_sym_POUND,
    ACTIONS(1867), 1,
      anon_sym_SLASH,
    STATE(904), 1,
      sym_comment,
  [14509] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1869), 1,
      sym_regex_pattern,
    STATE(905), 1,
      sym_comment,
  [14519] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1871), 1,
      sym_regex_pattern,
    STATE(906), 1,
      sym_comment,
  [14529] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1873), 1,
      sym_regex_pattern,
    STATE(907), 1,
      sym_comment,
  [14539] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1875), 1,
      sym_regex_pattern,
    STATE(908), 1,
      sym_comment,
  [14549] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1877), 1,
      sym_regex_pattern,
    STATE(909), 1,
      sym_comment,
  [14559] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1879), 1,
      sym_regex_pattern,
    STATE(910), 1,
      sym_comment,
  [14569] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1881), 1,
      sym_regex_pattern,
    STATE(911), 1,
      sym_comment,
  [14579] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1883), 1,
      sym_regex_pattern,
    STATE(912), 1,
      sym_comment,
  [14589] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1885), 1,
      sym_regex_pattern,
    STATE(913), 1,
      sym_comment,
  [14599] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1887), 1,
      sym_regex_pattern,
    STATE(914), 1,
      sym_comment,
  [14609] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1889), 1,
      sym_regex_pattern,
    STATE(915), 1,
      sym_comment,
  [14619] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1891), 1,
      sym_regex_pattern,
    STATE(916), 1,
      sym_comment,
  [14629] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1893), 1,
      sym_regex_pattern,
    STATE(917), 1,
      sym_comment,
  [14639] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1895), 1,
      sym_regex_pattern,
    STATE(918), 1,
      sym_comment,
  [14649] = 3,
    ACTIONS(3), 1,
      anon_sym_POUND,
    ACTIONS(1897), 1,
      sym_regex_pattern,
    STATE(919), 1,
      sym_comment,
  [14659] = 1,
    ACTIONS(1209), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 58,
  [SMALL_STATE(4)] = 113,
  [SMALL_STATE(5)] = 168,
  [SMALL_STATE(6)] = 223,
  [SMALL_STATE(7)] = 267,
  [SMALL_STATE(8)] = 309,
  [SMALL_STATE(9)] = 356,
  [SMALL_STATE(10)] = 403,
  [SMALL_STATE(11)] = 427,
  [SMALL_STATE(12)] = 471,
  [SMALL_STATE(13)] = 505,
  [SMALL_STATE(14)] = 531,
  [SMALL_STATE(15)] = 569,
  [SMALL_STATE(16)] = 603,
  [SMALL_STATE(17)] = 635,
  [SMALL_STATE(18)] = 659,
  [SMALL_STATE(19)] = 691,
  [SMALL_STATE(20)] = 735,
  [SMALL_STATE(21)] = 769,
  [SMALL_STATE(22)] = 803,
  [SMALL_STATE(23)] = 841,
  [SMALL_STATE(24)] = 865,
  [SMALL_STATE(25)] = 892,
  [SMALL_STATE(26)] = 915,
  [SMALL_STATE(27)] = 938,
  [SMALL_STATE(28)] = 963,
  [SMALL_STATE(29)] = 990,
  [SMALL_STATE(30)] = 1013,
  [SMALL_STATE(31)] = 1036,
  [SMALL_STATE(32)] = 1059,
  [SMALL_STATE(33)] = 1082,
  [SMALL_STATE(34)] = 1119,
  [SMALL_STATE(35)] = 1156,
  [SMALL_STATE(36)] = 1189,
  [SMALL_STATE(37)] = 1214,
  [SMALL_STATE(38)] = 1251,
  [SMALL_STATE(39)] = 1270,
  [SMALL_STATE(40)] = 1301,
  [SMALL_STATE(41)] = 1328,
  [SMALL_STATE(42)] = 1365,
  [SMALL_STATE(43)] = 1385,
  [SMALL_STATE(44)] = 1405,
  [SMALL_STATE(45)] = 1425,
  [SMALL_STATE(46)] = 1445,
  [SMALL_STATE(47)] = 1465,
  [SMALL_STATE(48)] = 1485,
  [SMALL_STATE(49)] = 1515,
  [SMALL_STATE(50)] = 1535,
  [SMALL_STATE(51)] = 1555,
  [SMALL_STATE(52)] = 1575,
  [SMALL_STATE(53)] = 1595,
  [SMALL_STATE(54)] = 1615,
  [SMALL_STATE(55)] = 1635,
  [SMALL_STATE(56)] = 1655,
  [SMALL_STATE(57)] = 1675,
  [SMALL_STATE(58)] = 1705,
  [SMALL_STATE(59)] = 1739,
  [SMALL_STATE(60)] = 1759,
  [SMALL_STATE(61)] = 1779,
  [SMALL_STATE(62)] = 1799,
  [SMALL_STATE(63)] = 1819,
  [SMALL_STATE(64)] = 1839,
  [SMALL_STATE(65)] = 1859,
  [SMALL_STATE(66)] = 1879,
  [SMALL_STATE(67)] = 1899,
  [SMALL_STATE(68)] = 1919,
  [SMALL_STATE(69)] = 1939,
  [SMALL_STATE(70)] = 1959,
  [SMALL_STATE(71)] = 1987,
  [SMALL_STATE(72)] = 2007,
  [SMALL_STATE(73)] = 2027,
  [SMALL_STATE(74)] = 2047,
  [SMALL_STATE(75)] = 2067,
  [SMALL_STATE(76)] = 2101,
  [SMALL_STATE(77)] = 2121,
  [SMALL_STATE(78)] = 2141,
  [SMALL_STATE(79)] = 2161,
  [SMALL_STATE(80)] = 2181,
  [SMALL_STATE(81)] = 2201,
  [SMALL_STATE(82)] = 2235,
  [SMALL_STATE(83)] = 2255,
  [SMALL_STATE(84)] = 2275,
  [SMALL_STATE(85)] = 2295,
  [SMALL_STATE(86)] = 2317,
  [SMALL_STATE(87)] = 2337,
  [SMALL_STATE(88)] = 2357,
  [SMALL_STATE(89)] = 2377,
  [SMALL_STATE(90)] = 2397,
  [SMALL_STATE(91)] = 2417,
  [SMALL_STATE(92)] = 2437,
  [SMALL_STATE(93)] = 2457,
  [SMALL_STATE(94)] = 2477,
  [SMALL_STATE(95)] = 2511,
  [SMALL_STATE(96)] = 2531,
  [SMALL_STATE(97)] = 2557,
  [SMALL_STATE(98)] = 2577,
  [SMALL_STATE(99)] = 2597,
  [SMALL_STATE(100)] = 2617,
  [SMALL_STATE(101)] = 2637,
  [SMALL_STATE(102)] = 2657,
  [SMALL_STATE(103)] = 2677,
  [SMALL_STATE(104)] = 2711,
  [SMALL_STATE(105)] = 2745,
  [SMALL_STATE(106)] = 2765,
  [SMALL_STATE(107)] = 2785,
  [SMALL_STATE(108)] = 2805,
  [SMALL_STATE(109)] = 2825,
  [SMALL_STATE(110)] = 2845,
  [SMALL_STATE(111)] = 2865,
  [SMALL_STATE(112)] = 2885,
  [SMALL_STATE(113)] = 2905,
  [SMALL_STATE(114)] = 2925,
  [SMALL_STATE(115)] = 2945,
  [SMALL_STATE(116)] = 2965,
  [SMALL_STATE(117)] = 2985,
  [SMALL_STATE(118)] = 3005,
  [SMALL_STATE(119)] = 3025,
  [SMALL_STATE(120)] = 3045,
  [SMALL_STATE(121)] = 3065,
  [SMALL_STATE(122)] = 3085,
  [SMALL_STATE(123)] = 3119,
  [SMALL_STATE(124)] = 3139,
  [SMALL_STATE(125)] = 3159,
  [SMALL_STATE(126)] = 3179,
  [SMALL_STATE(127)] = 3199,
  [SMALL_STATE(128)] = 3219,
  [SMALL_STATE(129)] = 3239,
  [SMALL_STATE(130)] = 3259,
  [SMALL_STATE(131)] = 3279,
  [SMALL_STATE(132)] = 3299,
  [SMALL_STATE(133)] = 3319,
  [SMALL_STATE(134)] = 3345,
  [SMALL_STATE(135)] = 3365,
  [SMALL_STATE(136)] = 3389,
  [SMALL_STATE(137)] = 3409,
  [SMALL_STATE(138)] = 3429,
  [SMALL_STATE(139)] = 3449,
  [SMALL_STATE(140)] = 3469,
  [SMALL_STATE(141)] = 3489,
  [SMALL_STATE(142)] = 3509,
  [SMALL_STATE(143)] = 3529,
  [SMALL_STATE(144)] = 3549,
  [SMALL_STATE(145)] = 3569,
  [SMALL_STATE(146)] = 3589,
  [SMALL_STATE(147)] = 3609,
  [SMALL_STATE(148)] = 3629,
  [SMALL_STATE(149)] = 3649,
  [SMALL_STATE(150)] = 3669,
  [SMALL_STATE(151)] = 3689,
  [SMALL_STATE(152)] = 3709,
  [SMALL_STATE(153)] = 3729,
  [SMALL_STATE(154)] = 3749,
  [SMALL_STATE(155)] = 3769,
  [SMALL_STATE(156)] = 3789,
  [SMALL_STATE(157)] = 3809,
  [SMALL_STATE(158)] = 3829,
  [SMALL_STATE(159)] = 3849,
  [SMALL_STATE(160)] = 3869,
  [SMALL_STATE(161)] = 3889,
  [SMALL_STATE(162)] = 3909,
  [SMALL_STATE(163)] = 3929,
  [SMALL_STATE(164)] = 3949,
  [SMALL_STATE(165)] = 3969,
  [SMALL_STATE(166)] = 3989,
  [SMALL_STATE(167)] = 4009,
  [SMALL_STATE(168)] = 4029,
  [SMALL_STATE(169)] = 4049,
  [SMALL_STATE(170)] = 4069,
  [SMALL_STATE(171)] = 4089,
  [SMALL_STATE(172)] = 4109,
  [SMALL_STATE(173)] = 4129,
  [SMALL_STATE(174)] = 4149,
  [SMALL_STATE(175)] = 4169,
  [SMALL_STATE(176)] = 4189,
  [SMALL_STATE(177)] = 4209,
  [SMALL_STATE(178)] = 4229,
  [SMALL_STATE(179)] = 4249,
  [SMALL_STATE(180)] = 4269,
  [SMALL_STATE(181)] = 4289,
  [SMALL_STATE(182)] = 4309,
  [SMALL_STATE(183)] = 4329,
  [SMALL_STATE(184)] = 4349,
  [SMALL_STATE(185)] = 4383,
  [SMALL_STATE(186)] = 4403,
  [SMALL_STATE(187)] = 4423,
  [SMALL_STATE(188)] = 4443,
  [SMALL_STATE(189)] = 4463,
  [SMALL_STATE(190)] = 4483,
  [SMALL_STATE(191)] = 4503,
  [SMALL_STATE(192)] = 4523,
  [SMALL_STATE(193)] = 4543,
  [SMALL_STATE(194)] = 4563,
  [SMALL_STATE(195)] = 4583,
  [SMALL_STATE(196)] = 4603,
  [SMALL_STATE(197)] = 4623,
  [SMALL_STATE(198)] = 4643,
  [SMALL_STATE(199)] = 4663,
  [SMALL_STATE(200)] = 4683,
  [SMALL_STATE(201)] = 4703,
  [SMALL_STATE(202)] = 4723,
  [SMALL_STATE(203)] = 4743,
  [SMALL_STATE(204)] = 4763,
  [SMALL_STATE(205)] = 4783,
  [SMALL_STATE(206)] = 4806,
  [SMALL_STATE(207)] = 4829,
  [SMALL_STATE(208)] = 4852,
  [SMALL_STATE(209)] = 4883,
  [SMALL_STATE(210)] = 4906,
  [SMALL_STATE(211)] = 4929,
  [SMALL_STATE(212)] = 4952,
  [SMALL_STATE(213)] = 4975,
  [SMALL_STATE(214)] = 4998,
  [SMALL_STATE(215)] = 5021,
  [SMALL_STATE(216)] = 5044,
  [SMALL_STATE(217)] = 5067,
  [SMALL_STATE(218)] = 5090,
  [SMALL_STATE(219)] = 5113,
  [SMALL_STATE(220)] = 5136,
  [SMALL_STATE(221)] = 5167,
  [SMALL_STATE(222)] = 5198,
  [SMALL_STATE(223)] = 5221,
  [SMALL_STATE(224)] = 5244,
  [SMALL_STATE(225)] = 5267,
  [SMALL_STATE(226)] = 5290,
  [SMALL_STATE(227)] = 5313,
  [SMALL_STATE(228)] = 5342,
  [SMALL_STATE(229)] = 5373,
  [SMALL_STATE(230)] = 5396,
  [SMALL_STATE(231)] = 5419,
  [SMALL_STATE(232)] = 5448,
  [SMALL_STATE(233)] = 5471,
  [SMALL_STATE(234)] = 5494,
  [SMALL_STATE(235)] = 5517,
  [SMALL_STATE(236)] = 5540,
  [SMALL_STATE(237)] = 5563,
  [SMALL_STATE(238)] = 5586,
  [SMALL_STATE(239)] = 5609,
  [SMALL_STATE(240)] = 5632,
  [SMALL_STATE(241)] = 5655,
  [SMALL_STATE(242)] = 5686,
  [SMALL_STATE(243)] = 5709,
  [SMALL_STATE(244)] = 5740,
  [SMALL_STATE(245)] = 5771,
  [SMALL_STATE(246)] = 5794,
  [SMALL_STATE(247)] = 5817,
  [SMALL_STATE(248)] = 5840,
  [SMALL_STATE(249)] = 5863,
  [SMALL_STATE(250)] = 5886,
  [SMALL_STATE(251)] = 5917,
  [SMALL_STATE(252)] = 5940,
  [SMALL_STATE(253)] = 5963,
  [SMALL_STATE(254)] = 5986,
  [SMALL_STATE(255)] = 6009,
  [SMALL_STATE(256)] = 6032,
  [SMALL_STATE(257)] = 6063,
  [SMALL_STATE(258)] = 6086,
  [SMALL_STATE(259)] = 6117,
  [SMALL_STATE(260)] = 6148,
  [SMALL_STATE(261)] = 6179,
  [SMALL_STATE(262)] = 6202,
  [SMALL_STATE(263)] = 6225,
  [SMALL_STATE(264)] = 6248,
  [SMALL_STATE(265)] = 6271,
  [SMALL_STATE(266)] = 6294,
  [SMALL_STATE(267)] = 6317,
  [SMALL_STATE(268)] = 6348,
  [SMALL_STATE(269)] = 6367,
  [SMALL_STATE(270)] = 6390,
  [SMALL_STATE(271)] = 6413,
  [SMALL_STATE(272)] = 6436,
  [SMALL_STATE(273)] = 6459,
  [SMALL_STATE(274)] = 6476,
  [SMALL_STATE(275)] = 6499,
  [SMALL_STATE(276)] = 6522,
  [SMALL_STATE(277)] = 6553,
  [SMALL_STATE(278)] = 6576,
  [SMALL_STATE(279)] = 6599,
  [SMALL_STATE(280)] = 6622,
  [SMALL_STATE(281)] = 6645,
  [SMALL_STATE(282)] = 6676,
  [SMALL_STATE(283)] = 6699,
  [SMALL_STATE(284)] = 6730,
  [SMALL_STATE(285)] = 6753,
  [SMALL_STATE(286)] = 6776,
  [SMALL_STATE(287)] = 6799,
  [SMALL_STATE(288)] = 6822,
  [SMALL_STATE(289)] = 6845,
  [SMALL_STATE(290)] = 6861,
  [SMALL_STATE(291)] = 6877,
  [SMALL_STATE(292)] = 6900,
  [SMALL_STATE(293)] = 6923,
  [SMALL_STATE(294)] = 6946,
  [SMALL_STATE(295)] = 6969,
  [SMALL_STATE(296)] = 6992,
  [SMALL_STATE(297)] = 7015,
  [SMALL_STATE(298)] = 7038,
  [SMALL_STATE(299)] = 7061,
  [SMALL_STATE(300)] = 7084,
  [SMALL_STATE(301)] = 7107,
  [SMALL_STATE(302)] = 7130,
  [SMALL_STATE(303)] = 7153,
  [SMALL_STATE(304)] = 7176,
  [SMALL_STATE(305)] = 7199,
  [SMALL_STATE(306)] = 7222,
  [SMALL_STATE(307)] = 7245,
  [SMALL_STATE(308)] = 7268,
  [SMALL_STATE(309)] = 7291,
  [SMALL_STATE(310)] = 7314,
  [SMALL_STATE(311)] = 7335,
  [SMALL_STATE(312)] = 7358,
  [SMALL_STATE(313)] = 7375,
  [SMALL_STATE(314)] = 7398,
  [SMALL_STATE(315)] = 7421,
  [SMALL_STATE(316)] = 7444,
  [SMALL_STATE(317)] = 7467,
  [SMALL_STATE(318)] = 7490,
  [SMALL_STATE(319)] = 7513,
  [SMALL_STATE(320)] = 7536,
  [SMALL_STATE(321)] = 7559,
  [SMALL_STATE(322)] = 7576,
  [SMALL_STATE(323)] = 7599,
  [SMALL_STATE(324)] = 7622,
  [SMALL_STATE(325)] = 7645,
  [SMALL_STATE(326)] = 7668,
  [SMALL_STATE(327)] = 7691,
  [SMALL_STATE(328)] = 7714,
  [SMALL_STATE(329)] = 7737,
  [SMALL_STATE(330)] = 7760,
  [SMALL_STATE(331)] = 7779,
  [SMALL_STATE(332)] = 7798,
  [SMALL_STATE(333)] = 7817,
  [SMALL_STATE(334)] = 7836,
  [SMALL_STATE(335)] = 7855,
  [SMALL_STATE(336)] = 7874,
  [SMALL_STATE(337)] = 7891,
  [SMALL_STATE(338)] = 7910,
  [SMALL_STATE(339)] = 7929,
  [SMALL_STATE(340)] = 7948,
  [SMALL_STATE(341)] = 7967,
  [SMALL_STATE(342)] = 7986,
  [SMALL_STATE(343)] = 7997,
  [SMALL_STATE(344)] = 8016,
  [SMALL_STATE(345)] = 8035,
  [SMALL_STATE(346)] = 8054,
  [SMALL_STATE(347)] = 8073,
  [SMALL_STATE(348)] = 8092,
  [SMALL_STATE(349)] = 8111,
  [SMALL_STATE(350)] = 8130,
  [SMALL_STATE(351)] = 8149,
  [SMALL_STATE(352)] = 8168,
  [SMALL_STATE(353)] = 8187,
  [SMALL_STATE(354)] = 8206,
  [SMALL_STATE(355)] = 8225,
  [SMALL_STATE(356)] = 8244,
  [SMALL_STATE(357)] = 8259,
  [SMALL_STATE(358)] = 8276,
  [SMALL_STATE(359)] = 8295,
  [SMALL_STATE(360)] = 8314,
  [SMALL_STATE(361)] = 8333,
  [SMALL_STATE(362)] = 8352,
  [SMALL_STATE(363)] = 8371,
  [SMALL_STATE(364)] = 8390,
  [SMALL_STATE(365)] = 8409,
  [SMALL_STATE(366)] = 8428,
  [SMALL_STATE(367)] = 8447,
  [SMALL_STATE(368)] = 8466,
  [SMALL_STATE(369)] = 8485,
  [SMALL_STATE(370)] = 8504,
  [SMALL_STATE(371)] = 8521,
  [SMALL_STATE(372)] = 8540,
  [SMALL_STATE(373)] = 8559,
  [SMALL_STATE(374)] = 8578,
  [SMALL_STATE(375)] = 8597,
  [SMALL_STATE(376)] = 8616,
  [SMALL_STATE(377)] = 8635,
  [SMALL_STATE(378)] = 8654,
  [SMALL_STATE(379)] = 8665,
  [SMALL_STATE(380)] = 8676,
  [SMALL_STATE(381)] = 8695,
  [SMALL_STATE(382)] = 8714,
  [SMALL_STATE(383)] = 8733,
  [SMALL_STATE(384)] = 8744,
  [SMALL_STATE(385)] = 8763,
  [SMALL_STATE(386)] = 8782,
  [SMALL_STATE(387)] = 8801,
  [SMALL_STATE(388)] = 8820,
  [SMALL_STATE(389)] = 8839,
  [SMALL_STATE(390)] = 8850,
  [SMALL_STATE(391)] = 8869,
  [SMALL_STATE(392)] = 8888,
  [SMALL_STATE(393)] = 8907,
  [SMALL_STATE(394)] = 8918,
  [SMALL_STATE(395)] = 8929,
  [SMALL_STATE(396)] = 8948,
  [SMALL_STATE(397)] = 8967,
  [SMALL_STATE(398)] = 8986,
  [SMALL_STATE(399)] = 9005,
  [SMALL_STATE(400)] = 9024,
  [SMALL_STATE(401)] = 9043,
  [SMALL_STATE(402)] = 9062,
  [SMALL_STATE(403)] = 9081,
  [SMALL_STATE(404)] = 9100,
  [SMALL_STATE(405)] = 9111,
  [SMALL_STATE(406)] = 9130,
  [SMALL_STATE(407)] = 9149,
  [SMALL_STATE(408)] = 9163,
  [SMALL_STATE(409)] = 9179,
  [SMALL_STATE(410)] = 9195,
  [SMALL_STATE(411)] = 9211,
  [SMALL_STATE(412)] = 9227,
  [SMALL_STATE(413)] = 9243,
  [SMALL_STATE(414)] = 9259,
  [SMALL_STATE(415)] = 9275,
  [SMALL_STATE(416)] = 9291,
  [SMALL_STATE(417)] = 9307,
  [SMALL_STATE(418)] = 9323,
  [SMALL_STATE(419)] = 9335,
  [SMALL_STATE(420)] = 9351,
  [SMALL_STATE(421)] = 9367,
  [SMALL_STATE(422)] = 9379,
  [SMALL_STATE(423)] = 9395,
  [SMALL_STATE(424)] = 9411,
  [SMALL_STATE(425)] = 9427,
  [SMALL_STATE(426)] = 9441,
  [SMALL_STATE(427)] = 9457,
  [SMALL_STATE(428)] = 9471,
  [SMALL_STATE(429)] = 9487,
  [SMALL_STATE(430)] = 9499,
  [SMALL_STATE(431)] = 9515,
  [SMALL_STATE(432)] = 9531,
  [SMALL_STATE(433)] = 9547,
  [SMALL_STATE(434)] = 9563,
  [SMALL_STATE(435)] = 9579,
  [SMALL_STATE(436)] = 9595,
  [SMALL_STATE(437)] = 9611,
  [SMALL_STATE(438)] = 9627,
  [SMALL_STATE(439)] = 9643,
  [SMALL_STATE(440)] = 9659,
  [SMALL_STATE(441)] = 9675,
  [SMALL_STATE(442)] = 9691,
  [SMALL_STATE(443)] = 9705,
  [SMALL_STATE(444)] = 9721,
  [SMALL_STATE(445)] = 9737,
  [SMALL_STATE(446)] = 9753,
  [SMALL_STATE(447)] = 9767,
  [SMALL_STATE(448)] = 9781,
  [SMALL_STATE(449)] = 9795,
  [SMALL_STATE(450)] = 9811,
  [SMALL_STATE(451)] = 9824,
  [SMALL_STATE(452)] = 9837,
  [SMALL_STATE(453)] = 9850,
  [SMALL_STATE(454)] = 9863,
  [SMALL_STATE(455)] = 9876,
  [SMALL_STATE(456)] = 9887,
  [SMALL_STATE(457)] = 9900,
  [SMALL_STATE(458)] = 9913,
  [SMALL_STATE(459)] = 9926,
  [SMALL_STATE(460)] = 9939,
  [SMALL_STATE(461)] = 9952,
  [SMALL_STATE(462)] = 9965,
  [SMALL_STATE(463)] = 9978,
  [SMALL_STATE(464)] = 9991,
  [SMALL_STATE(465)] = 10004,
  [SMALL_STATE(466)] = 10017,
  [SMALL_STATE(467)] = 10030,
  [SMALL_STATE(468)] = 10043,
  [SMALL_STATE(469)] = 10056,
  [SMALL_STATE(470)] = 10069,
  [SMALL_STATE(471)] = 10082,
  [SMALL_STATE(472)] = 10095,
  [SMALL_STATE(473)] = 10106,
  [SMALL_STATE(474)] = 10119,
  [SMALL_STATE(475)] = 10132,
  [SMALL_STATE(476)] = 10145,
  [SMALL_STATE(477)] = 10156,
  [SMALL_STATE(478)] = 10169,
  [SMALL_STATE(479)] = 10180,
  [SMALL_STATE(480)] = 10193,
  [SMALL_STATE(481)] = 10206,
  [SMALL_STATE(482)] = 10219,
  [SMALL_STATE(483)] = 10232,
  [SMALL_STATE(484)] = 10245,
  [SMALL_STATE(485)] = 10258,
  [SMALL_STATE(486)] = 10271,
  [SMALL_STATE(487)] = 10284,
  [SMALL_STATE(488)] = 10295,
  [SMALL_STATE(489)] = 10308,
  [SMALL_STATE(490)] = 10321,
  [SMALL_STATE(491)] = 10332,
  [SMALL_STATE(492)] = 10343,
  [SMALL_STATE(493)] = 10354,
  [SMALL_STATE(494)] = 10367,
  [SMALL_STATE(495)] = 10378,
  [SMALL_STATE(496)] = 10389,
  [SMALL_STATE(497)] = 10402,
  [SMALL_STATE(498)] = 10413,
  [SMALL_STATE(499)] = 10424,
  [SMALL_STATE(500)] = 10437,
  [SMALL_STATE(501)] = 10450,
  [SMALL_STATE(502)] = 10463,
  [SMALL_STATE(503)] = 10474,
  [SMALL_STATE(504)] = 10487,
  [SMALL_STATE(505)] = 10500,
  [SMALL_STATE(506)] = 10513,
  [SMALL_STATE(507)] = 10526,
  [SMALL_STATE(508)] = 10539,
  [SMALL_STATE(509)] = 10549,
  [SMALL_STATE(510)] = 10559,
  [SMALL_STATE(511)] = 10569,
  [SMALL_STATE(512)] = 10579,
  [SMALL_STATE(513)] = 10589,
  [SMALL_STATE(514)] = 10599,
  [SMALL_STATE(515)] = 10609,
  [SMALL_STATE(516)] = 10619,
  [SMALL_STATE(517)] = 10629,
  [SMALL_STATE(518)] = 10639,
  [SMALL_STATE(519)] = 10649,
  [SMALL_STATE(520)] = 10659,
  [SMALL_STATE(521)] = 10669,
  [SMALL_STATE(522)] = 10679,
  [SMALL_STATE(523)] = 10689,
  [SMALL_STATE(524)] = 10699,
  [SMALL_STATE(525)] = 10709,
  [SMALL_STATE(526)] = 10719,
  [SMALL_STATE(527)] = 10729,
  [SMALL_STATE(528)] = 10739,
  [SMALL_STATE(529)] = 10749,
  [SMALL_STATE(530)] = 10759,
  [SMALL_STATE(531)] = 10769,
  [SMALL_STATE(532)] = 10779,
  [SMALL_STATE(533)] = 10789,
  [SMALL_STATE(534)] = 10799,
  [SMALL_STATE(535)] = 10809,
  [SMALL_STATE(536)] = 10819,
  [SMALL_STATE(537)] = 10829,
  [SMALL_STATE(538)] = 10839,
  [SMALL_STATE(539)] = 10849,
  [SMALL_STATE(540)] = 10859,
  [SMALL_STATE(541)] = 10869,
  [SMALL_STATE(542)] = 10879,
  [SMALL_STATE(543)] = 10889,
  [SMALL_STATE(544)] = 10899,
  [SMALL_STATE(545)] = 10909,
  [SMALL_STATE(546)] = 10919,
  [SMALL_STATE(547)] = 10929,
  [SMALL_STATE(548)] = 10939,
  [SMALL_STATE(549)] = 10949,
  [SMALL_STATE(550)] = 10959,
  [SMALL_STATE(551)] = 10969,
  [SMALL_STATE(552)] = 10979,
  [SMALL_STATE(553)] = 10989,
  [SMALL_STATE(554)] = 10999,
  [SMALL_STATE(555)] = 11009,
  [SMALL_STATE(556)] = 11019,
  [SMALL_STATE(557)] = 11029,
  [SMALL_STATE(558)] = 11039,
  [SMALL_STATE(559)] = 11049,
  [SMALL_STATE(560)] = 11059,
  [SMALL_STATE(561)] = 11069,
  [SMALL_STATE(562)] = 11079,
  [SMALL_STATE(563)] = 11089,
  [SMALL_STATE(564)] = 11099,
  [SMALL_STATE(565)] = 11109,
  [SMALL_STATE(566)] = 11119,
  [SMALL_STATE(567)] = 11129,
  [SMALL_STATE(568)] = 11139,
  [SMALL_STATE(569)] = 11149,
  [SMALL_STATE(570)] = 11159,
  [SMALL_STATE(571)] = 11169,
  [SMALL_STATE(572)] = 11179,
  [SMALL_STATE(573)] = 11189,
  [SMALL_STATE(574)] = 11199,
  [SMALL_STATE(575)] = 11209,
  [SMALL_STATE(576)] = 11219,
  [SMALL_STATE(577)] = 11229,
  [SMALL_STATE(578)] = 11239,
  [SMALL_STATE(579)] = 11249,
  [SMALL_STATE(580)] = 11259,
  [SMALL_STATE(581)] = 11269,
  [SMALL_STATE(582)] = 11279,
  [SMALL_STATE(583)] = 11289,
  [SMALL_STATE(584)] = 11299,
  [SMALL_STATE(585)] = 11309,
  [SMALL_STATE(586)] = 11319,
  [SMALL_STATE(587)] = 11329,
  [SMALL_STATE(588)] = 11339,
  [SMALL_STATE(589)] = 11349,
  [SMALL_STATE(590)] = 11359,
  [SMALL_STATE(591)] = 11369,
  [SMALL_STATE(592)] = 11379,
  [SMALL_STATE(593)] = 11389,
  [SMALL_STATE(594)] = 11399,
  [SMALL_STATE(595)] = 11409,
  [SMALL_STATE(596)] = 11419,
  [SMALL_STATE(597)] = 11429,
  [SMALL_STATE(598)] = 11439,
  [SMALL_STATE(599)] = 11449,
  [SMALL_STATE(600)] = 11459,
  [SMALL_STATE(601)] = 11469,
  [SMALL_STATE(602)] = 11479,
  [SMALL_STATE(603)] = 11489,
  [SMALL_STATE(604)] = 11499,
  [SMALL_STATE(605)] = 11509,
  [SMALL_STATE(606)] = 11519,
  [SMALL_STATE(607)] = 11529,
  [SMALL_STATE(608)] = 11539,
  [SMALL_STATE(609)] = 11549,
  [SMALL_STATE(610)] = 11559,
  [SMALL_STATE(611)] = 11569,
  [SMALL_STATE(612)] = 11579,
  [SMALL_STATE(613)] = 11589,
  [SMALL_STATE(614)] = 11599,
  [SMALL_STATE(615)] = 11609,
  [SMALL_STATE(616)] = 11619,
  [SMALL_STATE(617)] = 11629,
  [SMALL_STATE(618)] = 11639,
  [SMALL_STATE(619)] = 11649,
  [SMALL_STATE(620)] = 11659,
  [SMALL_STATE(621)] = 11669,
  [SMALL_STATE(622)] = 11679,
  [SMALL_STATE(623)] = 11689,
  [SMALL_STATE(624)] = 11699,
  [SMALL_STATE(625)] = 11709,
  [SMALL_STATE(626)] = 11719,
  [SMALL_STATE(627)] = 11729,
  [SMALL_STATE(628)] = 11739,
  [SMALL_STATE(629)] = 11749,
  [SMALL_STATE(630)] = 11759,
  [SMALL_STATE(631)] = 11769,
  [SMALL_STATE(632)] = 11779,
  [SMALL_STATE(633)] = 11789,
  [SMALL_STATE(634)] = 11799,
  [SMALL_STATE(635)] = 11809,
  [SMALL_STATE(636)] = 11819,
  [SMALL_STATE(637)] = 11829,
  [SMALL_STATE(638)] = 11839,
  [SMALL_STATE(639)] = 11849,
  [SMALL_STATE(640)] = 11859,
  [SMALL_STATE(641)] = 11869,
  [SMALL_STATE(642)] = 11879,
  [SMALL_STATE(643)] = 11889,
  [SMALL_STATE(644)] = 11899,
  [SMALL_STATE(645)] = 11909,
  [SMALL_STATE(646)] = 11919,
  [SMALL_STATE(647)] = 11929,
  [SMALL_STATE(648)] = 11939,
  [SMALL_STATE(649)] = 11949,
  [SMALL_STATE(650)] = 11959,
  [SMALL_STATE(651)] = 11969,
  [SMALL_STATE(652)] = 11979,
  [SMALL_STATE(653)] = 11989,
  [SMALL_STATE(654)] = 11999,
  [SMALL_STATE(655)] = 12009,
  [SMALL_STATE(656)] = 12019,
  [SMALL_STATE(657)] = 12029,
  [SMALL_STATE(658)] = 12039,
  [SMALL_STATE(659)] = 12049,
  [SMALL_STATE(660)] = 12059,
  [SMALL_STATE(661)] = 12069,
  [SMALL_STATE(662)] = 12079,
  [SMALL_STATE(663)] = 12089,
  [SMALL_STATE(664)] = 12099,
  [SMALL_STATE(665)] = 12109,
  [SMALL_STATE(666)] = 12119,
  [SMALL_STATE(667)] = 12129,
  [SMALL_STATE(668)] = 12139,
  [SMALL_STATE(669)] = 12149,
  [SMALL_STATE(670)] = 12159,
  [SMALL_STATE(671)] = 12169,
  [SMALL_STATE(672)] = 12179,
  [SMALL_STATE(673)] = 12189,
  [SMALL_STATE(674)] = 12199,
  [SMALL_STATE(675)] = 12209,
  [SMALL_STATE(676)] = 12219,
  [SMALL_STATE(677)] = 12229,
  [SMALL_STATE(678)] = 12239,
  [SMALL_STATE(679)] = 12249,
  [SMALL_STATE(680)] = 12259,
  [SMALL_STATE(681)] = 12269,
  [SMALL_STATE(682)] = 12279,
  [SMALL_STATE(683)] = 12289,
  [SMALL_STATE(684)] = 12299,
  [SMALL_STATE(685)] = 12309,
  [SMALL_STATE(686)] = 12319,
  [SMALL_STATE(687)] = 12329,
  [SMALL_STATE(688)] = 12339,
  [SMALL_STATE(689)] = 12349,
  [SMALL_STATE(690)] = 12359,
  [SMALL_STATE(691)] = 12369,
  [SMALL_STATE(692)] = 12379,
  [SMALL_STATE(693)] = 12389,
  [SMALL_STATE(694)] = 12399,
  [SMALL_STATE(695)] = 12409,
  [SMALL_STATE(696)] = 12419,
  [SMALL_STATE(697)] = 12429,
  [SMALL_STATE(698)] = 12439,
  [SMALL_STATE(699)] = 12449,
  [SMALL_STATE(700)] = 12459,
  [SMALL_STATE(701)] = 12469,
  [SMALL_STATE(702)] = 12479,
  [SMALL_STATE(703)] = 12489,
  [SMALL_STATE(704)] = 12499,
  [SMALL_STATE(705)] = 12509,
  [SMALL_STATE(706)] = 12519,
  [SMALL_STATE(707)] = 12529,
  [SMALL_STATE(708)] = 12539,
  [SMALL_STATE(709)] = 12549,
  [SMALL_STATE(710)] = 12559,
  [SMALL_STATE(711)] = 12569,
  [SMALL_STATE(712)] = 12579,
  [SMALL_STATE(713)] = 12589,
  [SMALL_STATE(714)] = 12599,
  [SMALL_STATE(715)] = 12609,
  [SMALL_STATE(716)] = 12619,
  [SMALL_STATE(717)] = 12629,
  [SMALL_STATE(718)] = 12639,
  [SMALL_STATE(719)] = 12649,
  [SMALL_STATE(720)] = 12659,
  [SMALL_STATE(721)] = 12669,
  [SMALL_STATE(722)] = 12679,
  [SMALL_STATE(723)] = 12689,
  [SMALL_STATE(724)] = 12699,
  [SMALL_STATE(725)] = 12709,
  [SMALL_STATE(726)] = 12719,
  [SMALL_STATE(727)] = 12729,
  [SMALL_STATE(728)] = 12739,
  [SMALL_STATE(729)] = 12749,
  [SMALL_STATE(730)] = 12759,
  [SMALL_STATE(731)] = 12769,
  [SMALL_STATE(732)] = 12779,
  [SMALL_STATE(733)] = 12789,
  [SMALL_STATE(734)] = 12799,
  [SMALL_STATE(735)] = 12809,
  [SMALL_STATE(736)] = 12819,
  [SMALL_STATE(737)] = 12829,
  [SMALL_STATE(738)] = 12839,
  [SMALL_STATE(739)] = 12849,
  [SMALL_STATE(740)] = 12859,
  [SMALL_STATE(741)] = 12869,
  [SMALL_STATE(742)] = 12879,
  [SMALL_STATE(743)] = 12889,
  [SMALL_STATE(744)] = 12899,
  [SMALL_STATE(745)] = 12909,
  [SMALL_STATE(746)] = 12919,
  [SMALL_STATE(747)] = 12929,
  [SMALL_STATE(748)] = 12939,
  [SMALL_STATE(749)] = 12949,
  [SMALL_STATE(750)] = 12959,
  [SMALL_STATE(751)] = 12969,
  [SMALL_STATE(752)] = 12979,
  [SMALL_STATE(753)] = 12989,
  [SMALL_STATE(754)] = 12999,
  [SMALL_STATE(755)] = 13009,
  [SMALL_STATE(756)] = 13019,
  [SMALL_STATE(757)] = 13029,
  [SMALL_STATE(758)] = 13039,
  [SMALL_STATE(759)] = 13049,
  [SMALL_STATE(760)] = 13059,
  [SMALL_STATE(761)] = 13069,
  [SMALL_STATE(762)] = 13079,
  [SMALL_STATE(763)] = 13089,
  [SMALL_STATE(764)] = 13099,
  [SMALL_STATE(765)] = 13109,
  [SMALL_STATE(766)] = 13119,
  [SMALL_STATE(767)] = 13129,
  [SMALL_STATE(768)] = 13139,
  [SMALL_STATE(769)] = 13149,
  [SMALL_STATE(770)] = 13159,
  [SMALL_STATE(771)] = 13169,
  [SMALL_STATE(772)] = 13179,
  [SMALL_STATE(773)] = 13189,
  [SMALL_STATE(774)] = 13199,
  [SMALL_STATE(775)] = 13209,
  [SMALL_STATE(776)] = 13219,
  [SMALL_STATE(777)] = 13229,
  [SMALL_STATE(778)] = 13239,
  [SMALL_STATE(779)] = 13249,
  [SMALL_STATE(780)] = 13259,
  [SMALL_STATE(781)] = 13269,
  [SMALL_STATE(782)] = 13279,
  [SMALL_STATE(783)] = 13289,
  [SMALL_STATE(784)] = 13299,
  [SMALL_STATE(785)] = 13309,
  [SMALL_STATE(786)] = 13319,
  [SMALL_STATE(787)] = 13329,
  [SMALL_STATE(788)] = 13339,
  [SMALL_STATE(789)] = 13349,
  [SMALL_STATE(790)] = 13359,
  [SMALL_STATE(791)] = 13369,
  [SMALL_STATE(792)] = 13379,
  [SMALL_STATE(793)] = 13389,
  [SMALL_STATE(794)] = 13399,
  [SMALL_STATE(795)] = 13409,
  [SMALL_STATE(796)] = 13419,
  [SMALL_STATE(797)] = 13429,
  [SMALL_STATE(798)] = 13439,
  [SMALL_STATE(799)] = 13449,
  [SMALL_STATE(800)] = 13459,
  [SMALL_STATE(801)] = 13469,
  [SMALL_STATE(802)] = 13479,
  [SMALL_STATE(803)] = 13489,
  [SMALL_STATE(804)] = 13499,
  [SMALL_STATE(805)] = 13509,
  [SMALL_STATE(806)] = 13519,
  [SMALL_STATE(807)] = 13529,
  [SMALL_STATE(808)] = 13539,
  [SMALL_STATE(809)] = 13549,
  [SMALL_STATE(810)] = 13559,
  [SMALL_STATE(811)] = 13569,
  [SMALL_STATE(812)] = 13579,
  [SMALL_STATE(813)] = 13589,
  [SMALL_STATE(814)] = 13599,
  [SMALL_STATE(815)] = 13609,
  [SMALL_STATE(816)] = 13619,
  [SMALL_STATE(817)] = 13629,
  [SMALL_STATE(818)] = 13639,
  [SMALL_STATE(819)] = 13649,
  [SMALL_STATE(820)] = 13659,
  [SMALL_STATE(821)] = 13669,
  [SMALL_STATE(822)] = 13679,
  [SMALL_STATE(823)] = 13689,
  [SMALL_STATE(824)] = 13699,
  [SMALL_STATE(825)] = 13709,
  [SMALL_STATE(826)] = 13719,
  [SMALL_STATE(827)] = 13729,
  [SMALL_STATE(828)] = 13739,
  [SMALL_STATE(829)] = 13749,
  [SMALL_STATE(830)] = 13759,
  [SMALL_STATE(831)] = 13769,
  [SMALL_STATE(832)] = 13779,
  [SMALL_STATE(833)] = 13789,
  [SMALL_STATE(834)] = 13799,
  [SMALL_STATE(835)] = 13809,
  [SMALL_STATE(836)] = 13819,
  [SMALL_STATE(837)] = 13829,
  [SMALL_STATE(838)] = 13839,
  [SMALL_STATE(839)] = 13849,
  [SMALL_STATE(840)] = 13859,
  [SMALL_STATE(841)] = 13869,
  [SMALL_STATE(842)] = 13879,
  [SMALL_STATE(843)] = 13889,
  [SMALL_STATE(844)] = 13899,
  [SMALL_STATE(845)] = 13909,
  [SMALL_STATE(846)] = 13919,
  [SMALL_STATE(847)] = 13929,
  [SMALL_STATE(848)] = 13939,
  [SMALL_STATE(849)] = 13949,
  [SMALL_STATE(850)] = 13959,
  [SMALL_STATE(851)] = 13969,
  [SMALL_STATE(852)] = 13979,
  [SMALL_STATE(853)] = 13989,
  [SMALL_STATE(854)] = 13999,
  [SMALL_STATE(855)] = 14009,
  [SMALL_STATE(856)] = 14019,
  [SMALL_STATE(857)] = 14029,
  [SMALL_STATE(858)] = 14039,
  [SMALL_STATE(859)] = 14049,
  [SMALL_STATE(860)] = 14059,
  [SMALL_STATE(861)] = 14069,
  [SMALL_STATE(862)] = 14079,
  [SMALL_STATE(863)] = 14089,
  [SMALL_STATE(864)] = 14099,
  [SMALL_STATE(865)] = 14109,
  [SMALL_STATE(866)] = 14119,
  [SMALL_STATE(867)] = 14129,
  [SMALL_STATE(868)] = 14139,
  [SMALL_STATE(869)] = 14149,
  [SMALL_STATE(870)] = 14159,
  [SMALL_STATE(871)] = 14169,
  [SMALL_STATE(872)] = 14179,
  [SMALL_STATE(873)] = 14189,
  [SMALL_STATE(874)] = 14199,
  [SMALL_STATE(875)] = 14209,
  [SMALL_STATE(876)] = 14219,
  [SMALL_STATE(877)] = 14229,
  [SMALL_STATE(878)] = 14239,
  [SMALL_STATE(879)] = 14249,
  [SMALL_STATE(880)] = 14259,
  [SMALL_STATE(881)] = 14269,
  [SMALL_STATE(882)] = 14279,
  [SMALL_STATE(883)] = 14289,
  [SMALL_STATE(884)] = 14299,
  [SMALL_STATE(885)] = 14309,
  [SMALL_STATE(886)] = 14319,
  [SMALL_STATE(887)] = 14329,
  [SMALL_STATE(888)] = 14339,
  [SMALL_STATE(889)] = 14349,
  [SMALL_STATE(890)] = 14359,
  [SMALL_STATE(891)] = 14369,
  [SMALL_STATE(892)] = 14379,
  [SMALL_STATE(893)] = 14389,
  [SMALL_STATE(894)] = 14399,
  [SMALL_STATE(895)] = 14409,
  [SMALL_STATE(896)] = 14419,
  [SMALL_STATE(897)] = 14429,
  [SMALL_STATE(898)] = 14439,
  [SMALL_STATE(899)] = 14449,
  [SMALL_STATE(900)] = 14459,
  [SMALL_STATE(901)] = 14469,
  [SMALL_STATE(902)] = 14479,
  [SMALL_STATE(903)] = 14489,
  [SMALL_STATE(904)] = 14499,
  [SMALL_STATE(905)] = 14509,
  [SMALL_STATE(906)] = 14519,
  [SMALL_STATE(907)] = 14529,
  [SMALL_STATE(908)] = 14539,
  [SMALL_STATE(909)] = 14549,
  [SMALL_STATE(910)] = 14559,
  [SMALL_STATE(911)] = 14569,
  [SMALL_STATE(912)] = 14579,
  [SMALL_STATE(913)] = 14589,
  [SMALL_STATE(914)] = 14599,
  [SMALL_STATE(915)] = 14609,
  [SMALL_STATE(916)] = 14619,
  [SMALL_STATE(917)] = 14629,
  [SMALL_STATE(918)] = 14639,
  [SMALL_STATE(919)] = 14649,
  [SMALL_STATE(920)] = 14659,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [37] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(696),
  [40] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(20),
  [43] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(21),
  [46] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(407),
  [49] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(23),
  [52] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(23),
  [55] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2), SHIFT_REPEAT(10),
  [58] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [60] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [62] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [64] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [66] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [68] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [70] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [72] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [74] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [76] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [78] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [80] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [82] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [84] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [86] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [88] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [90] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [92] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [94] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [96] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [98] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1),
  [106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1),
  [108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_name, 1),
  [140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_name, 1),
  [142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_name, 1),
  [144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_repeat1, 2),
  [162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_repeat1, 2), SHIFT_REPEAT(64),
  [165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__single_quoted_string_repeat1, 2), SHIFT_REPEAT(455),
  [168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__single_quoted_string_repeat1, 2), SHIFT_REPEAT(132),
  [171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_repeat1, 2), SHIFT_REPEAT(9),
  [174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number_literal, 2),
  [176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number_literal, 2),
  [178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_repeat1, 2),
  [180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_repeat1, 2), SHIFT_REPEAT(61),
  [183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__double_quoted_string_repeat1, 2), SHIFT_REPEAT(478),
  [186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__double_quoted_string_repeat1, 2), SHIFT_REPEAT(63),
  [189] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_repeat1, 2), SHIFT_REPEAT(8),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number_literal, 1),
  [218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number_literal, 1),
  [220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1),
  [222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 1),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 1),
  [228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__double_quoted_string, 3),
  [230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__double_quoted_string, 3),
  [232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quoted_literal, 1),
  [234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quoted_literal, 1),
  [236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_name, 1),
  [238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_quoted_string, 3),
  [242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_quoted_string, 3),
  [244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_quoted_string, 2),
  [246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_quoted_string, 2),
  [248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 2, .production_id = 1),
  [250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable, 2, .production_id = 1),
  [252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__double_quoted_string, 2),
  [254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__double_quoted_string, 2),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1),
  [298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_name_repeat1, 2), SHIFT_REPEAT(112),
  [303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_name_repeat1, 2),
  [305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_name_repeat1, 2), SHIFT_REPEAT(273),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_flag, 1),
  [330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2),
  [332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(39),
  [335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(601),
  [338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(459),
  [341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(501),
  [344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_name, 1),
  [346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 12, .production_id = 12),
  [368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 12, .production_id = 12),
  [370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 11, .production_id = 9),
  [372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 11, .production_id = 9),
  [374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 10),
  [376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 10),
  [378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 4),
  [380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 4),
  [382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 5),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 5),
  [386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 3),
  [388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 3),
  [390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7),
  [400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 2),
  [402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 2),
  [404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 8),
  [406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 8),
  [408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 6),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 6),
  [412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 9),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 9),
  [416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 11),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 11),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 7),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 7),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 9),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 9),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 7, .production_id = 7),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 7, .production_id = 7),
  [456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__double_quoted_string_repeat1, 1),
  [458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__double_quoted_string_repeat1, 1),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 10),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 10),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 1),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_escape_sequence, 1),
  [468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__single_quoted_string_repeat1, 1),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__single_quoted_string_repeat1, 1),
  [472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 12),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 12),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 5),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 5),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 6),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 6),
  [484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 3),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 3),
  [488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 8),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 8),
  [492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2),
  [494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2), SHIFT_REPEAT(499),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2), SHIFT_REPEAT(27),
  [500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 4),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 4),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 4),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 4),
  [508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 8, .production_id = 6),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 8, .production_id = 6),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_expansion, 2, .production_id = 1),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_expansion, 2, .production_id = 1),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 11),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 11),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 2),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 2),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 7),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 7),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 9),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 9),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 8),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 8),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [572] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9),
  [574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9),
  [576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 13),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 13),
  [580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 3),
  [582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 3),
  [584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 2),
  [586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 2),
  [588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 10),
  [590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 10),
  [592] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 12),
  [594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 12),
  [596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 5),
  [598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 5),
  [600] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 8),
  [602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 8),
  [604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 9, .production_id = 6),
  [606] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 9, .production_id = 6),
  [608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_name_repeat1, 1),
  [610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_name_repeat1, 1),
  [612] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 11),
  [614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 11),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 5),
  [636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 5),
  [638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_name, 1),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 7),
  [646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 7),
  [648] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 3, .production_id = 2),
  [650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 3, .production_id = 2),
  [652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 9),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 9),
  [656] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 13),
  [658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 13),
  [660] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 10),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 10),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 12),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 12),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10),
  [706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10),
  [708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 3),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 3),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 10, .production_id = 8),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 10, .production_id = 8),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 11, .production_id = 11),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 11, .production_id = 11),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 11, .production_id = 13),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 11, .production_id = 13),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 11, .production_id = 10),
  [726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 11, .production_id = 10),
  [728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__char, 1),
  [730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__char, 1),
  [732] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 13, .production_id = 13),
  [734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 13, .production_id = 13),
  [736] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 11, .production_id = 12),
  [738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 11, .production_id = 12),
  [740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6),
  [744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 12, .production_id = 13),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 12, .production_id = 13),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 12, .production_id = 11),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 12, .production_id = 11),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 6, .production_id = 7),
  [772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 6, .production_id = 7),
  [774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_name_repeat1, 2), SHIFT_REPEAT(289),
  [777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_name_repeat1, 2),
  [779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_name_repeat1, 2), SHIFT_REPEAT(290),
  [782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 4, .production_id = 2),
  [784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 4, .production_id = 2),
  [786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 4, .production_id = 3),
  [788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 4, .production_id = 3),
  [790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 4),
  [792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 4),
  [794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5, .production_id = 6),
  [796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5, .production_id = 6),
  [798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 4, .production_id = 4),
  [800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 4, .production_id = 4),
  [802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5),
  [804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5),
  [806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5, .production_id = 4),
  [808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5, .production_id = 4),
  [810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5, .production_id = 5),
  [812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5, .production_id = 5),
  [814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5, .production_id = 2),
  [816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5, .production_id = 2),
  [818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_converter, 5, .production_id = 3),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_converter, 5, .production_id = 3),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2),
  [1068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [1102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_name_repeat1, 1),
  [1120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [1124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(448),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_handler_repeat1, 2),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_handler_repeat1, 2), SHIFT_REPEAT(13),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_timeformat_repeat1, 2),
  [1203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_timeformat_repeat1, 2), SHIFT_REPEAT(425),
  [1206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_timeformat_repeat1, 2), SHIFT_REPEAT(425),
  [1209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2),
  [1211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_timeformat, 1),
  [1213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_charset_repeat1, 2),
  [1215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_charset_repeat1, 2), SHIFT_REPEAT(448),
  [1218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_charset, 2),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_charset, 1),
  [1222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handler, 6),
  [1224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5),
  [1226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handler, 5),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4),
  [1230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handler, 4),
  [1232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 3),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyword, 1),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value, 1),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_timeformat_repeat1, 1),
  [1276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_timeformat_repeat1, 1),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [1280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_enum_repeat1, 2), SHIFT_REPEAT(479),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 1),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [1321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_charset_repeat1, 1),
  [1323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_charset_repeat1, 1),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_inout, 1),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_enum, 1),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_enum, 2),
  [1351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 2),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command, 5),
  [1359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment, 3),
  [1361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [1371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(625),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_inout, 3),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(518),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(525),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_enum_repeat1, 2),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(552),
  [1461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_checksum, 1),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(568),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(593),
  [1521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(569),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handler_name, 1),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1615] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [1641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [1643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [1651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(550),
  [1653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [1665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [1671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(607),
  [1677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [1679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [1685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(668),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [1699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [1713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [1723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [1731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [1783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [1797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(920),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [1859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [1871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [1873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [1877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [1883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [1889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [1891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [1893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [1895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [1897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(903),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_streamdevice_proto(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
