#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 13
#define STATE_COUNT 850
#define LARGE_STATE_COUNT 16
#define SYMBOL_COUNT 245
#define ALIAS_COUNT 1
#define TOKEN_COUNT 131
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 20
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 42

enum {
  anon_sym_PERCENT_LBRACE = 1,
  aux_sym__c_code_token1 = 2,
  anon_sym_RBRACE = 3,
  anon_sym_PERCENT = 4,
  anon_sym_RBRACE_PERCENT = 5,
  anon_sym_PERCENT_PERCENT = 6,
  aux_sym__c_code_token2 = 7,
  anon_sym_LF = 8,
  anon_sym_POUND = 9,
  sym_line_number = 10,
  anon_sym_program = 11,
  anon_sym_LPAREN = 12,
  anon_sym_RPAREN = 13,
  anon_sym_entry = 14,
  anon_sym_exit = 15,
  anon_sym_struct = 16,
  anon_sym_SEMI = 17,
  anon_sym_LBRACE = 18,
  anon_sym_COMMA = 19,
  anon_sym_EQ = 20,
  anon_sym_STAR = 21,
  anon_sym_foreign = 22,
  anon_sym_evflag = 23,
  anon_sym_enum = 24,
  anon_sym_union = 25,
  anon_sym_typename = 26,
  anon_sym_void = 27,
  anon_sym_char = 28,
  anon_sym_short = 29,
  anon_sym_int = 30,
  anon_sym_long = 31,
  anon_sym_unsigned = 32,
  anon_sym_int8_t = 33,
  anon_sym_uint8_t = 34,
  anon_sym_int16_t = 35,
  anon_sym_uint16_t = 36,
  anon_sym_int32_t = 37,
  anon_sym_uint32_t = 38,
  anon_sym_float = 39,
  anon_sym_double = 40,
  anon_sym_string = 41,
  anon_sym_const = 42,
  anon_sym_assign = 43,
  anon_sym_to = 44,
  anon_sym_DQUOTE = 45,
  aux_sym__expanded_string_literal_token1 = 46,
  anon_sym_LBRACE2 = 47,
  anon_sym_LBRACK = 48,
  anon_sym_RBRACK = 49,
  anon_sym_monitor = 50,
  anon_sym_sync = 51,
  anon_sym_syncq = 52,
  anon_sym_option = 53,
  anon_sym_PLUS = 54,
  anon_sym_DASH = 55,
  anon_sym_ss = 56,
  anon_sym_state = 57,
  anon_sym_when = 58,
  anon_sym_break = 59,
  anon_sym_continue = 60,
  anon_sym_if = 61,
  anon_sym_else = 62,
  anon_sym_while = 63,
  anon_sym_for = 64,
  anon_sym_return = 65,
  anon_sym_DOT = 66,
  anon_sym_DASH_GT = 67,
  anon_sym_DASH_DASH = 68,
  anon_sym_PLUS_PLUS = 69,
  anon_sym_AMP = 70,
  anon_sym_BANG = 71,
  anon_sym_TILDE = 72,
  anon_sym_SLASH = 73,
  anon_sym_PIPE_PIPE = 74,
  anon_sym_AMP_AMP = 75,
  anon_sym_PIPE = 76,
  anon_sym_CARET = 77,
  anon_sym_EQ_EQ = 78,
  anon_sym_BANG_EQ = 79,
  anon_sym_GT = 80,
  anon_sym_GT_EQ = 81,
  anon_sym_LT_EQ = 82,
  anon_sym_LT = 83,
  anon_sym_LT_LT = 84,
  anon_sym_GT_GT = 85,
  anon_sym_QMARK = 86,
  anon_sym_COLON = 87,
  anon_sym_STAR_EQ = 88,
  anon_sym_SLASH_EQ = 89,
  anon_sym_PERCENT_EQ = 90,
  anon_sym_PLUS_EQ = 91,
  anon_sym_DASH_EQ = 92,
  anon_sym_LT_LT_EQ = 93,
  anon_sym_GT_GT_EQ = 94,
  anon_sym_AMP_EQ = 95,
  anon_sym_CARET_EQ = 96,
  anon_sym_PIPE_EQ = 97,
  anon_sym_sizeof = 98,
  sym_true = 99,
  sym_false = 100,
  sym_null = 101,
  anon_sym_L_DQUOTE = 102,
  anon_sym_u_DQUOTE = 103,
  anon_sym_U_DQUOTE = 104,
  anon_sym_u8_DQUOTE = 105,
  aux_sym_string_literal_token1 = 106,
  sym_number_literal = 107,
  anon_sym_L_SQUOTE = 108,
  anon_sym_u_SQUOTE = 109,
  anon_sym_U_SQUOTE = 110,
  anon_sym_u8_SQUOTE = 111,
  anon_sym_SQUOTE = 112,
  aux_sym_char_literal_token1 = 113,
  sym_system_lib_string = 114,
  sym_identifier = 115,
  sym_escape_sequence = 116,
  aux_sym_preproc_include_token1 = 117,
  aux_sym_preproc_def_token1 = 118,
  anon_sym_LPAREN2 = 119,
  anon_sym_DOT_DOT_DOT = 120,
  aux_sym_preproc_if_token1 = 121,
  aux_sym_preproc_if_token2 = 122,
  aux_sym_preproc_ifdef_token1 = 123,
  aux_sym_preproc_ifdef_token2 = 124,
  aux_sym_preproc_else_token1 = 125,
  aux_sym_preproc_elif_token1 = 126,
  sym_preproc_directive = 127,
  sym_preproc_arg = 128,
  anon_sym_defined = 129,
  sym_comment = 130,
  sym_source_file = 131,
  sym__top_level_item = 132,
  sym__c_code = 133,
  sym_line_marker = 134,
  sym_program = 135,
  sym_program_param = 136,
  sym_initial_defn = 137,
  sym_final_defn = 138,
  sym_entry = 139,
  sym_exit = 140,
  sym_funcdef = 141,
  sym_structdef = 142,
  sym_field_declaration_list = 143,
  sym_member_decl = 144,
  sym_declaration = 145,
  sym_init_declarator = 146,
  sym_declarator = 147,
  sym__declarator = 148,
  sym_pointer_declarator = 149,
  sym_function_declarator = 150,
  sym_array_declarator = 151,
  sym_init_expr = 152,
  sym_foreign_declaration = 153,
  sym_basetype = 154,
  sym_prim_type = 155,
  sym_type_expr = 156,
  sym_abs_decl = 157,
  sym__abs_decl = 158,
  sym_abstract_pointer_declarator = 159,
  sym_abstract_function_declarator = 160,
  sym_type_qualifier = 161,
  sym_param_decl = 162,
  sym_assign = 163,
  sym__expanded_string_literal = 164,
  sym_parameter_expansion = 165,
  sym_subscript = 166,
  sym_monitor = 167,
  sym_sync = 168,
  sym_event_flag = 169,
  sym_syncq = 170,
  sym_syncq_size = 171,
  sym_option = 172,
  sym_option_value = 173,
  sym_state_set = 174,
  sym_ss_defn = 175,
  sym_state = 176,
  sym_state_block = 177,
  sym_state_defn = 178,
  sym_transition = 179,
  sym_block = 180,
  sym_block_defn = 181,
  sym_statement = 182,
  sym_break_statement = 183,
  sym_continue_statement = 184,
  sym_if_statement = 185,
  sym_else_statement = 186,
  sym_while_statement = 187,
  sym_for_statement = 188,
  sym__expr = 189,
  sym_parenthesized_expression = 190,
  sym_call_expression = 191,
  sym_exit_expression = 192,
  sym_subscript_expression = 193,
  sym_field_expression = 194,
  sym_update_expression = 195,
  sym_unary_expression = 196,
  sym_binary_expression = 197,
  sym_conditional_expression = 198,
  sym_assignment_expression = 199,
  sym_cast_expression = 200,
  sym_sizeof_expression = 201,
  sym__comma_expr = 202,
  sym_comma_expr = 203,
  sym_args = 204,
  sym_string_literal = 205,
  sym_char_literal = 206,
  sym_preproc_include = 207,
  sym_preproc_def = 208,
  sym_preproc_function_def = 209,
  sym_preproc_params = 210,
  sym_preproc_call = 211,
  sym_preproc_if = 212,
  sym_preproc_ifdef = 213,
  sym_preproc_else = 214,
  sym_preproc_elif = 215,
  sym__preproc_expression = 216,
  sym_preproc_parenthesized_expression = 217,
  sym_preproc_defined = 218,
  sym_preproc_unary_expression = 219,
  sym_preproc_call_expression = 220,
  sym_preproc_argument_list = 221,
  sym_preproc_binary_expression = 222,
  aux_sym_source_file_repeat1 = 223,
  aux_sym__c_code_repeat1 = 224,
  aux_sym_program_repeat1 = 225,
  aux_sym_program_repeat2 = 226,
  aux_sym_program_repeat3 = 227,
  aux_sym_field_declaration_list_repeat1 = 228,
  aux_sym_declaration_repeat1 = 229,
  aux_sym_function_declarator_repeat1 = 230,
  aux_sym_init_expr_repeat1 = 231,
  aux_sym_foreign_declaration_repeat1 = 232,
  aux_sym_assign_repeat1 = 233,
  aux_sym__expanded_string_literal_repeat1 = 234,
  aux_sym_state_set_repeat1 = 235,
  aux_sym_state_set_repeat2 = 236,
  aux_sym_state_block_repeat1 = 237,
  aux_sym_state_block_repeat2 = 238,
  aux_sym_block_repeat1 = 239,
  aux_sym_block_repeat2 = 240,
  aux_sym_comma_expr_repeat1 = 241,
  aux_sym_string_literal_repeat1 = 242,
  aux_sym_preproc_params_repeat1 = 243,
  aux_sym_preproc_argument_list_repeat1 = 244,
  alias_sym_file_name = 245,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_PERCENT_LBRACE] = "%{",
  [aux_sym__c_code_token1] = "_c_code_token1",
  [anon_sym_RBRACE] = "}",
  [anon_sym_PERCENT] = "%",
  [anon_sym_RBRACE_PERCENT] = "}%",
  [anon_sym_PERCENT_PERCENT] = "%%",
  [aux_sym__c_code_token2] = "c_code",
  [anon_sym_LF] = "\n",
  [anon_sym_POUND] = "#",
  [sym_line_number] = "line_number",
  [anon_sym_program] = "program",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_entry] = "entry",
  [anon_sym_exit] = "exit",
  [anon_sym_struct] = "struct",
  [anon_sym_SEMI] = ";",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_EQ] = "=",
  [anon_sym_STAR] = "*",
  [anon_sym_foreign] = "foreign",
  [anon_sym_evflag] = "evflag",
  [anon_sym_enum] = "enum",
  [anon_sym_union] = "union",
  [anon_sym_typename] = "typename",
  [anon_sym_void] = "void",
  [anon_sym_char] = "char",
  [anon_sym_short] = "short",
  [anon_sym_int] = "int",
  [anon_sym_long] = "long",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_int8_t] = "int8_t",
  [anon_sym_uint8_t] = "uint8_t",
  [anon_sym_int16_t] = "int16_t",
  [anon_sym_uint16_t] = "uint16_t",
  [anon_sym_int32_t] = "int32_t",
  [anon_sym_uint32_t] = "uint32_t",
  [anon_sym_float] = "float",
  [anon_sym_double] = "double",
  [anon_sym_string] = "string",
  [anon_sym_const] = "const",
  [anon_sym_assign] = "assign",
  [anon_sym_to] = "to",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym__expanded_string_literal_token1] = "_expanded_string_literal_token1",
  [anon_sym_LBRACE2] = "{",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_monitor] = "monitor",
  [anon_sym_sync] = "sync",
  [anon_sym_syncq] = "syncq",
  [anon_sym_option] = "option",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_ss] = "ss",
  [anon_sym_state] = "state",
  [anon_sym_when] = "when",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [anon_sym_return] = "return",
  [anon_sym_DOT] = ".",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_AMP] = "&",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_SLASH] = "/",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_sizeof] = "sizeof",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_null] = "null",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [aux_sym_string_literal_token1] = "string_literal_token1",
  [sym_number_literal] = "number_literal",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_char_literal_token1] = "char_literal_token1",
  [sym_system_lib_string] = "system_lib_string",
  [sym_identifier] = "identifier",
  [sym_escape_sequence] = "escape_sequence",
  [aux_sym_preproc_include_token1] = "#include",
  [aux_sym_preproc_def_token1] = "#define",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_DOT_DOT_DOT] = "...",
  [aux_sym_preproc_if_token1] = "#if",
  [aux_sym_preproc_if_token2] = "#endif",
  [aux_sym_preproc_ifdef_token1] = "#ifdef",
  [aux_sym_preproc_ifdef_token2] = "#ifndef",
  [aux_sym_preproc_else_token1] = "#else",
  [aux_sym_preproc_elif_token1] = "#elif",
  [sym_preproc_directive] = "preproc_directive",
  [sym_preproc_arg] = "preproc_arg",
  [anon_sym_defined] = "defined",
  [sym_comment] = "comment",
  [sym_source_file] = "source_file",
  [sym__top_level_item] = "_top_level_item",
  [sym__c_code] = "_c_code",
  [sym_line_marker] = "line_marker",
  [sym_program] = "program",
  [sym_program_param] = "program_param",
  [sym_initial_defn] = "initial_defn",
  [sym_final_defn] = "final_defn",
  [sym_entry] = "entry",
  [sym_exit] = "exit",
  [sym_funcdef] = "funcdef",
  [sym_structdef] = "structdef",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym_member_decl] = "member_decl",
  [sym_declaration] = "declaration",
  [sym_init_declarator] = "init_declarator",
  [sym_declarator] = "declarator",
  [sym__declarator] = "_declarator",
  [sym_pointer_declarator] = "pointer_declarator",
  [sym_function_declarator] = "function_declarator",
  [sym_array_declarator] = "array_declarator",
  [sym_init_expr] = "init_expr",
  [sym_foreign_declaration] = "foreign_declaration",
  [sym_basetype] = "basetype",
  [sym_prim_type] = "prim_type",
  [sym_type_expr] = "type_expr",
  [sym_abs_decl] = "abs_decl",
  [sym__abs_decl] = "_abs_decl",
  [sym_abstract_pointer_declarator] = "abstract_pointer_declarator",
  [sym_abstract_function_declarator] = "abstract_function_declarator",
  [sym_type_qualifier] = "type_qualifier",
  [sym_param_decl] = "param_decl",
  [sym_assign] = "assign",
  [sym__expanded_string_literal] = "string_literal",
  [sym_parameter_expansion] = "parameter_expansion",
  [sym_subscript] = "subscript",
  [sym_monitor] = "monitor",
  [sym_sync] = "sync",
  [sym_event_flag] = "event_flag",
  [sym_syncq] = "syncq",
  [sym_syncq_size] = "syncq_size",
  [sym_option] = "option",
  [sym_option_value] = "option_value",
  [sym_state_set] = "state_set",
  [sym_ss_defn] = "ss_defn",
  [sym_state] = "state",
  [sym_state_block] = "state_block",
  [sym_state_defn] = "state_defn",
  [sym_transition] = "transition",
  [sym_block] = "block",
  [sym_block_defn] = "block_defn",
  [sym_statement] = "statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_statement] = "else_statement",
  [sym_while_statement] = "while_statement",
  [sym_for_statement] = "for_statement",
  [sym__expr] = "_expr",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_call_expression] = "call_expression",
  [sym_exit_expression] = "exit_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_field_expression] = "field_expression",
  [sym_update_expression] = "update_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym__comma_expr] = "_comma_expr",
  [sym_comma_expr] = "comma_expr",
  [sym_args] = "args",
  [sym_string_literal] = "string_literal",
  [sym_char_literal] = "char_literal",
  [sym_preproc_include] = "preproc_include",
  [sym_preproc_def] = "preproc_def",
  [sym_preproc_function_def] = "preproc_function_def",
  [sym_preproc_params] = "preproc_params",
  [sym_preproc_call] = "preproc_call",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_ifdef] = "preproc_ifdef",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_elif] = "preproc_elif",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "parenthesized_expression",
  [sym_preproc_defined] = "preproc_defined",
  [sym_preproc_unary_expression] = "unary_expression",
  [sym_preproc_call_expression] = "call_expression",
  [sym_preproc_argument_list] = "argument_list",
  [sym_preproc_binary_expression] = "binary_expression",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__c_code_repeat1] = "_c_code_repeat1",
  [aux_sym_program_repeat1] = "program_repeat1",
  [aux_sym_program_repeat2] = "program_repeat2",
  [aux_sym_program_repeat3] = "program_repeat3",
  [aux_sym_field_declaration_list_repeat1] = "field_declaration_list_repeat1",
  [aux_sym_declaration_repeat1] = "declaration_repeat1",
  [aux_sym_function_declarator_repeat1] = "function_declarator_repeat1",
  [aux_sym_init_expr_repeat1] = "init_expr_repeat1",
  [aux_sym_foreign_declaration_repeat1] = "foreign_declaration_repeat1",
  [aux_sym_assign_repeat1] = "assign_repeat1",
  [aux_sym__expanded_string_literal_repeat1] = "_expanded_string_literal_repeat1",
  [aux_sym_state_set_repeat1] = "state_set_repeat1",
  [aux_sym_state_set_repeat2] = "state_set_repeat2",
  [aux_sym_state_block_repeat1] = "state_block_repeat1",
  [aux_sym_state_block_repeat2] = "state_block_repeat2",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_block_repeat2] = "block_repeat2",
  [aux_sym_comma_expr_repeat1] = "comma_expr_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_preproc_params_repeat1] = "preproc_params_repeat1",
  [aux_sym_preproc_argument_list_repeat1] = "preproc_argument_list_repeat1",
  [alias_sym_file_name] = "file_name",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_PERCENT_LBRACE] = anon_sym_PERCENT_LBRACE,
  [aux_sym__c_code_token1] = aux_sym__c_code_token1,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_RBRACE_PERCENT] = anon_sym_RBRACE_PERCENT,
  [anon_sym_PERCENT_PERCENT] = anon_sym_PERCENT_PERCENT,
  [aux_sym__c_code_token2] = aux_sym__c_code_token2,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_POUND] = anon_sym_POUND,
  [sym_line_number] = sym_line_number,
  [anon_sym_program] = anon_sym_program,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_entry] = anon_sym_entry,
  [anon_sym_exit] = anon_sym_exit,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_foreign] = anon_sym_foreign,
  [anon_sym_evflag] = anon_sym_evflag,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_typename] = anon_sym_typename,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_char] = anon_sym_char,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_int8_t] = anon_sym_int8_t,
  [anon_sym_uint8_t] = anon_sym_uint8_t,
  [anon_sym_int16_t] = anon_sym_int16_t,
  [anon_sym_uint16_t] = anon_sym_uint16_t,
  [anon_sym_int32_t] = anon_sym_int32_t,
  [anon_sym_uint32_t] = anon_sym_uint32_t,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_double] = anon_sym_double,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_assign] = anon_sym_assign,
  [anon_sym_to] = anon_sym_to,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym__expanded_string_literal_token1] = aux_sym__expanded_string_literal_token1,
  [anon_sym_LBRACE2] = anon_sym_LBRACE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_monitor] = anon_sym_monitor,
  [anon_sym_sync] = anon_sym_sync,
  [anon_sym_syncq] = anon_sym_syncq,
  [anon_sym_option] = anon_sym_option,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_ss] = anon_sym_ss,
  [anon_sym_state] = anon_sym_state,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_null] = sym_null,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [sym_number_literal] = sym_number_literal,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
  [sym_system_lib_string] = sym_system_lib_string,
  [sym_identifier] = sym_identifier,
  [sym_escape_sequence] = sym_escape_sequence,
  [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
  [aux_sym_preproc_def_token1] = aux_sym_preproc_def_token1,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [aux_sym_preproc_if_token1] = aux_sym_preproc_if_token1,
  [aux_sym_preproc_if_token2] = aux_sym_preproc_if_token2,
  [aux_sym_preproc_ifdef_token1] = aux_sym_preproc_ifdef_token1,
  [aux_sym_preproc_ifdef_token2] = aux_sym_preproc_ifdef_token2,
  [aux_sym_preproc_else_token1] = aux_sym_preproc_else_token1,
  [aux_sym_preproc_elif_token1] = aux_sym_preproc_elif_token1,
  [sym_preproc_directive] = sym_preproc_directive,
  [sym_preproc_arg] = sym_preproc_arg,
  [anon_sym_defined] = anon_sym_defined,
  [sym_comment] = sym_comment,
  [sym_source_file] = sym_source_file,
  [sym__top_level_item] = sym__top_level_item,
  [sym__c_code] = sym__c_code,
  [sym_line_marker] = sym_line_marker,
  [sym_program] = sym_program,
  [sym_program_param] = sym_program_param,
  [sym_initial_defn] = sym_initial_defn,
  [sym_final_defn] = sym_final_defn,
  [sym_entry] = sym_entry,
  [sym_exit] = sym_exit,
  [sym_funcdef] = sym_funcdef,
  [sym_structdef] = sym_structdef,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym_member_decl] = sym_member_decl,
  [sym_declaration] = sym_declaration,
  [sym_init_declarator] = sym_init_declarator,
  [sym_declarator] = sym_declarator,
  [sym__declarator] = sym__declarator,
  [sym_pointer_declarator] = sym_pointer_declarator,
  [sym_function_declarator] = sym_function_declarator,
  [sym_array_declarator] = sym_array_declarator,
  [sym_init_expr] = sym_init_expr,
  [sym_foreign_declaration] = sym_foreign_declaration,
  [sym_basetype] = sym_basetype,
  [sym_prim_type] = sym_prim_type,
  [sym_type_expr] = sym_type_expr,
  [sym_abs_decl] = sym_abs_decl,
  [sym__abs_decl] = sym__abs_decl,
  [sym_abstract_pointer_declarator] = sym_abstract_pointer_declarator,
  [sym_abstract_function_declarator] = sym_abstract_function_declarator,
  [sym_type_qualifier] = sym_type_qualifier,
  [sym_param_decl] = sym_param_decl,
  [sym_assign] = sym_assign,
  [sym__expanded_string_literal] = sym_string_literal,
  [sym_parameter_expansion] = sym_parameter_expansion,
  [sym_subscript] = sym_subscript,
  [sym_monitor] = sym_monitor,
  [sym_sync] = sym_sync,
  [sym_event_flag] = sym_event_flag,
  [sym_syncq] = sym_syncq,
  [sym_syncq_size] = sym_syncq_size,
  [sym_option] = sym_option,
  [sym_option_value] = sym_option_value,
  [sym_state_set] = sym_state_set,
  [sym_ss_defn] = sym_ss_defn,
  [sym_state] = sym_state,
  [sym_state_block] = sym_state_block,
  [sym_state_defn] = sym_state_defn,
  [sym_transition] = sym_transition,
  [sym_block] = sym_block,
  [sym_block_defn] = sym_block_defn,
  [sym_statement] = sym_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_statement] = sym_else_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_for_statement] = sym_for_statement,
  [sym__expr] = sym__expr,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_exit_expression] = sym_exit_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym__comma_expr] = sym__comma_expr,
  [sym_comma_expr] = sym_comma_expr,
  [sym_args] = sym_args,
  [sym_string_literal] = sym_string_literal,
  [sym_char_literal] = sym_char_literal,
  [sym_preproc_include] = sym_preproc_include,
  [sym_preproc_def] = sym_preproc_def,
  [sym_preproc_function_def] = sym_preproc_function_def,
  [sym_preproc_params] = sym_preproc_params,
  [sym_preproc_call] = sym_preproc_call,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_ifdef] = sym_preproc_ifdef,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_parenthesized_expression,
  [sym_preproc_defined] = sym_preproc_defined,
  [sym_preproc_unary_expression] = sym_unary_expression,
  [sym_preproc_call_expression] = sym_call_expression,
  [sym_preproc_argument_list] = sym_preproc_argument_list,
  [sym_preproc_binary_expression] = sym_binary_expression,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__c_code_repeat1] = aux_sym__c_code_repeat1,
  [aux_sym_program_repeat1] = aux_sym_program_repeat1,
  [aux_sym_program_repeat2] = aux_sym_program_repeat2,
  [aux_sym_program_repeat3] = aux_sym_program_repeat3,
  [aux_sym_field_declaration_list_repeat1] = aux_sym_field_declaration_list_repeat1,
  [aux_sym_declaration_repeat1] = aux_sym_declaration_repeat1,
  [aux_sym_function_declarator_repeat1] = aux_sym_function_declarator_repeat1,
  [aux_sym_init_expr_repeat1] = aux_sym_init_expr_repeat1,
  [aux_sym_foreign_declaration_repeat1] = aux_sym_foreign_declaration_repeat1,
  [aux_sym_assign_repeat1] = aux_sym_assign_repeat1,
  [aux_sym__expanded_string_literal_repeat1] = aux_sym__expanded_string_literal_repeat1,
  [aux_sym_state_set_repeat1] = aux_sym_state_set_repeat1,
  [aux_sym_state_set_repeat2] = aux_sym_state_set_repeat2,
  [aux_sym_state_block_repeat1] = aux_sym_state_block_repeat1,
  [aux_sym_state_block_repeat2] = aux_sym_state_block_repeat2,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_block_repeat2] = aux_sym_block_repeat2,
  [aux_sym_comma_expr_repeat1] = aux_sym_comma_expr_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_preproc_params_repeat1] = aux_sym_preproc_params_repeat1,
  [aux_sym_preproc_argument_list_repeat1] = aux_sym_preproc_argument_list_repeat1,
  [alias_sym_file_name] = alias_sym_file_name,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_PERCENT_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__c_code_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__c_code_token2] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [sym_line_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_program] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_entry] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_evflag] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typename] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_char] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int8_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint8_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int16_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint16_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int32_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uint32_t] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assign] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_to] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__expanded_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACE2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_monitor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sync] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_syncq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ss] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_state] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_char_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_system_lib_string] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preproc_include_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_def_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_else_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elif_token1] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_defined] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_item] = {
    .visible = false,
    .named = true,
  },
  [sym__c_code] = {
    .visible = false,
    .named = true,
  },
  [sym_line_marker] = {
    .visible = true,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_program_param] = {
    .visible = true,
    .named = true,
  },
  [sym_initial_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_final_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_exit] = {
    .visible = true,
    .named = true,
  },
  [sym_funcdef] = {
    .visible = true,
    .named = true,
  },
  [sym_structdef] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_member_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_init_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_init_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_foreign_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_basetype] = {
    .visible = true,
    .named = true,
  },
  [sym_prim_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_abs_decl] = {
    .visible = true,
    .named = true,
  },
  [sym__abs_decl] = {
    .visible = false,
    .named = true,
  },
  [sym_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_param_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_assign] = {
    .visible = true,
    .named = true,
  },
  [sym__expanded_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_monitor] = {
    .visible = true,
    .named = true,
  },
  [sym_sync] = {
    .visible = true,
    .named = true,
  },
  [sym_event_flag] = {
    .visible = true,
    .named = true,
  },
  [sym_syncq] = {
    .visible = true,
    .named = true,
  },
  [sym_syncq_size] = {
    .visible = true,
    .named = true,
  },
  [sym_option] = {
    .visible = true,
    .named = true,
  },
  [sym_option_value] = {
    .visible = true,
    .named = true,
  },
  [sym_state_set] = {
    .visible = true,
    .named = true,
  },
  [sym_ss_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_state] = {
    .visible = true,
    .named = true,
  },
  [sym_state_block] = {
    .visible = true,
    .named = true,
  },
  [sym_state_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_transition] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_block_defn] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__expr] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_exit_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__comma_expr] = {
    .visible = false,
    .named = true,
  },
  [sym_comma_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_args] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_include] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_params] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_defined] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__c_code_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_program_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_init_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_foreign_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_assign_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__expanded_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_set_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_state_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_comma_expr_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_file_name] = {
    .visible = true,
    .named = true,
  },
};

enum {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_body = 4,
  field_condition = 5,
  field_consequence = 6,
  field_declarator = 7,
  field_directive = 8,
  field_field = 9,
  field_function = 10,
  field_initializer = 11,
  field_left = 12,
  field_name = 13,
  field_operator = 14,
  field_parameters = 15,
  field_path = 16,
  field_right = 17,
  field_type = 18,
  field_update = 19,
  field_value = 20,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_declarator] = "declarator",
  [field_directive] = "directive",
  [field_field] = "field",
  [field_function] = "function",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_right] = "right",
  [field_type] = "type",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 2},
  [6] = {.index = 7, .length = 2},
  [8] = {.index = 9, .length = 2},
  [9] = {.index = 11, .length = 2},
  [10] = {.index = 13, .length = 3},
  [11] = {.index = 16, .length = 1},
  [12] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 3},
  [15] = {.index = 22, .length = 2},
  [16] = {.index = 24, .length = 2},
  [17] = {.index = 26, .length = 1},
  [18] = {.index = 27, .length = 2},
  [19] = {.index = 29, .length = 2},
  [20] = {.index = 31, .length = 1},
  [21] = {.index = 32, .length = 1},
  [22] = {.index = 33, .length = 2},
  [23] = {.index = 35, .length = 1},
  [24] = {.index = 36, .length = 1},
  [25] = {.index = 37, .length = 2},
  [26] = {.index = 39, .length = 1},
  [27] = {.index = 40, .length = 2},
  [28] = {.index = 42, .length = 2},
  [29] = {.index = 44, .length = 3},
  [30] = {.index = 47, .length = 1},
  [31] = {.index = 48, .length = 1},
  [32] = {.index = 49, .length = 2},
  [33] = {.index = 51, .length = 2},
  [34] = {.index = 53, .length = 2},
  [35] = {.index = 55, .length = 3},
  [36] = {.index = 58, .length = 3},
  [37] = {.index = 61, .length = 3},
  [38] = {.index = 64, .length = 4},
  [39] = {.index = 68, .length = 1},
  [40] = {.index = 69, .length = 1},
  [41] = {.index = 70, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_directive, 0},
  [1] =
    {field_name, 1},
  [2] =
    {field_path, 1},
  [3] =
    {field_arguments, 1},
    {field_function, 0},
  [5] =
    {field_argument, 1},
    {field_operator, 0},
  [7] =
    {field_argument, 1},
    {field_directive, 0},
  [9] =
    {field_name, 1},
    {field_value, 2},
  [11] =
    {field_name, 1},
    {field_parameters, 2},
  [13] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [16] =
    {field_condition, 1},
  [17] =
    {field_alternative, 2},
    {field_name, 1},
  [19] =
    {field_name, 1},
    {field_parameters, 2},
    {field_value, 3},
  [22] =
    {field_alternative, 3},
    {field_condition, 1},
  [24] =
    {field_alternative, 3},
    {field_name, 1},
  [26] =
    {field_value, 1},
  [27] =
    {field_argument, 0},
    {field_operator, 1},
  [29] =
    {field_body, 2},
    {field_name, 1},
  [31] =
    {field_name, 2},
  [32] =
    {field_declarator, 0},
  [33] =
    {field_alternative, 4},
    {field_condition, 1},
  [35] =
    {field_function, 0},
  [36] =
    {field_field, 2},
  [37] =
    {field_type, 1},
    {field_value, 3},
  [39] =
    {field_type, 2},
  [40] =
    {field_condition, 2},
    {field_consequence, 4},
  [42] =
    {field_body, 4},
    {field_condition, 2},
  [44] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [47] =
    {field_body, 5},
  [48] =
    {field_consequence, 1},
  [49] =
    {field_body, 6},
    {field_update, 4},
  [51] =
    {field_body, 6},
    {field_condition, 3},
  [53] =
    {field_body, 6},
    {field_initializer, 2},
  [55] =
    {field_body, 7},
    {field_condition, 3},
    {field_update, 5},
  [58] =
    {field_body, 7},
    {field_initializer, 2},
    {field_update, 5},
  [61] =
    {field_body, 7},
    {field_condition, 4},
    {field_initializer, 2},
  [64] =
    {field_body, 8},
    {field_condition, 4},
    {field_initializer, 2},
    {field_update, 6},
  [68] =
    {field_name, 5},
  [69] =
    {field_condition, 2},
  [70] =
    {field_condition, 2},
    {field_name, 6},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [7] = {
    [2] = alias_sym_file_name,
  },
  [13] = {
    [1] = aux_sym__c_code_token2,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_string_literal, 2,
    sym_string_literal,
    alias_sym_file_name,
  aux_sym__c_code_repeat1, 2,
    aux_sym__c_code_repeat1,
    aux_sym__c_code_token2,
  0,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(243);
      if (lookahead == '!') ADVANCE(375);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '#') ADVANCE(264);
      if (lookahead == '%') ADVANCE(251);
      if (lookahead == '&') ADVANCE(373);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(608);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(282);
      if (lookahead == '+') ADVANCE(343);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '-') ADVANCE(348);
      if (lookahead == '.') ADVANCE(367);
      if (lookahead == '/') ADVANCE(378);
      if (lookahead == ':') ADVANCE(398);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '<') ADVANCE(391);
      if (lookahead == '=') ADVANCE(280);
      if (lookahead == '>') ADVANCE(387);
      if (lookahead == '?') ADVANCE(397);
      if (lookahead == 'F') ADVANCE(49);
      if (lookahead == 'L') ADVANCE(18);
      if (lookahead == 'N') ADVANCE(59);
      if (lookahead == 'T') ADVANCE(55);
      if (lookahead == 'U') ADVANCE(20);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == ']') ADVANCE(335);
      if (lookahead == '^') ADVANCE(384);
      if (lookahead == 'a') ADVANCE(194);
      if (lookahead == 'b') ADVANCE(188);
      if (lookahead == 'c') ADVANCE(116);
      if (lookahead == 'd') ADVANCE(84);
      if (lookahead == 'e') ADVANCE(137);
      if (lookahead == 'f') ADVANCE(66);
      if (lookahead == 'i') ADVANCE(103);
      if (lookahead == 'l') ADVANCE(171);
      if (lookahead == 'm') ADVANCE(175);
      if (lookahead == 'o') ADVANCE(181);
      if (lookahead == 'p') ADVANCE(189);
      if (lookahead == 'r') ADVANCE(95);
      if (lookahead == 's') ADVANCE(119);
      if (lookahead == 't') ADVANCE(169);
      if (lookahead == 'u') ADVANCE(21);
      if (lookahead == 'v') ADVANCE(172);
      if (lookahead == 'w') ADVANCE(118);
      if (lookahead == '{') ADVANCE(333);
      if (lookahead == '|') ADVANCE(381);
      if (lookahead == '}') ADVANCE(249);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(241)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(267);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(262);
      if (lookahead == '!') ADVANCE(45);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '%') ADVANCE(250);
      if (lookahead == '&') ADVANCE(372);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == '*') ADVANCE(281);
      if (lookahead == '+') ADVANCE(340);
      if (lookahead == '-') ADVANCE(345);
      if (lookahead == '/') ADVANCE(377);
      if (lookahead == '<') ADVANCE(392);
      if (lookahead == '=') ADVANCE(46);
      if (lookahead == '>') ADVANCE(388);
      if (lookahead == 'L') ADVANCE(17);
      if (lookahead == 'U') ADVANCE(19);
      if (lookahead == '^') ADVANCE(383);
      if (lookahead == 'u') ADVANCE(22);
      if (lookahead == '|') ADVANCE(382);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(1)
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(16)
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '/') ADVANCE(328);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == '{') ADVANCE(333);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(331);
      if (lookahead != 0) ADVANCE(332);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(16)
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '/') ADVANCE(421);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(424);
      if (lookahead != 0) ADVANCE(425);
      END_STATE();
    case 4:
      if (lookahead == '\n') ADVANCE(263);
      if (lookahead == '(') ADVANCE(608);
      if (lookahead == '/') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(648);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(644);
      if (lookahead != 0) ADVANCE(646);
      END_STATE();
    case 5:
      if (lookahead == '\n') ADVANCE(263);
      if (lookahead == '/') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(648);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(644);
      if (lookahead != 0) ADVANCE(646);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(39)
      if (lookahead == '/') ADVANCE(447);
      if (lookahead == '\\') ADVANCE(448);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(449);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(446);
      END_STATE();
    case 7:
      if (lookahead == '!') ADVANCE(375);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '%') ADVANCE(251);
      if (lookahead == '&') ADVANCE(373);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(282);
      if (lookahead == '+') ADVANCE(341);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '-') ADVANCE(346);
      if (lookahead == '.') ADVANCE(368);
      if (lookahead == '/') ADVANCE(378);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == ':') ADVANCE(398);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '<') ADVANCE(391);
      if (lookahead == '=') ADVANCE(280);
      if (lookahead == '>') ADVANCE(387);
      if (lookahead == '?') ADVANCE(397);
      if (lookahead == 'F') ADVANCE(470);
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(479);
      if (lookahead == 'T') ADVANCE(476);
      if (lookahead == 'U') ADVANCE(454);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == ']') ADVANCE(335);
      if (lookahead == '^') ADVANCE(384);
      if (lookahead == 'e') ADVANCE(599);
      if (lookahead == 'f') ADVANCE(489);
      if (lookahead == 's') ADVANCE(528);
      if (lookahead == 't') ADVANCE(576);
      if (lookahead == 'u') ADVANCE(457);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '|') ADVANCE(381);
      if (lookahead == '}') ADVANCE(248);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(7)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 8:
      if (lookahead == '!') ADVANCE(374);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '#') ADVANCE(101);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == '+') ADVANCE(342);
      if (lookahead == '-') ADVANCE(347);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == 'F') ADVANCE(470);
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(479);
      if (lookahead == 'T') ADVANCE(476);
      if (lookahead == 'U') ADVANCE(454);
      if (lookahead == 'b') ADVANCE(571);
      if (lookahead == 'c') ADVANCE(522);
      if (lookahead == 'd') ADVANCE(561);
      if (lookahead == 'e') ADVANCE(550);
      if (lookahead == 'f') ADVANCE(486);
      if (lookahead == 'i') ADVANCE(513);
      if (lookahead == 'l') ADVANCE(563);
      if (lookahead == 's') ADVANCE(526);
      if (lookahead == 't') ADVANCE(575);
      if (lookahead == 'u') ADVANCE(456);
      if (lookahead == 'v') ADVANCE(565);
      if (lookahead == 'w') ADVANCE(525);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '}') ADVANCE(248);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(8)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 9:
      if (lookahead == '!') ADVANCE(374);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == '+') ADVANCE(342);
      if (lookahead == '-') ADVANCE(347);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == 'F') ADVANCE(470);
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(479);
      if (lookahead == 'T') ADVANCE(476);
      if (lookahead == 'U') ADVANCE(454);
      if (lookahead == 'b') ADVANCE(571);
      if (lookahead == 'c') ADVANCE(560);
      if (lookahead == 'e') ADVANCE(599);
      if (lookahead == 'f') ADVANCE(488);
      if (lookahead == 'i') ADVANCE(514);
      if (lookahead == 's') ADVANCE(528);
      if (lookahead == 't') ADVANCE(576);
      if (lookahead == 'u') ADVANCE(457);
      if (lookahead == 'w') ADVANCE(525);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '}') ADVANCE(248);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(9)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 10:
      if (lookahead == '!') ADVANCE(374);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == '+') ADVANCE(342);
      if (lookahead == '-') ADVANCE(347);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == 'F') ADVANCE(470);
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(479);
      if (lookahead == 'T') ADVANCE(476);
      if (lookahead == 'U') ADVANCE(454);
      if (lookahead == 'b') ADVANCE(571);
      if (lookahead == 'c') ADVANCE(560);
      if (lookahead == 'e') ADVANCE(544);
      if (lookahead == 'f') ADVANCE(488);
      if (lookahead == 'i') ADVANCE(514);
      if (lookahead == 's') ADVANCE(528);
      if (lookahead == 't') ADVANCE(576);
      if (lookahead == 'u') ADVANCE(457);
      if (lookahead == 'w') ADVANCE(525);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '}') ADVANCE(248);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(10)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 11:
      if (lookahead == '!') ADVANCE(374);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == '+') ADVANCE(342);
      if (lookahead == '-') ADVANCE(347);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == 'F') ADVANCE(470);
      if (lookahead == 'L') ADVANCE(452);
      if (lookahead == 'N') ADVANCE(479);
      if (lookahead == 'T') ADVANCE(476);
      if (lookahead == 'U') ADVANCE(454);
      if (lookahead == 'c') ADVANCE(524);
      if (lookahead == 'd') ADVANCE(561);
      if (lookahead == 'e') ADVANCE(550);
      if (lookahead == 'f') ADVANCE(487);
      if (lookahead == 'i') ADVANCE(547);
      if (lookahead == 'l') ADVANCE(563);
      if (lookahead == 's') ADVANCE(526);
      if (lookahead == 't') ADVANCE(575);
      if (lookahead == 'u') ADVANCE(456);
      if (lookahead == 'v') ADVANCE(565);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(11)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 12:
      if (lookahead == '!') ADVANCE(374);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '+') ADVANCE(344);
      if (lookahead == '-') ADVANCE(349);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == 'L') ADVANCE(461);
      if (lookahead == 'U') ADVANCE(462);
      if (lookahead == 'd') ADVANCE(511);
      if (lookahead == 'u') ADVANCE(463);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(12)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 13:
      if (lookahead == '!') ADVANCE(45);
      if (lookahead == '%') ADVANCE(251);
      if (lookahead == '&') ADVANCE(373);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(282);
      if (lookahead == '+') ADVANCE(343);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '-') ADVANCE(348);
      if (lookahead == '.') ADVANCE(366);
      if (lookahead == '/') ADVANCE(378);
      if (lookahead == ':') ADVANCE(398);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '<') ADVANCE(391);
      if (lookahead == '=') ADVANCE(280);
      if (lookahead == '>') ADVANCE(387);
      if (lookahead == '?') ADVANCE(397);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == ']') ADVANCE(335);
      if (lookahead == '^') ADVANCE(384);
      if (lookahead == 'c') ADVANCE(523);
      if (lookahead == 'd') ADVANCE(561);
      if (lookahead == 'e') ADVANCE(551);
      if (lookahead == 'f') ADVANCE(540);
      if (lookahead == 'i') ADVANCE(547);
      if (lookahead == 'l') ADVANCE(563);
      if (lookahead == 's') ADVANCE(527);
      if (lookahead == 't') ADVANCE(600);
      if (lookahead == 'u') ADVANCE(535);
      if (lookahead == 'v') ADVANCE(565);
      if (lookahead == '|') ADVANCE(381);
      if (lookahead == '}') ADVANCE(248);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(13)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 14:
      if (lookahead == '!') ADVANCE(45);
      if (lookahead == '%') ADVANCE(250);
      if (lookahead == '&') ADVANCE(372);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(281);
      if (lookahead == '+') ADVANCE(340);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '-') ADVANCE(345);
      if (lookahead == '/') ADVANCE(377);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '<') ADVANCE(392);
      if (lookahead == '=') ADVANCE(46);
      if (lookahead == '>') ADVANCE(388);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == '^') ADVANCE(383);
      if (lookahead == 'c') ADVANCE(569);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '|') ADVANCE(382);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(14)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 15:
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '<') ADVANCE(47);
      if (lookahead == 'L') ADVANCE(453);
      if (lookahead == 'U') ADVANCE(455);
      if (lookahead == 'u') ADVANCE(458);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(15)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 16:
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(16)
      END_STATE();
    case 17:
      if (lookahead == '"') ADVANCE(417);
      END_STATE();
    case 18:
      if (lookahead == '"') ADVANCE(417);
      if (lookahead == '\'') ADVANCE(441);
      END_STATE();
    case 19:
      if (lookahead == '"') ADVANCE(419);
      END_STATE();
    case 20:
      if (lookahead == '"') ADVANCE(419);
      if (lookahead == '\'') ADVANCE(443);
      END_STATE();
    case 21:
      if (lookahead == '"') ADVANCE(418);
      if (lookahead == '\'') ADVANCE(442);
      if (lookahead == '8') ADVANCE(24);
      if (lookahead == 'i') ADVANCE(163);
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 22:
      if (lookahead == '"') ADVANCE(418);
      if (lookahead == '8') ADVANCE(23);
      END_STATE();
    case 23:
      if (lookahead == '"') ADVANCE(420);
      END_STATE();
    case 24:
      if (lookahead == '"') ADVANCE(420);
      if (lookahead == '\'') ADVANCE(444);
      END_STATE();
    case 25:
      if (lookahead == '#') ADVANCE(264);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '+') ADVANCE(340);
      if (lookahead == '-') ADVANCE(345);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == 'c') ADVANCE(115);
      if (lookahead == 'd') ADVANCE(168);
      if (lookahead == 'e') ADVANCE(159);
      if (lookahead == 'f') ADVANCE(138);
      if (lookahead == 'i') ADVANCE(148);
      if (lookahead == 'l') ADVANCE(171);
      if (lookahead == 'p') ADVANCE(189);
      if (lookahead == 's') ADVANCE(121);
      if (lookahead == 't') ADVANCE(224);
      if (lookahead == 'u') ADVANCE(127);
      if (lookahead == 'v') ADVANCE(172);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(25)
      END_STATE();
    case 26:
      if (lookahead == '#') ADVANCE(265);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == 'c') ADVANCE(115);
      if (lookahead == 'd') ADVANCE(168);
      if (lookahead == 'e') ADVANCE(159);
      if (lookahead == 'f') ADVANCE(138);
      if (lookahead == 'i') ADVANCE(148);
      if (lookahead == 'l') ADVANCE(171);
      if (lookahead == 'p') ADVANCE(189);
      if (lookahead == 's') ADVANCE(121);
      if (lookahead == 't') ADVANCE(224);
      if (lookahead == 'u') ADVANCE(127);
      if (lookahead == 'v') ADVANCE(172);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(26)
      END_STATE();
    case 27:
      if (lookahead == '%') ADVANCE(253);
      if (lookahead == '{') ADVANCE(244);
      END_STATE();
    case 28:
      if (lookahead == '%') ADVANCE(250);
      if (lookahead == '/') ADVANCE(246);
      if (lookahead == '}') ADVANCE(249);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(247);
      if (lookahead != 0) ADVANCE(245);
      END_STATE();
    case 29:
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '.') ADVANCE(33);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(29)
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 30:
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(656);
      END_STATE();
    case 31:
      if (lookahead == '*') ADVANCE(31);
      if (lookahead == '/') ADVANCE(654);
      if (lookahead != 0) ADVANCE(32);
      END_STATE();
    case 32:
      if (lookahead == '*') ADVANCE(31);
      if (lookahead != 0) ADVANCE(32);
      END_STATE();
    case 33:
      if (lookahead == '.') ADVANCE(34);
      END_STATE();
    case 34:
      if (lookahead == '.') ADVANCE(609);
      END_STATE();
    case 35:
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == 't') ADVANCE(562);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(36);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(35)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 36:
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 37:
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(427);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(428);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(437);
      END_STATE();
    case 38:
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(429);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 39:
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(39)
      END_STATE();
    case 40:
      if (lookahead == '1') ADVANCE(44);
      if (lookahead == '3') ADVANCE(42);
      if (lookahead == '8') ADVANCE(63);
      END_STATE();
    case 41:
      if (lookahead == '2') ADVANCE(62);
      END_STATE();
    case 42:
      if (lookahead == '2') ADVANCE(65);
      END_STATE();
    case 43:
      if (lookahead == '6') ADVANCE(61);
      END_STATE();
    case 44:
      if (lookahead == '6') ADVANCE(64);
      END_STATE();
    case 45:
      if (lookahead == '=') ADVANCE(386);
      END_STATE();
    case 46:
      if (lookahead == '=') ADVANCE(385);
      END_STATE();
    case 47:
      if (lookahead == '>') ADVANCE(450);
      if (lookahead == '\\') ADVANCE(48);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(47);
      END_STATE();
    case 48:
      if (lookahead == '>') ADVANCE(451);
      if (lookahead == '\\') ADVANCE(48);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(47);
      END_STATE();
    case 49:
      if (lookahead == 'A') ADVANCE(52);
      END_STATE();
    case 50:
      if (lookahead == 'E') ADVANCE(411);
      END_STATE();
    case 51:
      if (lookahead == 'E') ADVANCE(413);
      END_STATE();
    case 52:
      if (lookahead == 'L') ADVANCE(56);
      END_STATE();
    case 53:
      if (lookahead == 'L') ADVANCE(415);
      END_STATE();
    case 54:
      if (lookahead == 'L') ADVANCE(53);
      END_STATE();
    case 55:
      if (lookahead == 'R') ADVANCE(58);
      END_STATE();
    case 56:
      if (lookahead == 'S') ADVANCE(51);
      END_STATE();
    case 57:
      if (lookahead == 'U') ADVANCE(239);
      if (lookahead == 'u') ADVANCE(235);
      if (lookahead == 'x') ADVANCE(233);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(605);
      if (lookahead != 0) ADVANCE(603);
      END_STATE();
    case 58:
      if (lookahead == 'U') ADVANCE(50);
      END_STATE();
    case 59:
      if (lookahead == 'U') ADVANCE(54);
      END_STATE();
    case 60:
      if (lookahead == '_') ADVANCE(206);
      END_STATE();
    case 61:
      if (lookahead == '_') ADVANCE(208);
      END_STATE();
    case 62:
      if (lookahead == '_') ADVANCE(209);
      END_STATE();
    case 63:
      if (lookahead == '_') ADVANCE(210);
      END_STATE();
    case 64:
      if (lookahead == '_') ADVANCE(211);
      END_STATE();
    case 65:
      if (lookahead == '_') ADVANCE(212);
      END_STATE();
    case 66:
      if (lookahead == 'a') ADVANCE(143);
      if (lookahead == 'l') ADVANCE(174);
      if (lookahead == 'o') ADVANCE(183);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(136);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(145);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(146);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(185);
      END_STATE();
    case 71:
      if (lookahead == 'a') ADVANCE(109);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(216);
      if (lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(204);
      END_STATE();
    case 74:
      if (lookahead == 'b') ADVANCE(142);
      END_STATE();
    case 75:
      if (lookahead == 'c') ADVANCE(337);
      END_STATE();
    case 76:
      if (lookahead == 'c') ADVANCE(207);
      END_STATE();
    case 77:
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'e') ADVANCE(636);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(77);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 78:
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'e') ADVANCE(638);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(78);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 79:
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 80:
      if (lookahead == 'd') ADVANCE(292);
      END_STATE();
    case 81:
      if (lookahead == 'd') ADVANCE(652);
      END_STATE();
    case 82:
      if (lookahead == 'd') ADVANCE(302);
      END_STATE();
    case 83:
      if (lookahead == 'd') ADVANCE(125);
      END_STATE();
    case 84:
      if (lookahead == 'e') ADVANCE(107);
      if (lookahead == 'o') ADVANCE(218);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(411);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(359);
      END_STATE();
    case 87:
      if (lookahead == 'e') ADVANCE(413);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(351);
      END_STATE();
    case 89:
      if (lookahead == 'e') ADVANCE(361);
      END_STATE();
    case 90:
      if (lookahead == 'e') ADVANCE(318);
      END_STATE();
    case 91:
      if (lookahead == 'e') ADVANCE(355);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(290);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(213);
      END_STATE();
    case 96:
      if (lookahead == 'e') ADVANCE(82);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 98:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 99:
      if (lookahead == 'e') ADVANCE(152);
      if (lookahead == 'i') ADVANCE(141);
      END_STATE();
    case 100:
      if (lookahead == 'e') ADVANCE(162);
      END_STATE();
    case 101:
      if (lookahead == 'e') ADVANCE(160);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(101);
      END_STATE();
    case 102:
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 103:
      if (lookahead == 'f') ADVANCE(357);
      if (lookahead == 'n') ADVANCE(200);
      END_STATE();
    case 104:
      if (lookahead == 'f') ADVANCE(409);
      END_STATE();
    case 105:
      if (lookahead == 'f') ADVANCE(611);
      END_STATE();
    case 106:
      if (lookahead == 'f') ADVANCE(140);
      END_STATE();
    case 107:
      if (lookahead == 'f') ADVANCE(128);
      END_STATE();
    case 108:
      if (lookahead == 'g') ADVANCE(300);
      END_STATE();
    case 109:
      if (lookahead == 'g') ADVANCE(284);
      END_STATE();
    case 110:
      if (lookahead == 'g') ADVANCE(320);
      END_STATE();
    case 111:
      if (lookahead == 'g') ADVANCE(190);
      END_STATE();
    case 112:
      if (lookahead == 'g') ADVANCE(154);
      END_STATE();
    case 113:
      if (lookahead == 'g') ADVANCE(157);
      END_STATE();
    case 114:
      if (lookahead == 'g') ADVANCE(165);
      END_STATE();
    case 115:
      if (lookahead == 'h') ADVANCE(70);
      END_STATE();
    case 116:
      if (lookahead == 'h') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(149);
      END_STATE();
    case 117:
      if (lookahead == 'h') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(158);
      END_STATE();
    case 118:
      if (lookahead == 'h') ADVANCE(99);
      END_STATE();
    case 119:
      if (lookahead == 'h') ADVANCE(177);
      if (lookahead == 'i') ADVANCE(225);
      if (lookahead == 's') ADVANCE(350);
      if (lookahead == 't') ADVANCE(72);
      if (lookahead == 'y') ADVANCE(151);
      END_STATE();
    case 120:
      if (lookahead == 'h') ADVANCE(177);
      if (lookahead == 's') ADVANCE(350);
      if (lookahead == 't') ADVANCE(72);
      if (lookahead == 'y') ADVANCE(151);
      END_STATE();
    case 121:
      if (lookahead == 'h') ADVANCE(177);
      if (lookahead == 's') ADVANCE(350);
      if (lookahead == 't') ADVANCE(184);
      END_STATE();
    case 122:
      if (lookahead == 'h') ADVANCE(98);
      END_STATE();
    case 123:
      if (lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 124:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 125:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 126:
      if (lookahead == 'i') ADVANCE(201);
      END_STATE();
    case 127:
      if (lookahead == 'i') ADVANCE(163);
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 128:
      if (lookahead == 'i') ADVANCE(164);
      END_STATE();
    case 129:
      if (lookahead == 'i') ADVANCE(161);
      if (lookahead == 'u') ADVANCE(76);
      END_STATE();
    case 130:
      if (lookahead == 'i') ADVANCE(217);
      END_STATE();
    case 131:
      if (lookahead == 'i') ADVANCE(167);
      END_STATE();
    case 132:
      if (lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 133:
      if (lookahead == 'i') ADVANCE(179);
      if (lookahead == 's') ADVANCE(132);
      END_STATE();
    case 134:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 135:
      if (lookahead == 'i') ADVANCE(180);
      END_STATE();
    case 136:
      if (lookahead == 'k') ADVANCE(353);
      END_STATE();
    case 137:
      if (lookahead == 'l') ADVANCE(195);
      if (lookahead == 'n') ADVANCE(214);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(126);
      END_STATE();
    case 138:
      if (lookahead == 'l') ADVANCE(174);
      END_STATE();
    case 139:
      if (lookahead == 'l') ADVANCE(174);
      if (lookahead == 'o') ADVANCE(193);
      END_STATE();
    case 140:
      if (lookahead == 'l') ADVANCE(71);
      END_STATE();
    case 141:
      if (lookahead == 'l') ADVANCE(89);
      END_STATE();
    case 142:
      if (lookahead == 'l') ADVANCE(90);
      END_STATE();
    case 143:
      if (lookahead == 'l') ADVANCE(197);
      END_STATE();
    case 144:
      if (lookahead == 'm') ADVANCE(286);
      END_STATE();
    case 145:
      if (lookahead == 'm') ADVANCE(268);
      END_STATE();
    case 146:
      if (lookahead == 'm') ADVANCE(92);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(214);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(126);
      END_STATE();
    case 148:
      if (lookahead == 'n') ADVANCE(200);
      END_STATE();
    case 149:
      if (lookahead == 'n') ADVANCE(199);
      END_STATE();
    case 150:
      if (lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 151:
      if (lookahead == 'n') ADVANCE(75);
      END_STATE();
    case 152:
      if (lookahead == 'n') ADVANCE(352);
      END_STATE();
    case 153:
      if (lookahead == 'n') ADVANCE(288);
      END_STATE();
    case 154:
      if (lookahead == 'n') ADVANCE(324);
      END_STATE();
    case 155:
      if (lookahead == 'n') ADVANCE(339);
      END_STATE();
    case 156:
      if (lookahead == 'n') ADVANCE(365);
      END_STATE();
    case 157:
      if (lookahead == 'n') ADVANCE(283);
      END_STATE();
    case 158:
      if (lookahead == 'n') ADVANCE(198);
      END_STATE();
    case 159:
      if (lookahead == 'n') ADVANCE(219);
      if (lookahead == 'v') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(126);
      END_STATE();
    case 160:
      if (lookahead == 'n') ADVANCE(83);
      END_STATE();
    case 161:
      if (lookahead == 'n') ADVANCE(110);
      END_STATE();
    case 162:
      if (lookahead == 'n') ADVANCE(69);
      END_STATE();
    case 163:
      if (lookahead == 'n') ADVANCE(202);
      END_STATE();
    case 164:
      if (lookahead == 'n') ADVANCE(94);
      END_STATE();
    case 165:
      if (lookahead == 'n') ADVANCE(96);
      END_STATE();
    case 166:
      if (lookahead == 'n') ADVANCE(130);
      END_STATE();
    case 167:
      if (lookahead == 'n') ADVANCE(222);
      END_STATE();
    case 168:
      if (lookahead == 'o') ADVANCE(218);
      END_STATE();
    case 169:
      if (lookahead == 'o') ADVANCE(325);
      if (lookahead == 'r') ADVANCE(220);
      if (lookahead == 'y') ADVANCE(182);
      END_STATE();
    case 170:
      if (lookahead == 'o') ADVANCE(325);
      if (lookahead == 'y') ADVANCE(182);
      END_STATE();
    case 171:
      if (lookahead == 'o') ADVANCE(150);
      END_STATE();
    case 172:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 173:
      if (lookahead == 'o') ADVANCE(111);
      END_STATE();
    case 174:
      if (lookahead == 'o') ADVANCE(73);
      END_STATE();
    case 175:
      if (lookahead == 'o') ADVANCE(166);
      END_STATE();
    case 176:
      if (lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 177:
      if (lookahead == 'o') ADVANCE(191);
      END_STATE();
    case 178:
      if (lookahead == 'o') ADVANCE(187);
      END_STATE();
    case 179:
      if (lookahead == 'o') ADVANCE(153);
      END_STATE();
    case 180:
      if (lookahead == 'o') ADVANCE(155);
      END_STATE();
    case 181:
      if (lookahead == 'p') ADVANCE(215);
      END_STATE();
    case 182:
      if (lookahead == 'p') ADVANCE(100);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(363);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(129);
      END_STATE();
    case 185:
      if (lookahead == 'r') ADVANCE(294);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(223);
      END_STATE();
    case 187:
      if (lookahead == 'r') ADVANCE(336);
      END_STATE();
    case 188:
      if (lookahead == 'r') ADVANCE(93);
      END_STATE();
    case 189:
      if (lookahead == 'r') ADVANCE(173);
      END_STATE();
    case 190:
      if (lookahead == 'r') ADVANCE(68);
      END_STATE();
    case 191:
      if (lookahead == 'r') ADVANCE(205);
      END_STATE();
    case 192:
      if (lookahead == 'r') ADVANCE(156);
      END_STATE();
    case 193:
      if (lookahead == 'r') ADVANCE(102);
      END_STATE();
    case 194:
      if (lookahead == 's') ADVANCE(196);
      END_STATE();
    case 195:
      if (lookahead == 's') ADVANCE(86);
      END_STATE();
    case 196:
      if (lookahead == 's') ADVANCE(124);
      END_STATE();
    case 197:
      if (lookahead == 's') ADVANCE(87);
      END_STATE();
    case 198:
      if (lookahead == 's') ADVANCE(203);
      END_STATE();
    case 199:
      if (lookahead == 's') ADVANCE(203);
      if (lookahead == 't') ADVANCE(131);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(298);
      END_STATE();
    case 201:
      if (lookahead == 't') ADVANCE(272);
      END_STATE();
    case 202:
      if (lookahead == 't') ADVANCE(40);
      END_STATE();
    case 203:
      if (lookahead == 't') ADVANCE(322);
      END_STATE();
    case 204:
      if (lookahead == 't') ADVANCE(316);
      END_STATE();
    case 205:
      if (lookahead == 't') ADVANCE(296);
      END_STATE();
    case 206:
      if (lookahead == 't') ADVANCE(304);
      END_STATE();
    case 207:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 208:
      if (lookahead == 't') ADVANCE(308);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 210:
      if (lookahead == 't') ADVANCE(306);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(310);
      END_STATE();
    case 212:
      if (lookahead == 't') ADVANCE(314);
      END_STATE();
    case 213:
      if (lookahead == 't') ADVANCE(221);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(186);
      if (lookahead == 'u') ADVANCE(144);
      END_STATE();
    case 215:
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 216:
      if (lookahead == 't') ADVANCE(88);
      END_STATE();
    case 217:
      if (lookahead == 't') ADVANCE(178);
      END_STATE();
    case 218:
      if (lookahead == 'u') ADVANCE(74);
      END_STATE();
    case 219:
      if (lookahead == 'u') ADVANCE(144);
      END_STATE();
    case 220:
      if (lookahead == 'u') ADVANCE(85);
      END_STATE();
    case 221:
      if (lookahead == 'u') ADVANCE(192);
      END_STATE();
    case 222:
      if (lookahead == 'u') ADVANCE(91);
      END_STATE();
    case 223:
      if (lookahead == 'y') ADVANCE(271);
      END_STATE();
    case 224:
      if (lookahead == 'y') ADVANCE(182);
      END_STATE();
    case 225:
      if (lookahead == 'z') ADVANCE(97);
      END_STATE();
    case 226:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 227:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(426);
      END_STATE();
    case 228:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(428);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(437);
      END_STATE();
    case 229:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(603);
      END_STATE();
    case 230:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(434);
      END_STATE();
    case 231:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(437);
      END_STATE();
    case 232:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(432);
      END_STATE();
    case 233:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(229);
      END_STATE();
    case 234:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(233);
      END_STATE();
    case 235:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(234);
      END_STATE();
    case 236:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(235);
      END_STATE();
    case 237:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(236);
      END_STATE();
    case 238:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(237);
      END_STATE();
    case 239:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(238);
      END_STATE();
    case 240:
      if (lookahead != 0 &&
          lookahead != '\r') ADVANCE(656);
      if (lookahead == '\r') ADVANCE(658);
      END_STATE();
    case 241:
      if (eof) ADVANCE(243);
      if (lookahead == '!') ADVANCE(375);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '#') ADVANCE(264);
      if (lookahead == '%') ADVANCE(251);
      if (lookahead == '&') ADVANCE(373);
      if (lookahead == '\'') ADVANCE(445);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(282);
      if (lookahead == '+') ADVANCE(343);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '-') ADVANCE(348);
      if (lookahead == '.') ADVANCE(367);
      if (lookahead == '/') ADVANCE(378);
      if (lookahead == ':') ADVANCE(398);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '<') ADVANCE(391);
      if (lookahead == '=') ADVANCE(280);
      if (lookahead == '>') ADVANCE(387);
      if (lookahead == '?') ADVANCE(397);
      if (lookahead == 'F') ADVANCE(49);
      if (lookahead == 'L') ADVANCE(18);
      if (lookahead == 'N') ADVANCE(59);
      if (lookahead == 'T') ADVANCE(55);
      if (lookahead == 'U') ADVANCE(20);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == '\\') ADVANCE(57);
      if (lookahead == ']') ADVANCE(335);
      if (lookahead == '^') ADVANCE(384);
      if (lookahead == 'a') ADVANCE(194);
      if (lookahead == 'b') ADVANCE(188);
      if (lookahead == 'c') ADVANCE(116);
      if (lookahead == 'd') ADVANCE(84);
      if (lookahead == 'e') ADVANCE(137);
      if (lookahead == 'f') ADVANCE(66);
      if (lookahead == 'i') ADVANCE(103);
      if (lookahead == 'l') ADVANCE(171);
      if (lookahead == 'm') ADVANCE(175);
      if (lookahead == 'o') ADVANCE(181);
      if (lookahead == 'p') ADVANCE(189);
      if (lookahead == 'r') ADVANCE(95);
      if (lookahead == 's') ADVANCE(119);
      if (lookahead == 't') ADVANCE(169);
      if (lookahead == 'u') ADVANCE(21);
      if (lookahead == 'v') ADVANCE(172);
      if (lookahead == 'w') ADVANCE(118);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '|') ADVANCE(381);
      if (lookahead == '}') ADVANCE(249);
      if (lookahead == '~') ADVANCE(376);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(241)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(267);
      END_STATE();
    case 242:
      if (eof) ADVANCE(243);
      if (lookahead == '"') ADVANCE(327);
      if (lookahead == '#') ADVANCE(266);
      if (lookahead == '%') ADVANCE(27);
      if (lookahead == '(') ADVANCE(269);
      if (lookahead == ')') ADVANCE(270);
      if (lookahead == '*') ADVANCE(281);
      if (lookahead == ',') ADVANCE(278);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '/') ADVANCE(30);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == ';') ADVANCE(276);
      if (lookahead == '=') ADVANCE(279);
      if (lookahead == '[') ADVANCE(334);
      if (lookahead == 'a') ADVANCE(194);
      if (lookahead == 'c') ADVANCE(117);
      if (lookahead == 'd') ADVANCE(168);
      if (lookahead == 'e') ADVANCE(147);
      if (lookahead == 'f') ADVANCE(139);
      if (lookahead == 'i') ADVANCE(148);
      if (lookahead == 'l') ADVANCE(171);
      if (lookahead == 'm') ADVANCE(175);
      if (lookahead == 'o') ADVANCE(181);
      if (lookahead == 'p') ADVANCE(189);
      if (lookahead == 's') ADVANCE(120);
      if (lookahead == 't') ADVANCE(170);
      if (lookahead == 'u') ADVANCE(127);
      if (lookahead == 'v') ADVANCE(172);
      if (lookahead == 'w') ADVANCE(122);
      if (lookahead == '{') ADVANCE(277);
      if (lookahead == '}') ADVANCE(248);
      if (('+' <= lookahead && lookahead <= '-')) ADVANCE(36);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(242)
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_PERCENT_LBRACE);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(656);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(aux_sym__c_code_token1);
      if (lookahead == '/') ADVANCE(246);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(247);
      if (lookahead != 0 &&
          lookahead != '%' &&
          lookahead != '}') ADVANCE(245);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      if (lookahead == '%') ADVANCE(252);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(401);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_RBRACE_PERCENT);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_PERCENT_PERCENT);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '*') ADVANCE(254);
      if (lookahead == '/') ADVANCE(261);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '*') ADVANCE(254);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(656);
      if (lookahead == '\r') ADVANCE(257);
      if (lookahead != 0) ADVANCE(260);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\n') ADVANCE(656);
      if (lookahead == '\\') ADVANCE(256);
      if (lookahead != 0) ADVANCE(260);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '*') ADVANCE(255);
      if (lookahead == '/') ADVANCE(260);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(261);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '/') ADVANCE(258);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(259);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(261);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead == '\\') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(260);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(aux_sym__c_code_token2);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(261);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(262);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(263);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(644);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'e') ADVANCE(636);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(77);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'e') ADVANCE(638);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(78);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_POUND);
      if (lookahead == 'd') ADVANCE(621);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(sym_line_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(267);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_program);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_entry);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_exit);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_exit);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_struct);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(385);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(399);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(anon_sym_foreign);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_evflag);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_evflag);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_enum);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_union);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(anon_sym_typename);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_typename);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_void);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_char);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(anon_sym_char);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_short);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '1') ADVANCE(43);
      if (lookahead == '3') ADVANCE(41);
      if (lookahead == '8') ADVANCE(60);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '1') ADVANCE(468);
      if (lookahead == '3') ADVANCE(466);
      if (lookahead == '8') ADVANCE(480);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym_long);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_unsigned);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_int8_t);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(anon_sym_int8_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_uint8_t);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_uint8_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(anon_sym_int16_t);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(anon_sym_int16_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_uint16_t);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_uint16_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_int32_t);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_int32_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_uint32_t);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_uint32_t);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_float);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(anon_sym_double);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(anon_sym_string);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_const);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(anon_sym_assign);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(anon_sym_to);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(anon_sym_to);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(330);
      if (lookahead == '/') ADVANCE(332);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(332);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(329);
      if (lookahead == '/') ADVANCE(332);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(330);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '*') ADVANCE(329);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(330);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead == '/') ADVANCE(328);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(331);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(332);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(aux_sym__expanded_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{') ADVANCE(332);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_LBRACE2);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(anon_sym_monitor);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_sync);
      if (lookahead == 'q') ADVANCE(338);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_syncq);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(anon_sym_option);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(371);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == '=') ADVANCE(402);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(371);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(371);
      if (lookahead == '=') ADVANCE(402);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(370);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (lookahead == '=') ADVANCE(403);
      if (lookahead == '>') ADVANCE(369);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(370);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(370);
      if (lookahead == '=') ADVANCE(403);
      if (lookahead == '>') ADVANCE(369);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(227);
      if (lookahead == '0') ADVANCE(430);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_ss);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_state);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_break);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_continue);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(anon_sym_else);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_while);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_for);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(34);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(426);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(380);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(380);
      if (lookahead == '=') ADVANCE(406);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(386);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(656);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(656);
      if (lookahead == '=') ADVANCE(400);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(408);
      if (lookahead == '|') ADVANCE(379);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(379);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(407);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(389);
      if (lookahead == '>') ADVANCE(396);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(389);
      if (lookahead == '>') ADVANCE(395);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(394);
      if (lookahead == '=') ADVANCE(390);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(393);
      if (lookahead == '=') ADVANCE(390);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(404);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(405);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_sizeof);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(sym_true);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(sym_false);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(sym_null);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(sym_null);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(423);
      if (lookahead == '/') ADVANCE(425);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(425);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(422);
      if (lookahead == '/') ADVANCE(425);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(423);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(422);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(423);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(421);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(424);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(425);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(425);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(227);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(426);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(228);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(437);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'b') ADVANCE(436);
      if (lookahead == 'x') ADVANCE(231);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(435);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(437);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(428);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(228);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(437);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(435);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(437);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(428);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(226);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'b') ADVANCE(226);
      if (lookahead == 'x') ADVANCE(231);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(226);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'b') ADVANCE(38);
      if (lookahead == 'x') ADVANCE(37);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(226);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'P' ||
          lookahead == 'e' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(431);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(232);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(432);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'E') ||
          ('a' <= lookahead && lookahead <= 'e')) ADVANCE(432);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(230);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(434);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(232);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(433);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(434);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(230);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(434);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(433);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(434);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(231);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(437);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(232);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(435);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(437);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(231);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(437);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(435);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(437);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(428);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(231);
      if (lookahead == '.') ADVANCE(438);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(437);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(435);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(437);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(434);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(433);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(439);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'D') ||
          ('a' <= lookahead && lookahead <= 'd')) ADVANCE(434);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(432);
      if (lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(232);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'E') ||
          ('a' <= lookahead && lookahead <= 'e')) ADVANCE(432);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'F' ||
          lookahead == 'L' ||
          lookahead == 'U' ||
          lookahead == 'f' ||
          lookahead == 'l' ||
          lookahead == 'u') ADVANCE(440);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '*') ADVANCE(32);
      if (lookahead == '/') ADVANCE(656);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == 'U') ADVANCE(239);
      if (lookahead == 'u') ADVANCE(235);
      if (lookahead == 'x') ADVANCE(233);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(605);
      if (lookahead != 0) ADVANCE(603);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\\') ADVANCE(57);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(sym_system_lib_string);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(sym_system_lib_string);
      if (lookahead == '>') ADVANCE(450);
      if (lookahead == '\\') ADVANCE(48);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(47);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(417);
      if (lookahead == '\'') ADVANCE(441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(417);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(419);
      if (lookahead == '\'') ADVANCE(443);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(419);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(418);
      if (lookahead == '\'') ADVANCE(442);
      if (lookahead == '8') ADVANCE(459);
      if (lookahead == 'i') ADVANCE(555);
      if (lookahead == 'n') ADVANCE(536);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(418);
      if (lookahead == '\'') ADVANCE(442);
      if (lookahead == '8') ADVANCE(459);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(418);
      if (lookahead == '8') ADVANCE(460);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(420);
      if (lookahead == '\'') ADVANCE(444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(420);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(441);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(443);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(442);
      if (lookahead == '8') ADVANCE(464);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(469);
      if (lookahead == '3') ADVANCE(467);
      if (lookahead == '8') ADVANCE(483);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(482);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(481);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(484);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A') ADVANCE(473);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(414);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(416);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(474);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R') ADVANCE(478);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(472);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(475);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(588);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(589);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(590);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(591);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(592);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(539);
      if (lookahead == 'l') ADVANCE(566);
      if (lookahead == 'o') ADVANCE(572);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(539);
      if (lookahead == 'l') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(539);
      if (lookahead == 'o') ADVANCE(572);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(539);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(538);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(546);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(519);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(574);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(543);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(587);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(293);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(303);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(653);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(414);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(362);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(319);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(356);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(291);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(360);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(490);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(498);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(499);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(557);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(517);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(564);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(358);
      if (lookahead == 'n') ADVANCE(581);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(358);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(410);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(541);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(537);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(301);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(285);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(321);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(558);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(493);
      if (lookahead == 'o') ADVANCE(552);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(493);
      if (lookahead == 'o') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(493);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(567);
      if (lookahead == 'i') ADVANCE(601);
      if (lookahead == 't') ADVANCE(573);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(567);
      if (lookahead == 't') ADVANCE(573);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(601);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(521);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(556);
      if (lookahead == 'u') ADVANCE(496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(542);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(582);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(554);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(555);
      if (lookahead == 'n') ADVANCE(536);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(568);
      if (lookahead == 's') ADVANCE(530);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(559);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(354);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(578);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(492);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(502);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(503);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(579);
      if (lookahead == 'x') ADVANCE(533);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(287);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(505);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(581);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(518);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(289);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(596);
      if (lookahead == 'v') ADVANCE(516);
      if (lookahead == 'x') ADVANCE(533);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(596);
      if (lookahead == 'v') ADVANCE(516);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(594);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(580);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(598);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(583);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(520);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(491);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(508);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(509);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(552);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(595);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(326);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(548);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(515);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(529);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(494);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(577);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(549);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(510);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(507);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(364);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(531);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(295);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(597);
      if (lookahead == 'y') ADVANCE(570);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(597);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(585);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(501);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(506);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(593);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(299);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(465);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(317);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(297);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(305);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(275);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(309);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(313);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(307);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(311);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(315);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(534);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(495);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(545);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(500);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(504);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(533);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(570);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'z') ADVANCE(512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(602);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(603);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(604);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(aux_sym_preproc_include_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(aux_sym_preproc_def_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(aux_sym_preproc_if_token1);
      if (lookahead == 'd') ADVANCE(625);
      if (lookahead == 'n') ADVANCE(620);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'c') ADVANCE(637);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(635);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(624);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(626);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(628);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(615);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(607);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(631);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(632);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(610);
      if (lookahead == 'n') ADVANCE(617);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(633);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(616);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(612);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(613);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(614);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(639);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(629);
      if (lookahead == 's') ADVANCE(622);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(630);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(634);
      if (lookahead == 'n') ADVANCE(618);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(640);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(618);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(623);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'u') ADVANCE(619);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(641);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '*') ADVANCE(642);
      if (lookahead == '/') ADVANCE(654);
      if (lookahead == '\\') ADVANCE(647);
      if (lookahead != 0) ADVANCE(643);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(32);
      if (lookahead == '*') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(647);
      if (lookahead != 0) ADVANCE(643);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(263);
      if (lookahead == '/') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(648);
      if (lookahead == '\t' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(644);
      if (lookahead != 0) ADVANCE(646);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(643);
      if (lookahead == '/') ADVANCE(657);
      if (lookahead == '\\') ADVANCE(648);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(646);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\\') ADVANCE(648);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(646);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '*' &&
          lookahead != '\\') ADVANCE(643);
      if (lookahead == '\r') ADVANCE(650);
      if (lookahead == '*') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(647);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '\\') ADVANCE(646);
      if (lookahead == '\r') ADVANCE(651);
      if (lookahead == '\\') ADVANCE(648);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead != 0 &&
          lookahead != '\r' &&
          lookahead != '\\') ADVANCE(657);
      if (lookahead == '\r') ADVANCE(659);
      if (lookahead == '\\') ADVANCE(655);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead != 0 &&
          lookahead != '*' &&
          lookahead != '\\') ADVANCE(643);
      if (lookahead == '*') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(647);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead != 0 &&
          lookahead != '\\') ADVANCE(646);
      if (lookahead == '\\') ADVANCE(648);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_defined);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_defined);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(657);
      if (lookahead == '\\') ADVANCE(649);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(657);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(240);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(656);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(649);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(657);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\\') ADVANCE(656);
      if (lookahead == '\\') ADVANCE(240);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\\') ADVANCE(657);
      if (lookahead == '\\') ADVANCE(649);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 242},
  [2] = {.lex_state = 8},
  [3] = {.lex_state = 8},
  [4] = {.lex_state = 8},
  [5] = {.lex_state = 8},
  [6] = {.lex_state = 8},
  [7] = {.lex_state = 8},
  [8] = {.lex_state = 8},
  [9] = {.lex_state = 8},
  [10] = {.lex_state = 8},
  [11] = {.lex_state = 8},
  [12] = {.lex_state = 7},
  [13] = {.lex_state = 11},
  [14] = {.lex_state = 11},
  [15] = {.lex_state = 11},
  [16] = {.lex_state = 9},
  [17] = {.lex_state = 8},
  [18] = {.lex_state = 9},
  [19] = {.lex_state = 9},
  [20] = {.lex_state = 9},
  [21] = {.lex_state = 9},
  [22] = {.lex_state = 9},
  [23] = {.lex_state = 9},
  [24] = {.lex_state = 9},
  [25] = {.lex_state = 9},
  [26] = {.lex_state = 9},
  [27] = {.lex_state = 9},
  [28] = {.lex_state = 9},
  [29] = {.lex_state = 9},
  [30] = {.lex_state = 9},
  [31] = {.lex_state = 9},
  [32] = {.lex_state = 9},
  [33] = {.lex_state = 9},
  [34] = {.lex_state = 9},
  [35] = {.lex_state = 9},
  [36] = {.lex_state = 9},
  [37] = {.lex_state = 9},
  [38] = {.lex_state = 9},
  [39] = {.lex_state = 9},
  [40] = {.lex_state = 9},
  [41] = {.lex_state = 9},
  [42] = {.lex_state = 9},
  [43] = {.lex_state = 9},
  [44] = {.lex_state = 9},
  [45] = {.lex_state = 9},
  [46] = {.lex_state = 9},
  [47] = {.lex_state = 9},
  [48] = {.lex_state = 9},
  [49] = {.lex_state = 9},
  [50] = {.lex_state = 8},
  [51] = {.lex_state = 8},
  [52] = {.lex_state = 8},
  [53] = {.lex_state = 8},
  [54] = {.lex_state = 8},
  [55] = {.lex_state = 8},
  [56] = {.lex_state = 8},
  [57] = {.lex_state = 8},
  [58] = {.lex_state = 242},
  [59] = {.lex_state = 242},
  [60] = {.lex_state = 242},
  [61] = {.lex_state = 242},
  [62] = {.lex_state = 242},
  [63] = {.lex_state = 242},
  [64] = {.lex_state = 242},
  [65] = {.lex_state = 242},
  [66] = {.lex_state = 242},
  [67] = {.lex_state = 242},
  [68] = {.lex_state = 242},
  [69] = {.lex_state = 242},
  [70] = {.lex_state = 25},
  [71] = {.lex_state = 25},
  [72] = {.lex_state = 25},
  [73] = {.lex_state = 25},
  [74] = {.lex_state = 242},
  [75] = {.lex_state = 26},
  [76] = {.lex_state = 26},
  [77] = {.lex_state = 242},
  [78] = {.lex_state = 242},
  [79] = {.lex_state = 242},
  [80] = {.lex_state = 26},
  [81] = {.lex_state = 242},
  [82] = {.lex_state = 242},
  [83] = {.lex_state = 242},
  [84] = {.lex_state = 242},
  [85] = {.lex_state = 242},
  [86] = {.lex_state = 26},
  [87] = {.lex_state = 242},
  [88] = {.lex_state = 13},
  [89] = {.lex_state = 13},
  [90] = {.lex_state = 7},
  [91] = {.lex_state = 13},
  [92] = {.lex_state = 13},
  [93] = {.lex_state = 13},
  [94] = {.lex_state = 13},
  [95] = {.lex_state = 7},
  [96] = {.lex_state = 7},
  [97] = {.lex_state = 13},
  [98] = {.lex_state = 7},
  [99] = {.lex_state = 13},
  [100] = {.lex_state = 7},
  [101] = {.lex_state = 7},
  [102] = {.lex_state = 13},
  [103] = {.lex_state = 7},
  [104] = {.lex_state = 7},
  [105] = {.lex_state = 7},
  [106] = {.lex_state = 7},
  [107] = {.lex_state = 7},
  [108] = {.lex_state = 13},
  [109] = {.lex_state = 13},
  [110] = {.lex_state = 7},
  [111] = {.lex_state = 13},
  [112] = {.lex_state = 13},
  [113] = {.lex_state = 13},
  [114] = {.lex_state = 13},
  [115] = {.lex_state = 13},
  [116] = {.lex_state = 7},
  [117] = {.lex_state = 13},
  [118] = {.lex_state = 13},
  [119] = {.lex_state = 7},
  [120] = {.lex_state = 13},
  [121] = {.lex_state = 13},
  [122] = {.lex_state = 13},
  [123] = {.lex_state = 13},
  [124] = {.lex_state = 13},
  [125] = {.lex_state = 13},
  [126] = {.lex_state = 7},
  [127] = {.lex_state = 13},
  [128] = {.lex_state = 7},
  [129] = {.lex_state = 7},
  [130] = {.lex_state = 13},
  [131] = {.lex_state = 13},
  [132] = {.lex_state = 7},
  [133] = {.lex_state = 7},
  [134] = {.lex_state = 7},
  [135] = {.lex_state = 7},
  [136] = {.lex_state = 7},
  [137] = {.lex_state = 7},
  [138] = {.lex_state = 7},
  [139] = {.lex_state = 7},
  [140] = {.lex_state = 25},
  [141] = {.lex_state = 25},
  [142] = {.lex_state = 13},
  [143] = {.lex_state = 25},
  [144] = {.lex_state = 25},
  [145] = {.lex_state = 25},
  [146] = {.lex_state = 25},
  [147] = {.lex_state = 25},
  [148] = {.lex_state = 25},
  [149] = {.lex_state = 25},
  [150] = {.lex_state = 25},
  [151] = {.lex_state = 7},
  [152] = {.lex_state = 7},
  [153] = {.lex_state = 7},
  [154] = {.lex_state = 7},
  [155] = {.lex_state = 7},
  [156] = {.lex_state = 7},
  [157] = {.lex_state = 13},
  [158] = {.lex_state = 242},
  [159] = {.lex_state = 242},
  [160] = {.lex_state = 7},
  [161] = {.lex_state = 242},
  [162] = {.lex_state = 7},
  [163] = {.lex_state = 7},
  [164] = {.lex_state = 242},
  [165] = {.lex_state = 13},
  [166] = {.lex_state = 7},
  [167] = {.lex_state = 7},
  [168] = {.lex_state = 13},
  [169] = {.lex_state = 7},
  [170] = {.lex_state = 7},
  [171] = {.lex_state = 242},
  [172] = {.lex_state = 7},
  [173] = {.lex_state = 13},
  [174] = {.lex_state = 7},
  [175] = {.lex_state = 7},
  [176] = {.lex_state = 7},
  [177] = {.lex_state = 7},
  [178] = {.lex_state = 7},
  [179] = {.lex_state = 13},
  [180] = {.lex_state = 7},
  [181] = {.lex_state = 7},
  [182] = {.lex_state = 26},
  [183] = {.lex_state = 242},
  [184] = {.lex_state = 26},
  [185] = {.lex_state = 242},
  [186] = {.lex_state = 242},
  [187] = {.lex_state = 242},
  [188] = {.lex_state = 26},
  [189] = {.lex_state = 26},
  [190] = {.lex_state = 26},
  [191] = {.lex_state = 26},
  [192] = {.lex_state = 242},
  [193] = {.lex_state = 26},
  [194] = {.lex_state = 242},
  [195] = {.lex_state = 242},
  [196] = {.lex_state = 26},
  [197] = {.lex_state = 26},
  [198] = {.lex_state = 242},
  [199] = {.lex_state = 242},
  [200] = {.lex_state = 26},
  [201] = {.lex_state = 242},
  [202] = {.lex_state = 13},
  [203] = {.lex_state = 25},
  [204] = {.lex_state = 13},
  [205] = {.lex_state = 0},
  [206] = {.lex_state = 0},
  [207] = {.lex_state = 0},
  [208] = {.lex_state = 0},
  [209] = {.lex_state = 0},
  [210] = {.lex_state = 0},
  [211] = {.lex_state = 242},
  [212] = {.lex_state = 10},
  [213] = {.lex_state = 10},
  [214] = {.lex_state = 26},
  [215] = {.lex_state = 25},
  [216] = {.lex_state = 25},
  [217] = {.lex_state = 242},
  [218] = {.lex_state = 10},
  [219] = {.lex_state = 242},
  [220] = {.lex_state = 242},
  [221] = {.lex_state = 242},
  [222] = {.lex_state = 242},
  [223] = {.lex_state = 242},
  [224] = {.lex_state = 242},
  [225] = {.lex_state = 10},
  [226] = {.lex_state = 0},
  [227] = {.lex_state = 242},
  [228] = {.lex_state = 10},
  [229] = {.lex_state = 10},
  [230] = {.lex_state = 242},
  [231] = {.lex_state = 10},
  [232] = {.lex_state = 10},
  [233] = {.lex_state = 242},
  [234] = {.lex_state = 242},
  [235] = {.lex_state = 10},
  [236] = {.lex_state = 242},
  [237] = {.lex_state = 10},
  [238] = {.lex_state = 242},
  [239] = {.lex_state = 242},
  [240] = {.lex_state = 242},
  [241] = {.lex_state = 10},
  [242] = {.lex_state = 242},
  [243] = {.lex_state = 10},
  [244] = {.lex_state = 10},
  [245] = {.lex_state = 10},
  [246] = {.lex_state = 10},
  [247] = {.lex_state = 10},
  [248] = {.lex_state = 10},
  [249] = {.lex_state = 242},
  [250] = {.lex_state = 10},
  [251] = {.lex_state = 10},
  [252] = {.lex_state = 242},
  [253] = {.lex_state = 10},
  [254] = {.lex_state = 242},
  [255] = {.lex_state = 10},
  [256] = {.lex_state = 242},
  [257] = {.lex_state = 10},
  [258] = {.lex_state = 9},
  [259] = {.lex_state = 26},
  [260] = {.lex_state = 9},
  [261] = {.lex_state = 242},
  [262] = {.lex_state = 9},
  [263] = {.lex_state = 25},
  [264] = {.lex_state = 25},
  [265] = {.lex_state = 9},
  [266] = {.lex_state = 9},
  [267] = {.lex_state = 9},
  [268] = {.lex_state = 9},
  [269] = {.lex_state = 9},
  [270] = {.lex_state = 9},
  [271] = {.lex_state = 9},
  [272] = {.lex_state = 25},
  [273] = {.lex_state = 9},
  [274] = {.lex_state = 26},
  [275] = {.lex_state = 9},
  [276] = {.lex_state = 25},
  [277] = {.lex_state = 9},
  [278] = {.lex_state = 25},
  [279] = {.lex_state = 25},
  [280] = {.lex_state = 9},
  [281] = {.lex_state = 25},
  [282] = {.lex_state = 9},
  [283] = {.lex_state = 9},
  [284] = {.lex_state = 9},
  [285] = {.lex_state = 242},
  [286] = {.lex_state = 25},
  [287] = {.lex_state = 242},
  [288] = {.lex_state = 9},
  [289] = {.lex_state = 25},
  [290] = {.lex_state = 9},
  [291] = {.lex_state = 9},
  [292] = {.lex_state = 242},
  [293] = {.lex_state = 26},
  [294] = {.lex_state = 26},
  [295] = {.lex_state = 26},
  [296] = {.lex_state = 26},
  [297] = {.lex_state = 242},
  [298] = {.lex_state = 26},
  [299] = {.lex_state = 26},
  [300] = {.lex_state = 26},
  [301] = {.lex_state = 26},
  [302] = {.lex_state = 26},
  [303] = {.lex_state = 242},
  [304] = {.lex_state = 242},
  [305] = {.lex_state = 242},
  [306] = {.lex_state = 242},
  [307] = {.lex_state = 242},
  [308] = {.lex_state = 242},
  [309] = {.lex_state = 242},
  [310] = {.lex_state = 242},
  [311] = {.lex_state = 0},
  [312] = {.lex_state = 242},
  [313] = {.lex_state = 0},
  [314] = {.lex_state = 0},
  [315] = {.lex_state = 0},
  [316] = {.lex_state = 0},
  [317] = {.lex_state = 0},
  [318] = {.lex_state = 0},
  [319] = {.lex_state = 0},
  [320] = {.lex_state = 0},
  [321] = {.lex_state = 0},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 0},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 14},
  [331] = {.lex_state = 242},
  [332] = {.lex_state = 12},
  [333] = {.lex_state = 0},
  [334] = {.lex_state = 1},
  [335] = {.lex_state = 12},
  [336] = {.lex_state = 14},
  [337] = {.lex_state = 14},
  [338] = {.lex_state = 14},
  [339] = {.lex_state = 14},
  [340] = {.lex_state = 12},
  [341] = {.lex_state = 14},
  [342] = {.lex_state = 12},
  [343] = {.lex_state = 12},
  [344] = {.lex_state = 12},
  [345] = {.lex_state = 14},
  [346] = {.lex_state = 14},
  [347] = {.lex_state = 12},
  [348] = {.lex_state = 14},
  [349] = {.lex_state = 12},
  [350] = {.lex_state = 14},
  [351] = {.lex_state = 12},
  [352] = {.lex_state = 12},
  [353] = {.lex_state = 12},
  [354] = {.lex_state = 14},
  [355] = {.lex_state = 12},
  [356] = {.lex_state = 12},
  [357] = {.lex_state = 12},
  [358] = {.lex_state = 12},
  [359] = {.lex_state = 12},
  [360] = {.lex_state = 14},
  [361] = {.lex_state = 12},
  [362] = {.lex_state = 12},
  [363] = {.lex_state = 14},
  [364] = {.lex_state = 14},
  [365] = {.lex_state = 14},
  [366] = {.lex_state = 12},
  [367] = {.lex_state = 12},
  [368] = {.lex_state = 14},
  [369] = {.lex_state = 14},
  [370] = {.lex_state = 12},
  [371] = {.lex_state = 12},
  [372] = {.lex_state = 12},
  [373] = {.lex_state = 12},
  [374] = {.lex_state = 12},
  [375] = {.lex_state = 12},
  [376] = {.lex_state = 12},
  [377] = {.lex_state = 12},
  [378] = {.lex_state = 14},
  [379] = {.lex_state = 14},
  [380] = {.lex_state = 14},
  [381] = {.lex_state = 12},
  [382] = {.lex_state = 14},
  [383] = {.lex_state = 14},
  [384] = {.lex_state = 12},
  [385] = {.lex_state = 14},
  [386] = {.lex_state = 12},
  [387] = {.lex_state = 1},
  [388] = {.lex_state = 26},
  [389] = {.lex_state = 1},
  [390] = {.lex_state = 1},
  [391] = {.lex_state = 1},
  [392] = {.lex_state = 1},
  [393] = {.lex_state = 1},
  [394] = {.lex_state = 26},
  [395] = {.lex_state = 1},
  [396] = {.lex_state = 1},
  [397] = {.lex_state = 1},
  [398] = {.lex_state = 1},
  [399] = {.lex_state = 1},
  [400] = {.lex_state = 242},
  [401] = {.lex_state = 1},
  [402] = {.lex_state = 1},
  [403] = {.lex_state = 242},
  [404] = {.lex_state = 14},
  [405] = {.lex_state = 1},
  [406] = {.lex_state = 26},
  [407] = {.lex_state = 1},
  [408] = {.lex_state = 1},
  [409] = {.lex_state = 1},
  [410] = {.lex_state = 1},
  [411] = {.lex_state = 1},
  [412] = {.lex_state = 1},
  [413] = {.lex_state = 14},
  [414] = {.lex_state = 1},
  [415] = {.lex_state = 1},
  [416] = {.lex_state = 1},
  [417] = {.lex_state = 14},
  [418] = {.lex_state = 14},
  [419] = {.lex_state = 14},
  [420] = {.lex_state = 14},
  [421] = {.lex_state = 14},
  [422] = {.lex_state = 14},
  [423] = {.lex_state = 0},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 0},
  [426] = {.lex_state = 0},
  [427] = {.lex_state = 0},
  [428] = {.lex_state = 0},
  [429] = {.lex_state = 14},
  [430] = {.lex_state = 242},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0},
  [433] = {.lex_state = 0},
  [434] = {.lex_state = 0},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 0},
  [437] = {.lex_state = 0},
  [438] = {.lex_state = 0},
  [439] = {.lex_state = 0},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 14},
  [443] = {.lex_state = 14},
  [444] = {.lex_state = 14},
  [445] = {.lex_state = 242},
  [446] = {.lex_state = 14},
  [447] = {.lex_state = 242},
  [448] = {.lex_state = 14},
  [449] = {.lex_state = 242},
  [450] = {.lex_state = 242},
  [451] = {.lex_state = 242},
  [452] = {.lex_state = 26},
  [453] = {.lex_state = 242},
  [454] = {.lex_state = 15},
  [455] = {.lex_state = 242},
  [456] = {.lex_state = 242},
  [457] = {.lex_state = 242},
  [458] = {.lex_state = 242},
  [459] = {.lex_state = 242},
  [460] = {.lex_state = 242},
  [461] = {.lex_state = 242},
  [462] = {.lex_state = 242},
  [463] = {.lex_state = 26},
  [464] = {.lex_state = 15},
  [465] = {.lex_state = 26},
  [466] = {.lex_state = 242},
  [467] = {.lex_state = 26},
  [468] = {.lex_state = 26},
  [469] = {.lex_state = 26},
  [470] = {.lex_state = 26},
  [471] = {.lex_state = 14},
  [472] = {.lex_state = 26},
  [473] = {.lex_state = 26},
  [474] = {.lex_state = 26},
  [475] = {.lex_state = 242},
  [476] = {.lex_state = 242},
  [477] = {.lex_state = 26},
  [478] = {.lex_state = 242},
  [479] = {.lex_state = 26},
  [480] = {.lex_state = 26},
  [481] = {.lex_state = 15},
  [482] = {.lex_state = 26},
  [483] = {.lex_state = 14},
  [484] = {.lex_state = 26},
  [485] = {.lex_state = 26},
  [486] = {.lex_state = 242},
  [487] = {.lex_state = 242},
  [488] = {.lex_state = 26},
  [489] = {.lex_state = 242},
  [490] = {.lex_state = 35},
  [491] = {.lex_state = 14},
  [492] = {.lex_state = 14},
  [493] = {.lex_state = 242},
  [494] = {.lex_state = 242},
  [495] = {.lex_state = 14},
  [496] = {.lex_state = 14},
  [497] = {.lex_state = 1},
  [498] = {.lex_state = 1},
  [499] = {.lex_state = 242},
  [500] = {.lex_state = 14},
  [501] = {.lex_state = 242},
  [502] = {.lex_state = 242},
  [503] = {.lex_state = 242},
  [504] = {.lex_state = 242},
  [505] = {.lex_state = 242},
  [506] = {.lex_state = 14},
  [507] = {.lex_state = 1},
  [508] = {.lex_state = 242},
  [509] = {.lex_state = 14},
  [510] = {.lex_state = 2},
  [511] = {.lex_state = 2},
  [512] = {.lex_state = 242},
  [513] = {.lex_state = 242},
  [514] = {.lex_state = 35},
  [515] = {.lex_state = 14},
  [516] = {.lex_state = 242},
  [517] = {.lex_state = 2},
  [518] = {.lex_state = 242},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 28},
  [521] = {.lex_state = 28},
  [522] = {.lex_state = 242},
  [523] = {.lex_state = 242},
  [524] = {.lex_state = 242},
  [525] = {.lex_state = 28},
  [526] = {.lex_state = 28},
  [527] = {.lex_state = 242},
  [528] = {.lex_state = 28},
  [529] = {.lex_state = 28},
  [530] = {.lex_state = 28},
  [531] = {.lex_state = 35},
  [532] = {.lex_state = 28},
  [533] = {.lex_state = 242},
  [534] = {.lex_state = 242},
  [535] = {.lex_state = 28},
  [536] = {.lex_state = 242},
  [537] = {.lex_state = 28},
  [538] = {.lex_state = 242},
  [539] = {.lex_state = 242},
  [540] = {.lex_state = 28},
  [541] = {.lex_state = 28},
  [542] = {.lex_state = 242},
  [543] = {.lex_state = 28},
  [544] = {.lex_state = 242},
  [545] = {.lex_state = 0},
  [546] = {.lex_state = 3},
  [547] = {.lex_state = 242},
  [548] = {.lex_state = 3},
  [549] = {.lex_state = 0},
  [550] = {.lex_state = 4},
  [551] = {.lex_state = 3},
  [552] = {.lex_state = 2},
  [553] = {.lex_state = 4},
  [554] = {.lex_state = 242},
  [555] = {.lex_state = 242},
  [556] = {.lex_state = 3},
  [557] = {.lex_state = 0},
  [558] = {.lex_state = 242},
  [559] = {.lex_state = 242},
  [560] = {.lex_state = 35},
  [561] = {.lex_state = 242},
  [562] = {.lex_state = 28},
  [563] = {.lex_state = 242},
  [564] = {.lex_state = 242},
  [565] = {.lex_state = 0},
  [566] = {.lex_state = 3},
  [567] = {.lex_state = 242},
  [568] = {.lex_state = 242},
  [569] = {.lex_state = 242},
  [570] = {.lex_state = 242},
  [571] = {.lex_state = 4},
  [572] = {.lex_state = 242},
  [573] = {.lex_state = 242},
  [574] = {.lex_state = 242},
  [575] = {.lex_state = 242},
  [576] = {.lex_state = 242},
  [577] = {.lex_state = 242},
  [578] = {.lex_state = 0},
  [579] = {.lex_state = 242},
  [580] = {.lex_state = 242},
  [581] = {.lex_state = 242},
  [582] = {.lex_state = 1},
  [583] = {.lex_state = 242},
  [584] = {.lex_state = 242},
  [585] = {.lex_state = 242},
  [586] = {.lex_state = 242},
  [587] = {.lex_state = 25},
  [588] = {.lex_state = 242},
  [589] = {.lex_state = 242},
  [590] = {.lex_state = 0},
  [591] = {.lex_state = 242},
  [592] = {.lex_state = 242},
  [593] = {.lex_state = 242},
  [594] = {.lex_state = 0},
  [595] = {.lex_state = 29},
  [596] = {.lex_state = 0},
  [597] = {.lex_state = 0},
  [598] = {.lex_state = 1},
  [599] = {.lex_state = 0},
  [600] = {.lex_state = 242},
  [601] = {.lex_state = 0},
  [602] = {.lex_state = 0},
  [603] = {.lex_state = 242},
  [604] = {.lex_state = 0},
  [605] = {.lex_state = 0},
  [606] = {.lex_state = 0},
  [607] = {.lex_state = 0},
  [608] = {.lex_state = 0},
  [609] = {.lex_state = 0},
  [610] = {.lex_state = 0},
  [611] = {.lex_state = 0},
  [612] = {.lex_state = 242},
  [613] = {.lex_state = 0},
  [614] = {.lex_state = 242},
  [615] = {.lex_state = 242},
  [616] = {.lex_state = 1},
  [617] = {.lex_state = 0},
  [618] = {.lex_state = 0},
  [619] = {.lex_state = 0},
  [620] = {.lex_state = 242},
  [621] = {.lex_state = 242},
  [622] = {.lex_state = 242},
  [623] = {.lex_state = 35},
  [624] = {.lex_state = 0},
  [625] = {.lex_state = 242},
  [626] = {.lex_state = 0},
  [627] = {.lex_state = 0},
  [628] = {.lex_state = 0},
  [629] = {.lex_state = 0},
  [630] = {.lex_state = 0},
  [631] = {.lex_state = 0},
  [632] = {.lex_state = 0},
  [633] = {.lex_state = 242},
  [634] = {.lex_state = 242},
  [635] = {.lex_state = 0},
  [636] = {.lex_state = 242},
  [637] = {.lex_state = 0},
  [638] = {.lex_state = 0},
  [639] = {.lex_state = 0},
  [640] = {.lex_state = 0},
  [641] = {.lex_state = 0},
  [642] = {.lex_state = 242},
  [643] = {.lex_state = 0},
  [644] = {.lex_state = 0},
  [645] = {.lex_state = 5},
  [646] = {.lex_state = 0},
  [647] = {.lex_state = 0},
  [648] = {.lex_state = 242},
  [649] = {.lex_state = 6},
  [650] = {.lex_state = 0},
  [651] = {.lex_state = 6},
  [652] = {.lex_state = 29},
  [653] = {.lex_state = 0},
  [654] = {.lex_state = 242},
  [655] = {.lex_state = 242},
  [656] = {.lex_state = 29},
  [657] = {.lex_state = 5},
  [658] = {.lex_state = 242},
  [659] = {.lex_state = 29},
  [660] = {.lex_state = 242},
  [661] = {.lex_state = 6},
  [662] = {.lex_state = 242},
  [663] = {.lex_state = 242},
  [664] = {.lex_state = 29},
  [665] = {.lex_state = 0},
  [666] = {.lex_state = 242},
  [667] = {.lex_state = 29},
  [668] = {.lex_state = 242},
  [669] = {.lex_state = 242},
  [670] = {.lex_state = 5},
  [671] = {.lex_state = 242},
  [672] = {.lex_state = 5},
  [673] = {.lex_state = 29},
  [674] = {.lex_state = 242},
  [675] = {.lex_state = 5},
  [676] = {.lex_state = 5},
  [677] = {.lex_state = 29},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 5},
  [680] = {.lex_state = 242},
  [681] = {.lex_state = 5},
  [682] = {.lex_state = 242},
  [683] = {.lex_state = 242},
  [684] = {.lex_state = 242},
  [685] = {.lex_state = 0},
  [686] = {.lex_state = 29},
  [687] = {.lex_state = 242},
  [688] = {.lex_state = 0},
  [689] = {.lex_state = 0},
  [690] = {.lex_state = 242},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 5},
  [693] = {.lex_state = 242},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 242},
  [697] = {.lex_state = 242},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 242},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 1},
  [703] = {.lex_state = 0},
  [704] = {.lex_state = 8},
  [705] = {.lex_state = 8},
  [706] = {.lex_state = 1},
  [707] = {.lex_state = 1},
  [708] = {.lex_state = 29},
  [709] = {.lex_state = 242},
  [710] = {.lex_state = 1},
  [711] = {.lex_state = 1},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 8},
  [714] = {.lex_state = 1},
  [715] = {.lex_state = 1},
  [716] = {.lex_state = 1},
  [717] = {.lex_state = 0},
  [718] = {.lex_state = 8},
  [719] = {.lex_state = 8},
  [720] = {.lex_state = 8},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 0},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 29},
  [727] = {.lex_state = 8},
  [728] = {.lex_state = 0},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 29},
  [733] = {.lex_state = 29},
  [734] = {.lex_state = 242},
  [735] = {.lex_state = 242},
  [736] = {.lex_state = 8},
  [737] = {.lex_state = 242},
  [738] = {.lex_state = 0},
  [739] = {.lex_state = 1},
  [740] = {.lex_state = 0},
  [741] = {.lex_state = 1},
  [742] = {.lex_state = 1},
  [743] = {.lex_state = 1},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 0},
  [746] = {.lex_state = 0},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 1},
  [749] = {.lex_state = 0},
  [750] = {.lex_state = 0},
  [751] = {.lex_state = 8},
  [752] = {.lex_state = 8},
  [753] = {.lex_state = 29},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 1},
  [756] = {.lex_state = 0},
  [757] = {.lex_state = 0},
  [758] = {.lex_state = 29},
  [759] = {.lex_state = 242},
  [760] = {.lex_state = 1},
  [761] = {.lex_state = 8},
  [762] = {.lex_state = 1},
  [763] = {.lex_state = 8},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 242},
  [766] = {.lex_state = 0},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 0},
  [769] = {.lex_state = 8},
  [770] = {.lex_state = 1},
  [771] = {.lex_state = 242},
  [772] = {.lex_state = 29},
  [773] = {.lex_state = 0},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 1},
  [776] = {.lex_state = 0},
  [777] = {.lex_state = 29},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 29},
  [780] = {.lex_state = 0},
  [781] = {.lex_state = 0},
  [782] = {.lex_state = 1},
  [783] = {.lex_state = 29},
  [784] = {.lex_state = 29},
  [785] = {.lex_state = 29},
  [786] = {.lex_state = 29},
  [787] = {.lex_state = 242},
  [788] = {.lex_state = 0},
  [789] = {.lex_state = 1},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 29},
  [792] = {.lex_state = 0},
  [793] = {.lex_state = 29},
  [794] = {.lex_state = 29},
  [795] = {.lex_state = 29},
  [796] = {.lex_state = 0},
  [797] = {.lex_state = 242},
  [798] = {.lex_state = 259},
  [799] = {.lex_state = 29},
  [800] = {.lex_state = 0},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 242},
  [803] = {.lex_state = 29},
  [804] = {.lex_state = 0},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 8},
  [807] = {.lex_state = 259},
  [808] = {.lex_state = 0},
  [809] = {.lex_state = 0},
  [810] = {.lex_state = 1},
  [811] = {.lex_state = 0},
  [812] = {.lex_state = 0},
  [813] = {.lex_state = 1},
  [814] = {.lex_state = 0},
  [815] = {.lex_state = 0},
  [816] = {.lex_state = 29},
  [817] = {.lex_state = 0},
  [818] = {.lex_state = 29},
  [819] = {.lex_state = 29},
  [820] = {.lex_state = 29},
  [821] = {.lex_state = 0},
  [822] = {.lex_state = 259},
  [823] = {.lex_state = 0},
  [824] = {.lex_state = 0},
  [825] = {.lex_state = 0},
  [826] = {.lex_state = 1},
  [827] = {.lex_state = 259},
  [828] = {.lex_state = 259},
  [829] = {.lex_state = 259},
  [830] = {.lex_state = 0},
  [831] = {.lex_state = 29},
  [832] = {.lex_state = 242},
  [833] = {.lex_state = 29},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 0},
  [838] = {.lex_state = 0},
  [839] = {.lex_state = 29},
  [840] = {.lex_state = 29},
  [841] = {.lex_state = 242},
  [842] = {.lex_state = 29},
  [843] = {.lex_state = 242},
  [844] = {.lex_state = 29},
  [845] = {.lex_state = 29},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 29},
  [848] = {.lex_state = 242},
  [849] = {.lex_state = 242},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_RBRACE_PERCENT] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [sym_line_number] = ACTIONS(1),
    [anon_sym_program] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_entry] = ACTIONS(1),
    [anon_sym_exit] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_foreign] = ACTIONS(1),
    [anon_sym_evflag] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_typename] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_char] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_int8_t] = ACTIONS(1),
    [anon_sym_uint8_t] = ACTIONS(1),
    [anon_sym_int16_t] = ACTIONS(1),
    [anon_sym_uint16_t] = ACTIONS(1),
    [anon_sym_int32_t] = ACTIONS(1),
    [anon_sym_uint32_t] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_assign] = ACTIONS(1),
    [anon_sym_to] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_LBRACE2] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_monitor] = ACTIONS(1),
    [anon_sym_sync] = ACTIONS(1),
    [anon_sym_syncq] = ACTIONS(1),
    [anon_sym_option] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_ss] = ACTIONS(1),
    [anon_sym_state] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_null] = ACTIONS(1),
    [anon_sym_L_DQUOTE] = ACTIONS(1),
    [anon_sym_u_DQUOTE] = ACTIONS(1),
    [anon_sym_U_DQUOTE] = ACTIONS(1),
    [anon_sym_u8_DQUOTE] = ACTIONS(1),
    [anon_sym_L_SQUOTE] = ACTIONS(1),
    [anon_sym_u_SQUOTE] = ACTIONS(1),
    [anon_sym_U_SQUOTE] = ACTIONS(1),
    [anon_sym_u8_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [aux_sym_preproc_include_token1] = ACTIONS(1),
    [aux_sym_preproc_def_token1] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [aux_sym_preproc_if_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token2] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1),
    [aux_sym_preproc_else_token1] = ACTIONS(1),
    [aux_sym_preproc_elif_token1] = ACTIONS(1),
    [sym_preproc_directive] = ACTIONS(1),
    [anon_sym_defined] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_source_file] = STATE(835),
    [sym__top_level_item] = STATE(400),
    [sym_line_marker] = STATE(400),
    [sym_program] = STATE(400),
    [sym_preproc_include] = STATE(400),
    [sym_preproc_def] = STATE(400),
    [sym_preproc_function_def] = STATE(400),
    [sym_preproc_call] = STATE(400),
    [sym_preproc_if] = STATE(400),
    [sym_preproc_ifdef] = STATE(400),
    [aux_sym_source_file_repeat1] = STATE(400),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_POUND] = ACTIONS(7),
    [anon_sym_program] = ACTIONS(9),
    [aux_sym_preproc_include_token1] = ACTIONS(11),
    [aux_sym_preproc_def_token1] = ACTIONS(13),
    [aux_sym_preproc_if_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(17),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(17),
    [sym_preproc_directive] = ACTIONS(19),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(7),
    [sym_statement] = STATE(22),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(7),
    [aux_sym_block_repeat2] = STATE(22),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(23),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(17),
    [sym_statement] = STATE(24),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(17),
    [aux_sym_block_repeat2] = STATE(24),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(67),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(17),
    [sym_statement] = STATE(25),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(17),
    [aux_sym_block_repeat2] = STATE(25),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(69),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(11),
    [sym_statement] = STATE(18),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(11),
    [aux_sym_block_repeat2] = STATE(18),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(71),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(4),
    [sym_statement] = STATE(26),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(4),
    [aux_sym_block_repeat2] = STATE(26),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(73),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(17),
    [sym_statement] = STATE(23),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(17),
    [aux_sym_block_repeat2] = STATE(23),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(75),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(10),
    [sym_statement] = STATE(21),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(10),
    [aux_sym_block_repeat2] = STATE(21),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(77),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(3),
    [sym_statement] = STATE(27),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(3),
    [aux_sym_block_repeat2] = STATE(27),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(79),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(17),
    [sym_statement] = STATE(16),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(17),
    [aux_sym_block_repeat2] = STATE(16),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(81),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__c_code] = STATE(57),
    [sym_declaration] = STATE(52),
    [sym_basetype] = STATE(421),
    [sym_prim_type] = STATE(496),
    [sym_block] = STATE(282),
    [sym_block_defn] = STATE(17),
    [sym_statement] = STATE(19),
    [sym_break_statement] = STATE(282),
    [sym_continue_statement] = STATE(282),
    [sym_if_statement] = STATE(282),
    [sym_while_statement] = STATE(282),
    [sym_for_statement] = STATE(282),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(746),
    [sym_comma_expr] = STATE(746),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [aux_sym_block_repeat1] = STATE(17),
    [aux_sym_block_repeat2] = STATE(19),
    [anon_sym_PERCENT_LBRACE] = ACTIONS(21),
    [anon_sym_RBRACE] = ACTIONS(83),
    [anon_sym_PERCENT_PERCENT] = ACTIONS(25),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_evflag] = ACTIONS(35),
    [anon_sym_enum] = ACTIONS(31),
    [anon_sym_union] = ACTIONS(31),
    [anon_sym_typename] = ACTIONS(31),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_char] = ACTIONS(37),
    [anon_sym_short] = ACTIONS(37),
    [anon_sym_int] = ACTIONS(37),
    [anon_sym_long] = ACTIONS(37),
    [anon_sym_unsigned] = ACTIONS(39),
    [anon_sym_int8_t] = ACTIONS(37),
    [anon_sym_uint8_t] = ACTIONS(37),
    [anon_sym_int16_t] = ACTIONS(37),
    [anon_sym_uint16_t] = ACTIONS(37),
    [anon_sym_int32_t] = ACTIONS(37),
    [anon_sym_uint32_t] = ACTIONS(37),
    [anon_sym_float] = ACTIONS(37),
    [anon_sym_double] = ACTIONS(37),
    [anon_sym_string] = ACTIONS(37),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_if] = ACTIONS(49),
    [anon_sym_while] = ACTIONS(51),
    [anon_sym_for] = ACTIONS(53),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__expr] = STATE(99),
    [sym_parenthesized_expression] = STATE(99),
    [sym_call_expression] = STATE(99),
    [sym_exit_expression] = STATE(99),
    [sym_subscript_expression] = STATE(99),
    [sym_field_expression] = STATE(99),
    [sym_update_expression] = STATE(99),
    [sym_unary_expression] = STATE(99),
    [sym_binary_expression] = STATE(99),
    [sym_conditional_expression] = STATE(99),
    [sym_assignment_expression] = STATE(99),
    [sym_cast_expression] = STATE(99),
    [sym_sizeof_expression] = STATE(99),
    [sym_string_literal] = STATE(99),
    [sym_char_literal] = STATE(99),
    [anon_sym_RBRACE] = ACTIONS(85),
    [anon_sym_PERCENT] = ACTIONS(87),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_RPAREN] = ACTIONS(85),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(85),
    [anon_sym_COMMA] = ACTIONS(85),
    [anon_sym_EQ] = ACTIONS(87),
    [anon_sym_STAR] = ACTIONS(87),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(85),
    [anon_sym_RBRACK] = ACTIONS(85),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(87),
    [anon_sym_DASH_GT] = ACTIONS(85),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(87),
    [anon_sym_BANG] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_SLASH] = ACTIONS(87),
    [anon_sym_PIPE_PIPE] = ACTIONS(85),
    [anon_sym_AMP_AMP] = ACTIONS(85),
    [anon_sym_PIPE] = ACTIONS(87),
    [anon_sym_CARET] = ACTIONS(87),
    [anon_sym_EQ_EQ] = ACTIONS(85),
    [anon_sym_BANG_EQ] = ACTIONS(85),
    [anon_sym_GT] = ACTIONS(87),
    [anon_sym_GT_EQ] = ACTIONS(85),
    [anon_sym_LT_EQ] = ACTIONS(85),
    [anon_sym_LT] = ACTIONS(87),
    [anon_sym_LT_LT] = ACTIONS(87),
    [anon_sym_GT_GT] = ACTIONS(87),
    [anon_sym_QMARK] = ACTIONS(85),
    [anon_sym_COLON] = ACTIONS(85),
    [anon_sym_STAR_EQ] = ACTIONS(85),
    [anon_sym_SLASH_EQ] = ACTIONS(85),
    [anon_sym_PERCENT_EQ] = ACTIONS(85),
    [anon_sym_PLUS_EQ] = ACTIONS(85),
    [anon_sym_DASH_EQ] = ACTIONS(85),
    [anon_sym_LT_LT_EQ] = ACTIONS(85),
    [anon_sym_GT_GT_EQ] = ACTIONS(85),
    [anon_sym_AMP_EQ] = ACTIONS(85),
    [anon_sym_CARET_EQ] = ACTIONS(85),
    [anon_sym_PIPE_EQ] = ACTIONS(85),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(89),
    [sym_false] = ACTIONS(89),
    [sym_null] = ACTIONS(89),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(91),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(89),
    [sym_comment] = ACTIONS(3),
  },
  [13] = {
    [sym_basetype] = STATE(430),
    [sym_prim_type] = STATE(522),
    [sym_type_expr] = STATE(767),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(817),
    [sym_comma_expr] = STATE(817),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [14] = {
    [sym_basetype] = STATE(430),
    [sym_prim_type] = STATE(522),
    [sym_type_expr] = STATE(809),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(817),
    [sym_comma_expr] = STATE(817),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
  [15] = {
    [sym_basetype] = STATE(430),
    [sym_prim_type] = STATE(522),
    [sym_type_expr] = STATE(830),
    [sym__expr] = STATE(168),
    [sym_parenthesized_expression] = STATE(168),
    [sym_call_expression] = STATE(168),
    [sym_exit_expression] = STATE(168),
    [sym_subscript_expression] = STATE(168),
    [sym_field_expression] = STATE(168),
    [sym_update_expression] = STATE(168),
    [sym_unary_expression] = STATE(168),
    [sym_binary_expression] = STATE(168),
    [sym_conditional_expression] = STATE(168),
    [sym_assignment_expression] = STATE(168),
    [sym_cast_expression] = STATE(168),
    [sym_sizeof_expression] = STATE(168),
    [sym__comma_expr] = STATE(817),
    [sym_comma_expr] = STATE(817),
    [sym_string_literal] = STATE(168),
    [sym_char_literal] = STATE(168),
    [anon_sym_LPAREN] = ACTIONS(27),
    [anon_sym_exit] = ACTIONS(29),
    [anon_sym_struct] = ACTIONS(93),
    [anon_sym_evflag] = ACTIONS(95),
    [anon_sym_enum] = ACTIONS(93),
    [anon_sym_union] = ACTIONS(93),
    [anon_sym_typename] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(95),
    [anon_sym_char] = ACTIONS(97),
    [anon_sym_short] = ACTIONS(97),
    [anon_sym_int] = ACTIONS(97),
    [anon_sym_long] = ACTIONS(97),
    [anon_sym_unsigned] = ACTIONS(99),
    [anon_sym_int8_t] = ACTIONS(97),
    [anon_sym_uint8_t] = ACTIONS(97),
    [anon_sym_int16_t] = ACTIONS(97),
    [anon_sym_uint16_t] = ACTIONS(97),
    [anon_sym_int32_t] = ACTIONS(97),
    [anon_sym_uint32_t] = ACTIONS(97),
    [anon_sym_float] = ACTIONS(97),
    [anon_sym_double] = ACTIONS(97),
    [anon_sym_string] = ACTIONS(97),
    [anon_sym_DQUOTE] = ACTIONS(41),
    [anon_sym_PLUS] = ACTIONS(43),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_DASH_DASH] = ACTIONS(55),
    [anon_sym_PLUS_PLUS] = ACTIONS(55),
    [anon_sym_BANG] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(57),
    [anon_sym_sizeof] = ACTIONS(59),
    [sym_true] = ACTIONS(61),
    [sym_false] = ACTIONS(61),
    [sym_null] = ACTIONS(61),
    [anon_sym_L_DQUOTE] = ACTIONS(41),
    [anon_sym_u_DQUOTE] = ACTIONS(41),
    [anon_sym_U_DQUOTE] = ACTIONS(41),
    [anon_sym_u8_DQUOTE] = ACTIONS(41),
    [sym_number_literal] = ACTIONS(63),
    [anon_sym_L_SQUOTE] = ACTIONS(65),
    [anon_sym_u_SQUOTE] = ACTIONS(65),
    [anon_sym_U_SQUOTE] = ACTIONS(65),
    [anon_sym_u8_SQUOTE] = ACTIONS(65),
    [anon_sym_SQUOTE] = ACTIONS(65),
    [sym_identifier] = ACTIONS(61),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(103), 1,
      anon_sym_RBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [109] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(112), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(126), 1,
      anon_sym_unsigned,
    STATE(52), 1,
      sym_declaration,
    STATE(56), 1,
      sym__c_code,
    STATE(421), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(120), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(17), 2,
      sym_block_defn,
      aux_sym_block_repeat1,
    ACTIONS(117), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(115), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(123), 13,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
    ACTIONS(110), 18,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [198] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(83), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [307] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(129), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [416] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(131), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(134), 1,
      anon_sym_RBRACE,
    ACTIONS(136), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(139), 1,
      anon_sym_LPAREN,
    ACTIONS(142), 1,
      anon_sym_exit,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(154), 1,
      anon_sym_break,
    ACTIONS(157), 1,
      anon_sym_continue,
    ACTIONS(160), 1,
      anon_sym_if,
    ACTIONS(163), 1,
      anon_sym_while,
    ACTIONS(166), 1,
      anon_sym_for,
    ACTIONS(175), 1,
      anon_sym_sizeof,
    ACTIONS(181), 1,
      sym_number_literal,
    ACTIONS(151), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(169), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(172), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(178), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(148), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(184), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [525] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(81), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [634] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(75), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [743] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(187), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [852] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(189), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [961] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(191), 1,
      anon_sym_RBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1070] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(69), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1179] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(67), 1,
      anon_sym_RBRACE,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(20), 2,
      sym_statement,
      aux_sym_block_repeat2,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1288] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(288), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1393] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(265), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1498] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(275), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1603] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(243), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1708] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(270), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1813] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(248), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [1918] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(218), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2023] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(212), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2128] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(213), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2233] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(250), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2338] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(241), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2443] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(237), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2548] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(284), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2653] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(235), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2758] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(253), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2863] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(262), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [2968] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(291), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3073] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(246), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3178] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(193), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(195), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(197), 1,
      anon_sym_LBRACE,
    ACTIONS(199), 1,
      anon_sym_break,
    ACTIONS(201), 1,
      anon_sym_continue,
    ACTIONS(203), 1,
      anon_sym_if,
    ACTIONS(205), 1,
      anon_sym_while,
    ACTIONS(207), 1,
      anon_sym_for,
    STATE(244), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(723), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(225), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3283] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(283), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3388] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(271), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3493] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      anon_sym_break,
    ACTIONS(47), 1,
      anon_sym_continue,
    ACTIONS(49), 1,
      anon_sym_if,
    ACTIONS(51), 1,
      anon_sym_while,
    ACTIONS(53), 1,
      anon_sym_for,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(101), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(105), 1,
      anon_sym_PERCENT_PERCENT,
    STATE(273), 1,
      sym_statement,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(746), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(282), 7,
      sym__c_code,
      sym_block,
      sym_break_statement,
      sym_continue_statement,
      sym_if_statement,
      sym_while_statement,
      sym_for_statement,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [3598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(209), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(211), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(213), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(215), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(221), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(223), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(225), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(227), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(229), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(231), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [3964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [4025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(217), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(219), 33,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
  [4086] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(64), 1,
      sym_program_param,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(590), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(63), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(85), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4187] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(62), 1,
      sym_program_param,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(618), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(69), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(71), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4288] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(237), 1,
      anon_sym_LPAREN,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(61), 1,
      sym_program_param,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(597), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(67), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(76), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4389] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(596), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(66), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(80), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4484] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(627), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(65), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(72), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4579] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(611), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4674] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(611), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(68), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4769] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(610), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(73), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4864] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(594), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(86), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [4959] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(596), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(80), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5054] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(641), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    STATE(77), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5149] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(243), 1,
      anon_sym_foreign,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(627), 1,
      sym_entry,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(72), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5244] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(148), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(147), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5329] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(283), 1,
      anon_sym_program,
    STATE(143), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(144), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5414] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(287), 1,
      anon_sym_program,
    STATE(150), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(146), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5499] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(265), 1,
      anon_sym_ss,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(277), 1,
      anon_sym_exit,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(140), 1,
      sym_exit,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(141), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5584] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(296), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(301), 1,
      anon_sym_struct,
    ACTIONS(304), 1,
      anon_sym_foreign,
    ACTIONS(316), 1,
      anon_sym_int,
    ACTIONS(319), 1,
      anon_sym_unsigned,
    ACTIONS(322), 1,
      anon_sym_assign,
    ACTIONS(325), 1,
      anon_sym_monitor,
    ACTIONS(328), 1,
      anon_sym_sync,
    ACTIONS(331), 1,
      anon_sym_syncq,
    ACTIONS(334), 1,
      anon_sym_option,
    STATE(420), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(299), 2,
      anon_sym_entry,
      anon_sym_ss,
    ACTIONS(307), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(74), 2,
      sym_initial_defn,
      aux_sym_program_repeat1,
    ACTIONS(310), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(304), 10,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
      sym_declaration,
      sym_foreign_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(313), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5670] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(341), 1,
      anon_sym_exit,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(191), 1,
      sym_exit,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(193), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5753] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(283), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(341), 1,
      anon_sym_exit,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(196), 1,
      sym_exit,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(190), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5836] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(345), 1,
      anon_sym_exit,
    STATE(187), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(198), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(211), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [5919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(347), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [5970] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(351), 1,
      anon_sym_RBRACE,
    ACTIONS(353), 1,
      anon_sym_when,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(513), 1,
      sym_entry,
    STATE(765), 1,
      sym_exit,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(171), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    STATE(512), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6059] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(287), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(341), 1,
      anon_sym_exit,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(197), 1,
      sym_exit,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(182), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(355), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [6193] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(359), 34,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [6244] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(345), 1,
      anon_sym_exit,
    STATE(183), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(194), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(211), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6327] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(345), 1,
      anon_sym_exit,
    STATE(199), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(287), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(201), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(211), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6410] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(263), 1,
      anon_sym_ss,
    ACTIONS(345), 1,
      anon_sym_exit,
    STATE(185), 1,
      sym_exit,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(283), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(195), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(211), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(281), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6493] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(267), 1,
      anon_sym_ss,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(341), 1,
      anon_sym_exit,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(189), 1,
      sym_exit,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6576] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(239), 1,
      anon_sym_entry,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(261), 1,
      anon_sym_option,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(353), 1,
      anon_sym_when,
    ACTIONS(363), 1,
      anon_sym_RBRACE,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(518), 1,
      sym_entry,
    STATE(735), 1,
      sym_exit,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(79), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    STATE(516), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [6665] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 8,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(365), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(379), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(377), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6773] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(381), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(811), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [6845] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(383), 6,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6929] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(415), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(413), 28,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [6981] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(417), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7031] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(423), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(421), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7081] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(425), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(730), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7153] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(427), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(804), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7225] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(429), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7275] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(433), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(754), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7347] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(437), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(435), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7401] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(439), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(823), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7473] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(441), 1,
      anon_sym_RBRACE,
    ACTIONS(443), 1,
      anon_sym_LPAREN,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      sym_number_literal,
    STATE(580), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(165), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(451), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [7597] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(455), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(812), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7669] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(443), 1,
      anon_sym_LPAREN,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      sym_number_literal,
    ACTIONS(457), 1,
      anon_sym_RBRACE,
    STATE(583), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(165), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7743] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(459), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(814), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7815] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(461), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(781), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7887] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(463), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(747), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [7959] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(467), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(465), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(469), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8063] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(473), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(846), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(475), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8185] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 6,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(365), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8245] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(479), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8295] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 4,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(365), 24,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8359] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(365), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8427] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(483), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(838), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8499] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(371), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(365), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8569] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(487), 6,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(485), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8629] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(489), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(836), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [8701] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(371), 1,
      anon_sym_EQ,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(365), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8773] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(371), 1,
      anon_sym_EQ,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(365), 21,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8847] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 4,
      anon_sym_EQ,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(365), 22,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(491), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [8963] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(371), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(365), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(495), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9069] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(499), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(744), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9141] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(501), 7,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_COLON,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9223] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(503), 1,
      anon_sym_RPAREN,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(808), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9295] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(505), 1,
      anon_sym_SEMI,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(796), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(509), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(507), 29,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9417] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(371), 13,
      anon_sym_PERCENT,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(365), 26,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_QMARK,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [9471] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(443), 1,
      anon_sym_LPAREN,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      sym_number_literal,
    STATE(693), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(165), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9542] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(805), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9611] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(511), 1,
      anon_sym_RPAREN,
    ACTIONS(515), 1,
      sym_number_literal,
    STATE(695), 1,
      sym_args,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(513), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(179), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9682] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(443), 1,
      anon_sym_LPAREN,
    ACTIONS(445), 1,
      anon_sym_LBRACE,
    ACTIONS(449), 1,
      sym_number_literal,
    STATE(688), 1,
      sym_init_expr,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(447), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(165), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9753] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(757), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9822] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(694), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9891] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(63), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    STATE(834), 2,
      sym__comma_expr,
      sym_comma_expr,
    ACTIONS(61), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(168), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [9960] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(515), 1,
      sym_number_literal,
    ACTIONS(517), 1,
      anon_sym_RPAREN,
    STATE(740), 1,
      sym_args,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(513), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(179), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10031] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(147), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10103] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(279), 1,
      anon_sym_struct,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10175] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(521), 1,
      anon_sym_COMMA,
    STATE(557), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(519), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [10261] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(287), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(146), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10333] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(287), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10405] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(526), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(531), 1,
      anon_sym_program,
    ACTIONS(533), 1,
      anon_sym_struct,
    ACTIONS(545), 1,
      anon_sym_int,
    ACTIONS(548), 1,
      anon_sym_unsigned,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(536), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(539), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(529), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(542), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10477] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10549] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10621] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(149), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10693] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(557), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(145), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(555), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10765] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(269), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(271), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(279), 1,
      anon_sym_struct,
    ACTIONS(291), 1,
      anon_sym_program,
    STATE(442), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(141), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(264), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [10837] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(91), 1,
      sym_number_literal,
    ACTIONS(559), 1,
      anon_sym_LBRACE,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(99), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10905] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(563), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(561), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(121), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [10970] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(567), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(565), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(122), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11035] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(571), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(569), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(91), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11100] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(575), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(573), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(173), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11165] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(577), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(92), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11230] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(39), 1,
      anon_sym_unsigned,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(591), 1,
      sym_identifier,
    STATE(417), 1,
      sym_basetype,
    STATE(419), 1,
      sym_type_qualifier,
    STATE(496), 1,
      sym_prim_type,
    STATE(639), 1,
      sym_param_decl,
    STATE(691), 1,
      sym_type_expr,
    ACTIONS(35), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(31), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(558), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(564), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
    ACTIONS(37), 13,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [11307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(229), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [11354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(595), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(593), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [11401] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(599), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(597), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(131), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(603), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(601), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [11513] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(607), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(605), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(108), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11578] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(609), 1,
      anon_sym_LPAREN,
    ACTIONS(613), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(611), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(118), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 9,
      anon_sym_POUND,
      anon_sym_int,
      anon_sym_sync,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(213), 30,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [11690] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(615), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [11771] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(619), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(617), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(142), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11836] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(623), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(621), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(127), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [11901] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_COMMA,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(625), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [11984] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(631), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(629), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(202), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12049] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(91), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(99), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12114] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(644), 1,
      anon_sym_int,
    ACTIONS(647), 1,
      anon_sym_unsigned,
    ACTIONS(650), 1,
      anon_sym_assign,
    ACTIONS(653), 1,
      anon_sym_monitor,
    ACTIONS(656), 1,
      anon_sym_sync,
    ACTIONS(659), 1,
      anon_sym_syncq,
    ACTIONS(662), 1,
      anon_sym_option,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(638), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(171), 2,
      sym_state_defn,
      aux_sym_state_block_repeat1,
    ACTIONS(633), 4,
      anon_sym_RBRACE,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_when,
    ACTIONS(635), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(308), 6,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
      sym_option,
    ACTIONS(641), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [12187] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(667), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(665), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(124), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12252] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(669), 3,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [12333] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(673), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(671), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(204), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12398] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(677), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(675), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(88), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12463] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(681), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(679), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(112), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12528] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(685), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(683), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(114), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12593] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(689), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(687), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(115), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12658] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(521), 1,
      anon_sym_COMMA,
    ACTIONS(691), 1,
      anon_sym_RPAREN,
    STATE(640), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [12743] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(695), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(693), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(117), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12808] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(27), 1,
      anon_sym_LPAREN,
    ACTIONS(29), 1,
      anon_sym_exit,
    ACTIONS(59), 1,
      anon_sym_sizeof,
    ACTIONS(699), 1,
      sym_number_literal,
    ACTIONS(43), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(55), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(57), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(697), 4,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
    ACTIONS(65), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(120), 15,
      sym__expr,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_exit_expression,
      sym_subscript_expression,
      sym_field_expression,
      sym_update_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_conditional_expression,
      sym_assignment_expression,
      sym_cast_expression,
      sym_sizeof_expression,
      sym_string_literal,
      sym_char_literal,
  [12873] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [12943] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(553), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(186), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13013] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    ACTIONS(557), 1,
      anon_sym_program,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(555), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13083] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(287), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(201), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13153] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(557), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(555), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13223] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(194), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13293] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13363] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(275), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(193), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13433] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(287), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13503] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(184), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13573] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 1,
      anon_sym_int,
    ACTIONS(548), 1,
      anon_sym_unsigned,
    ACTIONS(701), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(704), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(707), 1,
      anon_sym_struct,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(531), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(536), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(539), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(529), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(542), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13643] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    ACTIONS(553), 1,
      anon_sym_program,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13713] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(553), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(551), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13783] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(287), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13853] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(287), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(182), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(285), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13923] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(291), 1,
      anon_sym_program,
    ACTIONS(337), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(339), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(343), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(188), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [13993] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(275), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(273), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14063] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(198), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14133] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 1,
      anon_sym_program,
    ACTIONS(545), 1,
      anon_sym_int,
    ACTIONS(548), 1,
      anon_sym_unsigned,
    ACTIONS(710), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(713), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(716), 1,
      anon_sym_struct,
    STATE(444), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(536), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(200), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(539), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(296), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(529), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(542), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14203] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(233), 1,
      anon_sym_PERCENT_LBRACE,
    ACTIONS(235), 1,
      anon_sym_PERCENT_PERCENT,
    ACTIONS(241), 1,
      anon_sym_struct,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(446), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(291), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    STATE(192), 2,
      sym_final_defn,
      aux_sym_program_repeat3,
    ACTIONS(247), 3,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(297), 3,
      sym__c_code,
      sym_funcdef,
      sym_structdef,
    ACTIONS(289), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14273] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(719), 1,
      anon_sym_RBRACK,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [14352] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(725), 1,
      anon_sym_ss,
    STATE(203), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(721), 23,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14401] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LPAREN,
    ACTIONS(385), 1,
      anon_sym_EQ,
    ACTIONS(387), 1,
      anon_sym_LBRACK,
    ACTIONS(391), 1,
      anon_sym_AMP,
    ACTIONS(393), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(395), 1,
      anon_sym_AMP_AMP,
    ACTIONS(397), 1,
      anon_sym_PIPE,
    ACTIONS(399), 1,
      anon_sym_CARET,
    ACTIONS(409), 1,
      anon_sym_QMARK,
    ACTIONS(728), 1,
      anon_sym_COLON,
    ACTIONS(373), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(375), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(389), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(401), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(403), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(405), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(407), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(367), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(411), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [14480] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(210), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(547), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14550] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(207), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(544), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14620] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(226), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(563), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14690] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(209), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(567), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14760] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(226), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(574), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14830] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(253), 1,
      anon_sym_assign,
    ACTIONS(255), 1,
      anon_sym_monitor,
    ACTIONS(257), 1,
      anon_sym_sync,
    ACTIONS(259), 1,
      anon_sym_syncq,
    ACTIONS(730), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(226), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    STATE(554), 2,
      sym_state,
      aux_sym_state_set_repeat2,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14900] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 1,
      anon_sym_ss,
    STATE(211), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(721), 24,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [14947] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 1,
      anon_sym_else,
    STATE(280), 1,
      sym_else_statement,
    ACTIONS(737), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(735), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [14994] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(741), 1,
      anon_sym_else,
    STATE(245), 1,
      sym_else_statement,
    ACTIONS(737), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(735), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15041] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 1,
      anon_sym_ss,
    STATE(214), 2,
      sym_state_set,
      aux_sym_program_repeat2,
    ACTIONS(723), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(721), 23,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15088] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(746), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [15131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(752), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(750), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [15174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(756), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(754), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(758), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(764), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(762), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(768), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(766), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(772), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(770), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(776), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(774), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(778), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15468] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(784), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(782), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(788), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(786), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15552] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 1,
      anon_sym_int,
    ACTIONS(802), 1,
      anon_sym_unsigned,
    ACTIONS(805), 1,
      anon_sym_assign,
    ACTIONS(808), 1,
      anon_sym_monitor,
    ACTIONS(811), 1,
      anon_sym_sync,
    ACTIONS(814), 1,
      anon_sym_syncq,
    ACTIONS(817), 1,
      anon_sym_state,
    STATE(422), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(793), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(226), 2,
      sym_ss_defn,
      aux_sym_state_set_repeat1,
    ACTIONS(790), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(314), 5,
      sym_declaration,
      sym_assign,
      sym_monitor,
      sym_sync,
      sym_syncq,
    ACTIONS(796), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(819), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(823), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(829), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(827), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(833), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(831), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(835), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15828] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(359), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [15870] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(839), 1,
      anon_sym_LPAREN,
    ACTIONS(841), 1,
      anon_sym_STAR,
    ACTIONS(843), 1,
      anon_sym_const,
    STATE(417), 1,
      sym_basetype,
    STATE(445), 1,
      sym_type_qualifier,
    STATE(496), 1,
      sym_prim_type,
    STATE(639), 1,
      sym_param_decl,
    STATE(691), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    STATE(564), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [15940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(847), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(845), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [15982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(849), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(855), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(853), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(857), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(227), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(225), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(209), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(863), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(861), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(867), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(865), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(871), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(869), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(875), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(873), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(879), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(877), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(883), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(881), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(887), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(885), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(355), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(891), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(889), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(895), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(893), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(899), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(897), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(347), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16696] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(903), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(901), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(907), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(905), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(221), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(229), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(911), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(909), 32,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_state,
      anon_sym_when,
  [16906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 14,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_else,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(213), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(355), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [16989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(746), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(829), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(827), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(746), 25,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(859), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(857), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(603), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(601), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(913), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(891), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(889), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(359), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(347), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(823), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(213), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(875), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(873), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(879), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(877), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(917), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(887), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(885), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(752), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(750), 24,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [17645] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(867), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(865), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(359), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(837), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(835), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(595), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(593), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(355), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(883), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(881), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(347), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [17932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(788), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(786), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [17973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(907), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(905), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18014] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(760), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(758), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(923), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(921), 31,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
      anon_sym_when,
  [18096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(229), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(752), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(750), 25,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_ss,
  [18178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(899), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(897), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 11,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
    ACTIONS(213), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(229), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 13,
      anon_sym_exit,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_if,
      anon_sym_while,
      anon_sym_for,
      anon_sym_sizeof,
      sym_true,
      sym_false,
      sym_null,
      sym_identifier,
    ACTIONS(849), 20,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DQUOTE,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
  [18342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(917), 24,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(361), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(359), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(917), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(595), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(593), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(913), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(915), 8,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(913), 23,
      ts_builtin_sym_end,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18577] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(603), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(601), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(213), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18655] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(229), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(349), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(347), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 9,
      anon_sym_POUND,
      anon_sym_int,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
    ACTIONS(355), 22,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_program,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [18772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(927), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(925), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18810] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(931), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(929), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(935), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(933), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(939), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(937), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(943), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(941), 28,
      anon_sym_PERCENT_LBRACE,
      anon_sym_PERCENT_PERCENT,
      anon_sym_entry,
      anon_sym_struct,
      anon_sym_foreign,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_ss,
  [18962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(945), 27,
      anon_sym_RBRACE,
      anon_sym_entry,
      anon_sym_exit,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_option,
      anon_sym_when,
  [18999] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(949), 1,
      anon_sym_RBRACE,
    STATE(443), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(312), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19046] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(951), 1,
      anon_sym_RBRACE,
    STATE(443), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(309), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19093] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(953), 1,
      anon_sym_RPAREN,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(606), 1,
      sym_param_decl,
    STATE(691), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19142] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(955), 1,
      anon_sym_RBRACE,
    ACTIONS(966), 1,
      anon_sym_int,
    ACTIONS(969), 1,
      anon_sym_unsigned,
    STATE(443), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    ACTIONS(960), 2,
      anon_sym_evflag,
      anon_sym_void,
    STATE(312), 2,
      sym_member_decl,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(957), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(963), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19189] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    ACTIONS(972), 1,
      anon_sym_RPAREN,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(619), 1,
      sym_param_decl,
    STATE(691), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(976), 2,
      anon_sym_int,
      anon_sym_sync,
    ACTIONS(974), 23,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
      anon_sym_assign,
      anon_sym_monitor,
      anon_sym_syncq,
      anon_sym_state,
  [19271] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(37), 1,
      anon_sym_int,
    ACTIONS(251), 1,
      anon_sym_unsigned,
    STATE(417), 1,
      sym_basetype,
    STATE(496), 1,
      sym_prim_type,
    STATE(678), 1,
      sym_param_decl,
    STATE(691), 1,
      sym_type_expr,
    ACTIONS(245), 2,
      anon_sym_evflag,
      anon_sym_void,
    ACTIONS(247), 4,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
    ACTIONS(249), 12,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [19317] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(988), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(736), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(318), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19368] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(998), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(763), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19419] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1000), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(719), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19470] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1002), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(720), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19521] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1004), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(704), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19572] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1006), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(718), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(325), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19623] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1008), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(806), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19674] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1010), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(752), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(317), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19725] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1012), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(713), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(319), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19776] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1014), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(727), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19827] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1016), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(769), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19878] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1018), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(751), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(320), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19929] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1020), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(761), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(326), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [19980] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(978), 1,
      anon_sym_POUND,
    ACTIONS(980), 1,
      anon_sym_program,
    ACTIONS(982), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(984), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(986), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(992), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(994), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(996), 1,
      sym_preproc_directive,
    ACTIONS(1022), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(990), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(705), 2,
      sym_preproc_else,
      sym_preproc_elif,
    STATE(322), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [20031] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 1,
      anon_sym_LPAREN,
    STATE(346), 1,
      sym_preproc_argument_list,
    ACTIONS(1028), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1024), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20065] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1032), 1,
      anon_sym_int,
    ACTIONS(1030), 20,
      anon_sym_RBRACE,
      anon_sym_struct,
      anon_sym_evflag,
      anon_sym_enum,
      anon_sym_union,
      anon_sym_typename,
      anon_sym_void,
      anon_sym_char,
      anon_sym_short,
      anon_sym_long,
      anon_sym_unsigned,
      anon_sym_int8_t,
      anon_sym_uint8_t,
      anon_sym_int16_t,
      anon_sym_uint16_t,
      anon_sym_int32_t,
      anon_sym_uint32_t,
      anon_sym_float,
      anon_sym_double,
      anon_sym_string,
  [20094] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1036), 1,
      anon_sym_RPAREN,
    ACTIONS(1042), 1,
      sym_number_literal,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(336), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20137] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1050), 1,
      anon_sym_POUND,
    ACTIONS(1053), 1,
      anon_sym_program,
    ACTIONS(1056), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1059), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1062), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1070), 1,
      sym_preproc_directive,
    ACTIONS(1067), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    ACTIONS(1065), 3,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(333), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [20180] = 5,
    ACTIONS(1024), 1,
      anon_sym_LF,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      sym_comment,
    STATE(407), 1,
      sym_preproc_argument_list,
    ACTIONS(1028), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20213] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1077), 1,
      anon_sym_RPAREN,
    ACTIONS(1079), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(337), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20256] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1083), 1,
      anon_sym_RPAREN,
    ACTIONS(1085), 1,
      anon_sym_COMMA,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    STATE(635), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20311] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COMMA,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1109), 1,
      anon_sym_RPAREN,
    STATE(607), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20366] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1111), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [20408] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 3,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
  [20456] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1115), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(380), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1119), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1117), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20524] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1121), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(379), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20564] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1129), 1,
      sym_number_literal,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(411), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20604] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1137), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(365), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1141), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1139), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20672] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1145), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1143), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20700] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1147), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(383), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(471), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(469), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20768] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1149), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(385), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1113), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20836] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1151), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(339), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20876] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1153), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(368), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20916] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1155), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(338), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [20956] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1113), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 13,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [20988] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1157), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(387), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21028] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1159), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(354), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21068] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1161), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(401), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21108] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1163), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(378), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21148] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1165), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(399), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21188] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1169), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1167), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21216] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1171), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(396), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21256] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1173), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(393), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1175), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1181), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1179), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1185), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1183), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21380] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1187), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(392), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21420] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1189), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(350), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21460] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1191), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [21510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1195), 5,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1193), 15,
      anon_sym_PERCENT,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21538] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1197), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(391), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21578] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1199), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(404), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21618] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1201), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(412), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21658] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1203), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(413), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21698] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1205), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(395), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21738] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1207), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(410), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21778] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_defined,
    ACTIONS(1209), 1,
      sym_number_literal,
    ACTIONS(1038), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1040), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1044), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(382), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21818] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1211), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(414), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [21858] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1113), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 11,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [21892] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 4,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1111), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [21928] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1113), 2,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1111), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [21968] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1213), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(409), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22008] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1113), 1,
      anon_sym_PIPE,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [22052] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1113), 1,
      anon_sym_PIPE,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [22098] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1215), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(405), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22138] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1111), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [22184] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1123), 1,
      anon_sym_LPAREN,
    ACTIONS(1133), 1,
      sym_identifier,
    ACTIONS(1135), 1,
      anon_sym_defined,
    ACTIONS(1217), 1,
      sym_number_literal,
    ACTIONS(1125), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1127), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1131), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(397), 7,
      sym_char_literal,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
  [22224] = 7,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(1113), 7,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [22259] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1227), 1,
      anon_sym_POUND,
    ACTIONS(1230), 1,
      anon_sym_program,
    ACTIONS(1233), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1236), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1239), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1245), 1,
      sym_preproc_directive,
    ACTIONS(1242), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(388), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22300] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1175), 1,
      anon_sym_LF,
    ACTIONS(1177), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22327] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1117), 1,
      anon_sym_LF,
    ACTIONS(1119), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22354] = 9,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22393] = 10,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1113), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22434] = 11,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1113), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22477] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_POUND,
    ACTIONS(1258), 1,
      anon_sym_program,
    ACTIONS(1260), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1262), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1264), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1266), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1270), 1,
      sym_preproc_directive,
    ACTIONS(1268), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(406), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22518] = 12,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1272), 1,
      anon_sym_LF,
    ACTIONS(1274), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1276), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22563] = 12,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1113), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1276), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22608] = 6,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 11,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [22641] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1179), 1,
      anon_sym_LF,
    ACTIONS(1181), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22668] = 8,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(1113), 5,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
  [22705] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_POUND,
    ACTIONS(9), 1,
      anon_sym_program,
    ACTIONS(11), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(19), 1,
      sym_preproc_directive,
    ACTIONS(1278), 1,
      ts_builtin_sym_end,
    ACTIONS(17), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(403), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22746] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 15,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22775] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1193), 1,
      anon_sym_LF,
    ACTIONS(1195), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22802] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1280), 1,
      ts_builtin_sym_end,
    ACTIONS(1282), 1,
      anon_sym_POUND,
    ACTIONS(1285), 1,
      anon_sym_program,
    ACTIONS(1288), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1291), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1294), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1300), 1,
      sym_preproc_directive,
    ACTIONS(1297), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(403), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22843] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1303), 1,
      anon_sym_RPAREN,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22892] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1113), 13,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22923] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_POUND,
    ACTIONS(1258), 1,
      anon_sym_program,
    ACTIONS(1260), 1,
      aux_sym_preproc_include_token1,
    ACTIONS(1262), 1,
      aux_sym_preproc_def_token1,
    ACTIONS(1264), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(1270), 1,
      sym_preproc_directive,
    ACTIONS(1305), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(1268), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(388), 10,
      sym__top_level_item,
      sym_line_marker,
      sym_program,
      sym_preproc_include,
      sym_preproc_def,
      sym_preproc_function_def,
      sym_preproc_call,
      sym_preproc_if,
      sym_preproc_ifdef,
      aux_sym_source_file_repeat1,
  [22964] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1143), 1,
      anon_sym_LF,
    ACTIONS(1145), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [22991] = 3,
    ACTIONS(469), 1,
      anon_sym_LF,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(471), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23018] = 12,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1274), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1276), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1307), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23063] = 12,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1274), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1276), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1309), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23108] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1111), 1,
      anon_sym_LF,
    ACTIONS(1113), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23135] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1183), 1,
      anon_sym_LF,
    ACTIONS(1185), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23162] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1089), 1,
      anon_sym_AMP,
    ACTIONS(1091), 1,
      anon_sym_SLASH,
    ACTIONS(1093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1095), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1097), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_CARET,
    ACTIONS(1311), 1,
      anon_sym_RPAREN,
    ACTIONS(1081), 2,
      anon_sym_PERCENT,
      anon_sym_STAR,
    ACTIONS(1087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1101), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1105), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1107), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23211] = 12,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1248), 1,
      anon_sym_AMP,
    ACTIONS(1252), 1,
      anon_sym_CARET,
    ACTIONS(1254), 1,
      anon_sym_PIPE,
    ACTIONS(1274), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1276), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1313), 1,
      anon_sym_LF,
    ACTIONS(1221), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1225), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1250), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1219), 3,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1223), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [23256] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1167), 1,
      anon_sym_LF,
    ACTIONS(1169), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23283] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1139), 1,
      anon_sym_LF,
    ACTIONS(1141), 18,
      anon_sym_PERCENT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [23310] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1317), 1,
      sym_identifier,
    STATE(419), 1,
      sym_type_qualifier,
    STATE(647), 1,
      sym_declarator,
    STATE(689), 1,
      sym_abs_decl,
    ACTIONS(1315), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(527), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23354] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1321), 1,
      sym_identifier,
    STATE(419), 1,
      sym_type_qualifier,
    ACTIONS(1319), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(533), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23392] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      anon_sym_STAR,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1325), 1,
      sym_identifier,
    STATE(419), 1,
      sym_type_qualifier,
    ACTIONS(1323), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(489), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
    STATE(534), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23430] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_SEMI,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(536), 1,
      sym_declarator,
    STATE(613), 1,
      sym_init_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23464] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    ACTIONS(1333), 1,
      anon_sym_SEMI,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(617), 1,
      sym_init_declarator,
    STATE(628), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23498] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1329), 1,
      anon_sym_SEMI,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(613), 1,
      sym_init_declarator,
    STATE(628), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_program,
    ACTIONS(1335), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_program,
    ACTIONS(1339), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      anon_sym_program,
    ACTIONS(1343), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 1,
      anon_sym_program,
    ACTIONS(1347), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 1,
      anon_sym_program,
    ACTIONS(1351), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 1,
      anon_sym_program,
    ACTIONS(1355), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23646] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(628), 1,
      sym_declarator,
    STATE(685), 1,
      sym_init_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23677] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(839), 1,
      anon_sym_LPAREN,
    ACTIONS(841), 1,
      anon_sym_STAR,
    ACTIONS(843), 1,
      anon_sym_const,
    ACTIONS(1315), 1,
      anon_sym_RPAREN,
    STATE(445), 1,
      sym_type_qualifier,
    STATE(689), 1,
      sym_abs_decl,
    STATE(527), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [23708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      anon_sym_program,
    ACTIONS(1359), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 1,
      anon_sym_program,
    ACTIONS(1363), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 1,
      anon_sym_program,
    ACTIONS(1367), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 1,
      anon_sym_program,
    ACTIONS(1371), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      anon_sym_program,
    ACTIONS(1375), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_program,
    ACTIONS(1379), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      anon_sym_program,
    ACTIONS(1383), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 1,
      anon_sym_program,
    ACTIONS(1387), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 1,
      anon_sym_program,
    ACTIONS(1391), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 1,
      anon_sym_program,
    ACTIONS(1395), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 1,
      anon_sym_program,
    ACTIONS(1399), 10,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
      sym_preproc_directive,
  [23917] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(687), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23945] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(773), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [23973] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(668), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24001] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(839), 1,
      anon_sym_LPAREN,
    ACTIONS(841), 1,
      anon_sym_STAR,
    ACTIONS(843), 1,
      anon_sym_const,
    ACTIONS(1323), 1,
      anon_sym_RPAREN,
    STATE(445), 1,
      sym_type_qualifier,
    STATE(534), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [24029] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1317), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(658), 1,
      sym_declarator,
    STATE(493), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24057] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(839), 1,
      anon_sym_LPAREN,
    ACTIONS(841), 1,
      anon_sym_STAR,
    ACTIONS(843), 1,
      anon_sym_const,
    ACTIONS(1319), 1,
      anon_sym_RPAREN,
    STATE(445), 1,
      sym_type_qualifier,
    STATE(533), 4,
      sym__abs_decl,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_subscript,
  [24085] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1325), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(489), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1335), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24127] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1387), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1347), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24161] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 1,
      anon_sym_program,
    ACTIONS(1391), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1367), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24195] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1405), 1,
      sym_system_lib_string,
    ACTIONS(1407), 1,
      sym_identifier,
    STATE(702), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1375), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1355), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1343), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1339), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1351), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1391), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1399), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1379), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1341), 1,
      anon_sym_program,
    ACTIONS(1339), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24369] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 1,
      sym_system_lib_string,
    ACTIONS(1411), 1,
      sym_identifier,
    STATE(739), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 1,
      anon_sym_program,
    ACTIONS(1399), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1371), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 1,
      anon_sym_program,
    ACTIONS(1387), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1377), 1,
      anon_sym_program,
    ACTIONS(1375), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      anon_sym_program,
    ACTIONS(1343), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24475] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 1,
      anon_sym_program,
    ACTIONS(1395), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24492] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(1321), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(494), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 1,
      anon_sym_program,
    ACTIONS(1383), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 1,
      anon_sym_program,
    ACTIONS(1351), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 1,
      anon_sym_program,
    ACTIONS(1367), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1363), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_to,
      anon_sym_DQUOTE,
      anon_sym_LBRACK,
  [24600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 1,
      anon_sym_program,
    ACTIONS(1347), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24617] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1359), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 1,
      anon_sym_program,
    ACTIONS(1359), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 1,
      anon_sym_program,
    ACTIONS(1363), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24668] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1415), 1,
      sym_system_lib_string,
    ACTIONS(1417), 1,
      sym_identifier,
    STATE(826), 2,
      sym_string_literal,
      sym_preproc_call_expression,
    ACTIONS(1403), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 1,
      anon_sym_program,
    ACTIONS(1371), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24706] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 1,
      anon_sym_const,
    ACTIONS(591), 1,
      sym_identifier,
    ACTIONS(1327), 1,
      anon_sym_LPAREN,
    ACTIONS(1331), 1,
      anon_sym_STAR,
    STATE(448), 1,
      sym_type_qualifier,
    STATE(558), 4,
      sym__declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
  [24731] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1337), 1,
      anon_sym_program,
    ACTIONS(1335), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1381), 1,
      anon_sym_program,
    ACTIONS(1379), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1383), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24782] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      ts_builtin_sym_end,
      anon_sym_program,
    ACTIONS(1395), 7,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 1,
      anon_sym_program,
    ACTIONS(1355), 8,
      anon_sym_POUND,
      aux_sym_preproc_include_token1,
      aux_sym_preproc_def_token1,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [24816] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym_subscript,
    ACTIONS(1421), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24836] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1423), 1,
      anon_sym_SEMI,
    ACTIONS(1425), 1,
      anon_sym_to,
    ACTIONS(1427), 1,
      anon_sym_LBRACK,
    ACTIONS(1429), 1,
      sym_number_literal,
    ACTIONS(1431), 1,
      sym_identifier,
    STATE(514), 1,
      sym_subscript,
    STATE(615), 1,
      sym_event_flag,
    STATE(800), 1,
      sym_syncq_size,
  [24864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1435), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1433), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1439), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1437), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24896] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym_subscript,
    ACTIONS(1441), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24916] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    STATE(503), 1,
      sym_subscript,
    ACTIONS(1443), 5,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
  [24936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1447), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1445), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1451), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1449), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [24968] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1453), 1,
      anon_sym_LF,
    STATE(707), 1,
      sym_string_literal,
    ACTIONS(1455), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [24985] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1457), 1,
      anon_sym_LF,
    STATE(743), 1,
      sym_string_literal,
    ACTIONS(1455), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1459), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25015] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1461), 1,
      anon_sym_LBRACE,
    STATE(749), 1,
      sym_field_declaration_list,
    ACTIONS(1435), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1433), 3,
      anon_sym_LPAREN,
      anon_sym_SEMI,
      anon_sym_STAR,
  [25034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1465), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25060] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1467), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25073] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1469), 1,
      anon_sym_SEMI,
    ACTIONS(1471), 1,
      anon_sym_LBRACE,
    ACTIONS(1473), 1,
      anon_sym_to,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    STATE(629), 1,
      sym_subscript,
    STATE(768), 1,
      sym__expanded_string_literal,
  [25098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1477), 7,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
  [25111] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 2,
      anon_sym_const,
      sym_identifier,
    ACTIONS(1479), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [25126] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1483), 1,
      anon_sym_LF,
    STATE(810), 1,
      sym_string_literal,
    ACTIONS(1455), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25143] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(353), 1,
      anon_sym_when,
    ACTIONS(1485), 1,
      anon_sym_RBRACE,
    STATE(797), 1,
      sym_exit,
    STATE(524), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25163] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1461), 1,
      anon_sym_LBRACE,
    STATE(725), 1,
      sym_field_declaration_list,
    ACTIONS(1433), 2,
      anon_sym_LPAREN,
      anon_sym_STAR,
    ACTIONS(1435), 2,
      anon_sym_const,
      sym_identifier,
  [25181] = 6,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1487), 1,
      anon_sym_DQUOTE,
    ACTIONS(1489), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1491), 1,
      anon_sym_LBRACE2,
    ACTIONS(1493), 1,
      sym_escape_sequence,
    STATE(511), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25201] = 6,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1491), 1,
      anon_sym_LBRACE2,
    ACTIONS(1495), 1,
      anon_sym_DQUOTE,
    ACTIONS(1497), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1499), 1,
      sym_escape_sequence,
    STATE(517), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25221] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(353), 1,
      anon_sym_when,
    ACTIONS(1501), 1,
      anon_sym_RBRACE,
    STATE(737), 1,
      sym_exit,
    STATE(524), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25241] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(353), 1,
      anon_sym_when,
    ACTIONS(1501), 1,
      anon_sym_RBRACE,
    STATE(737), 1,
      sym_exit,
    STATE(508), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25261] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym_number_literal,
    ACTIONS(1431), 1,
      sym_identifier,
    ACTIONS(1503), 1,
      anon_sym_SEMI,
    ACTIONS(1505), 1,
      anon_sym_to,
    STATE(614), 1,
      sym_event_flag,
    STATE(724), 1,
      sym_syncq_size,
  [25283] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1461), 1,
      anon_sym_LBRACE,
    STATE(766), 1,
      sym_field_declaration_list,
    ACTIONS(1433), 2,
      anon_sym_LPAREN,
      anon_sym_STAR,
    ACTIONS(1435), 2,
      anon_sym_const,
      sym_identifier,
  [25301] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(351), 1,
      anon_sym_RBRACE,
    ACTIONS(353), 1,
      anon_sym_when,
    STATE(765), 1,
      sym_exit,
    STATE(524), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25321] = 6,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1507), 1,
      anon_sym_DQUOTE,
    ACTIONS(1509), 1,
      aux_sym__expanded_string_literal_token1,
    ACTIONS(1512), 1,
      anon_sym_LBRACE2,
    ACTIONS(1515), 1,
      sym_escape_sequence,
    STATE(517), 2,
      sym_parameter_expansion,
      aux_sym__expanded_string_literal_repeat1,
  [25341] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(345), 1,
      anon_sym_exit,
    ACTIONS(351), 1,
      anon_sym_RBRACE,
    ACTIONS(353), 1,
      anon_sym_when,
    STATE(765), 1,
      sym_exit,
    STATE(512), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25361] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(738), 1,
      sym_string_literal,
    ACTIONS(41), 5,
      anon_sym_DQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
  [25375] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1520), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25390] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1522), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(541), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25416] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1445), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1526), 1,
      anon_sym_when,
    ACTIONS(1524), 2,
      anon_sym_RBRACE,
      anon_sym_exit,
    STATE(524), 2,
      sym_transition,
      aux_sym_state_block_repeat2,
  [25442] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1529), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25457] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1531), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(520), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25472] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(561), 1,
      sym_subscript,
    ACTIONS(1535), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25489] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1537), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(525), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25504] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1539), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25519] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1541), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(529), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25534] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1427), 1,
      anon_sym_LBRACK,
    ACTIONS(1431), 1,
      sym_identifier,
    ACTIONS(1543), 1,
      anon_sym_to,
    STATE(623), 1,
      sym_subscript,
    STATE(780), 1,
      sym_event_flag,
  [25553] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1545), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25568] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(561), 1,
      sym_subscript,
    ACTIONS(1547), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25585] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    STATE(561), 1,
      sym_subscript,
    ACTIONS(1549), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [25602] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1551), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(532), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25617] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    ACTIONS(1557), 1,
      anon_sym_EQ,
    STATE(159), 1,
      sym_block,
    ACTIONS(1553), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [25634] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1559), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1433), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1437), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25671] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1561), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(537), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25686] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1563), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1518), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1479), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_const,
      anon_sym_LBRACK,
  [25712] = 4,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1568), 1,
      anon_sym_RBRACE_PERCENT,
    STATE(543), 1,
      aux_sym__c_code_repeat1,
    ACTIONS(1565), 3,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
  [25727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1570), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25741] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1572), 1,
      anon_sym_COMMA,
    STATE(545), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(669), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [25755] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1575), 1,
      anon_sym_DQUOTE,
    ACTIONS(1577), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1580), 1,
      sym_escape_sequence,
    STATE(546), 1,
      aux_sym_string_literal_repeat1,
  [25771] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1583), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25785] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1585), 1,
      anon_sym_DQUOTE,
    ACTIONS(1587), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1589), 1,
      sym_escape_sequence,
    STATE(546), 1,
      aux_sym_string_literal_repeat1,
  [25801] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 4,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
  [25811] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1593), 1,
      anon_sym_LF,
    ACTIONS(1595), 1,
      anon_sym_LPAREN2,
    ACTIONS(1597), 1,
      sym_preproc_arg,
    STATE(675), 1,
      sym_preproc_params,
  [25827] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1599), 1,
      anon_sym_DQUOTE,
    ACTIONS(1601), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1603), 1,
      sym_escape_sequence,
    STATE(548), 1,
      aux_sym_string_literal_repeat1,
  [25843] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1605), 2,
      anon_sym_DQUOTE,
      sym_escape_sequence,
    ACTIONS(1607), 2,
      aux_sym__expanded_string_literal_token1,
      anon_sym_LBRACE2,
  [25855] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1595), 1,
      anon_sym_LPAREN2,
    ACTIONS(1609), 1,
      anon_sym_LF,
    ACTIONS(1611), 1,
      sym_preproc_arg,
    STATE(672), 1,
      sym_preproc_params,
  [25871] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1613), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25885] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1615), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25895] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1587), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1589), 1,
      sym_escape_sequence,
    ACTIONS(1617), 1,
      anon_sym_DQUOTE,
    STATE(546), 1,
      aux_sym_string_literal_repeat1,
  [25911] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 1,
      anon_sym_COMMA,
    STATE(545), 1,
      aux_sym_comma_expr_repeat1,
    ACTIONS(1619), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [25925] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    ACTIONS(1621), 1,
      anon_sym_RPAREN,
    STATE(503), 1,
      sym_subscript,
  [25941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1623), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1413), 2,
      anon_sym_SEMI,
      sym_number_literal,
    ACTIONS(1625), 2,
      anon_sym_to,
      sym_identifier,
  [25963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1549), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [25973] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1627), 4,
      aux_sym__c_code_token1,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_RBRACE_PERCENT,
  [25983] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1629), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [25997] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1533), 1,
      anon_sym_LPAREN,
    ACTIONS(1631), 1,
      anon_sym_RPAREN,
    STATE(561), 1,
      sym_subscript,
  [26013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1633), 4,
      anon_sym_char,
      anon_sym_short,
      anon_sym_int,
      anon_sym_long,
  [26023] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1635), 1,
      anon_sym_DQUOTE,
    ACTIONS(1637), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1639), 1,
      sym_escape_sequence,
    STATE(556), 1,
      aux_sym_string_literal_repeat1,
  [26039] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1641), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1643), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [26063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1645), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [26073] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [26083] = 5,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1595), 1,
      anon_sym_LPAREN2,
    ACTIONS(1649), 1,
      anon_sym_LF,
    ACTIONS(1651), 1,
      sym_preproc_arg,
    STATE(670), 1,
      sym_preproc_params,
  [26099] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1653), 4,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_ss,
      anon_sym_when,
  [26109] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1655), 1,
      anon_sym_RBRACE,
    ACTIONS(1657), 1,
      anon_sym_state,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26123] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 1,
      anon_sym_state,
    ACTIONS(1660), 1,
      anon_sym_RBRACE,
    STATE(573), 2,
      sym_state,
      aux_sym_state_set_repeat2,
  [26137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26155] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 1,
      anon_sym_RBRACE,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    STATE(600), 1,
      aux_sym_init_expr_repeat1,
  [26168] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 1,
      anon_sym_RPAREN,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    STATE(631), 1,
      aux_sym_function_declarator_repeat1,
  [26181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26190] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1676), 1,
      anon_sym_RBRACE,
    STATE(625), 1,
      aux_sym_init_expr_repeat1,
  [26203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1678), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26212] = 4,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_LF,
    STATE(407), 1,
      sym_preproc_argument_list,
  [26225] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1682), 1,
      anon_sym_RBRACE,
    STATE(577), 1,
      aux_sym_init_expr_repeat1,
  [26238] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym_number_literal,
    ACTIONS(1684), 1,
      anon_sym_SEMI,
    STATE(703), 1,
      sym_syncq_size,
  [26251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1686), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26260] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1688), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(732), 1,
      sym_option_value,
    ACTIONS(1690), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [26280] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 1,
      anon_sym_RBRACE,
    ACTIONS(1694), 1,
      anon_sym_COMMA,
    STATE(642), 1,
      aux_sym_assign_repeat1,
  [26293] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1692), 1,
      anon_sym_RBRACE,
    ACTIONS(1694), 1,
      anon_sym_COMMA,
    STATE(633), 1,
      aux_sym_assign_repeat1,
  [26306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(84), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26317] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1696), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1698), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1700), 3,
      anon_sym_RBRACE,
      anon_sym_exit,
      anon_sym_when,
  [26344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(75), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1702), 1,
      anon_sym_RPAREN,
    ACTIONS(1704), 2,
      sym_identifier,
      anon_sym_DOT_DOT_DOT,
  [26366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(86), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(267), 1,
      anon_sym_ss,
    STATE(80), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26388] = 4,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1706), 1,
      anon_sym_LF,
    STATE(407), 1,
      sym_preproc_argument_list,
  [26401] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    ACTIONS(1708), 1,
      anon_sym_RPAREN,
    STATE(631), 1,
      aux_sym_function_declarator_repeat1,
  [26414] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 1,
      anon_sym_RBRACE,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(600), 1,
      aux_sym_init_expr_repeat1,
  [26427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1715), 1,
      anon_sym_SEMI,
    ACTIONS(1717), 1,
      anon_sym_COMMA,
    STATE(637), 1,
      aux_sym_foreign_declaration_repeat1,
  [26440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1719), 1,
      anon_sym_RPAREN,
    ACTIONS(1721), 1,
      anon_sym_COMMA,
    STATE(602), 1,
      aux_sym_preproc_params_repeat1,
  [26453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1724), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26462] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 1,
      anon_sym_LBRACK,
    ACTIONS(1726), 1,
      anon_sym_SEMI,
    STATE(778), 1,
      sym_subscript,
  [26475] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      anon_sym_RPAREN,
    ACTIONS(1728), 1,
      anon_sym_COMMA,
    STATE(605), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26488] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    ACTIONS(1731), 1,
      anon_sym_RPAREN,
    STATE(578), 1,
      aux_sym_function_declarator_repeat1,
  [26501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COMMA,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    STATE(605), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26514] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1735), 1,
      anon_sym_SEMI,
    ACTIONS(1737), 1,
      anon_sym_COMMA,
    STATE(609), 1,
      aux_sym_declaration_repeat1,
  [26527] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1739), 1,
      anon_sym_SEMI,
    ACTIONS(1741), 1,
      anon_sym_COMMA,
    STATE(609), 1,
      aux_sym_declaration_repeat1,
  [26540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(70), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26551] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(77), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1744), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26571] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 1,
      anon_sym_COMMA,
    ACTIONS(1746), 1,
      anon_sym_SEMI,
    STATE(638), 1,
      aux_sym_declaration_repeat1,
  [26584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym_number_literal,
    ACTIONS(1748), 1,
      anon_sym_SEMI,
    STATE(824), 1,
      sym_syncq_size,
  [26597] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1429), 1,
      sym_number_literal,
    ACTIONS(1503), 1,
      anon_sym_SEMI,
    STATE(724), 1,
      sym_syncq_size,
  [26610] = 4,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1750), 1,
      anon_sym_LF,
    STATE(407), 1,
      sym_preproc_argument_list,
  [26623] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 1,
      anon_sym_COMMA,
    ACTIONS(1752), 1,
      anon_sym_SEMI,
    STATE(608), 1,
      aux_sym_declaration_repeat1,
  [26636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(72), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26647] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    ACTIONS(1754), 1,
      anon_sym_RPAREN,
    STATE(599), 1,
      aux_sym_function_declarator_repeat1,
  [26660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1756), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26669] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    ACTIONS(1758), 1,
      anon_sym_RBRACE,
    STATE(588), 1,
      sym__expanded_string_literal,
  [26682] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1694), 1,
      anon_sym_COMMA,
    ACTIONS(1758), 1,
      anon_sym_RBRACE,
    STATE(589), 1,
      aux_sym_assign_repeat1,
  [26695] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1431), 1,
      sym_identifier,
    ACTIONS(1760), 1,
      anon_sym_to,
    STATE(745), 1,
      sym_event_flag,
  [26708] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 1,
      anon_sym_SEMI,
    ACTIONS(1764), 1,
      anon_sym_COMMA,
    STATE(624), 1,
      aux_sym_foreign_declaration_repeat1,
  [26721] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 1,
      anon_sym_COMMA,
    ACTIONS(1767), 1,
      anon_sym_RBRACE,
    STATE(600), 1,
      aux_sym_init_expr_repeat1,
  [26734] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1769), 1,
      anon_sym_RPAREN,
    ACTIONS(1771), 1,
      anon_sym_COMMA,
    STATE(632), 1,
      aux_sym_preproc_params_repeat1,
  [26747] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(265), 1,
      anon_sym_ss,
    STATE(73), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26758] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1557), 1,
      anon_sym_EQ,
    ACTIONS(1553), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [26769] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    ACTIONS(1773), 1,
      anon_sym_to,
    STATE(825), 1,
      sym__expanded_string_literal,
  [26782] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    ACTIONS(1754), 1,
      anon_sym_RPAREN,
    STATE(631), 1,
      aux_sym_function_declarator_repeat1,
  [26795] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1775), 1,
      anon_sym_RPAREN,
    ACTIONS(1777), 1,
      anon_sym_COMMA,
    STATE(631), 1,
      aux_sym_function_declarator_repeat1,
  [26808] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1771), 1,
      anon_sym_COMMA,
    ACTIONS(1780), 1,
      anon_sym_RPAREN,
    STATE(602), 1,
      aux_sym_preproc_params_repeat1,
  [26821] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 1,
      anon_sym_RBRACE,
    ACTIONS(1784), 1,
      anon_sym_COMMA,
    STATE(633), 1,
      aux_sym_assign_repeat1,
  [26834] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    ACTIONS(1787), 1,
      anon_sym_LBRACE,
    STATE(825), 1,
      sym__expanded_string_literal,
  [26847] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1085), 1,
      anon_sym_COMMA,
    ACTIONS(1789), 1,
      anon_sym_RPAREN,
    STATE(605), 1,
      aux_sym_preproc_argument_list_repeat1,
  [26860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    ACTIONS(1791), 1,
      anon_sym_RBRACE,
    STATE(622), 1,
      sym__expanded_string_literal,
  [26873] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1717), 1,
      anon_sym_COMMA,
    ACTIONS(1793), 1,
      anon_sym_SEMI,
    STATE(624), 1,
      aux_sym_foreign_declaration_repeat1,
  [26886] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1737), 1,
      anon_sym_COMMA,
    ACTIONS(1795), 1,
      anon_sym_SEMI,
    STATE(609), 1,
      aux_sym_declaration_repeat1,
  [26899] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_RPAREN,
    ACTIONS(1672), 1,
      anon_sym_COMMA,
    STATE(630), 1,
      aux_sym_function_declarator_repeat1,
  [26912] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(521), 1,
      anon_sym_COMMA,
    ACTIONS(1797), 1,
      anon_sym_RPAREN,
    STATE(545), 1,
      aux_sym_comma_expr_repeat1,
  [26925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      anon_sym_ss,
    STATE(83), 2,
      sym_state_set,
      aux_sym_program_repeat2,
  [26936] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1694), 1,
      anon_sym_COMMA,
    ACTIONS(1799), 1,
      anon_sym_RBRACE,
    STATE(633), 1,
      aux_sym_assign_repeat1,
  [26949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1801), 1,
      anon_sym_exit,
    ACTIONS(1803), 1,
      anon_sym_state,
  [26959] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1719), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [26967] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1805), 1,
      anon_sym_LF,
    ACTIONS(1807), 1,
      sym_preproc_arg,
  [26977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    STATE(776), 1,
      sym__expanded_string_literal,
  [26987] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [26995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1811), 1,
      anon_sym_LBRACE,
    STATE(690), 1,
      sym_state_block,
  [27005] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1813), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [27013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1762), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27021] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1815), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [27029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1817), 1,
      anon_sym_LPAREN,
    ACTIONS(1819), 1,
      sym_identifier,
  [27039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1821), 1,
      anon_sym_exit,
    ACTIONS(1823), 1,
      anon_sym_state,
  [27049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    STATE(643), 1,
      sym_block,
  [27059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    STATE(572), 1,
      sym_block,
  [27069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1825), 2,
      sym_identifier,
      anon_sym_DOT_DOT_DOT,
  [27077] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1827), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [27085] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    STATE(159), 1,
      sym_block,
  [27095] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1829), 1,
      anon_sym_SEMI,
    ACTIONS(1831), 1,
      sym_identifier,
  [27105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1833), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27113] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1835), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [27121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1837), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27129] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1839), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      sym_identifier,
    STATE(614), 1,
      sym_event_flag,
  [27147] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 1,
      anon_sym_DQUOTE,
    STATE(671), 1,
      sym__expanded_string_literal,
  [27157] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1843), 2,
      anon_sym_SEMI,
      sym_number_literal,
  [27165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      sym_identifier,
    STATE(745), 1,
      sym_event_flag,
  [27175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_LBRACE,
    STATE(295), 1,
      sym_block,
  [27185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      anon_sym_LBRACE,
    STATE(294), 1,
      sym_block,
  [27195] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1847), 1,
      anon_sym_LF,
    ACTIONS(1849), 1,
      sym_preproc_arg,
  [27205] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1782), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [27213] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1851), 1,
      anon_sym_LF,
    ACTIONS(1853), 1,
      sym_preproc_arg,
  [27223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      sym_identifier,
    STATE(792), 1,
      sym_event_flag,
  [27233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    STATE(653), 1,
      sym_block,
  [27243] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1855), 1,
      anon_sym_LF,
    ACTIONS(1857), 1,
      sym_preproc_arg,
  [27253] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1859), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [27261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1841), 1,
      sym_identifier,
    STATE(584), 1,
      sym_event_flag,
  [27271] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1775), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27279] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1861), 2,
      anon_sym_LF,
      sym_preproc_arg,
  [27287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1863), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27295] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1865), 1,
      anon_sym_LF,
    ACTIONS(1867), 1,
      sym_preproc_arg,
  [27305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1869), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1555), 1,
      anon_sym_LBRACE,
    STATE(292), 1,
      sym_block,
  [27323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      anon_sym_LBRACE,
    STATE(272), 1,
      sym_block,
  [27333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1739), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1873), 1,
      anon_sym_LPAREN,
    ACTIONS(1875), 1,
      sym_identifier,
  [27351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      anon_sym_LBRACE,
    STATE(278), 1,
      sym_block,
  [27361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1877), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [27369] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1879), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1881), 2,
      anon_sym_RBRACE,
      anon_sym_state,
  [27385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [27393] = 3,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1885), 1,
      anon_sym_LF,
    ACTIONS(1887), 1,
      sym_preproc_arg,
  [27403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1710), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [27411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1889), 1,
      anon_sym_RPAREN,
  [27418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_RPAREN,
  [27425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1893), 1,
      anon_sym_LPAREN,
  [27432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_LPAREN,
  [27439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1897), 1,
      anon_sym_SEMI,
  [27446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 1,
      anon_sym_SEMI,
  [27453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1901), 1,
      anon_sym_LPAREN,
  [27460] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_SEMI,
  [27467] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1750), 1,
      anon_sym_LF,
  [27474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1905), 1,
      anon_sym_SEMI,
  [27481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1907), 1,
      aux_sym_preproc_if_token2,
  [27488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1909), 1,
      aux_sym_preproc_if_token2,
  [27495] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1911), 1,
      anon_sym_LF,
  [27502] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LF,
  [27509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1915), 1,
      sym_identifier,
  [27516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 1,
      anon_sym_LBRACE,
  [27523] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1919), 1,
      anon_sym_LF,
  [27530] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1921), 1,
      anon_sym_LF,
  [27537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1923), 1,
      anon_sym_SQUOTE,
  [27544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      aux_sym_preproc_if_token2,
  [27551] = 2,
    ACTIONS(475), 1,
      anon_sym_LF,
    ACTIONS(1075), 1,
      sym_comment,
  [27558] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1927), 1,
      anon_sym_LF,
  [27565] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1929), 1,
      anon_sym_LF,
  [27572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 1,
      anon_sym_RPAREN,
  [27579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1933), 1,
      aux_sym_preproc_if_token2,
  [27586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      aux_sym_preproc_if_token2,
  [27593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1937), 1,
      aux_sym_preproc_if_token2,
  [27600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_SEMI,
  [27607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
  [27614] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1943), 1,
      anon_sym_SEMI,
  [27621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1748), 1,
      anon_sym_SEMI,
  [27628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1945), 1,
      anon_sym_SEMI,
  [27635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 1,
      sym_identifier,
  [27642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 1,
      aux_sym_preproc_if_token2,
  [27649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1951), 1,
      sym_line_number,
  [27656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 1,
      anon_sym_RBRACK,
  [27663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1955), 1,
      anon_sym_SEMI,
  [27670] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_SEMI,
  [27677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 1,
      sym_identifier,
  [27684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      sym_identifier,
  [27691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1963), 1,
      anon_sym_LPAREN,
  [27698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(351), 1,
      anon_sym_RBRACE,
  [27705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1965), 1,
      aux_sym_preproc_if_token2,
  [27712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1485), 1,
      anon_sym_RBRACE,
  [27719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1967), 1,
      anon_sym_RPAREN,
  [27726] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1706), 1,
      anon_sym_LF,
  [27733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1969), 1,
      anon_sym_RPAREN,
  [27740] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LF,
  [27747] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1973), 1,
      anon_sym_LF,
  [27754] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1975), 1,
      anon_sym_LF,
  [27761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1977), 1,
      anon_sym_RPAREN,
  [27768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1979), 1,
      anon_sym_SEMI,
  [27775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1981), 1,
      anon_sym_SEMI,
  [27782] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 1,
      anon_sym_RPAREN,
  [27789] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1985), 1,
      anon_sym_LF,
  [27796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      anon_sym_SEMI,
  [27803] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1989), 1,
      anon_sym_SQUOTE,
  [27810] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1991), 1,
      aux_sym_preproc_if_token2,
  [27817] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      aux_sym_preproc_if_token2,
  [27824] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1995), 1,
      sym_identifier,
  [27831] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1997), 1,
      anon_sym_RPAREN,
  [27838] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1999), 1,
      anon_sym_LF,
  [27845] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2001), 1,
      anon_sym_SQUOTE,
  [27852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2003), 1,
      anon_sym_RPAREN,
  [27859] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2005), 1,
      sym_identifier,
  [27866] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2007), 1,
      sym_number_literal,
  [27873] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2009), 1,
      anon_sym_LF,
  [27880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 1,
      aux_sym_preproc_if_token2,
  [27887] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2013), 1,
      anon_sym_LF,
  [27894] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2015), 1,
      aux_sym_preproc_if_token2,
  [27901] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2017), 1,
      anon_sym_SEMI,
  [27908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1501), 1,
      anon_sym_RBRACE,
  [27915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2019), 1,
      anon_sym_SEMI,
  [27922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2021), 1,
      anon_sym_RPAREN,
  [27929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2023), 1,
      anon_sym_SEMI,
  [27936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2025), 1,
      aux_sym_preproc_if_token2,
  [27943] = 2,
    ACTIONS(451), 1,
      anon_sym_LF,
    ACTIONS(1075), 1,
      sym_comment,
  [27950] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2027), 1,
      anon_sym_LPAREN,
  [27957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2029), 1,
      sym_identifier,
  [27964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2031), 1,
      anon_sym_SEMI,
  [27971] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_SEMI,
  [27978] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2035), 1,
      anon_sym_LF,
  [27985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2037), 1,
      anon_sym_SEMI,
  [27992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 1,
      sym_identifier,
  [27999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2041), 1,
      anon_sym_SEMI,
  [28006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      sym_identifier,
  [28013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 1,
      anon_sym_SEMI,
  [28020] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2047), 1,
      anon_sym_SEMI,
  [28027] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2049), 1,
      anon_sym_LF,
  [28034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2051), 1,
      sym_identifier,
  [28041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2053), 1,
      sym_identifier,
  [28048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2055), 1,
      sym_identifier,
  [28055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2057), 1,
      sym_identifier,
  [28062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2059), 1,
      anon_sym_RBRACE,
  [28069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2061), 1,
      anon_sym_SEMI,
  [28076] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2063), 1,
      anon_sym_LF,
  [28083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2065), 1,
      sym_line_number,
  [28090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 1,
      sym_identifier,
  [28097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2069), 1,
      anon_sym_SEMI,
  [28104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 1,
      sym_identifier,
  [28111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 1,
      sym_identifier,
  [28118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2075), 1,
      sym_identifier,
  [28125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2077), 1,
      anon_sym_SEMI,
  [28132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2079), 1,
      anon_sym_RBRACE,
  [28139] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2081), 1,
      aux_sym__c_code_token2,
  [28146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2083), 1,
      sym_identifier,
  [28153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1503), 1,
      anon_sym_SEMI,
  [28160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 1,
      anon_sym_SEMI,
  [28167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2087), 1,
      sym_number_literal,
  [28174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2089), 1,
      sym_identifier,
  [28181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2091), 1,
      anon_sym_RPAREN,
  [28188] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2093), 1,
      anon_sym_RPAREN,
  [28195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2095), 1,
      aux_sym_preproc_if_token2,
  [28202] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2097), 1,
      aux_sym__c_code_token2,
  [28209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2099), 1,
      anon_sym_RPAREN,
  [28216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2101), 1,
      anon_sym_RPAREN,
  [28223] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2103), 1,
      anon_sym_LF,
  [28230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2105), 1,
      anon_sym_RPAREN,
  [28237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2107), 1,
      anon_sym_RPAREN,
  [28244] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2109), 1,
      anon_sym_LF,
  [28251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2111), 1,
      anon_sym_RPAREN,
  [28258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      sym_line_number,
  [28265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2115), 1,
      sym_identifier,
  [28272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2117), 1,
      anon_sym_RPAREN,
  [28279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2119), 1,
      sym_identifier,
  [28286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2121), 1,
      sym_identifier,
  [28293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2123), 1,
      sym_identifier,
  [28300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2125), 1,
      anon_sym_RPAREN,
  [28307] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2127), 1,
      aux_sym__c_code_token2,
  [28314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2129), 1,
      anon_sym_RPAREN,
  [28321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1684), 1,
      anon_sym_SEMI,
  [28328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2131), 1,
      anon_sym_SEMI,
  [28335] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(1680), 1,
      anon_sym_LF,
  [28342] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2133), 1,
      aux_sym__c_code_token2,
  [28349] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2135), 1,
      aux_sym__c_code_token2,
  [28356] = 2,
    ACTIONS(1075), 1,
      sym_comment,
    ACTIONS(2137), 1,
      aux_sym__c_code_token2,
  [28363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2139), 1,
      anon_sym_RPAREN,
  [28370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2141), 1,
      sym_identifier,
  [28377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2143), 1,
      anon_sym_LBRACE,
  [28384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2145), 1,
      sym_identifier,
  [28391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2147), 1,
      anon_sym_RPAREN,
  [28398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2149), 1,
      ts_builtin_sym_end,
  [28405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2151), 1,
      anon_sym_SEMI,
  [28412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2153), 1,
      anon_sym_RBRACK,
  [28419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2155), 1,
      anon_sym_SEMI,
  [28426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2157), 1,
      sym_identifier,
  [28433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2159), 1,
      sym_identifier,
  [28440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2161), 1,
      anon_sym_LBRACE,
  [28447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2163), 1,
      sym_identifier,
  [28454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2165), 1,
      anon_sym_LPAREN,
  [28461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2167), 1,
      sym_identifier,
  [28468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2169), 1,
      sym_identifier,
  [28475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2171), 1,
      anon_sym_SEMI,
  [28482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2173), 1,
      sym_identifier,
  [28489] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2175), 1,
      anon_sym_LPAREN,
  [28496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2177), 1,
      anon_sym_LPAREN,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(16)] = 0,
  [SMALL_STATE(17)] = 109,
  [SMALL_STATE(18)] = 198,
  [SMALL_STATE(19)] = 307,
  [SMALL_STATE(20)] = 416,
  [SMALL_STATE(21)] = 525,
  [SMALL_STATE(22)] = 634,
  [SMALL_STATE(23)] = 743,
  [SMALL_STATE(24)] = 852,
  [SMALL_STATE(25)] = 961,
  [SMALL_STATE(26)] = 1070,
  [SMALL_STATE(27)] = 1179,
  [SMALL_STATE(28)] = 1288,
  [SMALL_STATE(29)] = 1393,
  [SMALL_STATE(30)] = 1498,
  [SMALL_STATE(31)] = 1603,
  [SMALL_STATE(32)] = 1708,
  [SMALL_STATE(33)] = 1813,
  [SMALL_STATE(34)] = 1918,
  [SMALL_STATE(35)] = 2023,
  [SMALL_STATE(36)] = 2128,
  [SMALL_STATE(37)] = 2233,
  [SMALL_STATE(38)] = 2338,
  [SMALL_STATE(39)] = 2443,
  [SMALL_STATE(40)] = 2548,
  [SMALL_STATE(41)] = 2653,
  [SMALL_STATE(42)] = 2758,
  [SMALL_STATE(43)] = 2863,
  [SMALL_STATE(44)] = 2968,
  [SMALL_STATE(45)] = 3073,
  [SMALL_STATE(46)] = 3178,
  [SMALL_STATE(47)] = 3283,
  [SMALL_STATE(48)] = 3388,
  [SMALL_STATE(49)] = 3493,
  [SMALL_STATE(50)] = 3598,
  [SMALL_STATE(51)] = 3659,
  [SMALL_STATE(52)] = 3720,
  [SMALL_STATE(53)] = 3781,
  [SMALL_STATE(54)] = 3842,
  [SMALL_STATE(55)] = 3903,
  [SMALL_STATE(56)] = 3964,
  [SMALL_STATE(57)] = 4025,
  [SMALL_STATE(58)] = 4086,
  [SMALL_STATE(59)] = 4187,
  [SMALL_STATE(60)] = 4288,
  [SMALL_STATE(61)] = 4389,
  [SMALL_STATE(62)] = 4484,
  [SMALL_STATE(63)] = 4579,
  [SMALL_STATE(64)] = 4674,
  [SMALL_STATE(65)] = 4769,
  [SMALL_STATE(66)] = 4864,
  [SMALL_STATE(67)] = 4959,
  [SMALL_STATE(68)] = 5054,
  [SMALL_STATE(69)] = 5149,
  [SMALL_STATE(70)] = 5244,
  [SMALL_STATE(71)] = 5329,
  [SMALL_STATE(72)] = 5414,
  [SMALL_STATE(73)] = 5499,
  [SMALL_STATE(74)] = 5584,
  [SMALL_STATE(75)] = 5670,
  [SMALL_STATE(76)] = 5753,
  [SMALL_STATE(77)] = 5836,
  [SMALL_STATE(78)] = 5919,
  [SMALL_STATE(79)] = 5970,
  [SMALL_STATE(80)] = 6059,
  [SMALL_STATE(81)] = 6142,
  [SMALL_STATE(82)] = 6193,
  [SMALL_STATE(83)] = 6244,
  [SMALL_STATE(84)] = 6327,
  [SMALL_STATE(85)] = 6410,
  [SMALL_STATE(86)] = 6493,
  [SMALL_STATE(87)] = 6576,
  [SMALL_STATE(88)] = 6665,
  [SMALL_STATE(89)] = 6723,
  [SMALL_STATE(90)] = 6773,
  [SMALL_STATE(91)] = 6845,
  [SMALL_STATE(92)] = 6929,
  [SMALL_STATE(93)] = 6981,
  [SMALL_STATE(94)] = 7031,
  [SMALL_STATE(95)] = 7081,
  [SMALL_STATE(96)] = 7153,
  [SMALL_STATE(97)] = 7225,
  [SMALL_STATE(98)] = 7275,
  [SMALL_STATE(99)] = 7347,
  [SMALL_STATE(100)] = 7401,
  [SMALL_STATE(101)] = 7473,
  [SMALL_STATE(102)] = 7547,
  [SMALL_STATE(103)] = 7597,
  [SMALL_STATE(104)] = 7669,
  [SMALL_STATE(105)] = 7743,
  [SMALL_STATE(106)] = 7815,
  [SMALL_STATE(107)] = 7887,
  [SMALL_STATE(108)] = 7959,
  [SMALL_STATE(109)] = 8013,
  [SMALL_STATE(110)] = 8063,
  [SMALL_STATE(111)] = 8135,
  [SMALL_STATE(112)] = 8185,
  [SMALL_STATE(113)] = 8245,
  [SMALL_STATE(114)] = 8295,
  [SMALL_STATE(115)] = 8359,
  [SMALL_STATE(116)] = 8427,
  [SMALL_STATE(117)] = 8499,
  [SMALL_STATE(118)] = 8569,
  [SMALL_STATE(119)] = 8629,
  [SMALL_STATE(120)] = 8701,
  [SMALL_STATE(121)] = 8773,
  [SMALL_STATE(122)] = 8847,
  [SMALL_STATE(123)] = 8913,
  [SMALL_STATE(124)] = 8963,
  [SMALL_STATE(125)] = 9019,
  [SMALL_STATE(126)] = 9069,
  [SMALL_STATE(127)] = 9141,
  [SMALL_STATE(128)] = 9223,
  [SMALL_STATE(129)] = 9295,
  [SMALL_STATE(130)] = 9367,
  [SMALL_STATE(131)] = 9417,
  [SMALL_STATE(132)] = 9471,
  [SMALL_STATE(133)] = 9542,
  [SMALL_STATE(134)] = 9611,
  [SMALL_STATE(135)] = 9682,
  [SMALL_STATE(136)] = 9753,
  [SMALL_STATE(137)] = 9822,
  [SMALL_STATE(138)] = 9891,
  [SMALL_STATE(139)] = 9960,
  [SMALL_STATE(140)] = 10031,
  [SMALL_STATE(141)] = 10103,
  [SMALL_STATE(142)] = 10175,
  [SMALL_STATE(143)] = 10261,
  [SMALL_STATE(144)] = 10333,
  [SMALL_STATE(145)] = 10405,
  [SMALL_STATE(146)] = 10477,
  [SMALL_STATE(147)] = 10549,
  [SMALL_STATE(148)] = 10621,
  [SMALL_STATE(149)] = 10693,
  [SMALL_STATE(150)] = 10765,
  [SMALL_STATE(151)] = 10837,
  [SMALL_STATE(152)] = 10905,
  [SMALL_STATE(153)] = 10970,
  [SMALL_STATE(154)] = 11035,
  [SMALL_STATE(155)] = 11100,
  [SMALL_STATE(156)] = 11165,
  [SMALL_STATE(157)] = 11230,
  [SMALL_STATE(158)] = 11307,
  [SMALL_STATE(159)] = 11354,
  [SMALL_STATE(160)] = 11401,
  [SMALL_STATE(161)] = 11466,
  [SMALL_STATE(162)] = 11513,
  [SMALL_STATE(163)] = 11578,
  [SMALL_STATE(164)] = 11643,
  [SMALL_STATE(165)] = 11690,
  [SMALL_STATE(166)] = 11771,
  [SMALL_STATE(167)] = 11836,
  [SMALL_STATE(168)] = 11901,
  [SMALL_STATE(169)] = 11984,
  [SMALL_STATE(170)] = 12049,
  [SMALL_STATE(171)] = 12114,
  [SMALL_STATE(172)] = 12187,
  [SMALL_STATE(173)] = 12252,
  [SMALL_STATE(174)] = 12333,
  [SMALL_STATE(175)] = 12398,
  [SMALL_STATE(176)] = 12463,
  [SMALL_STATE(177)] = 12528,
  [SMALL_STATE(178)] = 12593,
  [SMALL_STATE(179)] = 12658,
  [SMALL_STATE(180)] = 12743,
  [SMALL_STATE(181)] = 12808,
  [SMALL_STATE(182)] = 12873,
  [SMALL_STATE(183)] = 12943,
  [SMALL_STATE(184)] = 13013,
  [SMALL_STATE(185)] = 13083,
  [SMALL_STATE(186)] = 13153,
  [SMALL_STATE(187)] = 13223,
  [SMALL_STATE(188)] = 13293,
  [SMALL_STATE(189)] = 13363,
  [SMALL_STATE(190)] = 13433,
  [SMALL_STATE(191)] = 13503,
  [SMALL_STATE(192)] = 13573,
  [SMALL_STATE(193)] = 13643,
  [SMALL_STATE(194)] = 13713,
  [SMALL_STATE(195)] = 13783,
  [SMALL_STATE(196)] = 13853,
  [SMALL_STATE(197)] = 13923,
  [SMALL_STATE(198)] = 13993,
  [SMALL_STATE(199)] = 14063,
  [SMALL_STATE(200)] = 14133,
  [SMALL_STATE(201)] = 14203,
  [SMALL_STATE(202)] = 14273,
  [SMALL_STATE(203)] = 14352,
  [SMALL_STATE(204)] = 14401,
  [SMALL_STATE(205)] = 14480,
  [SMALL_STATE(206)] = 14550,
  [SMALL_STATE(207)] = 14620,
  [SMALL_STATE(208)] = 14690,
  [SMALL_STATE(209)] = 14760,
  [SMALL_STATE(210)] = 14830,
  [SMALL_STATE(211)] = 14900,
  [SMALL_STATE(212)] = 14947,
  [SMALL_STATE(213)] = 14994,
  [SMALL_STATE(214)] = 15041,
  [SMALL_STATE(215)] = 15088,
  [SMALL_STATE(216)] = 15131,
  [SMALL_STATE(217)] = 15174,
  [SMALL_STATE(218)] = 15216,
  [SMALL_STATE(219)] = 15258,
  [SMALL_STATE(220)] = 15300,
  [SMALL_STATE(221)] = 15342,
  [SMALL_STATE(222)] = 15384,
  [SMALL_STATE(223)] = 15426,
  [SMALL_STATE(224)] = 15468,
  [SMALL_STATE(225)] = 15510,
  [SMALL_STATE(226)] = 15552,
  [SMALL_STATE(227)] = 15618,
  [SMALL_STATE(228)] = 15660,
  [SMALL_STATE(229)] = 15702,
  [SMALL_STATE(230)] = 15744,
  [SMALL_STATE(231)] = 15786,
  [SMALL_STATE(232)] = 15828,
  [SMALL_STATE(233)] = 15870,
  [SMALL_STATE(234)] = 15940,
  [SMALL_STATE(235)] = 15982,
  [SMALL_STATE(236)] = 16024,
  [SMALL_STATE(237)] = 16066,
  [SMALL_STATE(238)] = 16108,
  [SMALL_STATE(239)] = 16150,
  [SMALL_STATE(240)] = 16192,
  [SMALL_STATE(241)] = 16234,
  [SMALL_STATE(242)] = 16276,
  [SMALL_STATE(243)] = 16318,
  [SMALL_STATE(244)] = 16360,
  [SMALL_STATE(245)] = 16402,
  [SMALL_STATE(246)] = 16444,
  [SMALL_STATE(247)] = 16486,
  [SMALL_STATE(248)] = 16528,
  [SMALL_STATE(249)] = 16570,
  [SMALL_STATE(250)] = 16612,
  [SMALL_STATE(251)] = 16654,
  [SMALL_STATE(252)] = 16696,
  [SMALL_STATE(253)] = 16738,
  [SMALL_STATE(254)] = 16780,
  [SMALL_STATE(255)] = 16822,
  [SMALL_STATE(256)] = 16864,
  [SMALL_STATE(257)] = 16906,
  [SMALL_STATE(258)] = 16948,
  [SMALL_STATE(259)] = 16989,
  [SMALL_STATE(260)] = 17030,
  [SMALL_STATE(261)] = 17071,
  [SMALL_STATE(262)] = 17112,
  [SMALL_STATE(263)] = 17153,
  [SMALL_STATE(264)] = 17194,
  [SMALL_STATE(265)] = 17235,
  [SMALL_STATE(266)] = 17276,
  [SMALL_STATE(267)] = 17317,
  [SMALL_STATE(268)] = 17358,
  [SMALL_STATE(269)] = 17399,
  [SMALL_STATE(270)] = 17440,
  [SMALL_STATE(271)] = 17481,
  [SMALL_STATE(272)] = 17522,
  [SMALL_STATE(273)] = 17563,
  [SMALL_STATE(274)] = 17604,
  [SMALL_STATE(275)] = 17645,
  [SMALL_STATE(276)] = 17686,
  [SMALL_STATE(277)] = 17727,
  [SMALL_STATE(278)] = 17768,
  [SMALL_STATE(279)] = 17809,
  [SMALL_STATE(280)] = 17850,
  [SMALL_STATE(281)] = 17891,
  [SMALL_STATE(282)] = 17932,
  [SMALL_STATE(283)] = 17973,
  [SMALL_STATE(284)] = 18014,
  [SMALL_STATE(285)] = 18055,
  [SMALL_STATE(286)] = 18096,
  [SMALL_STATE(287)] = 18137,
  [SMALL_STATE(288)] = 18178,
  [SMALL_STATE(289)] = 18219,
  [SMALL_STATE(290)] = 18260,
  [SMALL_STATE(291)] = 18301,
  [SMALL_STATE(292)] = 18342,
  [SMALL_STATE(293)] = 18382,
  [SMALL_STATE(294)] = 18421,
  [SMALL_STATE(295)] = 18460,
  [SMALL_STATE(296)] = 18499,
  [SMALL_STATE(297)] = 18538,
  [SMALL_STATE(298)] = 18577,
  [SMALL_STATE(299)] = 18616,
  [SMALL_STATE(300)] = 18655,
  [SMALL_STATE(301)] = 18694,
  [SMALL_STATE(302)] = 18733,
  [SMALL_STATE(303)] = 18772,
  [SMALL_STATE(304)] = 18810,
  [SMALL_STATE(305)] = 18848,
  [SMALL_STATE(306)] = 18886,
  [SMALL_STATE(307)] = 18924,
  [SMALL_STATE(308)] = 18962,
  [SMALL_STATE(309)] = 18999,
  [SMALL_STATE(310)] = 19046,
  [SMALL_STATE(311)] = 19093,
  [SMALL_STATE(312)] = 19142,
  [SMALL_STATE(313)] = 19189,
  [SMALL_STATE(314)] = 19238,
  [SMALL_STATE(315)] = 19271,
  [SMALL_STATE(316)] = 19317,
  [SMALL_STATE(317)] = 19368,
  [SMALL_STATE(318)] = 19419,
  [SMALL_STATE(319)] = 19470,
  [SMALL_STATE(320)] = 19521,
  [SMALL_STATE(321)] = 19572,
  [SMALL_STATE(322)] = 19623,
  [SMALL_STATE(323)] = 19674,
  [SMALL_STATE(324)] = 19725,
  [SMALL_STATE(325)] = 19776,
  [SMALL_STATE(326)] = 19827,
  [SMALL_STATE(327)] = 19878,
  [SMALL_STATE(328)] = 19929,
  [SMALL_STATE(329)] = 19980,
  [SMALL_STATE(330)] = 20031,
  [SMALL_STATE(331)] = 20065,
  [SMALL_STATE(332)] = 20094,
  [SMALL_STATE(333)] = 20137,
  [SMALL_STATE(334)] = 20180,
  [SMALL_STATE(335)] = 20213,
  [SMALL_STATE(336)] = 20256,
  [SMALL_STATE(337)] = 20311,
  [SMALL_STATE(338)] = 20366,
  [SMALL_STATE(339)] = 20408,
  [SMALL_STATE(340)] = 20456,
  [SMALL_STATE(341)] = 20496,
  [SMALL_STATE(342)] = 20524,
  [SMALL_STATE(343)] = 20564,
  [SMALL_STATE(344)] = 20604,
  [SMALL_STATE(345)] = 20644,
  [SMALL_STATE(346)] = 20672,
  [SMALL_STATE(347)] = 20700,
  [SMALL_STATE(348)] = 20740,
  [SMALL_STATE(349)] = 20768,
  [SMALL_STATE(350)] = 20808,
  [SMALL_STATE(351)] = 20836,
  [SMALL_STATE(352)] = 20876,
  [SMALL_STATE(353)] = 20916,
  [SMALL_STATE(354)] = 20956,
  [SMALL_STATE(355)] = 20988,
  [SMALL_STATE(356)] = 21028,
  [SMALL_STATE(357)] = 21068,
  [SMALL_STATE(358)] = 21108,
  [SMALL_STATE(359)] = 21148,
  [SMALL_STATE(360)] = 21188,
  [SMALL_STATE(361)] = 21216,
  [SMALL_STATE(362)] = 21256,
  [SMALL_STATE(363)] = 21296,
  [SMALL_STATE(364)] = 21324,
  [SMALL_STATE(365)] = 21352,
  [SMALL_STATE(366)] = 21380,
  [SMALL_STATE(367)] = 21420,
  [SMALL_STATE(368)] = 21460,
  [SMALL_STATE(369)] = 21510,
  [SMALL_STATE(370)] = 21538,
  [SMALL_STATE(371)] = 21578,
  [SMALL_STATE(372)] = 21618,
  [SMALL_STATE(373)] = 21658,
  [SMALL_STATE(374)] = 21698,
  [SMALL_STATE(375)] = 21738,
  [SMALL_STATE(376)] = 21778,
  [SMALL_STATE(377)] = 21818,
  [SMALL_STATE(378)] = 21858,
  [SMALL_STATE(379)] = 21892,
  [SMALL_STATE(380)] = 21928,
  [SMALL_STATE(381)] = 21968,
  [SMALL_STATE(382)] = 22008,
  [SMALL_STATE(383)] = 22052,
  [SMALL_STATE(384)] = 22098,
  [SMALL_STATE(385)] = 22138,
  [SMALL_STATE(386)] = 22184,
  [SMALL_STATE(387)] = 22224,
  [SMALL_STATE(388)] = 22259,
  [SMALL_STATE(389)] = 22300,
  [SMALL_STATE(390)] = 22327,
  [SMALL_STATE(391)] = 22354,
  [SMALL_STATE(392)] = 22393,
  [SMALL_STATE(393)] = 22434,
  [SMALL_STATE(394)] = 22477,
  [SMALL_STATE(395)] = 22518,
  [SMALL_STATE(396)] = 22563,
  [SMALL_STATE(397)] = 22608,
  [SMALL_STATE(398)] = 22641,
  [SMALL_STATE(399)] = 22668,
  [SMALL_STATE(400)] = 22705,
  [SMALL_STATE(401)] = 22746,
  [SMALL_STATE(402)] = 22775,
  [SMALL_STATE(403)] = 22802,
  [SMALL_STATE(404)] = 22843,
  [SMALL_STATE(405)] = 22892,
  [SMALL_STATE(406)] = 22923,
  [SMALL_STATE(407)] = 22964,
  [SMALL_STATE(408)] = 22991,
  [SMALL_STATE(409)] = 23018,
  [SMALL_STATE(410)] = 23063,
  [SMALL_STATE(411)] = 23108,
  [SMALL_STATE(412)] = 23135,
  [SMALL_STATE(413)] = 23162,
  [SMALL_STATE(414)] = 23211,
  [SMALL_STATE(415)] = 23256,
  [SMALL_STATE(416)] = 23283,
  [SMALL_STATE(417)] = 23310,
  [SMALL_STATE(418)] = 23354,
  [SMALL_STATE(419)] = 23392,
  [SMALL_STATE(420)] = 23430,
  [SMALL_STATE(421)] = 23464,
  [SMALL_STATE(422)] = 23498,
  [SMALL_STATE(423)] = 23532,
  [SMALL_STATE(424)] = 23551,
  [SMALL_STATE(425)] = 23570,
  [SMALL_STATE(426)] = 23589,
  [SMALL_STATE(427)] = 23608,
  [SMALL_STATE(428)] = 23627,
  [SMALL_STATE(429)] = 23646,
  [SMALL_STATE(430)] = 23677,
  [SMALL_STATE(431)] = 23708,
  [SMALL_STATE(432)] = 23727,
  [SMALL_STATE(433)] = 23746,
  [SMALL_STATE(434)] = 23765,
  [SMALL_STATE(435)] = 23784,
  [SMALL_STATE(436)] = 23803,
  [SMALL_STATE(437)] = 23822,
  [SMALL_STATE(438)] = 23841,
  [SMALL_STATE(439)] = 23860,
  [SMALL_STATE(440)] = 23879,
  [SMALL_STATE(441)] = 23898,
  [SMALL_STATE(442)] = 23917,
  [SMALL_STATE(443)] = 23945,
  [SMALL_STATE(444)] = 23973,
  [SMALL_STATE(445)] = 24001,
  [SMALL_STATE(446)] = 24029,
  [SMALL_STATE(447)] = 24057,
  [SMALL_STATE(448)] = 24085,
  [SMALL_STATE(449)] = 24110,
  [SMALL_STATE(450)] = 24127,
  [SMALL_STATE(451)] = 24144,
  [SMALL_STATE(452)] = 24161,
  [SMALL_STATE(453)] = 24178,
  [SMALL_STATE(454)] = 24195,
  [SMALL_STATE(455)] = 24216,
  [SMALL_STATE(456)] = 24233,
  [SMALL_STATE(457)] = 24250,
  [SMALL_STATE(458)] = 24267,
  [SMALL_STATE(459)] = 24284,
  [SMALL_STATE(460)] = 24301,
  [SMALL_STATE(461)] = 24318,
  [SMALL_STATE(462)] = 24335,
  [SMALL_STATE(463)] = 24352,
  [SMALL_STATE(464)] = 24369,
  [SMALL_STATE(465)] = 24390,
  [SMALL_STATE(466)] = 24407,
  [SMALL_STATE(467)] = 24424,
  [SMALL_STATE(468)] = 24441,
  [SMALL_STATE(469)] = 24458,
  [SMALL_STATE(470)] = 24475,
  [SMALL_STATE(471)] = 24492,
  [SMALL_STATE(472)] = 24517,
  [SMALL_STATE(473)] = 24534,
  [SMALL_STATE(474)] = 24551,
  [SMALL_STATE(475)] = 24568,
  [SMALL_STATE(476)] = 24585,
  [SMALL_STATE(477)] = 24600,
  [SMALL_STATE(478)] = 24617,
  [SMALL_STATE(479)] = 24634,
  [SMALL_STATE(480)] = 24651,
  [SMALL_STATE(481)] = 24668,
  [SMALL_STATE(482)] = 24689,
  [SMALL_STATE(483)] = 24706,
  [SMALL_STATE(484)] = 24731,
  [SMALL_STATE(485)] = 24748,
  [SMALL_STATE(486)] = 24765,
  [SMALL_STATE(487)] = 24782,
  [SMALL_STATE(488)] = 24799,
  [SMALL_STATE(489)] = 24816,
  [SMALL_STATE(490)] = 24836,
  [SMALL_STATE(491)] = 24864,
  [SMALL_STATE(492)] = 24880,
  [SMALL_STATE(493)] = 24896,
  [SMALL_STATE(494)] = 24916,
  [SMALL_STATE(495)] = 24936,
  [SMALL_STATE(496)] = 24952,
  [SMALL_STATE(497)] = 24968,
  [SMALL_STATE(498)] = 24985,
  [SMALL_STATE(499)] = 25002,
  [SMALL_STATE(500)] = 25015,
  [SMALL_STATE(501)] = 25034,
  [SMALL_STATE(502)] = 25047,
  [SMALL_STATE(503)] = 25060,
  [SMALL_STATE(504)] = 25073,
  [SMALL_STATE(505)] = 25098,
  [SMALL_STATE(506)] = 25111,
  [SMALL_STATE(507)] = 25126,
  [SMALL_STATE(508)] = 25143,
  [SMALL_STATE(509)] = 25163,
  [SMALL_STATE(510)] = 25181,
  [SMALL_STATE(511)] = 25201,
  [SMALL_STATE(512)] = 25221,
  [SMALL_STATE(513)] = 25241,
  [SMALL_STATE(514)] = 25261,
  [SMALL_STATE(515)] = 25283,
  [SMALL_STATE(516)] = 25301,
  [SMALL_STATE(517)] = 25321,
  [SMALL_STATE(518)] = 25341,
  [SMALL_STATE(519)] = 25361,
  [SMALL_STATE(520)] = 25375,
  [SMALL_STATE(521)] = 25390,
  [SMALL_STATE(522)] = 25405,
  [SMALL_STATE(523)] = 25416,
  [SMALL_STATE(524)] = 25427,
  [SMALL_STATE(525)] = 25442,
  [SMALL_STATE(526)] = 25457,
  [SMALL_STATE(527)] = 25472,
  [SMALL_STATE(528)] = 25489,
  [SMALL_STATE(529)] = 25504,
  [SMALL_STATE(530)] = 25519,
  [SMALL_STATE(531)] = 25534,
  [SMALL_STATE(532)] = 25553,
  [SMALL_STATE(533)] = 25568,
  [SMALL_STATE(534)] = 25585,
  [SMALL_STATE(535)] = 25602,
  [SMALL_STATE(536)] = 25617,
  [SMALL_STATE(537)] = 25634,
  [SMALL_STATE(538)] = 25649,
  [SMALL_STATE(539)] = 25660,
  [SMALL_STATE(540)] = 25671,
  [SMALL_STATE(541)] = 25686,
  [SMALL_STATE(542)] = 25701,
  [SMALL_STATE(543)] = 25712,
  [SMALL_STATE(544)] = 25727,
  [SMALL_STATE(545)] = 25741,
  [SMALL_STATE(546)] = 25755,
  [SMALL_STATE(547)] = 25771,
  [SMALL_STATE(548)] = 25785,
  [SMALL_STATE(549)] = 25801,
  [SMALL_STATE(550)] = 25811,
  [SMALL_STATE(551)] = 25827,
  [SMALL_STATE(552)] = 25843,
  [SMALL_STATE(553)] = 25855,
  [SMALL_STATE(554)] = 25871,
  [SMALL_STATE(555)] = 25885,
  [SMALL_STATE(556)] = 25895,
  [SMALL_STATE(557)] = 25911,
  [SMALL_STATE(558)] = 25925,
  [SMALL_STATE(559)] = 25941,
  [SMALL_STATE(560)] = 25951,
  [SMALL_STATE(561)] = 25963,
  [SMALL_STATE(562)] = 25973,
  [SMALL_STATE(563)] = 25983,
  [SMALL_STATE(564)] = 25997,
  [SMALL_STATE(565)] = 26013,
  [SMALL_STATE(566)] = 26023,
  [SMALL_STATE(567)] = 26039,
  [SMALL_STATE(568)] = 26053,
  [SMALL_STATE(569)] = 26063,
  [SMALL_STATE(570)] = 26073,
  [SMALL_STATE(571)] = 26083,
  [SMALL_STATE(572)] = 26099,
  [SMALL_STATE(573)] = 26109,
  [SMALL_STATE(574)] = 26123,
  [SMALL_STATE(575)] = 26137,
  [SMALL_STATE(576)] = 26146,
  [SMALL_STATE(577)] = 26155,
  [SMALL_STATE(578)] = 26168,
  [SMALL_STATE(579)] = 26181,
  [SMALL_STATE(580)] = 26190,
  [SMALL_STATE(581)] = 26203,
  [SMALL_STATE(582)] = 26212,
  [SMALL_STATE(583)] = 26225,
  [SMALL_STATE(584)] = 26238,
  [SMALL_STATE(585)] = 26251,
  [SMALL_STATE(586)] = 26260,
  [SMALL_STATE(587)] = 26269,
  [SMALL_STATE(588)] = 26280,
  [SMALL_STATE(589)] = 26293,
  [SMALL_STATE(590)] = 26306,
  [SMALL_STATE(591)] = 26317,
  [SMALL_STATE(592)] = 26326,
  [SMALL_STATE(593)] = 26335,
  [SMALL_STATE(594)] = 26344,
  [SMALL_STATE(595)] = 26355,
  [SMALL_STATE(596)] = 26366,
  [SMALL_STATE(597)] = 26377,
  [SMALL_STATE(598)] = 26388,
  [SMALL_STATE(599)] = 26401,
  [SMALL_STATE(600)] = 26414,
  [SMALL_STATE(601)] = 26427,
  [SMALL_STATE(602)] = 26440,
  [SMALL_STATE(603)] = 26453,
  [SMALL_STATE(604)] = 26462,
  [SMALL_STATE(605)] = 26475,
  [SMALL_STATE(606)] = 26488,
  [SMALL_STATE(607)] = 26501,
  [SMALL_STATE(608)] = 26514,
  [SMALL_STATE(609)] = 26527,
  [SMALL_STATE(610)] = 26540,
  [SMALL_STATE(611)] = 26551,
  [SMALL_STATE(612)] = 26562,
  [SMALL_STATE(613)] = 26571,
  [SMALL_STATE(614)] = 26584,
  [SMALL_STATE(615)] = 26597,
  [SMALL_STATE(616)] = 26610,
  [SMALL_STATE(617)] = 26623,
  [SMALL_STATE(618)] = 26636,
  [SMALL_STATE(619)] = 26647,
  [SMALL_STATE(620)] = 26660,
  [SMALL_STATE(621)] = 26669,
  [SMALL_STATE(622)] = 26682,
  [SMALL_STATE(623)] = 26695,
  [SMALL_STATE(624)] = 26708,
  [SMALL_STATE(625)] = 26721,
  [SMALL_STATE(626)] = 26734,
  [SMALL_STATE(627)] = 26747,
  [SMALL_STATE(628)] = 26758,
  [SMALL_STATE(629)] = 26769,
  [SMALL_STATE(630)] = 26782,
  [SMALL_STATE(631)] = 26795,
  [SMALL_STATE(632)] = 26808,
  [SMALL_STATE(633)] = 26821,
  [SMALL_STATE(634)] = 26834,
  [SMALL_STATE(635)] = 26847,
  [SMALL_STATE(636)] = 26860,
  [SMALL_STATE(637)] = 26873,
  [SMALL_STATE(638)] = 26886,
  [SMALL_STATE(639)] = 26899,
  [SMALL_STATE(640)] = 26912,
  [SMALL_STATE(641)] = 26925,
  [SMALL_STATE(642)] = 26936,
  [SMALL_STATE(643)] = 26949,
  [SMALL_STATE(644)] = 26959,
  [SMALL_STATE(645)] = 26967,
  [SMALL_STATE(646)] = 26977,
  [SMALL_STATE(647)] = 26987,
  [SMALL_STATE(648)] = 26995,
  [SMALL_STATE(649)] = 27005,
  [SMALL_STATE(650)] = 27013,
  [SMALL_STATE(651)] = 27021,
  [SMALL_STATE(652)] = 27029,
  [SMALL_STATE(653)] = 27039,
  [SMALL_STATE(654)] = 27049,
  [SMALL_STATE(655)] = 27059,
  [SMALL_STATE(656)] = 27069,
  [SMALL_STATE(657)] = 27077,
  [SMALL_STATE(658)] = 27085,
  [SMALL_STATE(659)] = 27095,
  [SMALL_STATE(660)] = 27105,
  [SMALL_STATE(661)] = 27113,
  [SMALL_STATE(662)] = 27121,
  [SMALL_STATE(663)] = 27129,
  [SMALL_STATE(664)] = 27137,
  [SMALL_STATE(665)] = 27147,
  [SMALL_STATE(666)] = 27157,
  [SMALL_STATE(667)] = 27165,
  [SMALL_STATE(668)] = 27175,
  [SMALL_STATE(669)] = 27185,
  [SMALL_STATE(670)] = 27195,
  [SMALL_STATE(671)] = 27205,
  [SMALL_STATE(672)] = 27213,
  [SMALL_STATE(673)] = 27223,
  [SMALL_STATE(674)] = 27233,
  [SMALL_STATE(675)] = 27243,
  [SMALL_STATE(676)] = 27253,
  [SMALL_STATE(677)] = 27261,
  [SMALL_STATE(678)] = 27271,
  [SMALL_STATE(679)] = 27279,
  [SMALL_STATE(680)] = 27287,
  [SMALL_STATE(681)] = 27295,
  [SMALL_STATE(682)] = 27305,
  [SMALL_STATE(683)] = 27313,
  [SMALL_STATE(684)] = 27323,
  [SMALL_STATE(685)] = 27333,
  [SMALL_STATE(686)] = 27341,
  [SMALL_STATE(687)] = 27351,
  [SMALL_STATE(688)] = 27361,
  [SMALL_STATE(689)] = 27369,
  [SMALL_STATE(690)] = 27377,
  [SMALL_STATE(691)] = 27385,
  [SMALL_STATE(692)] = 27393,
  [SMALL_STATE(693)] = 27403,
  [SMALL_STATE(694)] = 27411,
  [SMALL_STATE(695)] = 27418,
  [SMALL_STATE(696)] = 27425,
  [SMALL_STATE(697)] = 27432,
  [SMALL_STATE(698)] = 27439,
  [SMALL_STATE(699)] = 27446,
  [SMALL_STATE(700)] = 27453,
  [SMALL_STATE(701)] = 27460,
  [SMALL_STATE(702)] = 27467,
  [SMALL_STATE(703)] = 27474,
  [SMALL_STATE(704)] = 27481,
  [SMALL_STATE(705)] = 27488,
  [SMALL_STATE(706)] = 27495,
  [SMALL_STATE(707)] = 27502,
  [SMALL_STATE(708)] = 27509,
  [SMALL_STATE(709)] = 27516,
  [SMALL_STATE(710)] = 27523,
  [SMALL_STATE(711)] = 27530,
  [SMALL_STATE(712)] = 27537,
  [SMALL_STATE(713)] = 27544,
  [SMALL_STATE(714)] = 27551,
  [SMALL_STATE(715)] = 27558,
  [SMALL_STATE(716)] = 27565,
  [SMALL_STATE(717)] = 27572,
  [SMALL_STATE(718)] = 27579,
  [SMALL_STATE(719)] = 27586,
  [SMALL_STATE(720)] = 27593,
  [SMALL_STATE(721)] = 27600,
  [SMALL_STATE(722)] = 27607,
  [SMALL_STATE(723)] = 27614,
  [SMALL_STATE(724)] = 27621,
  [SMALL_STATE(725)] = 27628,
  [SMALL_STATE(726)] = 27635,
  [SMALL_STATE(727)] = 27642,
  [SMALL_STATE(728)] = 27649,
  [SMALL_STATE(729)] = 27656,
  [SMALL_STATE(730)] = 27663,
  [SMALL_STATE(731)] = 27670,
  [SMALL_STATE(732)] = 27677,
  [SMALL_STATE(733)] = 27684,
  [SMALL_STATE(734)] = 27691,
  [SMALL_STATE(735)] = 27698,
  [SMALL_STATE(736)] = 27705,
  [SMALL_STATE(737)] = 27712,
  [SMALL_STATE(738)] = 27719,
  [SMALL_STATE(739)] = 27726,
  [SMALL_STATE(740)] = 27733,
  [SMALL_STATE(741)] = 27740,
  [SMALL_STATE(742)] = 27747,
  [SMALL_STATE(743)] = 27754,
  [SMALL_STATE(744)] = 27761,
  [SMALL_STATE(745)] = 27768,
  [SMALL_STATE(746)] = 27775,
  [SMALL_STATE(747)] = 27782,
  [SMALL_STATE(748)] = 27789,
  [SMALL_STATE(749)] = 27796,
  [SMALL_STATE(750)] = 27803,
  [SMALL_STATE(751)] = 27810,
  [SMALL_STATE(752)] = 27817,
  [SMALL_STATE(753)] = 27824,
  [SMALL_STATE(754)] = 27831,
  [SMALL_STATE(755)] = 27838,
  [SMALL_STATE(756)] = 27845,
  [SMALL_STATE(757)] = 27852,
  [SMALL_STATE(758)] = 27859,
  [SMALL_STATE(759)] = 27866,
  [SMALL_STATE(760)] = 27873,
  [SMALL_STATE(761)] = 27880,
  [SMALL_STATE(762)] = 27887,
  [SMALL_STATE(763)] = 27894,
  [SMALL_STATE(764)] = 27901,
  [SMALL_STATE(765)] = 27908,
  [SMALL_STATE(766)] = 27915,
  [SMALL_STATE(767)] = 27922,
  [SMALL_STATE(768)] = 27929,
  [SMALL_STATE(769)] = 27936,
  [SMALL_STATE(770)] = 27943,
  [SMALL_STATE(771)] = 27950,
  [SMALL_STATE(772)] = 27957,
  [SMALL_STATE(773)] = 27964,
  [SMALL_STATE(774)] = 27971,
  [SMALL_STATE(775)] = 27978,
  [SMALL_STATE(776)] = 27985,
  [SMALL_STATE(777)] = 27992,
  [SMALL_STATE(778)] = 27999,
  [SMALL_STATE(779)] = 28006,
  [SMALL_STATE(780)] = 28013,
  [SMALL_STATE(781)] = 28020,
  [SMALL_STATE(782)] = 28027,
  [SMALL_STATE(783)] = 28034,
  [SMALL_STATE(784)] = 28041,
  [SMALL_STATE(785)] = 28048,
  [SMALL_STATE(786)] = 28055,
  [SMALL_STATE(787)] = 28062,
  [SMALL_STATE(788)] = 28069,
  [SMALL_STATE(789)] = 28076,
  [SMALL_STATE(790)] = 28083,
  [SMALL_STATE(791)] = 28090,
  [SMALL_STATE(792)] = 28097,
  [SMALL_STATE(793)] = 28104,
  [SMALL_STATE(794)] = 28111,
  [SMALL_STATE(795)] = 28118,
  [SMALL_STATE(796)] = 28125,
  [SMALL_STATE(797)] = 28132,
  [SMALL_STATE(798)] = 28139,
  [SMALL_STATE(799)] = 28146,
  [SMALL_STATE(800)] = 28153,
  [SMALL_STATE(801)] = 28160,
  [SMALL_STATE(802)] = 28167,
  [SMALL_STATE(803)] = 28174,
  [SMALL_STATE(804)] = 28181,
  [SMALL_STATE(805)] = 28188,
  [SMALL_STATE(806)] = 28195,
  [SMALL_STATE(807)] = 28202,
  [SMALL_STATE(808)] = 28209,
  [SMALL_STATE(809)] = 28216,
  [SMALL_STATE(810)] = 28223,
  [SMALL_STATE(811)] = 28230,
  [SMALL_STATE(812)] = 28237,
  [SMALL_STATE(813)] = 28244,
  [SMALL_STATE(814)] = 28251,
  [SMALL_STATE(815)] = 28258,
  [SMALL_STATE(816)] = 28265,
  [SMALL_STATE(817)] = 28272,
  [SMALL_STATE(818)] = 28279,
  [SMALL_STATE(819)] = 28286,
  [SMALL_STATE(820)] = 28293,
  [SMALL_STATE(821)] = 28300,
  [SMALL_STATE(822)] = 28307,
  [SMALL_STATE(823)] = 28314,
  [SMALL_STATE(824)] = 28321,
  [SMALL_STATE(825)] = 28328,
  [SMALL_STATE(826)] = 28335,
  [SMALL_STATE(827)] = 28342,
  [SMALL_STATE(828)] = 28349,
  [SMALL_STATE(829)] = 28356,
  [SMALL_STATE(830)] = 28363,
  [SMALL_STATE(831)] = 28370,
  [SMALL_STATE(832)] = 28377,
  [SMALL_STATE(833)] = 28384,
  [SMALL_STATE(834)] = 28391,
  [SMALL_STATE(835)] = 28398,
  [SMALL_STATE(836)] = 28405,
  [SMALL_STATE(837)] = 28412,
  [SMALL_STATE(838)] = 28419,
  [SMALL_STATE(839)] = 28426,
  [SMALL_STATE(840)] = 28433,
  [SMALL_STATE(841)] = 28440,
  [SMALL_STATE(842)] = 28447,
  [SMALL_STATE(843)] = 28454,
  [SMALL_STATE(844)] = 28461,
  [SMALL_STATE(845)] = 28468,
  [SMALL_STATE(846)] = 28475,
  [SMALL_STATE(847)] = 28482,
  [SMALL_STATE(848)] = 28489,
  [SMALL_STATE(849)] = 28496,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(377),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(839),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(495),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(565),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(156),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, .production_id = 26),
  [87] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, .production_id = 26),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(523),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(521),
  [110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2),
  [112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(798),
  [115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2),
  [117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(795),
  [120] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(496),
  [123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(495),
  [126] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2), SHIFT_REPEAT(565),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(526),
  [134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2),
  [136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(822),
  [139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(14),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(700),
  [145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(9),
  [148] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(551),
  [151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(156),
  [154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(699),
  [157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(698),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(697),
  [163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(696),
  [166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(771),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(162),
  [172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(156),
  [175] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(163),
  [178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(168),
  [181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(168),
  [184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2), SHIFT_REPEAT(651),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(843),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 3),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 3),
  [213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_code, 3, .production_id = 13),
  [215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_code, 3, .production_id = 13),
  [217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_defn, 1),
  [219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_defn, 1),
  [221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 2),
  [223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 2),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 4),
  [227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 4),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__c_code, 2),
  [231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__c_code, 2),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 6, .production_id = 2),
  [275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 6, .production_id = 2),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 3, .production_id = 2),
  [283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 3, .production_id = 2),
  [285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 4, .production_id = 2),
  [287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 4, .production_id = 2),
  [289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 5, .production_id = 2),
  [291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 5, .production_id = 2),
  [293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(528),
  [296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(807),
  [299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(803),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(659),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(496),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(795),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(495),
  [316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(495),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(565),
  [322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(785),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(784),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(783),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(779),
  [334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat1, 2), SHIFT_REPEAT(587),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4),
  [349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3),
  [357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3),
  [359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2),
  [361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, .production_id = 10),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, .production_id = 10),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, .production_id = 18),
  [379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, .production_id = 18),
  [381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, .production_id = 29),
  [385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2),
  [415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2),
  [417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4),
  [421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 4, .production_id = 23),
  [423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 4, .production_id = 23),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_expression, 4),
  [431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_expression, 4),
  [433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, .production_id = 25),
  [437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, .production_id = 25),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2),
  [453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, .production_id = 5),
  [467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, .production_id = 5),
  [469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_char_literal, 3),
  [471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_char_literal, 3),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 2, .production_id = 17),
  [487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 2, .production_id = 17),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, .production_id = 24),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, .production_id = 24),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit_expression, 3),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit_expression, 3),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, .production_id = 10),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, .production_id = 23),
  [509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, .production_id = 23),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expr, 3),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(540),
  [526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(827),
  [529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat3, 2),
  [531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2),
  [533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(831),
  [536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(496),
  [539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(795),
  [542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(495),
  [545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(495),
  [548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(565),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 7, .production_id = 2),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 7, .production_id = 2),
  [555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 8, .production_id = 2),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 8, .production_id = 2),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(121),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(122),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(91),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(506),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_funcdef, 3),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_funcdef, 3),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structdef, 4, .production_id = 19),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structdef, 4, .production_id = 19),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(108),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 1),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__comma_expr, 1),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2),
  [635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(795),
  [638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(496),
  [641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(495),
  [644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(495),
  [647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(565),
  [650] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(785),
  [653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(784),
  [656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(783),
  [659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(779),
  [662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat1, 2), SHIFT_REPEAT(587),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comma_expr_repeat1, 2),
  [671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 1),
  [693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(528),
  [704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(807),
  [707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(803),
  [710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(535),
  [713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(828),
  [716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat3, 2), SHIFT_REPEAT(840),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_program_repeat2, 2),
  [725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2), SHIFT_REPEAT(842),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2), SHIFT_REPEAT(777),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, .production_id = 27),
  [737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, .production_id = 27),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_program_repeat2, 2), SHIFT_REPEAT(847),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_set, 6, .production_id = 2),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_set, 6, .production_id = 2),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_set, 5, .production_id = 2),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_set, 5, .production_id = 2),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 5),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 5),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, .production_id = 30),
  [760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, .production_id = 30),
  [762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 8),
  [764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 8),
  [766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 7),
  [768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 7),
  [770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 7),
  [772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 7),
  [774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 6),
  [776] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 6),
  [778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 6),
  [780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 6),
  [782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 6),
  [784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 6),
  [786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1),
  [788] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1),
  [790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(795),
  [793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(496),
  [796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(495),
  [799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(495),
  [802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(565),
  [805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(785),
  [808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(784),
  [811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(783),
  [814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2), SHIFT_REPEAT(779),
  [817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_set_repeat1, 2),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 5),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 5),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2),
  [829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 5),
  [833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 5),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 2),
  [837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 2),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 4),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 4),
  [849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 34),
  [851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 34),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_monitor, 4),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_monitor, 4),
  [857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 33),
  [859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 33),
  [861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sync, 4),
  [863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sync, 4),
  [865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, .production_id = 32),
  [867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, .production_id = 32),
  [869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 4),
  [871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 4),
  [873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, .production_id = 38),
  [875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, .production_id = 38),
  [877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 37),
  [879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 37),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, .production_id = 27),
  [883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, .production_id = 27),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 36),
  [887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 36),
  [889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, .production_id = 28),
  [891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, .production_id = 28),
  [893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq, 3),
  [895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_syncq, 3),
  [897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_statement, 2, .production_id = 31),
  [899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_statement, 2, .production_id = 31),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_monitor, 3),
  [903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_monitor, 3),
  [905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, .production_id = 35),
  [907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, .production_id = 35),
  [909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assign, 3),
  [911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assign, 3),
  [913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_final_defn, 1),
  [915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_final_defn, 1),
  [917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exit, 2),
  [919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exit, 2),
  [921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option, 4, .production_id = 20),
  [923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option, 4, .production_id = 20),
  [925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 2),
  [927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 2),
  [929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initial_defn, 1),
  [931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initial_defn, 1),
  [933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program_param, 3),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program_param, 3),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 4),
  [939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 4),
  [941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreign_declaration, 3),
  [943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreign_declaration, 3),
  [945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_defn, 1),
  [947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_defn, 1),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2),
  [957] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2), SHIFT_REPEAT(795),
  [960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2), SHIFT_REPEAT(496),
  [963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2), SHIFT_REPEAT(495),
  [966] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2), SHIFT_REPEAT(495),
  [969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2), SHIFT_REPEAT(565),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ss_defn, 1),
  [976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ss_defn, 1),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 3, .production_id = 11),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(681),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [1000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 4, .production_id = 11),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [1004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [1008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [1016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [1020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(488),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1),
  [1030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_decl, 3),
  [1032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_decl, 3),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [1048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(790),
  [1053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(791),
  [1056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(454),
  [1059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(793),
  [1062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(374),
  [1065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2),
  [1067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(794),
  [1070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(681),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, .production_id = 10),
  [1113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, .production_id = 10),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [1117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 2),
  [1119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 2),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3),
  [1141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3),
  [1143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call_expression, 2, .production_id = 4),
  [1145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call_expression, 2, .production_id = 4),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 4),
  [1169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 4),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 4),
  [1177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 4),
  [1179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 3),
  [1181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 3),
  [1183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, .production_id = 5),
  [1185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, .production_id = 5),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [1191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2),
  [1193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 2),
  [1195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 2),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [1221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [1223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(386),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [1227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(815),
  [1230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(816),
  [1233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(464),
  [1236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(818),
  [1239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(381),
  [1242] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(819),
  [1245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(692),
  [1248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [1250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [1252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [1254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [1256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [1260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [1262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [1266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 1),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [1270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [1276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [1278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1),
  [1280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2),
  [1282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(728),
  [1285] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(845),
  [1288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(481),
  [1291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(844),
  [1294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(377),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(839),
  [1300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2), SHIFT_REPEAT(645),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 2),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_expr, 1),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 1, .dynamic_precedence = 1),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [1323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 1),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 5, .production_id = 14),
  [1337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 5, .production_id = 14),
  [1339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 2, .production_id = 1),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 2, .production_id = 1),
  [1343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 3, .production_id = 2),
  [1345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 3, .production_id = 2),
  [1347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 6, .production_id = 22),
  [1349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 6, .production_id = 22),
  [1351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 4, .production_id = 9),
  [1353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 4, .production_id = 9),
  [1355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 4, .production_id = 11),
  [1357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 4, .production_id = 11),
  [1359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 5, .production_id = 16),
  [1361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 5, .production_id = 16),
  [1363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, .production_id = 11),
  [1365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, .production_id = 11),
  [1367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_marker, 4, .production_id = 7),
  [1369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_marker, 4, .production_id = 7),
  [1371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, .production_id = 15),
  [1373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, .production_id = 15),
  [1375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_include, 3, .production_id = 3),
  [1377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_include, 3, .production_id = 3),
  [1379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 4, .production_id = 8),
  [1381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 4, .production_id = 8),
  [1383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 3, .production_id = 6),
  [1385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 3, .production_id = 6),
  [1387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_line_marker, 3),
  [1389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_line_marker, 3),
  [1391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, .production_id = 12),
  [1393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, .production_id = 12),
  [1395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 3, .production_id = 2),
  [1397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 3, .production_id = 2),
  [1399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, .production_id = 2),
  [1401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, .production_id = 2),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(598),
  [1413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 3),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 2),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [1431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [1433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_basetype, 2),
  [1435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_basetype, 2),
  [1437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prim_type, 2),
  [1439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prim_type, 2),
  [1441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declarator, 1),
  [1443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 2),
  [1445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prim_type, 1),
  [1447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prim_type, 1),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_basetype, 1),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_basetype, 1),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 4, .production_id = 21),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 3),
  [1465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 3, .production_id = 21),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 2),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 5, .production_id = 21),
  [1479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_qualifier, 1),
  [1481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_qualifier, 1),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [1507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2),
  [1509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2), SHIFT_REPEAT(517),
  [1512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2), SHIFT_REPEAT(833),
  [1515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__expanded_string_literal_repeat1, 2), SHIFT_REPEAT(517),
  [1518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(562),
  [1520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_block_repeat2, 2),
  [1526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_block_repeat2, 2), SHIFT_REPEAT(734),
  [1529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abs_decl, 1),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(255),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [1545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, .dynamic_precedence = 1),
  [1549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 2),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 1),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [1565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 2), SHIFT_REPEAT(562),
  [1568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 2),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1572] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comma_expr_repeat1, 2), SHIFT_REPEAT(155),
  [1575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2),
  [1577] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2), SHIFT_REPEAT(546),
  [1580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2), SHIFT_REPEAT(546),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(111),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [1599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [1605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_expansion, 3),
  [1607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_expansion, 3),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [1611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 3),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [1619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expr, 4),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abs_decl, 3),
  [1625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 3),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__c_code_repeat1, 1),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [1641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 4),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 2),
  [1647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 5),
  [1649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [1651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entry, 2),
  [1655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_state_set_repeat2, 2),
  [1657] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_state_set_repeat2, 2), SHIFT_REPEAT(726),
  [1660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expanded_string_literal, 3),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 3),
  [1666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 5),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 2),
  [1680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [1684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 7),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 5),
  [1690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [1692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [1696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 6, .production_id = 39),
  [1698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 6, .production_id = 40),
  [1700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_transition, 7, .production_id = 41),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [1706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_init_expr_repeat1, 2),
  [1712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_init_expr_repeat1, 2), SHIFT_REPEAT(132),
  [1715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2),
  [1721] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2), SHIFT_REPEAT(656),
  [1724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 4),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2), SHIFT_REPEAT(352),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2),
  [1741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2), SHIFT_REPEAT(429),
  [1744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_expr, 6),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [1754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expanded_string_literal, 2),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [1760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [1762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_foreign_declaration_repeat1, 2),
  [1764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_foreign_declaration_repeat1, 2), SHIFT_REPEAT(758),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_declarator_repeat1, 2),
  [1777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_declarator_repeat1, 2), SHIFT_REPEAT(315),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_assign_repeat1, 2),
  [1784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_assign_repeat1, 2), SHIFT_REPEAT(665),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_args, 2),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(458),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [1809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_decl, 2),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 3),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 5),
  [1835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [1837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 3),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 6),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [1843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_flag, 1),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [1853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(760),
  [1855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [1859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 2),
  [1861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 4),
  [1863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 4),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [1869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_block, 2),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 3),
  [1879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_expr, 2),
  [1881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state, 3, .production_id = 2),
  [1883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_decl, 1),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [1935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 5, .production_id = 22),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [1961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_value, 1),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, .production_id = 15),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [2061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_syncq_size, 1),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [2127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [2135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2149] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_snl(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
